(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2021429,      52695]*)
(*NotebookOutlinePosition[   2022359,      52726]*)
(*  CellTagsIndexPosition[   2022315,      52722]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
 
 Optical Layout of Squeezing Experiment\
\>", "Title"],

Cell["\<\

E060180-00-R

Daniel Sigg

June 2006

 \
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["\<\

Initialization\
\>", "Subtitle"],

Cell[CellGroupData[{

Cell["Load Packages / Initialization", "Section"],

Cell[BoxData[
    \(\(AppendTo[$Path, "\<C:\Users\Daniel\ModalModel\>"];\)\)], "Input"],

Cell[CellGroupData[{

Cell["General", "Subsection"],

Cell[BoxData[{
    \(\(Needs["\<Utilities`FilterOptions`\>"];\)\), "\n", 
    \(Needs["\<Graphics`Graphics`\>"]\), "\[IndentingNewLine]", 
    \(\(Needs["\<ModalModel`Utilities`\>"];\)\)}], "Input"],

Cell[BoxData[
    \(\(GouyPhase = GuoyPhase;\)\)], "Input"],

Cell[BoxData[
    \(\($TextStyle = {FontFamily \[Rule] "\<Helvetica\>", 
          FontSize \[Rule] 13};\)\)], "Input"],

Cell[BoxData[
    \(\(plotopt = 
        PlotStyle \[Rule] {{Thickness\ [0.007], \ 
              RGBColor\ [1, 0, 0]}, \n\t\t\t\ \ \ \ {Thickness\ [0.007], \ 
              RGBColor\ [0, 0, 1]}, \n\t\t\t\ \ \ \ {Thickness\ [0.007], \ 
              RGBColor\ [0.1, 0.7, 0.2]}, \n\t\t\t\ \ \ \ {Thickness\ [
                0.007], \ RGBColor\ [0.5, 0.5, 0.2]}};\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Section"],

Cell["The parameters are given in SI units. ", "Text"],

Cell[BoxData[{
    \(\(SpeedOfLight = 2.99792458*^8;\)\), "\n", 
    \(\(lambda = 1064*^-9;\)\), "\n", 
    \(\(kk = N[\(2\ \[Pi]\)\/lambda];\)\), "\n", 
    \(\(\(nFusedSilica\  = \ 1.44968\)\(;\)\(\ \ \ \ \ \ \ \ \)\( (*\ 
      refractive\ index\ *) \)\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ABCD Matrices", "Section"],

Cell["Definitions for ABCD matricies, see Siegman.", "Text"],

Cell[BoxData[{
    \(Clear[ABCD]\), "\n", 
    \(ABCDPropagator[L_] := {{1, L}, {0, 1}}\), "\n", 
    \(ABCDLens[f_] := {{1, 0}, {\(-\(1\/f\)\), 1}}\), "\n", 
    \(ABCDPropLens[f_, L_] := {{1, L}, {\(-\(1\/f\)\), 1 - L\/f}}\), "\n", 
    \(\(ABCD[A_, B_, C_, D_] := {{A, B}, {C, D}};\)\), "\n", 
    \(ABCDq[ABCD_?MatrixQ, 
        q_] := \(ABCD\[LeftDoubleBracket]1, 1\[RightDoubleBracket]\ q + ABCD\
\[LeftDoubleBracket]1, 2\[RightDoubleBracket]\)\/\(ABCD\[LeftDoubleBracket]2, \
1\[RightDoubleBracket]\ q + ABCD\[LeftDoubleBracket]2, 2\[RightDoubleBracket]\
\)\), "\n", 
    \(ABCDz[ABCD_?MatrixQ, q_] := Re[ABCDq[ABCD, q]]\), "\n", 
    \(ABCDz0[ABCD_?MatrixQ, q_] := Im[ABCDq[ABCD, q]]\), "\n", 
    \(ABCDGuoyPhase[ABCD_?MatrixQ, 
        q_] := \(-Arg[
          ABCD\[LeftDoubleBracket]1, 1\[RightDoubleBracket] + 
            ABCD\[LeftDoubleBracket]1, 2\[RightDoubleBracket]\/q]\)\), "\n", 
    \(ABCDSpotSizeRatio[ABCD_?MatrixQ, q_] := 
      Abs[ABCD\[LeftDoubleBracket]1, 1\[RightDoubleBracket] + 
          ABCD\[LeftDoubleBracket]1, 2\[RightDoubleBracket]\/q]\), "\n", 
    \(ABCDGouyPhaseTelescope[rw_, gouy_, z_, 
        z0_] := {{rw\ \((Cos[gouy] - \(z\ Sin[gouy]\)\/z0)\), 
          rw\ Sin[gouy]\ z0\ \((1 + \((z\/z0)\)\^2)\)}, {\(-\(Sign[
                  Sin[gouy]]\/\(rw\ z0\)\)\), 
          If[Cos[gouy] === 0, 
            Sign[Sin[gouy]]\/rw, \(1 - Abs[Sin[gouy]]\)\/\(rw\ Cos[gouy]\)]}}\
\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GouyPhaseTelescope", "Section"],

Cell["\<\
GouyPhaseTelescope [{zFirst, zLast}, {w0, zw0}, train, k] returns the guoy \
phase shift acquired in the telescope and the spot size at the output with \
position zLast, starting with a beam at position zFirst which has a waist \
size w0 at the waist poition zw0. k is the wavevector. Train is a list of \
doublets consisting of focal length and lens position.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[GouyPhaseTelescope];\)\), "\n", 
    \(GouyPhaseTelescope[z : {zFirst_, zLast_}, inp : {w0_, zw0_}, 
        train : {{_, _} .. }, k_] := 
      Block[{ABCD, qin, i}, 
        ABCD = ABCDPropLens[
            train\[LeftDoubleBracket]1, 1\[RightDoubleBracket], 
            train\[LeftDoubleBracket]1, 2\[RightDoubleBracket] - zFirst]; 
        For[i = 2, i \[LessEqual] Length[train], \(i++\), 
          ABCD = ABCDPropLens[
                train\[LeftDoubleBracket]i, 1\[RightDoubleBracket], 
                train\[LeftDoubleBracket]i, 2\[RightDoubleBracket] - 
                  train\[LeftDoubleBracket]i - 1, 2\[RightDoubleBracket]] . 
              ABCD]; ABCD = 
          ABCDPropagator[
              zLast - train\[LeftDoubleBracket]\(-1\), 
                  2\[RightDoubleBracket]] . ABCD; 
        qin = 1\/2\ I\ k\ w0\^2 + zFirst - zw0; {ABCDGouyPhase[ABCD, qin], 
          ABCDSpotSizeRatio[ABCD, qin]\ SpotSize[zFirst - zw0, w0, 
              k]}]\), "\n", 
    \(GouyPhaseTelescope[z : {zFirst_, zLast_}, inp : {w0_, zw0_}, 
        train : {}, 
        k_] := {GouyPhase[zLast - zw0, w0, k] - 
          GouyPhase[zFirst - zw0, w0, k], 
        SpotSize[zLast - zw0, w0, k]}\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GPTPlot", "Section"],

Cell["\<\
GPTPlot [{zFirst, zLast}, {w0, zw0}, train, k] plots the beam profile (spot \
size) as a function of the propagation direction, starting at the port \
position and up to the detector position.\
\>", "Text"],

Cell[BoxData[
    \(GPTPlot[z : {zFirst_, zLast_}, inp : {w0_, zw0_}, 
        train : {{_, _} .. } | {}, k_, opts___] := 
      Block[{opt, int, f, g, plt1, plt2}, 
        opt = FoldList[Lensing[#1, #2, k] &, inp, train]; 
        int = Partition[
            Join[{zFirst}, \((#1\[LeftDoubleBracket]2\[RightDoubleBracket] &)\
\) /@ train, {zLast + 1}], 2, 1]; 
        f[x_] = Plus @@ 
            Apply[If[#3 \[LessEqual] x < #4, 1000\ SpotSize[x - #2, #1, k], 
                  0] &, Flatten /@ Transpose[{opt, int}], 2]; 
        g[x_] = Plus @@ 
            Apply[Which[#3 \[LessEqual] x < #4, 
                  GouyPhase[x - #2, #1, k] - 
                    GouyPhase[#3 - #2, #1, k], #3 \[LessEqual] 
                      x && #4 \[LessEqual] x, 
                  GouyPhase[#4 - #2, #1, k] - GouyPhase[#3 - #2, #1, k], 
                  True, 0] &, Flatten /@ Transpose[{opt, int}], 2]; 
        plt1 = Plot[{f[x], \(-f[x]\)}, {x, zFirst, zLast}, 
            DisplayFunction \[Rule] Identity, opts, MaxBend \[Rule] 5]; 
        plt2 = Plot[g[x], {x, zFirst, zLast}, 
            DisplayFunction \[Rule] Identity, 
            PlotStyle \[Rule] {RGBColor[0.481, 0.301, 0.023]}, opts]; 
        Show[Graphics[{RGBColor[0.977, 0.121, 0.023], 
              Thickness[
                0.0075], \((Line[{{#1, \(-f[#1]\)}, {#1, 
                          f[#1]}}] &)\) /@ \(\((#1\[LeftDoubleBracket]2\
\[RightDoubleBracket] &)\) /@ train\)}], 
          Graphics[{RGBColor[0, 0.133, 0.859], 
              Thickness[
                0.0075], \((Line[{{#1, \(-f[#1]\)}, {#1, f[#1]}}] &)\) /@ 
                z}], plt1, plt2, opts, Frame \[Rule] True, 
          GridLines \[Rule] Automatic, PlotRange \[Rule] All, 
          AspectRatio \[Rule] 0.4, 
          FrameLabel \[Rule] {"\<z-position [m]\>", "\<spot size [mm]\>", \
"\<Beam Profile\>", "\<Gouy phase [rad]\>"}, 
          DisplayFunction \[Rule] $DisplayFunction]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TelescopePlot", "Section"],

Cell["\<\
Telescope [{zFirst, zLast}, {w0, zw0}, train, k] plots the beam profile (spot \
size) as a function of the propagation direction, starting at the port \
position and up to the detector position.\
\>", "Text"],

Cell[BoxData[
    \(TelescopePlot[z : {zFirst_, zLast_}, inp : {w0_, zw0_}, 
        train : {{_, _} .. } | {}, k_, opts___] := 
      Block[{opt, int, f, g, plt1, plt2}, 
        opt = FoldList[Lensing[#1, #2, k] &, inp, train]; 
        int = Partition[
            Join[{zFirst}, \((#1\[LeftDoubleBracket]2\[RightDoubleBracket] &)\
\) /@ train, {zLast + 1}], 2, 1]; 
        f[x_] = Plus @@ 
            Apply[If[#3 \[LessEqual] x < #4, 1000\ SpotSize[x - #2, #1, k], 
                  0] &, Flatten /@ Transpose[{opt, int}], 2]; 
        g[x_] = Plus @@ 
            Apply[Which[#3 \[LessEqual] x < #4, 
                  GouyPhase[x - #2, #1, k] - 
                    GouyPhase[#3 - #2, #1, k], #3 \[LessEqual] 
                      x && #4 \[LessEqual] x, 
                  GouyPhase[#4 - #2, #1, k] - GouyPhase[#3 - #2, #1, k], 
                  True, 0] &, Flatten /@ Transpose[{opt, int}], 2]; 
        plt1 = Plot[{f[x], \(-f[x]\)}, {x, zFirst, zLast}, 
            DisplayFunction \[Rule] Identity, opts, PlotPoints \[Rule] 1000, 
            MaxBend \[Rule] 2]; 
        Show[Graphics[{RGBColor[0.977, 0.121, 0.023], 
              Thickness[
                0.0075], \((Line[{{#1, \(-f[#1]\)}, {#1, 
                          f[#1]}}] &)\) /@ \(\((#1\[LeftDoubleBracket]2\
\[RightDoubleBracket] &)\) /@ train\)}], 
          Graphics[{RGBColor[0, 0.133, 0.859], 
              Thickness[
                0.0075], \((Line[{{#1, \(-f[#1]\)}, {#1, f[#1]}}] &)\) /@ 
                z}], plt1, opts, Frame \[Rule] True, 
          GridLines \[Rule] Automatic, PlotRange \[Rule] All, 
          AspectRatio \[Rule] 0.4, 
          FrameLabel \[Rule] {"\<z-position [m]\>", "\<spot size [mm]\>", \
"\<Beam Profile\>", "\<\>"}, 
          DisplayFunction \[Rule] $DisplayFunction]]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

Parameters\
\>", "Subtitle"],

Cell["\<\
z-axis points from ETM to  ITM
z=0 is at the beamsplitter
X is the short arm and perpendicular
ITM/BS are fused silica\
\>", "Text"],

Cell[BoxData[{
    \(\(ShortenCavity = 0;\)\), "\[IndentingNewLine]", 
    \(\(CavityLength = 1.0 - ShortenCavity;\)\), "\[IndentingNewLine]", 
    \(\(ETMCurvature = 0.52;\)\), "\[IndentingNewLine]", 
    \(\(ITMCurvature = 0.52;\)\), "\[IndentingNewLine]", 
    \(\(ITMThickness = 0.028;\)\), "\[IndentingNewLine]", 
    \(\(BSThickness = 0.025;\)\), "\[IndentingNewLine]", 
    \(\(gETM = 1 - CavityLength\/ETMCurvature;\)\), "\[IndentingNewLine]", 
    \(\(gITM = 1 - CavityLength\/ITMCurvature;\)\), "\[IndentingNewLine]", 
    \(\(gCavity = gETM\ gITM;\)\), "\[IndentingNewLine]", 
    \(\({CavityWaist, CavityRayleighLength, {ETMPosition, ITMPosition}, 
          CavityGouyPhase} = 
        GaussianBeam[{CavityLength, \(-ETMCurvature\), \ ITMCurvature}, 
          kk];\)\), "\[IndentingNewLine]", 
    \(CavityWaistPosition = 
      zzz /. FindRoot[
          RadiusOfCurvature[zzz, CavityWaist, kk] \[Equal] 
            ETMCurvature, {zzz, CavityLength/2}]\ ;  (*\ 
      from\ ETM\ *) \[IndentingNewLine]ETMSpotSize = 
      SpotSize[CavityWaistPosition, CavityWaist, 
        kk];\), "\[IndentingNewLine]", 
    \(\(ITMSpotSize = 
        SpotSize[CavityLength - CavityWaistPosition, CavityWaist, 
          kk];\)\), "\[IndentingNewLine]", 
    \(\(ITMFocalLength = \(-ITMCurvature\)\/\(nFusedSilica - 1\);\)\), "\
\[IndentingNewLine]", 
    \(\(MichelsonXLength = 0.3 + ShortenCavity;\)\), "\[IndentingNewLine]", 
    \(\(MichelsonYLength = 0.4 + ShortenCavity;\)\), "\[IndentingNewLine]", 
    \(\(MichelsonLength = \(MichelsonYLength + MichelsonXLength\)\/2;\)\), "\
\[IndentingNewLine]", 
    \(\(MichelsonAsymmetry = 
        MichelsonYLength - MichelsonXLength;\)\), "\[IndentingNewLine]", 
    \(\(ITMAddedPathLength = \((nFusedSilica - 1)\) 
          ITMThickness;\)\), "\[IndentingNewLine]", 
    \(\(BSAddedPathLength = \((nFusedSilica - 1)\) \(\@2\) 
          BSThickness;\)\), "\[IndentingNewLine]", 
    \(\(zBS = 0;\)\), "\[IndentingNewLine]", 
    \(\(zETM = \(-MichelsonLength\) - 
          CavityLength;\)\), "\[IndentingNewLine]", 
    \(\(zITM = \(-MichelsonLength\);\)\), "\[IndentingNewLine]", 
    \(\(zCavityWaist = 
        zETM + CavityWaistPosition;\)\), "\[IndentingNewLine]", 
    \(\({Waist, 
          zWaist} = \[IndentingNewLine]Lensing[{CavityWaist, 
            zCavityWaist}, {ITMFocalLength, zITM}, 
          kk];\)\), "\[IndentingNewLine]", 
    \(\(RayleighRange = RayleighLength[Waist, kk];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Print["\<Length of Cavity = \>", 
      CavityLength, \ "\< m\>"]\), "\[IndentingNewLine]", 
    \(Print["\<Curvature of ETM = \>", \ 
      ETMCurvature, \ "\< m\>"]\), "\[IndentingNewLine]", 
    \(Print["\<Curvature of ITM = \>", \ 
      ITMCurvature, \ "\< m\>"]\), "\[IndentingNewLine]", 
    \(Print["\<g-Factor of ETM = \>", \ 
      gETM, \ "\< m\>"]\), "\[IndentingNewLine]", 
    \(Print["\<g-Factor of ITM = \>", \ 
      gITM, \ "\< m\>"]\), "\[IndentingNewLine]", 
    \(Print["\<g-Factor of Cavity = \>", \ 
      gCavity, \ "\< m\>"]\), "\[IndentingNewLine]", 
    \(Print["\<Spot Size on ETM = \>", \ 
      1000\ ETMSpotSize, \ "\< mm\>"]\), "\[IndentingNewLine]", 
    \(Print["\<Spot Size on ITM = \>", \ 
      1000\ ITMSpotSize, \ "\< mm\>"]\), "\[IndentingNewLine]", 
    \(\(Print["\<Rayleigh Length of Cavity Mode = \>", \ 
        CavityRayleighLength, \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Size of Cavity Mode = \>", \ 
        1000\ CavityWaist, \ "\< mm\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Position inside Cavity = \>", \ 
        CavityWaistPosition, "\< m from ETM\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Focal Length of ITM = \>", \ 
        ITMFocalLength, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Michelson Asymmetry = \>", \ 
        MichelsonAsymmetry, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<ETMX Position (for optical path length) = \>", \ \
\(-CavityLength\) - 
          MichelsonXLength, \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<ITMX Position (for optical path length) = \>", \
\(-MichelsonXLength\), \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<ETMY Position (for optical path length) = \>", \ \
\(-CavityLength\) - 
          MichelsonYLength, \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<ITMY Position (for optical path length) = \>", \ \
\(-MichelsonYLength\), \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Average ETM Position = \>", \ 
        zETM, \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Average ITM Position = \>", \ 
        zITM, \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Additional ITM optical path length = \>", 
        ITMAddedPathLength, \ "\< m\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Additional BS optical path length = \>", 
        BSAddedPathLength, \ "\< m\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<True ETMX Position = \>", \ \(-CavityLength\) - 
          MichelsonXLength + 
          ITMAddedPathLength, \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<True ITMX Position = \>", \ \(-MichelsonXLength\) + 
          ITMAddedPathLength, \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<True ETMY Position = \>", \ \(-CavityLength\) - 
          MichelsonYLength + ITMAddedPathLength + 
          BSAddedPathLength, \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<True ITMY Position = \>", \ \(-MichelsonYLength\) + 
          ITMAddedPathLength + 
          BSAddedPathLength, \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<BS Position = \>", \ 
        zBS, \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Size outside Cavity = \>", \ 
        1000\ Waist, \ "\< mm\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Position outside Cavity = \>", \ 
        zWaist, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Rayleigh Length outside Cavity = \>", \ 
        RayleighRange, \ "\< m\>"];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Length of Cavity = "\[InvisibleSpace]1.`\
\[InvisibleSpace]" m"\),
      SequenceForm[ "Length of Cavity = ", 1.0, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Curvature of ETM = "\[InvisibleSpace]0.52`\
\[InvisibleSpace]" m"\),
      SequenceForm[ "Curvature of ETM = ", .52000000000000002, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Curvature of ITM = "\[InvisibleSpace]0.52`\
\[InvisibleSpace]" m"\),
      SequenceForm[ "Curvature of ITM = ", .52000000000000002, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("g-Factor of ETM = \
"\[InvisibleSpace]\(-0.9230769230769229`\)\[InvisibleSpace]" m"\),
      SequenceForm[ "g-Factor of ETM = ", -.92307692307692291, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("g-Factor of ITM = \
"\[InvisibleSpace]\(-0.9230769230769229`\)\[InvisibleSpace]" m"\),
      SequenceForm[ "g-Factor of ITM = ", -.92307692307692291, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("g-Factor of Cavity = \
"\[InvisibleSpace]0.8520710059171595`\[InvisibleSpace]" m"\),
      SequenceForm[ "g-Factor of Cavity = ", .85207100591715945, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Spot Size on ETM = \
"\[InvisibleSpace]0.9383882294332331`\[InvisibleSpace]" mm"\),
      SequenceForm[ "Spot Size on ETM = ", .93838822943323308, " mm"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Spot Size on ITM = \
"\[InvisibleSpace]0.9383882294332331`\[InvisibleSpace]" mm"\),
      SequenceForm[ "Spot Size on ITM = ", .93838822943323308, " mm"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Rayleigh Length of Cavity Mode = \
"\[InvisibleSpace]0.10000000000000005`\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Rayleigh Length of Cavity Mode = ", .10000000000000005, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Size of Cavity Mode = \
"\[InvisibleSpace]0.18403307281560927`\[InvisibleSpace]" mm"\),
      SequenceForm[ 
      "Waist Size of Cavity Mode = ", .18403307281560927, " mm"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Position inside Cavity = \
"\[InvisibleSpace]0.5`\[InvisibleSpace]" m from ETM"\),
      SequenceForm[ "Waist Position inside Cavity = ", .5, " m from ETM"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Focal Length of ITM = \
"\[InvisibleSpace]\(-1.1563778687066357`\)\[InvisibleSpace]" m"\),
      SequenceForm[ "Focal Length of ITM = ", -1.1563778687066357, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Michelson Asymmetry = \
"\[InvisibleSpace]0.10000000000000003`\[InvisibleSpace]" m"\),
      SequenceForm[ "Michelson Asymmetry = ", .10000000000000003, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ETMX Position (for optical path length) = "\
\[InvisibleSpace]\(-1.3`\)\[InvisibleSpace]" m"\),
      SequenceForm[ "ETMX Position (for optical path length) = ", -1.3, " m"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ITMX Position (for optical path length) = "\
\[InvisibleSpace]\(-0.3`\)\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "ITMX Position (for optical path length) = ", -.29999999999999999, 
        " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ETMY Position (for optical path length) = "\
\[InvisibleSpace]\(-1.4`\)\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "ETMY Position (for optical path length) = ", -1.3999999999999999, 
        " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("ITMY Position (for optical path length) = "\
\[InvisibleSpace]\(-0.4`\)\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "ITMY Position (for optical path length) = ", -.40000000000000002, 
        " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Average ETM Position = "\[InvisibleSpace]\(-1.35`\)\
\[InvisibleSpace]" m"\),
      SequenceForm[ "Average ETM Position = ", -1.3500000000000001, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Average ITM Position = "\[InvisibleSpace]\(-0.35`\)\
\[InvisibleSpace]" m"\),
      SequenceForm[ "Average ITM Position = ", -.34999999999999998, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Additional ITM optical path length = "\
\[InvisibleSpace]0.012591040000000003`\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Additional ITM optical path length = ", .012591040000000003, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Additional BS optical path length = "\
\[InvisibleSpace]0.015898588868198338`\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Additional BS optical path length = ", .015898588868198338, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("True ETMX Position = \
"\[InvisibleSpace]\(-1.28740896`\)\[InvisibleSpace]" m"\),
      SequenceForm[ "True ETMX Position = ", -1.28740896, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("True ITMX Position = \
"\[InvisibleSpace]\(-0.28740896`\)\[InvisibleSpace]" m"\),
      SequenceForm[ "True ITMX Position = ", -.28740895999999999, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("True ETMY Position = \
"\[InvisibleSpace]\(-1.3715103711318015`\)\[InvisibleSpace]" m"\),
      SequenceForm[ "True ETMY Position = ", -1.3715103711318015, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("True ITMY Position = \
"\[InvisibleSpace]\(-0.3715103711318017`\)\[InvisibleSpace]" m"\),
      SequenceForm[ "True ITMY Position = ", -.37151037113180169, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("BS Position = "\[InvisibleSpace]0\[InvisibleSpace]" \
m"\),
      SequenceForm[ "BS Position = ", 0, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Size outside Cavity = \
"\[InvisibleSpace]0.12824669943092262`\[InvisibleSpace]" mm"\),
      SequenceForm[ 
      "Waist Size outside Cavity = ", .12824669943092262, " mm"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Position outside Cavity = \
"\[InvisibleSpace]\(-0.7020001027073521`\)\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Waist Position outside Cavity = ", -.70200010270735214, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Rayleigh Length outside Cavity = \
"\[InvisibleSpace]0.04856245553602894`\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Rayleigh Length outside Cavity = ", .048562455536028941, " m"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

Michelson Compensation\
\>", "Subtitle"],

Cell["\<\
LX is a lens in the X-arm of the Michelson path
LY is a lens in the Y-arm of the Michelson path\
\>", "Text"],

Cell[BoxData[{
    \(\(ShiftLY = \(-0.002\);\)\), "\[IndentingNewLine]", 
    \(\(zLX = \(-0.125\);\)\), "\[IndentingNewLine]", 
    \(\(fLX = 0.681;\)\), "\[IndentingNewLine]", 
    \(\({WaistLX, 
          zWaistLX} = \[IndentingNewLine]Lensing[{Waist, 
            zWaist + MichelsonAsymmetry/2}, {fLX, zLX}, 
          kk];\)\), "\[IndentingNewLine]", 
    \(\(RayleighRangeLX = 
        RayleighLength[WaistLX, kk];\)\), "\[IndentingNewLine]", 
    \(\(zLY = 
        zLX - MichelsonAsymmetry + ShiftLY;\)\), "\[IndentingNewLine]", 
    \(\(fLY = 0.681;\)\), "\[IndentingNewLine]", 
    \(\({WaistLY, 
          zWaistLY} = \[IndentingNewLine]Lensing[{Waist, 
            zWaist - MichelsonAsymmetry/2}, {fLY, zLY}, 
          kk];\)\), "\[IndentingNewLine]", 
    \(\(RayleighRangeLY = 
        RayleighLength[WaistLY, kk];\)\), "\[IndentingNewLine]", 
    \(\(zLXY = \(zLX + zLY\)\/2;\)\), "\[IndentingNewLine]", 
    \(\(fLXY = \(fLX + fLY\)\/2;\)\), "\[IndentingNewLine]", 
    \(\({WaistLXY, 
          zWaistLXY} = \[IndentingNewLine]Lensing[{Waist, zWaist}, {fLXY, 
            zLXY}, kk];\)\), "\[IndentingNewLine]", 
    \(\(RayleighRangeLXY = RayleighLength[WaistLXY, kk];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Print["\<Focal Length of LX Lens = \>", 
        fLX, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Position of LX Lens (for optical path length) = \>", 
        zLX, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<True Position of LX Lens = \>", 
        zLX, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Size after LX = \>", \ 
        1000\ WaistLX, \ "\< mm\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Position after LX = \>", \ 
        zWaistLX, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Rayleigh Length after LX = \>", \ 
        RayleighRangeLX, \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Focal Length of LY Lens = \>", 
        fLY, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Position of LY Lens (for optical path length) = \>", 
        zLY, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<True Position of LY Lens = \>", 
        zLY + BSAddedPathLength, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Size after LY = \>", \ 
        1000\ WaistLY, \ "\< mm\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Position after LY = \>", \ 
        zWaistLY, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Rayleigh Length after LY = \>", \ 
        RayleighRangeLY, \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Average Waist Size after LX/LY = \>", \ 
        1000\ WaistLXY, \ "\< mm\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Average Waist Position after LX/LY = \>", \ 
        zWaistLXY, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Average Rayleigh Length after LX/LY = \>", \ 
        RayleighRangeLXY, \ "\< m\>"];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Focal Length of LX Lens = "\[InvisibleSpace]0.681`\
\[InvisibleSpace]" m"\),
      SequenceForm[ "Focal Length of LX Lens = ", .68100000000000005, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Position of LX Lens (for optical path length) = "\
\[InvisibleSpace]\(-0.125`\)\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Position of LX Lens (for optical path length) = ", -.125, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("True Position of LX Lens = \
"\[InvisibleSpace]\(-0.125`\)\[InvisibleSpace]" m"\),
      SequenceForm[ "True Position of LX Lens = ", -.125, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Size after LX = \
"\[InvisibleSpace]0.5408628378992951`\[InvisibleSpace]" mm"\),
      SequenceForm[ "Waist Size after LX = ", .54086283789929512, " mm"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Position after LX = \
"\[InvisibleSpace]\(-2.1830648994047936`\)\[InvisibleSpace]" m"\),
      SequenceForm[ "Waist Position after LX = ", -2.1830648994047936, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Rayleigh Length after LX = \
"\[InvisibleSpace]0.8637390006492761`\[InvisibleSpace]" m"\),
      SequenceForm[ "Rayleigh Length after LX = ", .86373900064927611, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Focal Length of LY Lens = "\[InvisibleSpace]0.681`\
\[InvisibleSpace]" m"\),
      SequenceForm[ "Focal Length of LY Lens = ", .68100000000000005, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Position of LY Lens (for optical path length) = "\
\[InvisibleSpace]\(-0.22700000000000004`\)\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Position of LY Lens (for optical path length) = ", -.22700000000000004,
         " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("True Position of LY Lens = \
"\[InvisibleSpace]\(-0.2111014111318017`\)\[InvisibleSpace]" m"\),
      SequenceForm[ "True Position of LY Lens = ", -.2111014111318017, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Size after LY = \
"\[InvisibleSpace]0.5345449151488461`\[InvisibleSpace]" mm"\),
      SequenceForm[ "Waist Size after LY = ", .53454491514884606, " mm"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Position after LY = \
"\[InvisibleSpace]\(-2.2561936539132157`\)\[InvisibleSpace]" m"\),
      SequenceForm[ "Waist Position after LY = ", -2.2561936539132157, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Rayleigh Length after LY = \
"\[InvisibleSpace]0.8436778555391463`\[InvisibleSpace]" m"\),
      SequenceForm[ "Rayleigh Length after LY = ", .84367785553914632, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Average Waist Size after LX/LY = \
"\[InvisibleSpace]0.5376862287834825`\[InvisibleSpace]" mm"\),
      SequenceForm[ 
      "Average Waist Size after LX/LY = ", .53768622878348249, " mm"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Average Waist Position after LX/LY = "\
\[InvisibleSpace]\(-2.2195629312010943`\)\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Average Waist Position after LX/LY = ", -2.2195629312010943, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Average Rayleigh Length after LX/LY = "\
\[InvisibleSpace]0.8536229282252673`\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Average Rayleigh Length after LX/LY = ", .85362292822526731, " m"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Michelson X-arm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TelescopePlot[{zETM + MichelsonAsymmetry/2, 5.0}, {CavityWaist, 
          zCavityWaist + MichelsonAsymmetry/2}, {{ITMFocalLength, 
            zITM + MichelsonAsymmetry/2}, {fLX, zLX}}, kk];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.220333 0.151172 0.2 0.0420445 [
[.06916 -0.0125 -10.0938 -16.375 ]
[.06916 -0.0125 10.0938 0 ]
[.22033 -0.0125 -5.59375 -16.375 ]
[.22033 -0.0125 5.59375 0 ]
[.3715 -0.0125 -5.59375 -16.375 ]
[.3715 -0.0125 5.59375 0 ]
[.52268 -0.0125 -5.59375 -16.375 ]
[.52268 -0.0125 5.59375 0 ]
[.67385 -0.0125 -5.59375 -16.375 ]
[.67385 -0.0125 5.59375 0 ]
[.82502 -0.0125 -5.59375 -16.375 ]
[.82502 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -16.375 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -43.1563 -32.75 ]
[.5 -0.0125 43.1563 -16.375 ]
[-0.0125 .03182 -20.1875 -8.1875 ]
[-0.0125 .03182 0 8.1875 ]
[-0.0125 .11591 -20.1875 -8.1875 ]
[-0.0125 .11591 0 8.1875 ]
[-0.0125 .2 -11.1875 -8.1875 ]
[-0.0125 .2 0 8.1875 ]
[-0.0125 .28409 -11.1875 -8.1875 ]
[-0.0125 .28409 0 8.1875 ]
[-0.0125 .36818 -11.1875 -8.1875 ]
[-0.0125 .36818 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .2 -36.5625 -44.3438 ]
[-0.01875 .2 -20.1875 44.3438 ]
[ 0 .4 .125 0 ]
[.5 .4125 -39 0 ]
[.5 .4125 39 16.375 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.06916 0 m
.06916 .4 L
s
.22033 0 m
.22033 .4 L
s
.3715 0 m
.3715 .4 L
s
.52268 0 m
.52268 .4 L
s
.67385 0 m
.67385 .4 L
s
.82502 0 m
.82502 .4 L
s
0 .03182 m
1 .03182 L
s
0 .11591 m
1 .11591 L
s
0 .2 m
1 .2 L
s
0 .28409 m
1 .28409 L
s
0 .36818 m
1 .36818 L
s
0 g
.06916 0 m
.06916 .00625 L
s
gsave
.06916 -0.0125 -71.0938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22033 0 m
.22033 .00625 L
s
gsave
.22033 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.3715 0 m
.3715 .00625 L
s
gsave
.3715 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.52268 0 m
.52268 .00625 L
s
gsave
.52268 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.67385 0 m
.67385 .00625 L
s
gsave
.67385 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.82502 0 m
.82502 .00625 L
s
gsave
.82502 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.0994 0 m
.0994 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.15986 0 m
.15986 .00375 L
s
.1901 0 m
.1901 .00375 L
s
.25057 0 m
.25057 .00375 L
s
.2808 0 m
.2808 .00375 L
s
.31104 0 m
.31104 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.43197 0 m
.43197 .00375 L
s
.46221 0 m
.46221 .00375 L
s
.49244 0 m
.49244 .00375 L
s
.55291 0 m
.55291 .00375 L
s
.58314 0 m
.58314 .00375 L
s
.61338 0 m
.61338 .00375 L
s
.64361 0 m
.64361 .00375 L
s
.70408 0 m
.70408 .00375 L
s
.73432 0 m
.73432 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79478 0 m
.79478 .00375 L
s
.85525 0 m
.85525 .00375 L
s
.88549 0 m
.88549 .00375 L
s
.91572 0 m
.91572 .00375 L
s
.94596 0 m
.94596 .00375 L
s
.03893 0 m
.03893 .00375 L
s
.00869 0 m
.00869 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -104.156 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.438 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.875 16.625 moveto
(@) show
130.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
141.000 16.625 moveto
(D) show
145.313 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03182 m
.00625 .03182 L
s
gsave
-0.0125 .03182 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .11591 m
.00625 .11591 L
s
gsave
-0.0125 .11591 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
gsave
-0.0125 .2 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .28409 m
.00625 .28409 L
s
gsave
-0.0125 .28409 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .36818 m
.00625 .36818 L
s
gsave
-0.0125 .36818 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05284 m
.00375 .05284 L
s
0 .07387 m
.00375 .07387 L
s
0 .09489 m
.00375 .09489 L
s
0 .13693 m
.00375 .13693 L
s
0 .15796 m
.00375 .15796 L
s
0 .17898 m
.00375 .17898 L
s
0 .22102 m
.00375 .22102 L
s
0 .24204 m
.00375 .24204 L
s
0 .26307 m
.00375 .26307 L
s
0 .30511 m
.00375 .30511 L
s
0 .32613 m
.00375 .32613 L
s
0 .34716 m
.00375 .34716 L
s
0 .0108 m
.00375 .0108 L
s
0 .3892 m
.00375 .3892 L
s
.25 Mabswid
0 0 m
0 .4 L
s
gsave
-0.01875 .2 -133.719 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
105.344 12.1875 translate
90 rotate
-105.344 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(spot) show
90.938 16.625 moveto
(size) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.438 16.625 moveto
(@) show
121.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
143.375 16.625 moveto
(D) show
147.688 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.06916 .39375 m
.06916 .4 L
s
.22033 .39375 m
.22033 .4 L
s
.3715 .39375 m
.3715 .4 L
s
.52268 .39375 m
.52268 .4 L
s
.67385 .39375 m
.67385 .4 L
s
.82502 .39375 m
.82502 .4 L
s
.97619 .39375 m
.97619 .4 L
s
.125 Mabswid
.0994 .39625 m
.0994 .4 L
s
.12963 .39625 m
.12963 .4 L
s
.15986 .39625 m
.15986 .4 L
s
.1901 .39625 m
.1901 .4 L
s
.25057 .39625 m
.25057 .4 L
s
.2808 .39625 m
.2808 .4 L
s
.31104 .39625 m
.31104 .4 L
s
.34127 .39625 m
.34127 .4 L
s
.40174 .39625 m
.40174 .4 L
s
.43197 .39625 m
.43197 .4 L
s
.46221 .39625 m
.46221 .4 L
s
.49244 .39625 m
.49244 .4 L
s
.55291 .39625 m
.55291 .4 L
s
.58314 .39625 m
.58314 .4 L
s
.61338 .39625 m
.61338 .4 L
s
.64361 .39625 m
.64361 .4 L
s
.70408 .39625 m
.70408 .4 L
s
.73432 .39625 m
.73432 .4 L
s
.76455 .39625 m
.76455 .4 L
s
.79478 .39625 m
.79478 .4 L
s
.85525 .39625 m
.85525 .4 L
s
.88549 .39625 m
.88549 .4 L
s
.91572 .39625 m
.91572 .4 L
s
.94596 .39625 m
.94596 .4 L
s
.03893 .39625 m
.03893 .4 L
s
.00869 .39625 m
.00869 .4 L
s
.25 Mabswid
0 .4 m
1 .4 L
s
gsave
.5 .4125 -100 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
100.375 16.625 moveto
(Profile) show
137.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .03182 m
1 .03182 L
s
.99375 .11591 m
1 .11591 L
s
.99375 .2 m
1 .2 L
s
.99375 .28409 m
1 .28409 L
s
.99375 .36818 m
1 .36818 L
s
.125 Mabswid
.99625 .05284 m
1 .05284 L
s
.99625 .07387 m
1 .07387 L
s
.99625 .09489 m
1 .09489 L
s
.99625 .13693 m
1 .13693 L
s
.99625 .15796 m
1 .15796 L
s
.99625 .17898 m
1 .17898 L
s
.99625 .22102 m
1 .22102 L
s
.99625 .24204 m
1 .24204 L
s
.99625 .26307 m
1 .26307 L
s
.99625 .30511 m
1 .30511 L
s
.99625 .32613 m
1 .32613 L
s
.99625 .34716 m
1 .34716 L
s
.99625 .0108 m
1 .0108 L
s
.99625 .3892 m
1 .3892 L
s
.25 Mabswid
1 0 m
1 .4 L
s
.977 .121 .023 r
.0075 w
.17498 .16055 m
.17498 .23945 L
s
.20144 .14124 m
.20144 .25876 L
s
0 .133 .859 r
.02381 .16055 m
.02381 .23945 L
s
.97619 .00952 m
.97619 .39048 L
s
0 g
.5 Mabswid
.02381 .23945 m
.04262 .23007 L
.06244 .22043 L
.07216 .21594 L
.0775 .21362 L
.08255 .21158 L
.08542 .21054 L
.08693 .21003 L
.08852 .20953 L
.08987 .20915 L
.09135 .20877 L
.0927 .20846 L
.09396 .20822 L
.09461 .20812 L
.09533 .20801 L
.09663 .20787 L
.0979 .20778 L
.09907 .20774 L
.09979 .20774 L
.10047 .20776 L
.10174 .20783 L
.10245 .20789 L
.1031 .20797 L
.10382 .20806 L
.10458 .20818 L
.1058 .2084 L
.10713 .20869 L
.10838 .209 L
.10954 .20932 L
.11406 .21078 L
.11898 .21266 L
.12422 .21488 L
.14255 .22341 L
.1803 .24333 L
.19052 .25078 L
.19609 .25485 L
.19881 .25684 L
.19999 .25771 L
.20128 .25865 L
.20246 .25893 L
.20356 .2591 L
.20572 .25945 L
.21046 .26021 L
.22051 .26184 L
.25919 .26815 L
.2986 .27465 L
.33648 .28096 L
.37682 .28773 L
.41565 .29427 L
.45692 .30127 L
Mistroke
.49668 .30802 L
.53493 .31454 L
.57563 .3215 L
.61481 .32821 L
.65644 .33535 L
.69656 .34224 L
.73516 .34888 L
.77622 .35595 L
.81576 .36277 L
.85378 .36933 L
.89426 .37632 L
.93322 .38305 L
.97463 .39021 L
.97619 .39048 L
Mfstroke
.02381 .16055 m
.04262 .16993 L
.06244 .17957 L
.07216 .18406 L
.0775 .18638 L
.08255 .18842 L
.08542 .18946 L
.08693 .18997 L
.08852 .19047 L
.08987 .19085 L
.09135 .19123 L
.0927 .19154 L
.09396 .19178 L
.09461 .19188 L
.09533 .19199 L
.09663 .19213 L
.0979 .19222 L
.09907 .19226 L
.09979 .19226 L
.10047 .19224 L
.10174 .19217 L
.10245 .19211 L
.1031 .19203 L
.10382 .19194 L
.10458 .19182 L
.1058 .1916 L
.10713 .19131 L
.10838 .191 L
.10954 .19068 L
.11406 .18922 L
.11898 .18734 L
.12422 .18512 L
.14255 .17659 L
.1803 .15667 L
.19052 .14922 L
.19609 .14515 L
.19881 .14316 L
.19999 .14229 L
.20128 .14135 L
.20246 .14107 L
.20356 .1409 L
.20572 .14055 L
.21046 .13979 L
.22051 .13816 L
.25919 .13185 L
.2986 .12535 L
.33648 .11904 L
.37682 .11227 L
.41565 .10573 L
.45692 .09873 L
Mistroke
.49668 .09198 L
.53493 .08546 L
.57563 .0785 L
.61481 .07179 L
.65644 .06465 L
.69656 .05776 L
.73516 .05112 L
.77622 .04405 L
.81576 .03723 L
.85378 .03067 L
.89426 .02368 L
.93322 .01695 L
.97463 .00979 L
.97619 .00952 L
Mfstroke
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{612.625, 245},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009T0000mB000`400?l00000o`00003oo`3ooooo
0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo;`3oool00`000000oooo0?ooo`0]0?ooo`<0
00003@3oool300000?<0oooo003o0?ooobl0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0?40oooo003o0?ooobl0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?40oooo003o0?ooob40oooo1@000009
0?ooo`040000003oool00000000000@0oooo0`0000040?ooo`<000000`3oool00`000000oooo0?oo
o`0200000080oooo00@000000?ooo`3oool0oooo0`0000030?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob80oooo00<000000?ooo`3o
ool02P3oool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000003
0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3a0?ooo`00o`3ooolR0?ooo`030000003oool0oooo00X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo0?oo
o`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0l@3o
ool00?l0oooo8`3oool010000000oooo0?ooo`3oool7000000030?ooo`000000oooo0080oooo00@0
00000?ooo`3oool000000`3oool010000000oooo0?ooo`3oool3000000<0oooo00@000000?ooo`3o
ool000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob@0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob@0oooo00<000000?ooo`3oool0203o
ool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3a0?ooo`00o`3ooolQ0?ooo`D000002@3oool010000000oooo0000000000040?ooo`<00000103o
ool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`040000003oool0oooo0?ooo`<00000
0`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0080oooo00@000000?ooo`00
000000000P3oool2000000D0oooo00<000000?ooo`3oool0l@3oool00?l0ooooA`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0l@3oool00?l0oooo
A`3oool00`000000oooo0?ooo`0E0?ooo`<000003@3oool300000?<0oooo003o0?oood@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooaP0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3o
oomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool008H0oooo00<000000?ooo`3o
ool0?03oool4000004<0oooo00<000000?ooo`3oool0@03oool600000400oooo100000140?ooo`03
0000003oool0oooo0400oooo100000100?ooo`00QP3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0m0?ooo`00QP3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0?@3o
ool6000004D0oooo00<000000?ooo`3oool0?@3oool007/0oooo1`0000040?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0n0?ooo`040000003oool0
oooo000004H0oooo00<000000?ooo`3oool0?@3oool008H0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo03h0oooo00@000000?ooo`3oool00000@@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo00260?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool0?`3oool300000480oooo00<000000?ooo`000000@@3oool5
00000400oooo00260?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool000000440oooo00<000000?ooo`3oool0@P3oool008@0
oooo00<000000?ooo`000000?@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`000000A`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0400
oooo0P0000120?ooo`030000003oool0oooo0440oooo00250?ooo`800000?@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03l0oooo0P0000120?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo
0P0000120?ooo`030000003oool0oooo0440oooo00260?ooo`030000003oool0oooo03`0oooo1000
00130?ooo`030000003oool0oooo0440oooo100000110?ooo`@00000A03oool00`000000oooo0?oo
o`100?ooo`D00000?`3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0
ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00H`3ooooo00000<`00000=P3oool006<0oooo00D000000?ooo`3oool0
oooo0000000<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0d0?ooo`00H`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003o
ool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo03l0oooo100000000`008]/0oooo0?ooo`070?ooo`030000003oool0oooo03@0oooo001S
0?ooo`8000007@3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0>P3oool500000080oooo0`008]/70?ooo`<00000=P3oool006<0oooo00<000000?oo
o`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0=P3oool4000000L0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`03
0000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0340oooo1@00000;0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`0/0?ooo`D00000403oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool09P3oool6000001D0oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0200oooo1P00000K0?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0d0?ooo`00F03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
01X0oooo1P00000Q0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00F03oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo01@0oooo1P00000W0?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00E03oool6000000T0oooo00<000000?ooo`3oool0703oool00`0007l0oooo
0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool03P3oool6000002d0oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo001<0?ooo`L000000P3oool010000000oooo0?oo
o`00000:0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo00P0oooo1P00000c0?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00E@3oool010000000oooo0?ooo`00000:0?ooo`<00000o`0007mm0000O`H00000
>@0007l3000Rf`H0001o1000000f0?ooo`00EP3oool00`000000oooo0000000:0?ooo`030000003o
ool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`110?ooo`H00000?`3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005H0oooo00<000000?ooo`0000002P3oool0
0`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0>`3oool6
000000030?ooo`0007l0oooo0480oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001G0?oo
o`8000002P3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0=@3oool6000000L0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool005L0oooo0P00000:0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3o
ool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@`3oool00`0007l0oooo0?ooo`0_0?ooo`H000003@3oool00`0007l0oooo0?ooo`110?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00F03oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0Y0?ooo`H00000
4`3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3o
ool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool08`3o
ool6000001T0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo01d0oooo1P00000O0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`0G0?ooo`H000009@3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool2000001d0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`0A0?ooo`H00000:`3oool00`0007l0oooo0?ooo`110?ooo`<002;K1`3oool3000003H0
oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`0;0?ooo`H00000<@3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0
001o0?ooo`3oool01@3oool6000003L0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`13
0?ooo`040000O`3oool0oooo0?ooo`@00000?@3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0
oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo1@0000110?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0?P3oool40000
00030?ooo`0007l0oooo04<0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0h0?ooo`H0
00001@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`03
0000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0
@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
<P3oool6000000/0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo02/0oooo1`00000A0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`0U0?ooo`H00000603oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`8000007@3oool00`00
07l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`0O0?ooo`H000007P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0440oooo0`008]/70?ooo`<00000=P3oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0
oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`0I0?ooo`H00000903oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo
00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool04`3oool6000002X0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?oo
o`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo00d0oooo1P00000`0?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<00000
0?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`070?ooo`H00000=P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?oo
o`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00@0001o0?ooo`3oool0oooo1P00000l0?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
06<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@03oool600000480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000
oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`0j0?ooo`H000000P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo
00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0=03oool6000000P0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
001S0?ooo`8000007@3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0;P3oool6000000h0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0440oooo0`008]/70?ooo`<00000=P3oool006<0oooo00<00000
0?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0:03oool6000001@0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?oo
o`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0240oooo1`00000J0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`0K0?ooo`H000008@3oool00`0007l0oooo0?ooo`130?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool05@3oool6000002L0oooo00<0001o0?ooo`3oool0
@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000
003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo00l0oooo1P00000]0?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0
oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`090?ooo`H00000<`3oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3
000Rf`T0oooo00<000000?ooo`3oool0=03oool005@0oooo1P0000090?ooo`030000003oool0oooo
01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
00<0oooo1P00000i0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool200000080
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0
oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`H00000?`3oool00`0007l0
oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool003/0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0703oool00`0007l0
oooo0?ooo`130?ooo`030000O`3oool0oooo03h0oooo100000000`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00P0oooo1`0000040?ooo`030000003oool0oooo00T0oooo0`00002N0000O`D0
0000o`0007lI0000O`<002;K1P0007l4000003H0oooo000k0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01`0
oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0e0?ooo`@000002@3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool00`000000oooo
0?ooo`02000001P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000
O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0;P3oool7000000d0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool09@3o
ool9000001@0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool005T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0
oooo04<0oooo00<0001o0?ooo`3oool07P3oool7000001d0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3
000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo2P00000?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0603oool6000002@0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool003`0oooo00D000000?ooo`3oool0oooo0000000D0?oo
o`@000002P3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool04P3oool6000002X0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool003/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0<0?ooo`H0
0000<03oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo00H0oooo1P00000f0?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`D000008P3o
ool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool01P00
000l0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S
0?ooo`8000007@3oool00`0007l0oooo0?ooo`110?ooo`D00000@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?oo
o`3oool0>@3oool30?XN1@D000000P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`D000008P3oool00`000000
oooo0?ooo`0L0?ooo`030000O`3oool0oooo03T0oooo0`0000070?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01`0oooo
00<0001o0?ooo`3oool0>@3oool00`000000nQh50?XN1@070?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01`0oooo00<0
001o0?ooo`3oool0=`3oool2000000<0nQh51`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0
oooo03D0oooo0P0000020?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`D000008P3oool00`00
0000oooo0?ooo`0L0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool00P3oool30?XN
1@L0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo0380
oooo0P0000050?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`0a0?ooo`030000003oool0oooo00D0oooo
0`3j7PD70?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool003T0oooo2@00000Q0?ooo`8000007@3oool00`0007l0oooo0?oo
o`0`0?ooo`030000003oool0oooo00H0oooo0`3j7PD70?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@@3oool3000Rf`L0oooo0`00000f0?ooo`00>`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool3000Rfa<0oooo00<0001o
0?ooo`3oool0;@3oool00`3j7PD00000000000090?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?oo
o`030000003oool0oooo00H0oooo00<002;K0000000000004`3oool00`0007l0oooo0?ooo`0/0?oo
o`8000000P3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo00H0
oooo0`008]/200000140oooo00<0001o0?ooo`3oool0:P3oool2000000040?ooo`3j7PD0nQh50?XN
1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool01P3oool3000Rf`80
oooo0P00000?0?ooo`030000O`3oool0oooo02P0oooo0P0000030?ooo`<0nQh52@3oool30?XN1@L0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`060?ooo`<002;K103oool2000000d0oooo
00<0001o0?ooo`3oool09P3oool2000000D0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
001S0?ooo`030000003oool0oooo00H0oooo0`008]/60?ooo`<000002P3oool00`0007l0oooo0?oo
o`0T0?ooo`8000001`3oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003`0oooo0P000002
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01P3oool3000Rf`T0oooo0P000008
0?ooo`030000O`3oool0oooo0280oooo0P0000090?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool01P3oool3000Rf`/0oooo0P0000060?ooo`030000O`3oool0oooo0200oooo0P00000;
0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool3000Rf`d0oooo0P000004
0?ooo`030000O`3oool0oooo01l0oooo00<000000?ooo`3oool02`3oool30?XN1@T0oooo0`3j7PD7
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<00000
0?ooo`3oool0=03oool003/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0O
0?ooo`8000001`3oool3000Rf`l0oooo0`0000000`3oool0001o0?ooo`0N0?ooo`8000003P3oool3
0?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3
000Rf`L0oooo0`00000f0?ooo`00?03oool00`000000oooo0?ooo`0200000280oooo00<000000?oo
o`3oool01P3oool3000Rfa80oooo0P00000M0?ooo`800000403oool30?XN1@T0oooo0`3j7PD70?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool006<0oooo00<000000?ooo`3oool01P3oool3000Rfa<0oooo00<0001o00000000
00006@3oool200000180oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000
003oool0oooo00H0oooo0`008]/C0?ooo`030000O`3oool0oooo00800000503oool3000001@0oooo
0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo000h0?ooo`030000003oool0oooo00L000008@3o
ool00`000000oooo0?ooo`060?ooo`<002;K4`3oool00`0007l0oooo0?ooo`020?ooo`800000403o
ool2000001L0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0
oooo00H0oooo0`008]/C0?ooo`030000O`3oool0oooo00@0oooo100000080?ooo`@000006@3oool3
0?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3
000Rf`T0oooo00<000000?ooo`3oool0=03oool005D0oooo1000000:0?ooo`030000003oool0oooo
00H0oooo0`008]/C0?ooo`030000O`3oool0oooo00L0oooo2@00000M0?ooo`<0nQh52@3oool30?XN
1@L0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo0`008]/C0?ooo`030000O`3oool0oooo02d0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0
oooo000k0?ooo`040000003oool0oooo0?ooo`<000004P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool3000Rfa<0oooo00<0001o0?ooo`3o
ool0;@3oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`<002;K4`3oool00`0007l0oooo0?ooo`0]0?ooo`<0
nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool3000000<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo0`0000060000O`<002;K
@`0007l30?XN1@T0001o0`3j7PGo0000Of40001o0`008]/60000O`@00000=P3oool003/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`<002;K4`3oool00`0007l0oooo0?oo
o`0]0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool3000Rfa<0oooo00<0001o
0?ooo`3oool0;@3oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo0`008]/C0?oo
o`030000O`3oool0oooo00T0oooo1P00000N0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00?03oool5000001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00H0oooo0`008]/C0?ooo`030000O`3oool0oooo00D0oooo100000050?ooo`<0
0000703oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0A0?ooo`@000002P3oool00`000000oooo0?ooo`060?ooo`<0
02;K4`3oool00`0007l0oooo0?ooo`030?ooo`<000002`3oool4000001P0oooo0`3j7PD90?ooo`<0
nQh51`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`03
0000003oool0oooo03@0oooo000k0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`060?ooo`<002;K4`3oool0100007l0oooo0?ooo`3oool20000
0180oooo0P00000F0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool3000R
fa<0oooo00@0001o00000000000000005P3oool2000001@0oooo0`3j7PD90?ooo`<0nQh51`3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo000l0?ooo`<0000000<0oooo0000003oool08@3oool00`000000oooo0?ooo`060?oo
o`<002;K4P3oool2000001/0oooo0P00000B0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00H`3oool2000000L0oooo0`008]/?0?ooo`<0000000<0oooo0000O`3oool0703oool3000000l0
oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440
oooo0`008]/70?ooo`<00000=P3oool006<0oooo00<000000?ooo`3oool01P3oool3000Rf`d0oooo
0P0000040?ooo`030000O`3oool0oooo01h0oooo0P00000=0?ooo`<0nQh52@3oool30?XN1@L0oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`060?ooo`<002;K2`3oool2000000H0oooo00<0
001o0?ooo`3oool0803oool2000000/0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S
0?ooo`030000003oool0oooo00H0oooo0`008]/90?ooo`800000203oool00`0007l0oooo0?ooo`0R
0?ooo`8000002@3oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003T0oooo3000000N0?oo
o`030000003oool0oooo00H0oooo0`008]/70?ooo`8000002P3oool00`0007l0oooo0?ooo`0T0?oo
o`030000003oool0oooo00H0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000i0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`<0
02;K1@3oool2000000`0oooo00<0001o0?ooo`3oool09@3oool2000000H0oooo0`3j7PD90?ooo`<0
nQh51`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`03
0000003oool0oooo03@0oooo000i0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`060?ooo`<002;K0`3oool2000000h0oooo00<0001o0?ooo`3oool0
9`3oool2000000@0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003o
ool0oooo00H0oooo0`008]/00`3oool000000000000@0?ooo`030000O`3oool0oooo02T0oooo0P00
00020?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`06
0?ooo`8002;K0P00000B0?ooo`030000O`3oool0oooo02/0oooo00<000000?ooo`3j7PD00P3j7PD9
0?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/9
0?ooo`030000003oool0oooo03@0oooo000k0?ooo`L000008@3oool00`000000oooo0?ooo`060?oo
o`03000Rf`00000002;K01<0oooo00<0001o0?ooo`3oool0;03oool200000080nQh52@3oool30?XN
1@L0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00?03oool00`000000oooo0?ooo`0T0?ooo`8000001`3oool3000Rfa<0
oooo00<0001o0?ooo`3oool0;@3oool00`3j7PD00000000000090?ooo`<0nQh51`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/70?ooo`<00000=P3oool003/0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo0300oooo
00<000000?ooo`3oool01P3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0<@3oool2000000H0oooo0`3j
7PD70?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool003`0oooo1P00000Q0?ooo`030000003oool0oooo01`0oooo00<0001o
0?ooo`3oool0<`3oool2000000@0oooo0`3j7PD70?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo03D0oooo00@000000?oo
o`3oool0oooo0`3j7PD70?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3
000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0L0?ooo`030000O`3oool0oooo03H0oooo00<000000?ooo`3oool00`3j7PD70?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool003/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo03L0oooo00<000000?ooo`3j7PD00P3j7PD70?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003`0oooo
1P00000Q0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0>03oool200000080nQh5
1`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000
003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0>@3o
ool00`3j7PD000000000000500000080oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L
0?ooo`030000O`3oool0oooo03T0oooo0`3j7PD50?ooo`D00000@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool700000240oooo0P00000M0?oo
o`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool01P00000l0?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0440oooo0`008]/70?ooo`<00000=P3oool003`0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool01P3oool6000003H0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo
00<0001o0?ooo`3oool0303oool500000340oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool04@3oool6000002/0oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003`0oooo1P00000Q
0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0G
0?ooo`H000009@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00>`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01`0oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`0M0?ooo`H000007`3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`0F0?ooo`H0
00002@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3o
ool08`3oool6000001T0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool003/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0Y0?ooo`H00000
4`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03o
ool6000001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0;`3oool6000000d0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005L0oooo00<000000?ooo`3oool02@3oool3
000009X0001o1P00003o0000Oa`0001o0`008]/60000O`@00000=P3oool005P0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0>`3oool6000000030?ooo`0007l0oooo04<0oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo000i0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`110?ooo`H00000@03oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003T0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool00P3oool6000003X0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
000i0?ooo``00000503oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo00<0
001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo00P0oooo1P00
000d0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool03P3oool7000002d0oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/9
0?ooo`030000003oool0oooo03@0oooo001E0?ooo`@000002P3oool00`000000oooo0?ooo`0L0?oo
o`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0E0?oo
o`H000009`3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3o
ool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool06`3oool600000240oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000
003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0240oooo1P00000K0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3o
ool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`0W0?ooo`H000005@3oool00`0007l0oooo0?ooo`130?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool006<0oooo0P00000M0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`0]0?ooo`H000003`3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`L0oooo0`00000f0?ooo`00H`3oool00`00
0000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`0c0?ooo`H000002@3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0
oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0>@3oool6000000<0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0
oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo03l0oooo1P0000130?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<0
00000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`07000003`0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool0
0`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo00L0oooo1P00000f0?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
06<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0=0?ooo`H00000<03oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool04`3oool6000002X0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo01T0oooo
1P00000T0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`0O0?ooo`H000007P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`00
8]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`8000007@3oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0U
0?ooo`D000006@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/7
0?ooo`<00000=P3oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0Z0?oo
o`D00000503oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?oo
o`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3o
ool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0;`3oool5000000l0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000
O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo03@0oooo1@00000:0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`0i0?ooo`D000001@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0
oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0?P3oool6000004@0oooo00<0001o0?ooo`3oool0@@3oool3
000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`00
07l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`130?ooo`030000O`000000000000@00000?P3oool00`0007l0oooo0?ooo`110?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0103oool6000003P0oooo00<0001o0?ooo`3o
ool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0
703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo00X0oooo1P00000b0?ooo`030000
O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`8000007@3o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0100oooo1P00000/0?ooo`030000O`3o
ool0oooo0440oooo0`008]/70?ooo`<00000=P3oool006<0oooo00<000000?ooo`3oool0703oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo01H0oooo1P00000V0?ooo`030000O`3oool0
oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo
01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0L0?ooo`H00000803oool00`00
07l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000
oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool08P3oool6000001X0
oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo
00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo02P0oooo
1`00000C0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?oo
o`0_0?ooo`H000003@3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?oo
o`0d0?ooo`00F03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01`0oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0e0?ooo`H000001`3oool00`0007l0oooo0?ooo`11
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00F03oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0k0?oo
o`H0000000<0oooo0000O`3oool0@P3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005@0
oooo1P0000090?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`110?ooo`H00000?`3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005D0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`020?ooo`H00000>@3oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool005D0oooo00@000000?ooo`3oool000002P3oool300000?l0
001oP`0007l5000003@0001o0`008]/60000O`@00000=P3oool005H0oooo00<000000?ooo`000000
2P3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`0=0?ooo`D00000;`3oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool005H0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0B0?ooo`@00000:`3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005L0oooo0P00000:0?ooo`030000003oool0
oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo01H0oooo1@00000V0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E`3oool20000
00X0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool06`3oool500000240oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo001H0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0703oool00`0007l0
oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0803oool6000001/0
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo
00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo02H0oooo
1P00000E0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?oo
o`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`0/0?ooo`H000003`3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<00000
0?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0<P3oool6000000T0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?oo
o`8000007@3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0>03oool6000000<0oooo0`008]/70?ooo`<00000=P3oool006<0oooo00<000000?ooo`3o
ool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0?P3oool500000003000Rf`3oool0oooo00L0oooo00<000000?ooo`3oool0=03oool006<0oooo
00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03@0oooo001S
0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0=03oool006<0ooooo`00003<000003H0oooo003o0?oo
ool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3o
ool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo
o`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo9@3oool60000
00@0oooo0`0000040?ooo`80000000D0oooo0000003oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0`00
00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0oooo0`00003j0?ooo`00
o`3ooolU0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool010000000
oooo0?ooo`0000020?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3o
ool0oooo0000003i0?ooo`00o`3ooolU0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0?/0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`05000000<0oooo100000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool500000?T0oooo
003o0?ooobD0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool00000
00D0oooo1P0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000003i0?ooo`00
o`3ooolU0?ooo`H000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo008000000P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo0?L0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`3oool3000000@0oooo0`0000030?ooo`040000003oool0000000000080oooo0P0000060?ooo`03
0000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`<000000P3oool3
000000050?ooo`000000oooo0?ooo`0000000`3oool300000?X0oooo003o0?ooobD0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?h0oooo003o0?oo
obD0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0?h0oooo003o0?ooobD0oooo1P00000O0?ooo`H000003`3oool300000080oooo00<000000?ooo`3o
ool0oP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo0000\
\>"],
  ImageRangeCache->{{{57.1875, 546.25}, {372, 177}} -> {-3.92318, 4.7361, \
0.0144452, 0.051938}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Michelson Y-arm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TelescopePlot[{zETM - MichelsonAsymmetry/2, 5.0}, {CavityWaist, 
          zCavityWaist - MichelsonAsymmetry/2}, {{ITMFocalLength, 
            zITM - MichelsonAsymmetry/2}, {fLY, zLY}}, kk];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.232143 0.14881 0.2 0.0411537 [
[.08333 -0.0125 -10.0938 -16.375 ]
[.08333 -0.0125 10.0938 0 ]
[.23214 -0.0125 -5.59375 -16.375 ]
[.23214 -0.0125 5.59375 0 ]
[.38095 -0.0125 -5.59375 -16.375 ]
[.38095 -0.0125 5.59375 0 ]
[.52976 -0.0125 -5.59375 -16.375 ]
[.52976 -0.0125 5.59375 0 ]
[.67857 -0.0125 -5.59375 -16.375 ]
[.67857 -0.0125 5.59375 0 ]
[.82738 -0.0125 -5.59375 -16.375 ]
[.82738 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -16.375 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -43.1563 -32.75 ]
[.5 -0.0125 43.1563 -16.375 ]
[-0.0125 .03539 -20.1875 -8.1875 ]
[-0.0125 .03539 0 8.1875 ]
[-0.0125 .11769 -20.1875 -8.1875 ]
[-0.0125 .11769 0 8.1875 ]
[-0.0125 .2 -11.1875 -8.1875 ]
[-0.0125 .2 0 8.1875 ]
[-0.0125 .28231 -11.1875 -8.1875 ]
[-0.0125 .28231 0 8.1875 ]
[-0.0125 .36461 -11.1875 -8.1875 ]
[-0.0125 .36461 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .2 -36.5625 -44.3438 ]
[-0.01875 .2 -20.1875 44.3438 ]
[ 0 .4 .125 0 ]
[.5 .4125 -39 0 ]
[.5 .4125 39 16.375 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .4 L
s
.23214 0 m
.23214 .4 L
s
.38095 0 m
.38095 .4 L
s
.52976 0 m
.52976 .4 L
s
.67857 0 m
.67857 .4 L
s
.82738 0 m
.82738 .4 L
s
0 .03539 m
1 .03539 L
s
0 .11769 m
1 .11769 L
s
0 .2 m
1 .2 L
s
0 .28231 m
1 .28231 L
s
0 .36461 m
1 .36461 L
s
0 g
.08333 0 m
.08333 .00625 L
s
gsave
.08333 -0.0125 -71.0938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.23214 0 m
.23214 .00625 L
s
gsave
.23214 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.52976 0 m
.52976 .00625 L
s
gsave
.52976 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.67857 0 m
.67857 .00625 L
s
gsave
.67857 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.82738 0 m
.82738 .00625 L
s
gsave
.82738 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.17262 0 m
.17262 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.35119 0 m
.35119 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.47024 0 m
.47024 .00375 L
s
.5 0 m
.5 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.64881 0 m
.64881 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76786 0 m
.76786 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94643 0 m
.94643 .00375 L
s
.05357 0 m
.05357 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -104.156 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.438 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.875 16.625 moveto
(@) show
130.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
141.000 16.625 moveto
(D) show
145.313 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03539 m
.00625 .03539 L
s
gsave
-0.0125 .03539 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .11769 m
.00625 .11769 L
s
gsave
-0.0125 .11769 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
gsave
-0.0125 .2 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .28231 m
.00625 .28231 L
s
gsave
-0.0125 .28231 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .36461 m
.00625 .36461 L
s
gsave
-0.0125 .36461 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05596 m
.00375 .05596 L
s
0 .07654 m
.00375 .07654 L
s
0 .09712 m
.00375 .09712 L
s
0 .13827 m
.00375 .13827 L
s
0 .15885 m
.00375 .15885 L
s
0 .17942 m
.00375 .17942 L
s
0 .22058 m
.00375 .22058 L
s
0 .24115 m
.00375 .24115 L
s
0 .26173 m
.00375 .26173 L
s
0 .30288 m
.00375 .30288 L
s
0 .32346 m
.00375 .32346 L
s
0 .34404 m
.00375 .34404 L
s
0 .01481 m
.00375 .01481 L
s
0 .38519 m
.00375 .38519 L
s
.25 Mabswid
0 0 m
0 .4 L
s
gsave
-0.01875 .2 -133.719 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
105.344 12.1875 translate
90 rotate
-105.344 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(spot) show
90.938 16.625 moveto
(size) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.438 16.625 moveto
(@) show
121.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
143.375 16.625 moveto
(D) show
147.688 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .39375 m
.08333 .4 L
s
.23214 .39375 m
.23214 .4 L
s
.38095 .39375 m
.38095 .4 L
s
.52976 .39375 m
.52976 .4 L
s
.67857 .39375 m
.67857 .4 L
s
.82738 .39375 m
.82738 .4 L
s
.97619 .39375 m
.97619 .4 L
s
.125 Mabswid
.1131 .39625 m
.1131 .4 L
s
.14286 .39625 m
.14286 .4 L
s
.17262 .39625 m
.17262 .4 L
s
.20238 .39625 m
.20238 .4 L
s
.2619 .39625 m
.2619 .4 L
s
.29167 .39625 m
.29167 .4 L
s
.32143 .39625 m
.32143 .4 L
s
.35119 .39625 m
.35119 .4 L
s
.41071 .39625 m
.41071 .4 L
s
.44048 .39625 m
.44048 .4 L
s
.47024 .39625 m
.47024 .4 L
s
.5 .39625 m
.5 .4 L
s
.55952 .39625 m
.55952 .4 L
s
.58929 .39625 m
.58929 .4 L
s
.61905 .39625 m
.61905 .4 L
s
.64881 .39625 m
.64881 .4 L
s
.70833 .39625 m
.70833 .4 L
s
.7381 .39625 m
.7381 .4 L
s
.76786 .39625 m
.76786 .4 L
s
.79762 .39625 m
.79762 .4 L
s
.85714 .39625 m
.85714 .4 L
s
.8869 .39625 m
.8869 .4 L
s
.91667 .39625 m
.91667 .4 L
s
.94643 .39625 m
.94643 .4 L
s
.05357 .39625 m
.05357 .4 L
s
.02381 .39625 m
.02381 .4 L
s
.25 Mabswid
0 .4 m
1 .4 L
s
gsave
.5 .4125 -100 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
100.375 16.625 moveto
(Profile) show
137.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .03539 m
1 .03539 L
s
.99375 .11769 m
1 .11769 L
s
.99375 .2 m
1 .2 L
s
.99375 .28231 m
1 .28231 L
s
.99375 .36461 m
1 .36461 L
s
.125 Mabswid
.99625 .05596 m
1 .05596 L
s
.99625 .07654 m
1 .07654 L
s
.99625 .09712 m
1 .09712 L
s
.99625 .13827 m
1 .13827 L
s
.99625 .15885 m
1 .15885 L
s
.99625 .17942 m
1 .17942 L
s
.99625 .22058 m
1 .22058 L
s
.99625 .24115 m
1 .24115 L
s
.99625 .26173 m
1 .26173 L
s
.99625 .30288 m
1 .30288 L
s
.99625 .32346 m
1 .32346 L
s
.99625 .34404 m
1 .34404 L
s
.99625 .01481 m
1 .01481 L
s
.99625 .38519 m
1 .38519 L
s
.25 Mabswid
1 0 m
1 .4 L
s
.977 .121 .023 r
.0075 w
.17262 .16138 m
.17262 .23862 L
s
.19836 .1427 m
.19836 .2573 L
s
0 .133 .859 r
.02381 .16138 m
.02381 .23862 L
s
.97619 .00952 m
.97619 .39048 L
s
0 g
.5 Mabswid
.02381 .23862 m
.04262 .22929 L
.06244 .21972 L
.07216 .21527 L
.0775 .21298 L
.08255 .21099 L
.08542 .20999 L
.08693 .20951 L
.08852 .20904 L
.08987 .20868 L
.09135 .20834 L
.092 .20821 L
.0927 .20808 L
.09396 .20788 L
.09466 .20779 L
.09532 .20772 L
.09603 .20765 L
.0968 .20761 L
.09753 .20758 L
.09822 .20757 L
.0995 .2076 L
.10077 .20768 L
.10194 .20781 L
.10322 .20799 L
.10387 .2081 L
.10458 .20824 L
.10588 .20852 L
.10709 .20882 L
.10982 .2096 L
.11223 .2104 L
.11478 .21134 L
.12409 .21519 L
.145 .22499 L
.18275 .24596 L
.19218 .25281 L
.19447 .25447 L
.19692 .25625 L
.19764 .25678 L
.19832 .25727 L
.1996 .2575 L
.2021 .25791 L
.21298 .25967 L
.22296 .2613 L
.26142 .26764 L
.30234 .27445 L
.34175 .28108 L
.37963 .28748 L
.41997 .29434 L
.4588 .30097 L
.50007 .30804 L
Mistroke
.53983 .31487 L
.57808 .32145 L
.61878 .32847 L
.65796 .33524 L
.69959 .34245 L
.73971 .34939 L
.77832 .35609 L
.81937 .36321 L
.85891 .37008 L
.89693 .37669 L
.93741 .38373 L
.97619 .39048 L
Mfstroke
.02381 .16138 m
.04262 .17071 L
.06244 .18028 L
.07216 .18473 L
.0775 .18702 L
.08255 .18901 L
.08542 .19001 L
.08693 .19049 L
.08852 .19096 L
.08987 .19132 L
.09135 .19166 L
.092 .19179 L
.0927 .19192 L
.09396 .19212 L
.09466 .19221 L
.09532 .19228 L
.09603 .19235 L
.0968 .19239 L
.09753 .19242 L
.09822 .19243 L
.0995 .1924 L
.10077 .19232 L
.10194 .19219 L
.10322 .19201 L
.10387 .1919 L
.10458 .19176 L
.10588 .19148 L
.10709 .19118 L
.10982 .1904 L
.11223 .1896 L
.11478 .18866 L
.12409 .18481 L
.145 .17501 L
.18275 .15404 L
.19218 .14719 L
.19447 .14553 L
.19692 .14375 L
.19764 .14322 L
.19832 .14273 L
.1996 .1425 L
.2021 .14209 L
.21298 .14033 L
.22296 .1387 L
.26142 .13236 L
.30234 .12555 L
.34175 .11892 L
.37963 .11252 L
.41997 .10566 L
.4588 .09903 L
.50007 .09196 L
Mistroke
.53983 .08513 L
.57808 .07855 L
.61878 .07153 L
.65796 .06476 L
.69959 .05755 L
.73971 .05061 L
.77832 .04391 L
.81937 .03679 L
.85891 .02992 L
.89693 .02331 L
.93741 .01627 L
.97619 .00952 L
Mfstroke
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{612.625, 245},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009T0000mB000`400?l00000o`00003oo`3ooooo
0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo;`3oool00`000000oooo0?ooo`0]0?ooo`<0
00003@3oool300000?<0oooo003o0?ooobl0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0?40oooo003o0?ooobl0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?40oooo003o0?ooob40oooo1@000009
0?ooo`040000003oool00000000000@0oooo0`0000040?ooo`<000000`3oool00`000000oooo0?oo
o`0200000080oooo00@000000?ooo`3oool0oooo0`0000030?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob80oooo00<000000?ooo`3o
ool02P3oool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000003
0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3a0?ooo`00o`3ooolR0?ooo`030000003oool0oooo00X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo0?oo
o`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0l@3o
ool00?l0oooo8`3oool010000000oooo0?ooo`3oool7000000030?ooo`000000oooo0080oooo00@0
00000?ooo`3oool000000`3oool010000000oooo0?ooo`3oool3000000<0oooo00@000000?ooo`3o
ool000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob@0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob@0oooo00<000000?ooo`3oool0203o
ool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3a0?ooo`00o`3ooolQ0?ooo`D000002@3oool010000000oooo0000000000040?ooo`<00000103o
ool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`040000003oool0oooo0?ooo`<00000
0`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0080oooo00@000000?ooo`00
000000000P3oool2000000D0oooo00<000000?ooo`3oool0l@3oool00?l0ooooA`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0l@3oool00?l0oooo
A`3oool00`000000oooo0?ooo`0E0?ooo`<000003@3oool300000?<0oooo003o0?oood@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooaP0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3o
oomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool008d0oooo00<000000?ooo`3o
ool0>P3oool4000004<0oooo00<000000?ooo`3oool0?P3oool6000003l0oooo100000130?ooo`03
0000003oool0oooo03l0oooo100000100?ooo`00S@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0m0?ooo`00S@3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0?03o
ool6000004@0oooo00<000000?ooo`3oool0?@3oool00880oooo1`0000040?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0m0?ooo`040000003oool0
oooo000004D0oooo00<000000?ooo`3oool0?@3oool008d0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo03d0oooo00@000000?ooo`3oool00000@03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo002=0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0?P3oool300000440oooo00<000000?ooo`000000@03oool5
00000400oooo002=0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool000000400oooo00<000000?ooo`3oool0@P3oool008/0
oooo00<000000?ooo`000000>`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`000000A@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03l0
oooo0P0000110?ooo`030000003oool0oooo0440oooo002<0?ooo`800000>`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03l0oooo0P0000100?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03l0oooo
0P0000110?ooo`030000003oool0oooo0440oooo002=0?ooo`030000003oool0oooo03X0oooo1000
00130?ooo`030000003oool0oooo03l0oooo100000100?ooo`@00000@`3oool00`000000oooo0?oo
o`0o0?ooo`D00000?`3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0
ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00H`3ooooo00000<`00000=P3oool006<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0400oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo03l0oooo0`0000000`008]/0oooo0?ooo`070?oo
o`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03T0oooo1P000000103oool0
02;K000Rf`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03<0
oooo1P0000070?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000002@0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo02d0oooo
1P00000=0?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo02T0oooo1000
000C0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0T
0?ooo`D000005`3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?oo
o`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0803oool4000001`0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`03
0000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo01/0oooo1@00000P0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`0E0?ooo`H000009@3oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool005P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0S0?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0?0?ooo`H00000:`3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`090?ooo`H00000<@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
05@0oooo1P0000090?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo00<0oooo1P00000g0?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00C03oool700000080oooo00@000000?ooo`3oool000002P3oool30000
0?l0001oN@0007l6000003d0001o0`008]/60000O`@00000=P3oool005D0oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0>P3oool7000000030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo001F0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool08`3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo03@0oooo1P0000070?ooo`030000O`3oool0oooo0400
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001F0?ooo`030000003oool0000000X0oooo
00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo02h0oooo
1P00000=0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
001G0?ooo`8000002P3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0:03oool6000001<0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool005L0oooo0P00000:0?ooo`030000003oool0oooo02<0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0R0?ooo`H000006@3oool00`0007l0oooo0?ooo`10
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00F03oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0L0?oo
o`H000007`3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool05P3oool6000002D0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0100oooo1P00000[0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000
003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`0:0?ooo`H00000<@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000002@0oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`040?ooo`H00000=`3oool00`0007l0oooo0?ooo`100?ooo`<002;K1`3oool3
000003H0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo00000004000003d0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`@0
0000@P3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03/0oooo1@0000020?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0f0?ooo`D000001`3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0<03oool6
000000`0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
02X0oooo1P00000B0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`0T0?ooo`H00000603oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool07P3oool6000001h0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000002@0oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0603oool6000002@0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`100?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool04P3oool6000002X0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`10
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo00`0oooo1P00000`0?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3o
ool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`060?ooo`H00000=P3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000
003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P00000l0?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<0
00000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0?P3oool600000480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0h
0?ooo`H000000`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?oo
o`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0<@3oool7000000T0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`03
0000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo02/0oooo1P00000@0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`0U0?ooo`H000005P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool006<0oooo0P00000T0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`0O0?ooo`H00000703oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`L0oooo0`00000f0?ooo`00H`3oool0
0`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`0I0?ooo`H000008P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
06<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool04`3oool6000002P0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo00d0oooo1P00000^0?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`090?ooo`@00000=03oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0103oool5000003P0oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`00
8]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`8000000P3oool00`000000oooo0?ooo`0A
0?ooo`H000002@3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`04000003d0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo000k0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`0o0?ooo`D00000@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
03/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo03T0oooo1P0000020?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo000k0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0203oool7
000000@0oooo00<000000?ooo`3oool02@3oool3000009d0001o1P00003o0000OaT0001o0`008]/6
0000O`@00000=P3oool003`0oooo00<000000?ooo`3oool00P00000G0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
02d0oooo1P00000>0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo001I0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo02L0oooo1P00000D0?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001I0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0240oooo
1P00000J0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
000k0?ooo`X00000503oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0J0?ooo`L00000803oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool01@000000oooo0?ooo`3o
ool0000001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0D0?ooo`H000009`3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo1000000:0?ooo`030000003oool0
oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0>0?ooo`H00000;@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08`3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo00P0oooo1P00000c0?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`D000008P3oool00`000000
oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool00P3oool6000003T0
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo
0P00000T0?ooo`030000O`3oool0oooo0400oooo1P00000o0?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo
0`008]/70?ooo`<00000=P3oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?oo
o`0a0?ooo`<0nQh50P3oool:000000030?ooo`0007l0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003`0oooo1@00000R0?ooo`030000003oool0
oooo02<0oooo00<0001o0?ooo`3oool0<@3oool00`3j7PD0000000000002000000/0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool08`3oool00`0007l0oooo0?ooo`0a0?ooo`030000003j7PD0nQh500d0oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool08`3oool00`0007l0oooo0?ooo`0_0?ooo`8000000`3j7PD=0?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02<0oooo
00<0001o0?ooo`3oool0;P3oool00`000000oooo0?ooo`030?XN1@d0oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03o
ool500000280oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0/0?ooo`8000000`3o
ool30?XN1@d0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0
oooo02/0oooo00<000000?ooo`3oool00`3oool30?XN1@d0oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0:P3oool00`00
0000oooo0?ooo`040?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000i0?ooo`T000008@3oool00`000000
oooo0?ooo`0S0?ooo`030000O`3oool0oooo02P0oooo0P0000070?ooo`<0nQh53@3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0
oooo000k0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07`3oool2000000L0oooo
0`008]/J0?ooo`030000O`3oool0oooo02D0oooo00<0nQh50000000000002@3oool30?XN1@d0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K1`3oool3000003H0oooo
001S0?ooo`030000003oool0oooo00H0oooo00<002;K0000000000006P3oool00`0007l0oooo0?oo
o`0T0?ooo`8000000P3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0
oooo00H0oooo0`008]/2000001P0oooo00<0001o0?ooo`3oool08P3oool2000000040?ooo`3j7PD0
nQh50?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool01P3oool3
000Rf`80oooo0P00000F0?ooo`030000O`3oool0oooo0200oooo0P0000030?ooo`<0nQh52@3oool3
0?XN1@d0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`060?ooo`<002;K103oool20000
01@0oooo00<0001o0?ooo`3oool07P3oool2000000D0oooo0`3j7PD90?ooo`<0nQh53@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo001S0?ooo`030000003oool0oooo00H0oooo0`008]/60?ooo`8000004P3oool00`0007l0
oooo0?ooo`0L0?ooo`8000001`3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003`0oooo
0P0000020?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01P3oool3000Rf`P0oooo
0P00000@0?ooo`030000O`3oool0oooo01X0oooo0P0000090?ooo`<0nQh52@3oool30?XN1@d0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool01P3oool3000Rf`X0oooo0P00000>0?ooo`030000O`3oool0oooo01T0oooo
00<000000?ooo`3oool02@3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00H0oooo
0`008]/<0?ooo`800000303oool00`0007l0oooo0?ooo`0G0?ooo`800000303oool30?XN1@T0oooo
0`3j7PD=0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool003/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0O0?ooo`8000001`3oool3000Rf`h0oooo0P00000:0?ooo`030000O`3oool0oooo01D0oooo
0P00000>0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`100?ooo`<002;K1`3oool3000003H0oooo000l0?ooo`030000003oool0oooo008000008P3o
ool00`000000oooo0?ooo`060?ooo`<002;K403oool2000000P0oooo00<0001o0?ooo`3oool04`3o
ool200000100oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0
oooo00H0oooo0`008]/B0?ooo`8000001P3oool00`0007l0oooo0?ooo`0A0?ooo`8000004P3oool3
0?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3
000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool01P3oool3000R
fa@0oooo0P0000040?ooo`030000O`3oool0oooo00h0oooo0`00000D0?ooo`<0nQh52@3oool30?XN
1@d0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00>03oool00`000000oooo0?ooo`0700000240oooo00<000000?ooo`3o
ool01P3oool3000RfaH0oooo0P0000020?ooo`030000O`3oool0oooo00/0oooo0`00000G0?ooo`<0
nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`060?ooo`<002;K
603oool4000000X0oooo0P00000J0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E@3o
ool4000000X0oooo00<000000?ooo`3oool01P3oool3000RfaX0oooo00<0001o0?ooo`0000002@00
000L0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo0`008]/J0?ooo`030000O`3oool0oooo02D0oooo0`3j7PD9
0?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/9
0?ooo`030000003oool0oooo03@0oooo000k0?ooo`040000003oool0oooo0?ooo`<000004P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool3
000RfaX0oooo00<0001o0?ooo`3oool09@3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
03/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`<002;K6P3oool0
0`0007l0oooo0?ooo`0U0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool30000
00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo0`0000060000O`<002;K@P0007l30?XN1@T0001o0`3j7PGo0000Of80001o0`008]/60000
O`@00000=P3oool003/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`<0
02;K6P3oool00`0007l0oooo0?ooo`0U0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
E03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool3000RfaX0oooo00<0001o0?ooo`3oool09@3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool005@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00H0oooo0`008]/J0?ooo`040000O`3oool0oooo0?ooo`L000007@3oool30?XN1@T0oooo
0`3j7PD=0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool003`0oooo1@00000C0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`<002;K6P3oool0100007l000000000
000000060?ooo`@000006P3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0A0?ooo`@000002P3oool00`000000oooo
0?ooo`060?ooo`<002;K6@3oool2000000d0oooo00<000000?ooo`3oool05`3oool30?XN1@T0oooo
0`3j7PD=0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool003/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00H0oooo0`008]/G0?ooo`80000000<0oooo0000O`3oool0
3@3oool2000001L0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`<002;K
503oool3000000<0oooo00<0001o0?ooo`3oool03P3oool3000001@0oooo0`3j7PD90?ooo`<0nQh5
3@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000
003oool0oooo03@0oooo000l0?ooo`<0000000<0oooo0000003oool08@3oool00`000000oooo0?oo
o`060?ooo`<002;K4P3oool2000000H0oooo00<0001o0?ooo`3oool04@3oool200000180oooo0`3j
7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`00
8]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`8000001`3oool3000Rf`l0oooo0`000008
0?ooo`030000O`3oool0oooo01<0oooo0`00000?0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K1`3oool3000003H0oooo001S0?oo
o`030000003oool0oooo00H0oooo0`008]/=0?ooo`8000002`3oool00`0007l0oooo0?ooo`0F0?oo
o`8000003@3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3o
ool01P3oool3000Rf`/0oooo0P00000=0?ooo`030000O`3oool0oooo01P0oooo0P00000;0?ooo`<0
nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`060?ooo`<002;K
2@3oool2000000l0oooo00<0001o0?ooo`3oool06P3oool2000000T0oooo0`3j7PD90?ooo`<0nQh5
3@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000
003oool0oooo03@0oooo000i0?ooo``000007P3oool00`000000oooo0?ooo`060?ooo`<002;K1P3o
ool300000140oooo00<0001o0?ooo`3oool0703oool2000000L0oooo0`3j7PD90?ooo`<0nQh53@3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo000i0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`060?ooo`<002;K103oool2000001@0oooo00<0001o0?ooo`3oool07P3oool0
0`000000oooo0?ooo`040?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool3000R
f`80oooo0P00000F0?ooo`030000O`3oool0oooo01l0oooo0P0000040?ooo`<0nQh52@3oool30?XN
1@d0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`060?ooo`<002;K0P00000H0?ooo`03
0000O`3oool0oooo0240oooo0P0000020?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
H`3oool00`000000oooo0?ooo`060?ooo`03000Rf`000000000001X0oooo00<0001o0?ooo`3oool0
8`3oool2000000<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool700000240oooo00<0
00000?ooo`3oool01P3oool3000RfaX0oooo00<0001o0?ooo`3oool09@3oool00`000000nQh50?XN
1@090?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`00
8]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`030000003oool0oooo02@0oooo0P00000T
0?ooo`030000O`3oool0oooo02H0oooo0P0000090?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0400oooo0`008]/70?ooo`<00000=P3oool003/0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo02P0oooo0P0000070?oo
o`<0nQh53@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?oo
o`030000003oool0oooo03@0oooo000k0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool08`3oool00`0007l0oooo0?ooo`0Z0?ooo`030000003oool0oooo00@0oooo0`3j7PD=0?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool003`0oooo1P00000Q0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0
:`3oool2000000@0oooo0`3j7PD=0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo02d0oooo0P0000020?ooo`<0nQh53@3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo000k0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool08`3oool0
0`0007l0oooo0?ooo`0_0?ooo`030000003oool0nQh50080nQh53@3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0`0?oo
o`8000000P3j7PD=0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool003`0oooo1P00000Q0?ooo`030000003oool0oooo02<0
oooo00<0001o0?ooo`3oool0<@3oool5000000/0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo
0?ooo`0S0?ooo`030000O`3oool0oooo0340oooo0`3j7PD20?ooo`D000001P3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
001S0?ooo`800000903oool00`0007l0oooo0?ooo`0k0?ooo`D0000000<0oooo0000O`3oool0@P3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`100?ooo`<002;K1`3oool3000003H0oooo000k0?ooo`L000008@3oool0
0`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0400oooo1P00000o0?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0080oooo1P00000i0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo000k0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool08`3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo00P0oooo1P00000c0?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00h0oooo
1P00000]0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
000l0?ooo`H000008@3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0503oool6000002L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool05P3oool6000000T0oooo00<00000
0?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo01X0oooo1P00000Q
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0803oool6000001/0oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`0V0?ooo`H000005@3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool6000001D0oooo00<000000?ooo`3oool0
2@3oool3000009H0001o1P00003o0000Ob00001o0`008]/60000O`@00000=P3oool005P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0<P3oool6000000T0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool005T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0S
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0>03oool6000000<0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03h0oooo1P0000110?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`06000003/0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000i0?ooo``000003`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3oool6000003D0oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo001E0?ooo`@000002P3oool00`000000oooo0?oo
o`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`0<0?ooo`H00000;`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<00000
0?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool04P3oool6000002T0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?oo
o`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo01P0oooo1P00000S0?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`0N0?ooo`L00000703oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool006<0oooo0P00000T0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`0U0?ooo`H000005P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`L0oooo0`00000f0?ooo`00H`3o
ool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`0[0?ooo`H00000403oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0<@3oool6000000X0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo03L0oooo1P0000040?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0m0?ooo`H00000@`3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0
oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`0000001@00000m0?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`050?ooo`H00000=`3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool02`3oool6
00000340oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0140oooo1P00000[0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool006<0oooo0P00000T0?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo01L0
oooo1000000W0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`L0
oooo0`00000f0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo01/0oooo
1@00000R0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`0P0?ooo`@000007P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`00
8]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0903oool5000001T0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`10
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo02T0oooo1P00000C0?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3o
ool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`0_0?ooo`H000003@3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000
003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0=@3oool7000000H0oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3o
ool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03`0oooo1P0000000`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S
0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool6000003h0oooo00<0001o
0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?oo
o`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo00<0oooo1`00000g0?oo
o`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`80
0000903oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo00X0oooo1P00000a0?ooo`03
0000O`3oool0oooo0400oooo0`008]/70?ooo`<00000=P3oool006<0oooo00<000000?ooo`3oool0
8`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0100oooo1P00000[0?ooo`030000
O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003o
ool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0F0?ooo`H000009@3o
ool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool0
0`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0703oool6
000001l0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
06<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0280oooo1P00000I0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`0X0?ooo`D00000503oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00F03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02<0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0]0?ooo`D000003`3oool00`0007l0oooo
0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00F03oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`0b0?ooo`@000002`3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?oo
o`0d0?ooo`00E03oool6000000T0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo03H0oooo1@0000060?ooo`030000O`3oool0oooo0400oooo0`008]/9
0?ooo`030000003oool0oooo03@0oooo001E0?ooo`040000003oool0oooo000000X0oooo0`00003o
0000Og<0001o1@0000140000O`<002;K1P0007l4000003H0oooo001E0?ooo`040000003oool0oooo
000000X0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0400oooo1P00000n0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00EP3oool00`00
0000oooo0000000:0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0080oooo1P00000h0?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00EP3oool00`000000oooo0000000:0?ooo`030000003oool0oooo02<0
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00P0
oooo1P00000b0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E`3oool2000000X0oooo
00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool03P3oool6000002`0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
001G0?ooo`8000002P3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0D0?ooo`H000009P3oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool005P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0S
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0J
0?ooo`H00000803oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?oo
o`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0803oool6000001X0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`03
0000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo02H0oooo1P00000D0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`0/0?ooo`H000003P3oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool006<0oooo0P00000T0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`0b0?ooo`H00000203oool3000Rf`L0oooo0`00000f0?ooo`00H`3oool0
0`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`0h0?ooo`H000000P3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
06<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0?P3oool400000003000Rf`3oool0oooo00L0oooo00<000000?oo
o`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=03o
ool006<0ooooo`00003<000003H0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00
o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?oo
ofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o
0?ooool0ooooIP3oool00?l0oooo9@3oool6000000@0oooo0`0000040?ooo`80000000D0oooo0000
003oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo0`0000030?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool0oooo0`00003j0?ooo`00o`3ooolU0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`06
0?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000003i0?ooo`00o`3ooolU0?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000001P3oool01@000000oooo0?ooo`3oool0
00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?/0oooo003o0?ooobD0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05000000<0oooo100000020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00H0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool500000?T0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
00000`3oool01@000000oooo0?ooo`3oool0000000D0oooo1P0000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00D000000?ooo`3oool0oooo0000003i0?ooo`00o`3ooolU0?ooo`H000000`3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000P3oool20000
0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
008000000P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0?L0oooo003o0?ooobD0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`3oool3000000@0oooo0`0000030?ooo`040000
003oool0000000000080oooo0P0000060?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3o
ool000000?ooo`0000020?ooo`<000000P3oool3000000050?ooo`000000oooo0?ooo`0000000`3o
ool300000?X0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0?h0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0?h0oooo003o0?ooobD0oooo1P00000O0?ooo`H0
00003`3oool300000080oooo00<000000?ooo`3oool0oP3oool00?l0ooooo`3ooomV0?ooo`00o`3o
oooo0?ooofH0oooo0000\
\>"],
  ImageRangeCache->{{{57.1875, 546.25}, {676.188, 481.188}} -> {-4.06481, \
25.0147, 0.0146745, 0.0530623}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Michelson X-arm with Lens Position of Y-Arm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TelescopePlot[{zETM + MichelsonAsymmetry/2, 5.0}, {CavityWaist, 
          zCavityWaist + MichelsonAsymmetry/2}, {{ITMFocalLength, 
            zITM + MichelsonAsymmetry/2}, {fLY, zLY}}, kk];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.220333 0.151172 0.2 0.0299056 [
[.06916 -0.0125 -10.0938 -16.375 ]
[.06916 -0.0125 10.0938 0 ]
[.22033 -0.0125 -5.59375 -16.375 ]
[.22033 -0.0125 5.59375 0 ]
[.3715 -0.0125 -5.59375 -16.375 ]
[.3715 -0.0125 5.59375 0 ]
[.52268 -0.0125 -5.59375 -16.375 ]
[.52268 -0.0125 5.59375 0 ]
[.67385 -0.0125 -5.59375 -16.375 ]
[.67385 -0.0125 5.59375 0 ]
[.82502 -0.0125 -5.59375 -16.375 ]
[.82502 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -16.375 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -43.1563 -32.75 ]
[.5 -0.0125 43.1563 -16.375 ]
[-0.0125 .02057 -20.1875 -8.1875 ]
[-0.0125 .02057 0 8.1875 ]
[-0.0125 .08038 -20.1875 -8.1875 ]
[-0.0125 .08038 0 8.1875 ]
[-0.0125 .14019 -20.1875 -8.1875 ]
[-0.0125 .14019 0 8.1875 ]
[-0.0125 .2 -11.1875 -8.1875 ]
[-0.0125 .2 0 8.1875 ]
[-0.0125 .25981 -11.1875 -8.1875 ]
[-0.0125 .25981 0 8.1875 ]
[-0.0125 .31962 -11.1875 -8.1875 ]
[-0.0125 .31962 0 8.1875 ]
[-0.0125 .37943 -11.1875 -8.1875 ]
[-0.0125 .37943 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .2 -36.5625 -44.3438 ]
[-0.01875 .2 -20.1875 44.3438 ]
[ 0 .4 .125 0 ]
[.5 .4125 -39 0 ]
[.5 .4125 39 16.375 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.06916 0 m
.06916 .4 L
s
.22033 0 m
.22033 .4 L
s
.3715 0 m
.3715 .4 L
s
.52268 0 m
.52268 .4 L
s
.67385 0 m
.67385 .4 L
s
.82502 0 m
.82502 .4 L
s
0 .02057 m
1 .02057 L
s
0 .08038 m
1 .08038 L
s
0 .14019 m
1 .14019 L
s
0 .2 m
1 .2 L
s
0 .25981 m
1 .25981 L
s
0 .31962 m
1 .31962 L
s
0 .37943 m
1 .37943 L
s
0 g
.06916 0 m
.06916 .00625 L
s
gsave
.06916 -0.0125 -71.0938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22033 0 m
.22033 .00625 L
s
gsave
.22033 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.3715 0 m
.3715 .00625 L
s
gsave
.3715 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.52268 0 m
.52268 .00625 L
s
gsave
.52268 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.67385 0 m
.67385 .00625 L
s
gsave
.67385 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.82502 0 m
.82502 .00625 L
s
gsave
.82502 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.0994 0 m
.0994 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.15986 0 m
.15986 .00375 L
s
.1901 0 m
.1901 .00375 L
s
.25057 0 m
.25057 .00375 L
s
.2808 0 m
.2808 .00375 L
s
.31104 0 m
.31104 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.43197 0 m
.43197 .00375 L
s
.46221 0 m
.46221 .00375 L
s
.49244 0 m
.49244 .00375 L
s
.55291 0 m
.55291 .00375 L
s
.58314 0 m
.58314 .00375 L
s
.61338 0 m
.61338 .00375 L
s
.64361 0 m
.64361 .00375 L
s
.70408 0 m
.70408 .00375 L
s
.73432 0 m
.73432 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79478 0 m
.79478 .00375 L
s
.85525 0 m
.85525 .00375 L
s
.88549 0 m
.88549 .00375 L
s
.91572 0 m
.91572 .00375 L
s
.94596 0 m
.94596 .00375 L
s
.03893 0 m
.03893 .00375 L
s
.00869 0 m
.00869 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -104.156 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.438 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.875 16.625 moveto
(@) show
130.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
141.000 16.625 moveto
(D) show
145.313 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02057 m
.00625 .02057 L
s
gsave
-0.0125 .02057 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
0 .08038 m
.00625 .08038 L
s
gsave
-0.0125 .08038 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .14019 m
.00625 .14019 L
s
gsave
-0.0125 .14019 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
gsave
-0.0125 .2 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .25981 m
.00625 .25981 L
s
gsave
-0.0125 .25981 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .31962 m
.00625 .31962 L
s
gsave
-0.0125 .31962 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .37943 m
.00625 .37943 L
s
gsave
-0.0125 .37943 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03552 m
.00375 .03552 L
s
0 .05047 m
.00375 .05047 L
s
0 .06542 m
.00375 .06542 L
s
0 .09533 m
.00375 .09533 L
s
0 .11028 m
.00375 .11028 L
s
0 .12524 m
.00375 .12524 L
s
0 .15514 m
.00375 .15514 L
s
0 .17009 m
.00375 .17009 L
s
0 .18505 m
.00375 .18505 L
s
0 .21495 m
.00375 .21495 L
s
0 .22991 m
.00375 .22991 L
s
0 .24486 m
.00375 .24486 L
s
0 .27476 m
.00375 .27476 L
s
0 .28972 m
.00375 .28972 L
s
0 .30467 m
.00375 .30467 L
s
0 .33458 m
.00375 .33458 L
s
0 .34953 m
.00375 .34953 L
s
0 .36448 m
.00375 .36448 L
s
0 .00561 m
.00375 .00561 L
s
0 .39439 m
.00375 .39439 L
s
.25 Mabswid
0 0 m
0 .4 L
s
gsave
-0.01875 .2 -133.719 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
105.344 12.1875 translate
90 rotate
-105.344 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(spot) show
90.938 16.625 moveto
(size) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.438 16.625 moveto
(@) show
121.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
143.375 16.625 moveto
(D) show
147.688 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.06916 .39375 m
.06916 .4 L
s
.22033 .39375 m
.22033 .4 L
s
.3715 .39375 m
.3715 .4 L
s
.52268 .39375 m
.52268 .4 L
s
.67385 .39375 m
.67385 .4 L
s
.82502 .39375 m
.82502 .4 L
s
.97619 .39375 m
.97619 .4 L
s
.125 Mabswid
.0994 .39625 m
.0994 .4 L
s
.12963 .39625 m
.12963 .4 L
s
.15986 .39625 m
.15986 .4 L
s
.1901 .39625 m
.1901 .4 L
s
.25057 .39625 m
.25057 .4 L
s
.2808 .39625 m
.2808 .4 L
s
.31104 .39625 m
.31104 .4 L
s
.34127 .39625 m
.34127 .4 L
s
.40174 .39625 m
.40174 .4 L
s
.43197 .39625 m
.43197 .4 L
s
.46221 .39625 m
.46221 .4 L
s
.49244 .39625 m
.49244 .4 L
s
.55291 .39625 m
.55291 .4 L
s
.58314 .39625 m
.58314 .4 L
s
.61338 .39625 m
.61338 .4 L
s
.64361 .39625 m
.64361 .4 L
s
.70408 .39625 m
.70408 .4 L
s
.73432 .39625 m
.73432 .4 L
s
.76455 .39625 m
.76455 .4 L
s
.79478 .39625 m
.79478 .4 L
s
.85525 .39625 m
.85525 .4 L
s
.88549 .39625 m
.88549 .4 L
s
.91572 .39625 m
.91572 .4 L
s
.94596 .39625 m
.94596 .4 L
s
.03893 .39625 m
.03893 .4 L
s
.00869 .39625 m
.00869 .4 L
s
.25 Mabswid
0 .4 m
1 .4 L
s
gsave
.5 .4125 -100 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
100.375 16.625 moveto
(Profile) show
137.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .02057 m
1 .02057 L
s
.99375 .08038 m
1 .08038 L
s
.99375 .14019 m
1 .14019 L
s
.99375 .2 m
1 .2 L
s
.99375 .25981 m
1 .25981 L
s
.99375 .31962 m
1 .31962 L
s
.99375 .37943 m
1 .37943 L
s
.125 Mabswid
.99625 .03552 m
1 .03552 L
s
.99625 .05047 m
1 .05047 L
s
.99625 .06542 m
1 .06542 L
s
.99625 .09533 m
1 .09533 L
s
.99625 .11028 m
1 .11028 L
s
.99625 .12524 m
1 .12524 L
s
.99625 .15514 m
1 .15514 L
s
.99625 .17009 m
1 .17009 L
s
.99625 .18505 m
1 .18505 L
s
.99625 .21495 m
1 .21495 L
s
.99625 .22991 m
1 .22991 L
s
.99625 .24486 m
1 .24486 L
s
.99625 .27476 m
1 .27476 L
s
.99625 .28972 m
1 .28972 L
s
.99625 .30467 m
1 .30467 L
s
.99625 .33458 m
1 .33458 L
s
.99625 .34953 m
1 .34953 L
s
.99625 .36448 m
1 .36448 L
s
.99625 .00561 m
1 .00561 L
s
.99625 .39439 m
1 .39439 L
s
.25 Mabswid
1 0 m
1 .4 L
s
.977 .121 .023 r
.0075 w
.17498 .17194 m
.17498 .22806 L
s
.18602 .16622 m
.18602 .23378 L
s
0 .133 .859 r
.02381 .17194 m
.02381 .22806 L
s
.97619 .00952 m
.97619 .39048 L
s
0 g
.5 Mabswid
.02381 .22806 m
.04262 .22139 L
.06244 .21453 L
.07216 .21134 L
.0775 .20969 L
.08255 .20824 L
.08542 .2075 L
.08693 .20713 L
.08852 .20678 L
.08987 .20651 L
.09135 .20623 L
.0927 .20602 L
.09396 .20585 L
.09461 .20577 L
.09533 .2057 L
.09663 .20559 L
.0979 .20553 L
.09907 .2055 L
.09979 .20551 L
.10047 .20552 L
.10174 .20557 L
.10245 .20561 L
.1031 .20567 L
.10382 .20573 L
.10458 .20582 L
.1058 .20598 L
.10713 .20618 L
.10838 .2064 L
.10954 .20663 L
.11406 .20767 L
.11898 .20901 L
.12422 .21058 L
.14255 .21665 L
.16225 .22353 L
.1803 .23082 L
.18266 .23204 L
.18396 .23272 L
.18518 .23335 L
.18633 .23384 L
.18756 .23408 L
.18973 .23449 L
.19447 .2354 L
.19965 .23639 L
.22051 .24042 L
.26142 .24839 L
.30083 .25611 L
.33871 .26358 L
.37905 .27155 L
.41788 .27925 L
.45915 .28744 L
Mistroke
.49892 .29534 L
.53716 .30294 L
.57786 .31104 L
.61704 .31884 L
.65867 .32714 L
.69879 .33513 L
.7374 .34283 L
.77845 .35102 L
.81799 .35891 L
.85602 .36649 L
.89649 .37457 L
.93545 .38234 L
.97619 .39048 L
Mfstroke
.02381 .17194 m
.04262 .17861 L
.06244 .18547 L
.07216 .18866 L
.0775 .19031 L
.08255 .19176 L
.08542 .1925 L
.08693 .19287 L
.08852 .19322 L
.08987 .19349 L
.09135 .19377 L
.0927 .19398 L
.09396 .19415 L
.09461 .19423 L
.09533 .1943 L
.09663 .19441 L
.0979 .19447 L
.09907 .1945 L
.09979 .19449 L
.10047 .19448 L
.10174 .19443 L
.10245 .19439 L
.1031 .19433 L
.10382 .19427 L
.10458 .19418 L
.1058 .19402 L
.10713 .19382 L
.10838 .1936 L
.10954 .19337 L
.11406 .19233 L
.11898 .19099 L
.12422 .18942 L
.14255 .18335 L
.16225 .17647 L
.1803 .16918 L
.18266 .16796 L
.18396 .16728 L
.18518 .16665 L
.18633 .16616 L
.18756 .16592 L
.18973 .16551 L
.19447 .1646 L
.19965 .16361 L
.22051 .15958 L
.26142 .15161 L
.30083 .14389 L
.33871 .13642 L
.37905 .12845 L
.41788 .12075 L
.45915 .11256 L
Mistroke
.49892 .10466 L
.53716 .09706 L
.57786 .08896 L
.61704 .08116 L
.65867 .07286 L
.69879 .06487 L
.7374 .05717 L
.77845 .04898 L
.81799 .04109 L
.85602 .03351 L
.89649 .02543 L
.93545 .01766 L
.97619 .00952 L
Mfstroke
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{612.625, 245},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009T0000mB000`400?l00000o`00003oo`3ooooo
0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo;`3oool00`000000oooo0?ooo`0]0?ooo`<0
00003@3oool300000?<0oooo003o0?ooobl0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0?40oooo003o0?ooobl0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?40oooo003o0?ooob40oooo1@000009
0?ooo`040000003oool00000000000@0oooo0`0000040?ooo`<000000`3oool00`000000oooo0?oo
o`0200000080oooo00@000000?ooo`3oool0oooo0`0000030?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob80oooo00<000000?ooo`3o
ool02P3oool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000003
0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3a0?ooo`00o`3ooolR0?ooo`030000003oool0oooo00X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo0?oo
o`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0l@3o
ool00?l0oooo8`3oool010000000oooo0?ooo`3oool7000000030?ooo`000000oooo0080oooo00@0
00000?ooo`3oool000000`3oool010000000oooo0?ooo`3oool3000000<0oooo00@000000?ooo`3o
ool000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob@0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob@0oooo00<000000?ooo`3oool0203o
ool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3a0?ooo`00o`3ooolQ0?ooo`D000002@3oool010000000oooo0000000000040?ooo`<00000103o
ool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`040000003oool0oooo0?ooo`<00000
0`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0080oooo00@000000?ooo`00
000000000P3oool2000000D0oooo00<000000?ooo`3oool0l@3oool00?l0ooooA`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0l@3oool00?l0oooo
A`3oool00`000000oooo0?ooo`0E0?ooo`<000003@3oool300000?<0oooo003o0?oood@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooaP0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3o
oomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool008H0oooo00<000000?ooo`3o
ool0?03oool4000004<0oooo00<000000?ooo`3oool0@03oool600000400oooo100000140?ooo`03
0000003oool0oooo0400oooo100000100?ooo`00QP3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0m0?ooo`00QP3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0?@3o
ool6000004D0oooo00<000000?ooo`3oool0?@3oool007/0oooo1`0000040?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0n0?ooo`040000003oool0
oooo000004H0oooo00<000000?ooo`3oool0?@3oool008H0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo03h0oooo00@000000?ooo`3oool00000@@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo00260?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool0?`3oool300000480oooo00<000000?ooo`000000@@3oool5
00000400oooo00260?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool000000440oooo00<000000?ooo`3oool0@P3oool008@0
oooo00<000000?ooo`000000?@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`000000A`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0400
oooo0P0000120?ooo`030000003oool0oooo0440oooo00250?ooo`800000?@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03l0oooo0P0000120?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo
0P0000120?ooo`030000003oool0oooo0440oooo00260?ooo`030000003oool0oooo03`0oooo1000
00130?ooo`030000003oool0oooo0440oooo100000110?ooo`@00000A03oool00`000000oooo0?oo
o`100?ooo`D00000?`3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0
ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00H`3ooooo00000<`00000=P3oool006<0oooo00D000000?ooo`3oool0
oooo0000000<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0d0?ooo`00H`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03@0oooo001S0?ooo`800000
7@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
@@3oool3000Rf`L0oooo0`00000f0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`100?ooo`<0000000<0
02;K0?ooo`3oool01`3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L
0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0k
0?ooo`D0000000@0oooo000Rf`008]/002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E@3oool4
000000X0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0=`3oool4000000H0oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`0b0?ooo`D000002P3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01`0
oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo02d0
oooo1@00000?0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00C03oool7000000030?oo
o`000000oooo00<0oooo00<000000?ooo`3oool01`3oool300000?l0001oY00007l4000001@0001o
0`008]/60000O`@00000=P3oool005@0oooo0P0000030?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool09@3oool4000001P0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001D
0?ooo`030000003oool00000008000002P3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0
oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0Q0?ooo`@00000703oool3
000Rf`T0oooo00<000000?ooo`3oool0=03oool005@0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`0K0?ooo`H00000803oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0E0?ooo`H000009P3oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool005@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo00l0oooo1P00000/0?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00E@3oool4000000X0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool02@3oool600000380oooo0`00
8]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`8000007@3oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool01@3oool4000003P0oooo0`008]/7
0?ooo`<00000=P3oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?oo
o`030000O`3oool0oooo0480oooo00@0001o0?ooo`3oool0oooo1000000l0?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0@P3oool400000400oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`0m0?ooo`D0000000<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000
O`3oool0oooo03L0oooo1P0000050?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000
003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3o
ool00`0007l0oooo0?ooo`0a0?ooo`H000002`3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0
oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo04<0oooo00<0001o0?ooo`3oool0:`3oool600000140oooo00<0001o0?ooo`3oool0@@3oool3
000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo0P00000M0?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool09P3oool5000001L0oooo00<0001o0?ooo`3oool0@@3oool3000R
f`L0oooo0`00000f0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool08P3oool4000001`0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo
0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`130?ooo`030000O`3oool0oooo01d0oooo1@00000P0?ooo`030000O`3oool0oooo0440oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0
001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0H0?ooo`D000009@3oool00`0007l0oooo0?oo
o`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L
0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0503oool4000002X0oooo00<0001o
0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?oo
o`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo00l0oooo1@00000^0?oo
o`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`03
0000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0;0?ooo`@0
0000<`3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
H`3oool2000001d0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`060?ooo`D00000
=`3oool00`0007l0oooo0?ooo`110?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000003o
ool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`06000003`0oooo00<0
001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<00000
0?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`100?ooo`H00000@P3oool00`0007l0oooo0?ooo`11
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00F03oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0>P3oool6000000<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00F03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3o
ool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0=@3oool5000000T0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E03oool6000000T0oooo00<000000?ooo`3oool0
703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`0`0?ooo`D000003P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001<0?ooo`L000000P3o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0
@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
:`3oool5000001<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00E@3oool010000000oooo0?ooo`00000:0?ooo`<00000
o`0007lF0000O`D00000X@0007l3000Rf`H0001o1000000f0?ooo`00EP3oool00`000000oooo0000
000:0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool08P3oool4000001d0oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?oo
o`0d0?ooo`00EP3oool00`000000oooo0000000:0?ooo`030000003oool0oooo01`0oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool07P3oool400000240oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E`3oool2000000X0oooo00<000000?oo
o`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`0J0?ooo`@000009@3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001G0?ooo`80
00002P3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo01@0oooo1P00000Y0?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool005P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`030000
O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo00h0oooo1P00000_0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`080?ooo`H00000=@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`8000007@3oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`020?ooo`H00000>`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0440oooo0`008]/70?ooo`<00000=P3oool006<0oooo00<000000?ooo`3oool0703oool00`00
07l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l000000000000200000440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0n0?ooo`D0
0000A@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`03
0000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0
@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo03X0oooo100000040?ooo`030000
O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0e0?ooo`D00000203o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0<@3oool4
000000d0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo
01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
02`0oooo1@00000A0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool200000080
oooo00<000000?ooo`3oool0803oool2000001d0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo02P0oooo1000000F0?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K1`3oool3000003H0
oooo000k0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`0R0?ooo`H000006P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01`0
oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo01`0
oooo1P00000P0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0703oool00`0007l0
oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool05P3oool6000002H0
oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`030000003oool0oooo00800000
8P3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`0@0?ooo`H00000;03oool00`0007l0oooo0?ooo`130?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0303oool400000380oooo00<0001o0?ooo`3oool0@`3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo001S0?ooo`8000007@3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool01`3oool5000003H0oooo00<0001o0?ooo`3oool0@`3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/70?ooo`<00000=P3oool0
03/0oooo2P00000N0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo00<0oooo1000000k0?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00?03oool01@000000oooo0?ooo`3oool000000280oooo00<000000?oo
o`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0000
000000000`00000o0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0703oool00`0007l0
oooo0?ooo`130?ooo`030000O`3oool0oooo03l0oooo100000140?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo
1P0000090?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`0j0?ooo`D000000`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00?03oool5000001@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0=P3oool4000000P0oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005H0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o
0?ooo`3oool0<@3oool5000000`0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<00000
0?ooo`3oool0=03oool004`0oooo1`0000040?ooo`030000003oool0oooo00T0oooo0`00002@0000
O`H00000o`0007lV0000O`<002;K1P0007l4000003H0oooo000l0?ooo`D000005`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`0U0?ooo`H000005`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo
00<0001o0?ooo`3oool07`3oool6000001d0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo01T0oooo1P00000S0?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`00
8]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0C0?ooo`H00000:@3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool5000001<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`0=0?ooo`H00000;`3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E@3oool4000000X0oooo00<000000?ooo`3o
ool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo00T0oooo1000000e0?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`030000
003oool0oooo02D0oooo0P00000M0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
103oool5000003T0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`L0oooo0`00000f0?ooo`00>@3o
ool900000240oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3o
ool0oooo00@00000?P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?oo
o`0d0?ooo`00>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0703oool00`0007l0oooo0?ooo`110?ooo`D00000@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?oo
o`030000O`3oool0oooo03`0oooo1@0000020?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3o
ool0703oool00`0007l0oooo0?ooo`0b0?ooo`<0nQh50P3oool5000000L0oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo0380oooo1@00000<0?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`0a0?ooo`8000000P3j
7PD>0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool006<0oooo0P0000070?ooo`<002;K4`3oool00`0007l0oooo0?ooo`0]
0?ooo`80nQh50P000000103oool0nQh50?XN1@3j7PD>0?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@@3oool3000Rf`L0oooo0`00000f0?ooo`00?03oool200000080oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`060?ooo`03000Rf`000000000001<0oooo00<0001o
0?ooo`3oool0;@3oool2000000030?XN1@3oool0oooo00<0nQh53P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`06
0?ooo`<002;K0`00000@0?ooo`030000O`3oool0oooo02X0oooo0`0000030?XN1@80oooo0`3j7PD>
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<00000
0?ooo`3oool0=03oool003/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00H0oooo0`008]/30?ooo`<000003@3oool00`0007l0oooo0?ooo`0W
0?ooo`<000000`3oool30?XN1@80oooo0`3j7PD>0?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00H0oooo0`008]/6
0?ooo`<000002P3oool00`0007l0oooo0?ooo`0T0?ooo`<000001P3oool30?XN1@80oooo0`3j7PD>
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<00000
0?ooo`3oool0=03oool003`0oooo00<000000?ooo`3oool00P00000R0?ooo`030000003oool0oooo
00H0oooo0`008]/90?ooo`<000001`3oool00`0007l0oooo0?ooo`0Q0?ooo`<000002@3oool30?XN
1@80oooo0`3j7PD>0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool01P3oool3000Rf``0
oooo0`0000040?ooo`030000O`3oool0oooo01h0oooo0`00000<0?ooo`<0nQh50P3oool30?XN1@h0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00H`3oool2000000L0oooo0`008]/?0?ooo`@0000000<0001o0?ooo`3oool0
703oool2000000l0oooo0`3j7PD20?ooo`<0nQh53P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo0`008]/70?ooo`<00000=P3oool003P0oooo00<000000?ooo`3oool01`00
000Q0?ooo`030000003oool0oooo00H0oooo0`008]/C0?ooo`<000006@3oool300000140oooo0`3j
7PD20?ooo`<0nQh53P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`00
8]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo00H0oooo0`008]/C
0?ooo`030000O`3oool0oooo00800000503oool3000001@0oooo0`3j7PD20?ooo`<0nQh53P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001E0?ooo`@000002P3oool00`000000oooo0?ooo`060?ooo`<002;K4`3oool00`00
07l0oooo0?ooo`020?ooo`@00000303oool4000001L0oooo0`3j7PD20?ooo`<0nQh53P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo000k0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool3000Rfa<0
oooo00<0001o0?ooo`3oool01P3oool<000001/0oooo0`3j7PD20?ooo`<0nQh53P3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0
oooo000k0?ooo`040000003oool0oooo0?ooo`<000004P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool3000Rfa<0oooo00<0001o0?ooo`3o
ool0;@3oool30?XN1@80oooo0`3j7PD>0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`<002;K4`3oool00`0007l0oooo0?ooo`0]0?ooo`<0
nQh50P3oool30?XN1@h0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool3000000<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo0`0000060000O`<002;K
@`0007l30?XN1@80001o0`3j7PGo0000OfP0001o0`008]/60000O`@00000=P3oool003/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`<002;K4`3oool00`0007l0oooo0?oo
o`0]0?ooo`<0nQh50P3oool30?XN1@h0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool3000Rfa<0oooo00<0001o
0?ooo`3oool0203oool7000001h0oooo0`3j7PD20?ooo`<0nQh53P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001D0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`<002;K4`3oool00`0007l0oooo0?ooo`030?ooo`D000001`3oool4000001X0oooo0`3j7PD20?oo
o`<0nQh53P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?oo
o`030000003oool0oooo03@0oooo000l0?ooo`D000004`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool3000Rfa<0oooo00@0001o0?ooo`3o
ool0oooo0P00000@0?ooo`<000005`3oool30?XN1@80oooo0`3j7PD>0?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0A0?ooo`@000002P3oool00`00
0000oooo0?ooo`060?ooo`<002;K4`3oool4000001D0oooo0`00000D0?ooo`<0nQh50P3oool30?XN
1@h0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool01P3oool3000Rf`l0oooo100000000`0007l0oooo0?ooo`0I0?oo
o`@00000403oool30?XN1@80oooo0`3j7PD>0?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0O0?ooo`8000001`3oool3000Rf``0oooo0`0000040?oo
o`030000O`3oool0oooo01d0oooo1000000<0?ooo`<0nQh50P3oool30?XN1@h0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K1`3oool3000003H0oooo000l0?ooo`<0
000000<0oooo0000003oool08@3oool00`000000oooo0?ooo`060?ooo`<002;K2@3oool3000000L0
oooo00<0001o0?ooo`3oool08@3oool3000000T0oooo0`3j7PD20?ooo`<0nQh53P3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0
oooo001S0?ooo`030000003oool0oooo00H0oooo0`008]/60?ooo`<000002P3oool00`0007l0oooo
0?ooo`0T0?ooo`<000001P3oool30?XN1@80oooo0`3j7PD>0?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<0
00000?ooo`3oool01P3oool3000Rf`@0oooo0P00000=0?ooo`030000O`3oool0oooo02L0oooo0P00
00040?ooo`<0nQh50P3oool30?XN1@h0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`06
0?ooo`<002;K0P3oool2000000l0oooo00<0001o0?ooo`3oool0:@3oool200000080oooo0`3j7PD2
0?ooo`<0nQh53P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/9
0?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo00H0oooo0`008]/20000
0140oooo00<0001o0?ooo`3oool0:`3oool2000000<0nQh50P3oool30?XN1@h0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00>@3oool<000001h0oooo0P0000070?ooo`03000Rf`000000000001<0oooo00<0001o0?ooo`3o
ool0;@3oool2000000030?XN1@3oool0oooo00<0nQh53P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0440oooo0`008]/70?ooo`<00000=P3oool003T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo0`008]/C0?ooo`030000
O`3oool0oooo02d0oooo0P3j7PD3000000<0nQh53P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000i0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo0380oooo0`00000>0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool0
0`0007l0oooo0?ooo`0b0?ooo`<0nQh51`0000070?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?oo
o`3oool0703oool00`0007l0oooo0?ooo`0l0?ooo`D000000P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`L0
00008@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo0440oooo1@0000120?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000
O`3oool0oooo00@00000?P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`0U0?ooo`8000007@3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo00@0oooo1@00000i0?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`00
8]/70?ooo`<00000=P3oool003/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0L
0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool02@3oool4000003D0oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003`0oooo1P00000Q0?oo
o`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0=0?oo
o`H00000;`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00>`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3o
ool0@`3oool00`0007l0oooo0?ooo`0C0?ooo`H00000:@3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`0F0?ooo`H00000
2@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
6@3oool6000002<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool003/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0O0?ooo`H000007@3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool6
000001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0
oooo04<0oooo00<0001o0?ooo`3oool09@3oool4000001T0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3
000Rf`T0oooo00<000000?ooo`3oool0=03oool005L0oooo00<000000?ooo`3oool02@3oool30000
08h0001o1000003o0000ObX0001o0`008]/60000O`@00000=P3oool005P0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3o
ool0;@3oool400000140oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool003/0oooo1`00000G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0340oooo1@00000<0?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0=P3oool6000000H0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool0
0`0007l0oooo0?ooo`0l0?ooo`H0000000<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<00000
0?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?oo
o`030000O`3oool0oooo0480oooo1P00000o0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00?03oool6000001<0oooo1000000:0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3o
ool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo00<0oooo1000000k0?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`0U0?ooo`800000
7@3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
1`3oool5000003H0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo0`008]/70?ooo`<00000=P3oool003/0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`0<0?ooo`@00000<P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool003/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0
oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0@0?ooo`D00000;@3oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3
000Rf`T0oooo00<000000?ooo`3oool0=03oool003`0oooo1P00000Q0?ooo`030000003oool0oooo
01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
01D0oooo1@00000X0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000
oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`0J0?ooo`@00000903oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo
00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool07P3oool5000001l0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
000i0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`0S0?ooo`D000006P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`8000007@3oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0:03oool6000001@0oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/7
0?ooo`<00000=P3oool003T0oooo3000000N0?ooo`030000003oool0oooo01`0oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo02h0oooo1P00000>0?oo
o`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0d0?ooo`H0
0000203oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0
703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
>P3oool4000000@0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003o
ool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo03h0oooo1@0000150?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l000000000000200000440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?oo
o`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0080oooo1@00000l0?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo0P00000M0?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo00L0oooo1@00000g0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool3000Rf`L0oooo0`00000f0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000
O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo00`0oooo1000000c0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`0@0?ooo`D00000;P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001H0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0E0?ooo`D00000:@3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001H0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0703oool00`00
07l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`0J0?ooo`H000008`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001D0?ooo`H000002@3oool00`000000
oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0200oooo1P00000M0?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005D0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo02H0
oooo1@00000H0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool005D0oooo00@000000?ooo`3oool000002P3oool300000?l0
001o6`0007l5000009`0001o0`008]/60000O`@00000=P3oool005H0oooo00<000000?ooo`000000
2P3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0300oooo1@00000>0?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool005H0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo03D0oooo1@0000090?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005L0oooo0P00000:0?ooo`030000003oool0
oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0>P3oool5000000@0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E`3oool20000
00X0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0o0?ooo`@0000000<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00F03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3o
ool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@`3oool500000400oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool006<0oooo0P00000M0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
0P3oool4000003`0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`L0oooo0`00000f0?ooo`00H`3o
ool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool01P3o
ool5000003L0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo00/0oooo1P00000a0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`0A0?ooo`H00000:`3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool05`3oool6000002D0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo
0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`130?ooo`030000O`3oool0oooo01d0oooo1@00000P0?ooo`030000O`3oool0oooo0440oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0
001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0R0?ooo`@00000703oool00`0007l0oooo0?oo
o`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000001d0oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0V0?ooo`D000005`3oool00`0007l0oooo0?ooo`11
0?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`0[0?ooo`D000004P3oool00`0007l0oooo0?ooo`110?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0<03oool4000000h0oooo00<0001o0?ooo`3o
ool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0
703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo03@0oooo1@0000090?ooo`030000
O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003o
ool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0i0?ooo`@000001@3o
ool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool0
0`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0?@3oool5
000000030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?oo
o`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?oo
o`H00000?P3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo0P00000M0?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`030?ooo`H0
0000>03oool3000Rf`L0oooo0`00000f0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000
O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`090?ooo`D00000
<`3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool03P3o
ool5000002h0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0
oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo01<0oooo1000000Z0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E@3oool40000
00X0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool05`3oool5000002D0oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo001D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`0L0?ooo`D00000803oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo
00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0240oooo
1P00000J0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00L0oooo0`00003o0000Oj80001o1P00000D0000O`<002;K1P00
07l4000003H0oooo001D0?ooo`8000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo02d0oooo1@00000?0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E03oool00`00
0000oooo00000002000000X0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0<P3oool5000000X0oooo0`008]/90?oo
o`030000003oool0oooo03@0oooo001D0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0=`3oool4000000H0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001D0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0>`3oool5000000040?ooo`008]/002;K000Rf`T0
oooo00<000000?ooo`3oool0=03oool005@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0400oooo0`0000000`008]/0oooo0?ooo`070?ooo`030000
003oool0oooo03@0oooo001E0?ooo`@000002P3oool00`000000oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000001d0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool01P3oool3
000003H0oooo001S0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=03oool006<0ooooo`00003<0000
03H0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o
0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0oooo
IP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0
oooo9@3oool6000000@0oooo0`0000040?ooo`80000000D0oooo0000003oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo0`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0oooo
0`00003j0?ooo`00o`3ooolU0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0`3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00D000000?ooo`3oool0oooo0000003i0?ooo`00o`3ooolU0?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0?/0oooo003o0?ooobD0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`05000000<0oooo100000020?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool500000?T0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01@000000oooo
0?ooo`3oool0000000D0oooo1P0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo
0000003i0?ooo`00o`3ooolU0?ooo`H000000`3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo000000020?ooo`8000000P3oool200000080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo008000000P3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo0?L0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`3oool3000000@0oooo0`0000030?ooo`040000003oool0000000000080oooo
0P0000060?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`0000020?oo
o`<000000P3oool3000000050?ooo`000000oooo0?ooo`0000000`3oool300000?X0oooo003o0?oo
obD0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0?h0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0?h0oooo003o0?ooobD0oooo1P00000O0?ooo`H000003`3oool300000080oooo
00<000000?ooo`3oool0oP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo0000\
\>"],
  ImageRangeCache->{{{57.1875, 546.25}, {372, 177}} -> {-3.92318, 6.65852, \
0.0144452, 0.07302}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Michelson Y-arm with Lens Position of X-Arm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TelescopePlot[{zETM - MichelsonAsymmetry/2, 5.0}, {CavityWaist, 
          zCavityWaist - MichelsonAsymmetry/2}, {{ITMFocalLength, 
            zITM - MichelsonAsymmetry/2}, {fLX, zLX}}, kk];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.232143 0.14881 0.2 0.066729 [
[.08333 -0.0125 -10.0938 -16.375 ]
[.08333 -0.0125 10.0938 0 ]
[.23214 -0.0125 -5.59375 -16.375 ]
[.23214 -0.0125 5.59375 0 ]
[.38095 -0.0125 -5.59375 -16.375 ]
[.38095 -0.0125 5.59375 0 ]
[.52976 -0.0125 -5.59375 -16.375 ]
[.52976 -0.0125 5.59375 0 ]
[.67857 -0.0125 -5.59375 -16.375 ]
[.67857 -0.0125 5.59375 0 ]
[.82738 -0.0125 -5.59375 -16.375 ]
[.82738 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -16.375 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -43.1563 -32.75 ]
[.5 -0.0125 43.1563 -16.375 ]
[-0.0125 .06654 -20.1875 -8.1875 ]
[-0.0125 .06654 0 8.1875 ]
[-0.0125 .13327 -20.1875 -8.1875 ]
[-0.0125 .13327 0 8.1875 ]
[-0.0125 .2 -11.1875 -8.1875 ]
[-0.0125 .2 0 8.1875 ]
[-0.0125 .26673 -11.1875 -8.1875 ]
[-0.0125 .26673 0 8.1875 ]
[-0.0125 .33346 -11.1875 -8.1875 ]
[-0.0125 .33346 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .2 -36.5625 -44.3438 ]
[-0.01875 .2 -20.1875 44.3438 ]
[ 0 .4 .125 0 ]
[.5 .4125 -39 0 ]
[.5 .4125 39 16.375 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .4 L
s
.23214 0 m
.23214 .4 L
s
.38095 0 m
.38095 .4 L
s
.52976 0 m
.52976 .4 L
s
.67857 0 m
.67857 .4 L
s
.82738 0 m
.82738 .4 L
s
0 .06654 m
1 .06654 L
s
0 .13327 m
1 .13327 L
s
0 .2 m
1 .2 L
s
0 .26673 m
1 .26673 L
s
0 .33346 m
1 .33346 L
s
0 g
.08333 0 m
.08333 .00625 L
s
gsave
.08333 -0.0125 -71.0938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.23214 0 m
.23214 .00625 L
s
gsave
.23214 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.52976 0 m
.52976 .00625 L
s
gsave
.52976 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.67857 0 m
.67857 .00625 L
s
gsave
.67857 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.82738 0 m
.82738 .00625 L
s
gsave
.82738 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.17262 0 m
.17262 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.35119 0 m
.35119 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.47024 0 m
.47024 .00375 L
s
.5 0 m
.5 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.64881 0 m
.64881 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76786 0 m
.76786 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94643 0 m
.94643 .00375 L
s
.05357 0 m
.05357 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -104.156 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.438 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.875 16.625 moveto
(@) show
130.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
141.000 16.625 moveto
(D) show
145.313 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .06654 m
.00625 .06654 L
s
gsave
-0.0125 .06654 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .13327 m
.00625 .13327 L
s
gsave
-0.0125 .13327 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
gsave
-0.0125 .2 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .26673 m
.00625 .26673 L
s
gsave
-0.0125 .26673 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .33346 m
.00625 .33346 L
s
gsave
-0.0125 .33346 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01316 m
.00375 .01316 L
s
0 .0265 m
.00375 .0265 L
s
0 .03985 m
.00375 .03985 L
s
0 .0532 m
.00375 .0532 L
s
0 .07989 m
.00375 .07989 L
s
0 .09323 m
.00375 .09323 L
s
0 .10658 m
.00375 .10658 L
s
0 .11993 m
.00375 .11993 L
s
0 .14662 m
.00375 .14662 L
s
0 .15996 m
.00375 .15996 L
s
0 .17331 m
.00375 .17331 L
s
0 .18665 m
.00375 .18665 L
s
0 .21335 m
.00375 .21335 L
s
0 .22669 m
.00375 .22669 L
s
0 .24004 m
.00375 .24004 L
s
0 .25338 m
.00375 .25338 L
s
0 .28007 m
.00375 .28007 L
s
0 .29342 m
.00375 .29342 L
s
0 .30677 m
.00375 .30677 L
s
0 .32011 m
.00375 .32011 L
s
0 .3468 m
.00375 .3468 L
s
0 .36015 m
.00375 .36015 L
s
0 .3735 m
.00375 .3735 L
s
0 .38684 m
.00375 .38684 L
s
.25 Mabswid
0 0 m
0 .4 L
s
gsave
-0.01875 .2 -133.719 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
105.344 12.1875 translate
90 rotate
-105.344 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(spot) show
90.938 16.625 moveto
(size) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.438 16.625 moveto
(@) show
121.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
143.375 16.625 moveto
(D) show
147.688 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .39375 m
.08333 .4 L
s
.23214 .39375 m
.23214 .4 L
s
.38095 .39375 m
.38095 .4 L
s
.52976 .39375 m
.52976 .4 L
s
.67857 .39375 m
.67857 .4 L
s
.82738 .39375 m
.82738 .4 L
s
.97619 .39375 m
.97619 .4 L
s
.125 Mabswid
.1131 .39625 m
.1131 .4 L
s
.14286 .39625 m
.14286 .4 L
s
.17262 .39625 m
.17262 .4 L
s
.20238 .39625 m
.20238 .4 L
s
.2619 .39625 m
.2619 .4 L
s
.29167 .39625 m
.29167 .4 L
s
.32143 .39625 m
.32143 .4 L
s
.35119 .39625 m
.35119 .4 L
s
.41071 .39625 m
.41071 .4 L
s
.44048 .39625 m
.44048 .4 L
s
.47024 .39625 m
.47024 .4 L
s
.5 .39625 m
.5 .4 L
s
.55952 .39625 m
.55952 .4 L
s
.58929 .39625 m
.58929 .4 L
s
.61905 .39625 m
.61905 .4 L
s
.64881 .39625 m
.64881 .4 L
s
.70833 .39625 m
.70833 .4 L
s
.7381 .39625 m
.7381 .4 L
s
.76786 .39625 m
.76786 .4 L
s
.79762 .39625 m
.79762 .4 L
s
.85714 .39625 m
.85714 .4 L
s
.8869 .39625 m
.8869 .4 L
s
.91667 .39625 m
.91667 .4 L
s
.94643 .39625 m
.94643 .4 L
s
.05357 .39625 m
.05357 .4 L
s
.02381 .39625 m
.02381 .4 L
s
.25 Mabswid
0 .4 m
1 .4 L
s
gsave
.5 .4125 -100 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
100.375 16.625 moveto
(Profile) show
137.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .06654 m
1 .06654 L
s
.99375 .13327 m
1 .13327 L
s
.99375 .2 m
1 .2 L
s
.99375 .26673 m
1 .26673 L
s
.99375 .33346 m
1 .33346 L
s
.125 Mabswid
.99625 .01316 m
1 .01316 L
s
.99625 .0265 m
1 .0265 L
s
.99625 .03985 m
1 .03985 L
s
.99625 .0532 m
1 .0532 L
s
.99625 .07989 m
1 .07989 L
s
.99625 .09323 m
1 .09323 L
s
.99625 .10658 m
1 .10658 L
s
.99625 .11993 m
1 .11993 L
s
.99625 .14662 m
1 .14662 L
s
.99625 .15996 m
1 .15996 L
s
.99625 .17331 m
1 .17331 L
s
.99625 .18665 m
1 .18665 L
s
.99625 .21335 m
1 .21335 L
s
.99625 .22669 m
1 .22669 L
s
.99625 .24004 m
1 .24004 L
s
.99625 .25338 m
1 .25338 L
s
.99625 .28007 m
1 .28007 L
s
.99625 .29342 m
1 .29342 L
s
.99625 .30677 m
1 .30677 L
s
.99625 .32011 m
1 .32011 L
s
.99625 .3468 m
1 .3468 L
s
.99625 .36015 m
1 .36015 L
s
.99625 .3735 m
1 .3735 L
s
.99625 .38684 m
1 .38684 L
s
.25 Mabswid
1 0 m
1 .4 L
s
.977 .121 .023 r
.0075 w
.17262 .13738 m
.17262 .26262 L
s
.21354 .08918 m
.21354 .31082 L
s
0 .133 .859 r
.02381 .13738 m
.02381 .26262 L
s
.97619 .00952 m
.97619 .39048 L
s
0 g
.5 Mabswid
.02381 .26262 m
.04262 .2475 L
.06244 .23197 L
.07216 .22476 L
.0775 .22105 L
.08255 .21783 L
.08542 .2162 L
.08693 .21541 L
.08852 .21465 L
.08987 .21408 L
.09135 .21352 L
.092 .21331 L
.0927 .2131 L
.09396 .21277 L
.09466 .21263 L
.09532 .21251 L
.09603 .21241 L
.0968 .21234 L
.09753 .21229 L
.09822 .21228 L
.0995 .21233 L
.10077 .21246 L
.10194 .21266 L
.10322 .21296 L
.10387 .21314 L
.10458 .21336 L
.10588 .21382 L
.10709 .2143 L
.10982 .21557 L
.11223 .21687 L
.11478 .21838 L
.12409 .22463 L
.145 .24052 L
.18275 .27453 L
.19297 .28656 L
.20373 .29924 L
.20817 .30448 L
.21061 .30736 L
.21181 .30877 L
.21291 .31008 L
.21422 .31088 L
.21491 .31094 L
.21564 .311 L
.21812 .31122 L
.22296 .31165 L
.26165 .3151 L
.29953 .31857 L
.33987 .32237 L
.3787 .32611 L
.41997 .33018 L
Mistroke
.45973 .33417 L
.49798 .33807 L
.53868 .34228 L
.57786 .3464 L
.61949 .35082 L
.65961 .35513 L
.69821 .35933 L
.73927 .36383 L
.77881 .3682 L
.81683 .37243 L
.85731 .37697 L
.89627 .38137 L
.93768 .38608 L
.97619 .39048 L
Mfstroke
.02381 .13738 m
.04262 .1525 L
.06244 .16803 L
.07216 .17524 L
.0775 .17895 L
.08255 .18217 L
.08542 .1838 L
.08693 .18459 L
.08852 .18535 L
.08987 .18592 L
.09135 .18648 L
.092 .18669 L
.0927 .1869 L
.09396 .18723 L
.09466 .18737 L
.09532 .18749 L
.09603 .18759 L
.0968 .18766 L
.09753 .18771 L
.09822 .18772 L
.0995 .18767 L
.10077 .18754 L
.10194 .18734 L
.10322 .18704 L
.10387 .18686 L
.10458 .18664 L
.10588 .18618 L
.10709 .1857 L
.10982 .18443 L
.11223 .18313 L
.11478 .18162 L
.12409 .17537 L
.145 .15948 L
.18275 .12547 L
.19297 .11344 L
.20373 .10076 L
.20817 .09552 L
.21061 .09264 L
.21181 .09123 L
.21291 .08992 L
.21422 .08912 L
.21491 .08906 L
.21564 .089 L
.21812 .08878 L
.22296 .08835 L
.26165 .0849 L
.29953 .08143 L
.33987 .07763 L
.3787 .07389 L
.41997 .06982 L
Mistroke
.45973 .06583 L
.49798 .06193 L
.53868 .05772 L
.57786 .0536 L
.61949 .04918 L
.65961 .04487 L
.69821 .04067 L
.73927 .03617 L
.77881 .0318 L
.81683 .02757 L
.85731 .02303 L
.89627 .01863 L
.93768 .01392 L
.97619 .00952 L
Mfstroke
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{612.625, 245},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009T0000mB000`400?l00000o`00003oo`3ooooo
0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo;`3oool00`000000oooo0?ooo`0]0?ooo`<0
00003@3oool300000?<0oooo003o0?ooobl0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0?40oooo003o0?ooobl0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?40oooo003o0?ooob40oooo1@000009
0?ooo`040000003oool00000000000@0oooo0`0000040?ooo`<000000`3oool00`000000oooo0?oo
o`0200000080oooo00@000000?ooo`3oool0oooo0`0000030?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob80oooo00<000000?ooo`3o
ool02P3oool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000003
0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3a0?ooo`00o`3ooolR0?ooo`030000003oool0oooo00X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo0?oo
o`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0l@3o
ool00?l0oooo8`3oool010000000oooo0?ooo`3oool7000000030?ooo`000000oooo0080oooo00@0
00000?ooo`3oool000000`3oool010000000oooo0?ooo`3oool3000000<0oooo00@000000?ooo`3o
ool000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob@0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob@0oooo00<000000?ooo`3oool0203o
ool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3a0?ooo`00o`3ooolQ0?ooo`D000002@3oool010000000oooo0000000000040?ooo`<00000103o
ool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`040000003oool0oooo0?ooo`<00000
0`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0080oooo00@000000?ooo`00
000000000P3oool2000000D0oooo00<000000?ooo`3oool0l@3oool00?l0ooooA`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0l@3oool00?l0oooo
A`3oool00`000000oooo0?ooo`0E0?ooo`<000003@3oool300000?<0oooo003o0?oood@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooaP0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3o
oomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool008d0oooo00<000000?ooo`3o
ool0>P3oool4000004<0oooo00<000000?ooo`3oool0?P3oool6000003l0oooo100000130?ooo`03
0000003oool0oooo03l0oooo100000100?ooo`00S@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0m0?ooo`00S@3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0?03o
ool6000004@0oooo00<000000?ooo`3oool0?@3oool00880oooo1`0000040?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0m0?ooo`040000003oool0
oooo000004D0oooo00<000000?ooo`3oool0?@3oool008d0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo03d0oooo00@000000?ooo`3oool00000@03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo002=0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0?P3oool300000440oooo00<000000?ooo`000000@03oool5
00000400oooo002=0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool000000400oooo00<000000?ooo`3oool0@P3oool008/0
oooo00<000000?ooo`000000>`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`000000A@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03l0
oooo0P0000110?ooo`030000003oool0oooo0440oooo002<0?ooo`800000>`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03l0oooo0P0000100?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03l0oooo
0P0000110?ooo`030000003oool0oooo0440oooo002=0?ooo`030000003oool0oooo03X0oooo1000
00130?ooo`030000003oool0oooo03l0oooo100000100?ooo`@00000@`3oool00`000000oooo0?oo
o`0o0?ooo`D00000?`3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0
ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00H`3ooooo00000<`00000=P3oool006<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0400oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo03d0oooo1@0000000`008]/0oooo0?ooo`070?oo
o`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03D0oooo200000030?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000002@0oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo02d0oooo2000000;0?ooo`<002;K
1`3oool3000003H0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo02L0oooo1P00000C0?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0Q0?ooo`H000006@3oool3
000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool06@3oool80000
01l0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0100
oooo2@00000W0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo
0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`070?ooo`T00000<03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo0P00
000T0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool:000003T0oooo0`00
8]/70?ooo`<00000=P3oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo03P0oooo2@0000000`0007l0oooo0?ooo`100?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0<03oool8000000T0oooo00<0001o0?ooo`3oool0@03oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo02L0oooo2@00000A0?ooo`030000O`3oool0oooo0400
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0N0?ooo`T000006P3oool00`0007l0oooo
0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?oo
o`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool05@3oool9000002<0oooo00<0
001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo0P00000T
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool02`3oool:000002`0oooo00<0001o
0?ooo`3oool0@03oool3000Rf`L0oooo0`00000f0?ooo`00H`3oool00`000000oooo0?ooo`0S0?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool00P3oool9000003H0oooo00<0001o0?oo
o`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3o
ool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`0n0?ooo`T00000?`3oool00`0007l0oooo0?ooo`100?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo03D0oooo2@0000040?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`0/0?ooo`T000003@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0
oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool08`3oool9000001H0oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool20000
02@0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool06@3oool:000001l0oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`100?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000003oool0oooo02<0
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0303oool=000002T0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo
0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`110?ooo`030000O`000000000000`00000=P3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001D0?ooo`H000002@3o
ool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`0h0?ooo`X00000A03oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001E0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0;`3oool9000000T0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001F0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08`3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool09P3oool90000
0180oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001<0?ooo`L00000103oool00`000000
oooo0?ooo`090?ooo`<00000b`0007l900000>L0001o0`008]/60000O`@00000=P3oool005P0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0D0?ooo`T00000903oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool005T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`0;0?ooo`T00000;@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@@3oool0100007l0oooo0?ooo`3oool:000003H0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo001I0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03`0oooo2@0000100?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0d0?ooo`00E03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
03<0oooo2@0000050?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo001E0?ooo`@000002P3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool09P3oool=000000h0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool006<0oooo0P00000T0?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0603oool>000001/0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`L0oooo
0`00000f0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0403oool8000002T0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo00<0oooo3@00000a0?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/9
0?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?oo
o`3oool0=`3oool30?XN1@<0oooo2P00000n0?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?oo
o`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3o
ool0=`3oool00`3j7PD0000000000003000000@0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo
0?ooo`0S0?ooo`030000O`3oool0oooo03L0oooo0P0000000`3j7PD0oooo0?ooo`050?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool006<0oooo0P00000T0?ooo`030000O`3oool0oooo03H0oooo00@000000?XN1@3j7PD0nQh5
1`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/70?ooo`<00000
=P3oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0f0?ooo`040000003j
7PD0nQh50?XN1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3o
ool0oooo03D0oooo00<000000?ooo`3j7PD00P3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<00000
0?ooo`3oool08`3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo00<0nQh51`3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0<`3oool01000
0000oooo0?ooo`3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`10
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?oo
o`030000O`3oool0oooo0380oooo00<000000?ooo`3oool00P3oool30?XN1@L0oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00H`3oool2000002@0oooo00<0001o0?ooo`3oool0<@3oool00`000000oooo0?ooo`030?ooo`<0
nQh51`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/70?ooo`<0
0000=P3oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0a0?ooo`030000
003oool0oooo00<0oooo0`3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003`0oooo0P0000020?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0`0?ooo`030000003o
ool0oooo00@0oooo0`3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0;`3o
ool00`000000oooo0?ooo`050?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3o
ool0oooo02h0oooo00<000000?ooo`3oool01P3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08`3o
ool00`0007l0oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo0`3j7PD70?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool003`0oooo00<000000?ooo`3oool00P00000R0?ooo`800000903oool00`0007l0oooo0?ooo`0/
0?ooo`030000003oool0oooo00P0oooo0`3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@03oool3000Rf`L0oooo0`00000f0?ooo`00H`3oool00`000000oooo0?ooo`0S0?oo
o`030000O`3oool0oooo02`0oooo00<000000?ooo`3oool0203oool30?XN1@L0oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo02/0oooo00<000000?ooo`3o
ool02@3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool:00000180oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo02X0oooo00<000000?ooo`3oool0
2P3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool01@000000oooo0?ooo`3oool0000001H0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo02T0oooo
00<000000?ooo`3oool02`3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0S0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool0303oool30?XN1@L0oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?oo
o`0d0?ooo`00>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo1`000004
0?ooo`030000003oool0oooo00T0oooo0`00001=0000O`030000000007l0001o00d0001o0`3j7PGo
0000Oe`0001o0`008]/60000O`@00000=P3oool003`0oooo1@00000F0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01P3oool3000RfaX0oooo00<0001o0?ooo`3oool09@3oool20000
00030?XN1@3oool0oooo00d0oooo0`3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005L0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`060?ooo`03000Rf`00000002;K01X0oooo00<0001o0?ooo`3o
ool0903oool010000000nQh50?XN1@3j7PD?0?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001G0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool2000Rf`030000003oool0oooo01P0
oooo00<0001o0?ooo`3oool08`3oool00`000000oooo0?XN1@020?XN1@l0oooo0`3j7PD70?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool003`0oooo1@00000D0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool0
1P3oool3000Rf`800000603oool00`0007l0oooo0?ooo`0R0?ooo`030000003oool0oooo00<0nQh5
3`3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0180oooo0P00000;0?ooo`030000003oool0oooo00H0oooo0`008]/20?ooo`030000003o
ool0oooo01D0oooo00<0001o0?ooo`3oool08@3oool010000000oooo0?ooo`3oool30?XN1@l0oooo
0`3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00T0oooo0P0000070?ooo`<002;K0`3oool00`000000oooo0?oo
o`0D0?ooo`030000O`3oool0oooo0200oooo00<000000?ooo`3oool00P3oool30?XN1@l0oooo0`3j
7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`L0oooo0`00
000f0?ooo`00>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool01P3oool3000Rf`@0oooo0P00000D0?ooo`030000O`3oool0oooo01l0oooo00<00000
0?ooo`3oool00`3oool30?XN1@l0oooo0`3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003`0oooo1@00000R0?oo
o`030000003oool0oooo00H0oooo0`008]/60?ooo`030000003oool0oooo0140oooo00<0001o0?oo
o`3oool07@3oool2000000H0oooo0`3j7PD?0?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`03
0000003oool0oooo00H0oooo0`008]/70?ooo`030000003oool0oooo0100oooo00<0001o0?ooo`3o
ool0703oool00`000000oooo0?ooo`060?ooo`<0nQh53`3oool30?XN1@L0oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
>`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00H0oooo0`008]/80?ooo`030000
003oool0oooo00l0oooo00<0001o0?ooo`3oool06`3oool00`000000oooo0?ooo`070?ooo`<0nQh5
3`3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00>@3oool900000240oooo00<000000?ooo`3oool01P3o
ool3000Rf`T0oooo0P00000?0?ooo`030000O`3oool0oooo01X0oooo00<000000?ooo`3oool0203o
ool30?XN1@l0oooo0`3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0O0?ooo`8000001`3oool3000Rf`/0oooo00<000000?ooo`3oool0303oool0
0`0007l0oooo0?ooo`0I0?ooo`030000003oool0oooo00T0oooo0`3j7PD?0?ooo`<0nQh51`3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/70?ooo`<00000=P3oool0
06<0oooo00<000000?ooo`3oool01P3oool3000Rf``0oooo00<000000?ooo`3oool02`3oool00`00
07l0oooo0?ooo`0G0?ooo`800000303oool30?XN1@l0oooo0`3j7PD70?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0
oooo00<000000?ooo`3oool01P3oool3000Rf`d0oooo0P00000;0?ooo`030000O`3oool0oooo01H0
oooo00<000000?ooo`3oool0303oool30?XN1@l0oooo0`3j7PD70?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo
00<000000?ooo`3oool01P3oool3000Rf`l0oooo00<000000?ooo`3oool0203oool00`0007l0oooo
0?ooo`0E0?ooo`030000003oool0oooo00d0oooo0`3j7PD?0?ooo`<0nQh51`3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
001S0?ooo`030000003oool0oooo00H0oooo0`008]/@0?ooo`030000003oool0oooo00L0oooo00<0
001o0?ooo`3oool04`3oool200000100oooo0`3j7PD?0?ooo`<0nQh51`3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S
0?ooo`030000003oool0oooo00H0oooo0`008]/A0?ooo`8000001`3oool00`0007l0oooo0?ooo`0B
0?ooo`030000003oool0oooo0100oooo0`3j7PD?0?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?oo
o`8000000P3oool00`000000oooo0?ooo`0P0?ooo`8000001`3oool3000Rfa<0oooo0P0000050?oo
o`030000O`3oool0oooo0100oooo0P00000C0?ooo`<0nQh53`3oool30?XN1@L0oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K1`3oool3000003H0oooo000k0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?oo
o`<002;K5@3oool00`000000oooo0?ooo`020?ooo`030000O`3oool0oooo00l0oooo00<000000?oo
o`3oool04`3oool30?XN1@l0oooo0`3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00H0oooo0`008]/F0?oo
o`050000003oool0oooo0?ooo`0007l0403oool00`000000oooo0?ooo`0D0?ooo`<0nQh53`3oool3
0?XN1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool01P3oool3000RfaL0oooo00@000000?ooo`3oool0001o3P3o
ool2000001L0oooo0`3j7PD?0?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`030000003oool0
oooo008000008P3oool00`000000oooo0?ooo`060?ooo`<002;K603oool00`000000oooo0000O`0=
0?ooo`030000003oool0oooo01L0oooo0`3j7PD?0?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?oo
o`030000003oool0oooo00H0oooo0`008]/I0?ooo`<000002`3oool00`000000oooo0?ooo`0H0?oo
o`<0nQh53`3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`060?ooo`<0
02;K6P3oool0100007l000000000000000060?ooo`<000006`3oool30?XN1@l0oooo0`3j7PD70?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool003P0oooo00<000000?ooo`3oool01`00000Q0?ooo`8000001`3oool3000RfaX0
oooo00@0001o0?ooo`3oool0oooo1`00000M0?ooo`<0nQh53`3oool30?XN1@L0oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`03
0000003oool0oooo00H0oooo0`008]/J0?ooo`030000O`3oool0oooo02D0oooo0`3j7PD?0?ooo`<0
nQh51`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`03
0000003oool0oooo03@0oooo001E0?ooo`@000002P3oool00`000000oooo0?ooo`060?ooo`<002;K
6P3oool00`0007l0oooo0?ooo`0U0?ooo`<0nQh53`3oool30?XN1@L0oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo0`008]/J0?ooo`030000O`3o
ool0oooo02D0oooo0`3j7PD?0?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`040000003oool0
oooo0?ooo`<000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool3000RfaX0oooo00<0001o0?ooo`3oool09@3oool30?XN1@l0oooo0`3j
7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool003/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`060?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0U0?ooo`<0nQh53`3oool30?XN1@L0oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?oo
o`0d0?ooo`00>`3oool3000000<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo0`0000060000O`<002;K@P0007l30?XN1@l0001o0`3j7PGo
0000Oe`0001o0`008]/60000O`@00000=P3oool003/0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0U0?ooo`<0nQh53`3oool30?XN
1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00E03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01P3oool3000RfaX0oooo00<0001o0?ooo`3oool09@3oool30?XN1@l0
oooo0`3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool005@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo0`008]/J0?ooo`030000O`3oool0oooo02D0oooo
0`3j7PD?0?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`D000004`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool3000RfaX0oooo00<0
001o0?ooo`3oool09@3oool30?XN1@l0oooo0`3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0A0?ooo`@000002P3oool00`000000oooo0?oo
o`060?ooo`<002;K6P3oool00`0007l0oooo0?ooo`020?ooo`@000007`3oool30?XN1@l0oooo0`3j
7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool003/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0O0?ooo`8000001`3oool3000RfaX0oooo00<0001o0?ooo`0000000`0000030?ooo`<00000703o
ool30?XN1@l0oooo0`3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03o
ool3000Rf`L0oooo0`00000f0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool01P3oool3000RfaX0oooo00<0001o0000003oool02@3o
ool2000001X0oooo0`3j7PD?0?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`<0000000<0oooo
0000003oool08@3oool00`000000oooo0?ooo`060?ooo`<002;K6@3oool2000000d0oooo00<00000
0?ooo`3oool05`3oool30?XN1@l0oooo0`3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?oo
o`3oool01P3oool3000RfaL0oooo0P0000000`3oool0001o0?ooo`0=0?ooo`030000003oool0oooo
01H0oooo0`3j7PD?0?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo00H0
oooo0`008]/F0?ooo`050000003oool0oooo0?ooo`0007l03`3oool2000001H0oooo0`3j7PD?0?oo
o`<0nQh51`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?oo
o`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo00H0oooo0`008]/E0?ooo`03
0000003oool0oooo0080oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`<0
nQh53`3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000000L0oooo0`008]/C0?ooo`800000
1@3oool00`0007l0oooo0?ooo`0@0?ooo`8000004`3oool30?XN1@l0oooo0`3j7PD70?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`L0oooo0`00000f0?ooo`00>@3o
ool<000001h0oooo00<000000?ooo`3oool01P3oool3000Rfa40oooo0P0000070?ooo`030000O`3o
ool0oooo0180oooo00<000000?ooo`3oool0403oool30?XN1@l0oooo0`3j7PD70?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool003T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00H0oooo0`008]/@0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool04`3oool0
0`000000oooo0?ooo`0?0?ooo`<0nQh53`3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool3000R
f`l0oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?ooo`0D0?ooo`8000003`3oool30?XN
1@l0oooo0`3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool01P3oool3000Rf`d0
oooo0P00000;0?ooo`030000O`3oool0oooo01H0oooo00<000000?ooo`3oool0303oool30?XN1@l0
oooo0`3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool01P3oool3000Rf``0oooo
00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0G0?ooo`800000303oool30?XN1@l0oooo
0`3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool003/0oooo1`00000Q0?ooo`8000001`3oool3000Rf`/0oooo00<0
00000?ooo`3oool0303oool00`0007l0oooo0?ooo`0I0?ooo`030000003oool0oooo00T0oooo0`3j
7PD?0?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`00
8]/70?ooo`<00000=P3oool003`0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`06
0?ooo`<002;K2@3oool2000000l0oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`08
0?ooo`<0nQh53`3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`10
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00H0oooo0`008]/80?ooo`030000003oool0oooo00l0oooo00<0001o0?oo
o`3oool06`3oool00`000000oooo0?ooo`070?ooo`<0nQh53`3oool30?XN1@L0oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00>`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00H0oooo0`008]/70?ooo`03
0000003oool0oooo0100oooo00<0001o0?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`<0
nQh53`3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool600000240oooo00<000000?ooo`3oool0
1P3oool3000Rf`H0oooo00<000000?ooo`3oool04@3oool00`0007l0oooo0?ooo`0M0?ooo`030000
003oool0oooo00D0oooo0`3j7PD?0?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool01P3oool3000Rf`@0oooo0P00000D0?ooo`030000O`3o
ool0oooo01h0oooo00<000000?ooo`3oool0103oool30?XN1@l0oooo0`3j7PD70?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool003/0oooo00<000000?ooo`3oool09@3oool2000000L0oooo0`008]/30?ooo`030000003oool0
oooo01@0oooo00<0001o0?ooo`3oool07`3oool00`000000oooo0?ooo`030?ooo`<0nQh53`3oool3
0?XN1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K1`3oool3
000003H0oooo000k0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01P3oool3000R
f`80oooo00<000000?ooo`3oool05@3oool00`0007l0oooo0?ooo`0P0?ooo`030000003oool0oooo
0080oooo0`3j7PD?0?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`H000008@3oool00`000000
oooo0?ooo`060?ooo`<002;K0P00000H0?ooo`030000O`3oool0oooo0240oooo0P0000020?ooo`<0
nQh53`3oool30?XN1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00H0oooo0P008]/00`000000oooo0?ooo`0H0?ooo`030000O`3oool0oooo02<0oooo
00<000000?ooo`3j7PD00P3j7PD?0?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001G0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`008]/00000000Rf`0J0?ooo`030000O`3o
ool0oooo02@0oooo00@000000?XN1@3j7PD0nQh53`3oool30?XN1@L0oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3o
ool7000001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`<002;K6P3o
ool00`0007l0oooo0?ooo`0U0?ooo`030000003j7PD0nQh500l0oooo0`3j7PD70?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool003`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`090?ooo`<00000C00007l0
0`000000001o0000O`0>0000O`<0nQh5o`0007mL0000O`<002;K1P0007l4000003H0oooo000k0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0S0?oo
o`030000O`3oool0oooo02L0oooo00<000000?ooo`3oool03@3oool30?XN1@L0oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00>`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool08`3oool00`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo00`0oooo0`3j7PD70?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool003`0oooo1P00000E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
8`3oool00`0007l0oooo0?ooo`0Y0?ooo`030000003oool0oooo00/0oooo0`3j7PD70?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool003/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0000000;0?ooo`030000003o
ool0oooo02<0oooo00<0001o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0:0?ooo`<0nQh51`3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo000k0?ooo`030000003oool0oooo01P0oooo0P00000;0?ooo`030000003oool0
oooo02<0oooo00<0001o0?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`<0nQh51`3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo000k0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool20000
02@0oooo00<0001o0?ooo`3oool0;03oool00`000000oooo0?ooo`080?ooo`<0nQh51`3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/70?ooo`<00000=P3oool003`0
oooo1P00000Q0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0;@3oool00`000000
oooo0?ooo`070?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo
00<0001o0?ooo`3oool0;P3oool00`000000oooo0?ooo`060?ooo`<0nQh51`3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0;`3oool00`000000oooo0?oo
o`050?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`00
8]/90?ooo`030000003oool0oooo03@0oooo000i0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0300oooo00<00000
0?ooo`3oool0103oool30?XN1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`10
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0a0?oo
o`030000003oool0oooo00<0oooo0`3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003T0oooo3000000N0?ooo`03
0000003oool0oooo02<0oooo00<0001o0?ooo`3oool0<@3oool00`000000oooo0?ooo`030?ooo`<0
nQh51`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`03
0000003oool0oooo03@0oooo001S0?ooo`800000903oool00`0007l0oooo0?ooo`0b0?ooo`030000
003oool0oooo0080oooo0`3j7PD70?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@03oool3000Rf`L0oooo0`00000f0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3o
ool0oooo03<0oooo00@000000?ooo`3oool0oooo0`3j7PD70?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<0
00000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo00<0nQh51`3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0=@3oool0
0`000000oooo0?XN1@020?XN1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`10
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?oo
o`030000O`3oool0oooo03D0oooo00<000000?ooo`3j7PD00P3j7PD70?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0
oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0f0?ooo`040000003j7PD0nQh50?XN
1@L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool2000002@0oooo00<0001o0?ooo`3oool0=`3oool00`000000
nQh50?XN1@070?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`L0
oooo0`00000f0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo03L0oooo
00<0nQh50000003j7PD01`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0
001o0?ooo`3oool0=`3oool20?XN1@d00000?`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool00P3oool>00000340oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3
000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0100oooo2000000Y0?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0H0?ooo`T00000803oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000002@0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0Q0?ooo`T000005`3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`100?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0Z0?ooo`T000003P3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E03oool6000000T0oooo00<00000
0?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03<0oooo2@000005
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001E0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo03`0oooo3P00000k0?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00EP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00H0oooo3P00000]0?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo01@0oooo2@00000T0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00F03o
ool00`000000oooo0?ooo`080?ooo`<00000b`0007l900000>L0001o0`008]/60000O`@00000=P3o
ool005T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0V0?ooo`T000004P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3
000Rf`T0oooo00<000000?ooo`3oool0=03oool005T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`0_0?ooo`T000002@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0h0?ooo`X00000A03oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0
oooo001D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`110?ooo`030000O`000000000000L00000>`3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001E0?ooo`@000002P3o
ool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00L0oooo2@00000b0?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool006<0oooo0P00000T0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0100oooo2@00000Y0?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`L0oooo0`00000f0?ooo`00H`3oool00`00
0000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo01T0oooo2P00000O0?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0
oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0S0?ooo`T000005P3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0
oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0;03oool9000000d0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03D0oooo2@00
00040?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0n
0?ooo`T00000?`3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00H`3oool2000002@0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`020?oo
o`T00000=P3oool00`0007l0oooo0?ooo`100?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`03
0000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0;0?ooo`X0
0000;03oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
5@3oool9000002<0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo01h0oooo2@00000J0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`0W0?ooo`T000004@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0<03oool8000000T0oooo00<0001o0?ooo`3oool0@03oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool006<0oooo0P00000T0?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0>03oool9000000030000O`3oool0oooo0400oooo0`008]/70?ooo`<0
0000=P3oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo2P00000i0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3o
ool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`070?ooo`T00000<03oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0403oool9000002L0oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo01T0oooo2@00000N0?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0R0?ooo`X00000503oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool006<0oooo0P00000T0?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0/0?ooo`T000002`3oool3000Rf`L0oooo
0`00000f0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0e0?ooo`P000000`3oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0?@3oool500000003000Rf`3oool0
oooo00L0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0=03oool006<0ooooo`00003<000003H0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3o
oomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00
o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo9@3oool6000000@0oooo0`000004
0?ooo`80000000D0oooo0000003oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0`0000030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool0oooo0`00003j0?ooo`00o`3ooolU0?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000002
0?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000003i
0?ooo`00o`3ooolU0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001P3oool0
1@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0?/0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050000
00<0oooo100000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool500000?T0oooo003o0?ooobD0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0
oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo1P000003
0?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000003i0?ooo`00o`3ooolU0?ooo`H0
00000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo00000002
0?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo008000000P3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0?L0
oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool3000000@0
oooo0`0000030?ooo`040000003oool0000000000080oooo0P0000060?ooo`030000003oool0oooo
00<0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`<000000P3oool3000000050?ooo`00
0000oooo0?ooo`0000000`3oool300000?X0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?h0oooo003o0?ooobD0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?h0oooo003o0?oo
obD0oooo1P00000O0?ooo`H000003`3oool300000080oooo00<000000?ooo`3oool0oP3oool00?l0
ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo0000\
\>"],
  ImageRangeCache->{{{57.1875, 546.25}, {676.188, 481.188}} -> {-4.06481, \
15.4273, 0.0146745, 0.032725}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

Input Beam\
\>", "Subtitle"],

Cell["Lens L1 is at the input before the probe beam is split off.", "Text"],

Cell[BoxData[{
    \(\(zL1 = 0.25;\)\), "\[IndentingNewLine]", 
    \(\(fL1 = 2.0334;\)\), "\[IndentingNewLine]", 
    \(\(fL1 = 1.5346;\)\), "\[IndentingNewLine]", 
    \(\(fL1 = 1.146;\)\), "\[IndentingNewLine]", 
    \(\({WaistL1, 
          zWaistL1} = \[IndentingNewLine]Lensing[{WaistLXY, zWaistLXY}, {fL1, 
            zL1}, kk];\)\), "\[IndentingNewLine]", 
    \(\({WaistL1X, 
          zWaistL1X} = \[IndentingNewLine]Lensing[{WaistLX, zWaistLX}, {fL1, 
            zL1}, kk];\)\), "\[IndentingNewLine]", 
    \(\({WaistL1Y, 
          zWaistL1Y} = \[IndentingNewLine]Lensing[{WaistLY, zWaistLY}, {fL1, 
            zL1}, kk];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Print["\<Focal Length of L1 Lens = \>", 
        fL1, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Position of L1 Lens = \>", 
        zL1, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Size after L1 = \>", \ 
        1000\ WaistL1, \ "\< mm\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Position after L1 = \>", \ 
        zWaistL1, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Rayleigh Range after L1 = \>", 
        RayleighLength[WaistL1, 
          kk], \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Size after L1 (X arm Michelson) = \>", \ 
        1000\ WaistL1X, \ "\< mm\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Position after L1 (X arm Michelson) = \>", \ 
        zWaistL1X, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Rayleigh Range after L1 (X arm Michelson) = \>", 
        RayleighLength[WaistL1X, 
          kk], \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Size after L1 (Y arm Michelson) = \>", \ 
        1000\ WaistL1Y, \ "\< mm\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Position after L1 (Y arm Michelson) = \>", \ 
        zWaistL1Y, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Rayleigh Range after L1 (Y arm Michelson) = \>", 
        RayleighLength[WaistL1Y, kk], \ "\< m\>"];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Focal Length of L1 Lens = "\[InvisibleSpace]1.146`\
\[InvisibleSpace]" m"\),
      SequenceForm[ "Focal Length of L1 Lens = ", 1.1459999999999999, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Position of L1 Lens = "\[InvisibleSpace]0.25`\
\[InvisibleSpace]" m"\),
      SequenceForm[ "Position of L1 Lens = ", .25, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Size after L1 = \
"\[InvisibleSpace]0.3912413140230727`\[InvisibleSpace]" mm"\),
      SequenceForm[ "Waist Size after L1 = ", .39124131402307272, " mm"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Position after L1 = \
"\[InvisibleSpace]2.09677110503253`\[InvisibleSpace]" m"\),
      SequenceForm[ "Waist Position after L1 = ", 2.0967711050325302, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Rayleigh Range after L1 = \
"\[InvisibleSpace]0.451957567405338`\[InvisibleSpace]" m"\),
      SequenceForm[ "Rayleigh Range after L1 = ", .45195756740533799, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Size after L1 (X arm Michelson) = "\
\[InvisibleSpace]0.39988280563834205`\[InvisibleSpace]" mm"\),
      SequenceForm[ 
      "Waist Size after L1 (X arm Michelson) = ", .39988280563834205, " mm"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Position after L1 (X arm Michelson) = "\
\[InvisibleSpace]2.0995445812016094`\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Waist Position after L1 (X arm Michelson) = ", 2.0995445812016094, 
        " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Rayleigh Range after L1 (X arm Michelson) = "\
\[InvisibleSpace]0.47214316368996967`\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Rayleigh Range after L1 (X arm Michelson) = ", .47214316368996967, 
        " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Size after L1 (Y arm Michelson) = "\
\[InvisibleSpace]0.38272436798269877`\[InvisibleSpace]" mm"\),
      SequenceForm[ 
      "Waist Size after L1 (Y arm Michelson) = ", .38272436798269877, " mm"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Position after L1 (Y arm Michelson) = "\
\[InvisibleSpace]2.093275760476528`\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Waist Position after L1 (Y arm Michelson) = ", 2.0932757604765282, 
        " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Rayleigh Range after L1 (Y arm Michelson) = "\
\[InvisibleSpace]0.43249438535889456`\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Rayleigh Range after L1 (Y arm Michelson) = ", .43249438535889456, 
        " m"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Change of L1 Position and focal Length", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindMaximum[\(Lensing[{WaistLXY, zWaistLXY}, {f, zL1}, 
          kk]\)\[LeftDoubleBracket]2\[RightDoubleBracket], {f, 2}]\)], "Input"],

Cell[BoxData[
    \({4.2490802431636965`, {f \[Rule] 2.0544782818631644`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[\(Lensing[{WaistLXY, zWaistLXY}, {fL1, zz}, 
            kk]\)\[LeftDoubleBracket]2\[RightDoubleBracket], {zz, \(-0.3\), 
          0.3}, GridLines \[Rule] Automatic, Frame \[Rule] True, 
        PlotPoints \[Rule] 1000, 
        FrameLabel \[Rule] {"\<Position of L1 (m)\>", "\<Waist position \
(m)\>"}, PlotRange \[Rule] All];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 1.5873 -1.79482 1.12286 [
[.02381 -0.0125 -15.4688 -16.375 ]
[.02381 -0.0125 15.4688 0 ]
[.18254 -0.0125 -15.4688 -16.375 ]
[.18254 -0.0125 15.4688 0 ]
[.34127 -0.0125 -15.4688 -16.375 ]
[.34127 -0.0125 15.4688 0 ]
[.5 -0.0125 -5.59375 -16.375 ]
[.5 -0.0125 5.59375 0 ]
[.65873 -0.0125 -10.9688 -16.375 ]
[.65873 -0.0125 10.9688 0 ]
[.81746 -0.0125 -10.9688 -16.375 ]
[.81746 -0.0125 10.9688 0 ]
[.97619 -0.0125 -10.9688 -16.375 ]
[.97619 -0.0125 10.9688 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -52.7188 -32.75 ]
[.5 -0.0125 52.7188 -16.375 ]
[-0.0125 .00175 -21.9375 -8.1875 ]
[-0.0125 .00175 0 8.1875 ]
[-0.0125 .11404 -21.9375 -8.1875 ]
[-0.0125 .11404 0 8.1875 ]
[-0.0125 .22632 -21.9375 -8.1875 ]
[-0.0125 .22632 0 8.1875 ]
[-0.0125 .33861 -21.9375 -8.1875 ]
[-0.0125 .33861 0 8.1875 ]
[-0.0125 .4509 -11.1875 -8.1875 ]
[-0.0125 .4509 0 8.1875 ]
[-0.0125 .56318 -21.9375 -8.1875 ]
[-0.0125 .56318 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -38.3125 -53.75 ]
[-0.01875 .30902 -21.9375 53.75 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.5 0 m
.5 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.81746 0 m
.81746 .61803 L
s
0 .11404 m
1 .11404 L
s
0 .22632 m
1 .22632 L
s
0 .33861 m
1 .33861 L
s
0 .4509 m
1 .4509 L
s
0 .56318 m
1 .56318 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -76.4688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -76.4688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -76.4688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -71.9688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -71.9688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -71.9688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -113.719 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Position) show
112.500 16.625 moveto
(of) show
127.313 16.625 moveto
(L1) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
145.250 16.625 moveto
(H) show
149.438 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
160.250 16.625 moveto
(L) show
164.438 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00175 m
.00625 .00175 L
s
gsave
-0.0125 .00175 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
0 .11404 m
.00625 .11404 L
s
gsave
-0.0125 .11404 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
1.000 setlinewidth
grestore
0 .22632 m
.00625 .22632 L
s
gsave
-0.0125 .22632 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
0 .33861 m
.00625 .33861 L
s
gsave
-0.0125 .33861 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
1.000 setlinewidth
grestore
0 .4509 m
.00625 .4509 L
s
gsave
-0.0125 .4509 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .56318 m
.00625 .56318 L
s
gsave
-0.0125 .56318 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02421 m
.00375 .02421 L
s
0 .04667 m
.00375 .04667 L
s
0 .06912 m
.00375 .06912 L
s
0 .09158 m
.00375 .09158 L
s
0 .1365 m
.00375 .1365 L
s
0 .15895 m
.00375 .15895 L
s
0 .18141 m
.00375 .18141 L
s
0 .20387 m
.00375 .20387 L
s
0 .24878 m
.00375 .24878 L
s
0 .27124 m
.00375 .27124 L
s
0 .2937 m
.00375 .2937 L
s
0 .31615 m
.00375 .31615 L
s
0 .36107 m
.00375 .36107 L
s
0 .38352 m
.00375 .38352 L
s
0 .40598 m
.00375 .40598 L
s
0 .42844 m
.00375 .42844 L
s
0 .47335 m
.00375 .47335 L
s
0 .49581 m
.00375 .49581 L
s
0 .51827 m
.00375 .51827 L
s
0 .54073 m
.00375 .54073 L
s
0 .58564 m
.00375 .58564 L
s
0 .6081 m
.00375 .6081 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -144.875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
114.75 12.1875 translate
90 rotate
-114.75 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Waist) show
99.250 16.625 moveto
(position) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
147.313 16.625 moveto
(H) show
151.500 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
162.313 16.625 moveto
(L) show
166.500 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00175 m
1 .00175 L
s
.99375 .11404 m
1 .11404 L
s
.99375 .22632 m
1 .22632 L
s
.99375 .33861 m
1 .33861 L
s
.99375 .4509 m
1 .4509 L
s
.99375 .56318 m
1 .56318 L
s
.125 Mabswid
.99625 .02421 m
1 .02421 L
s
.99625 .04667 m
1 .04667 L
s
.99625 .06912 m
1 .06912 L
s
.99625 .09158 m
1 .09158 L
s
.99625 .1365 m
1 .1365 L
s
.99625 .15895 m
1 .15895 L
s
.99625 .18141 m
1 .18141 L
s
.99625 .20387 m
1 .20387 L
s
.99625 .24878 m
1 .24878 L
s
.99625 .27124 m
1 .27124 L
s
.99625 .2937 m
1 .2937 L
s
.99625 .31615 m
1 .31615 L
s
.99625 .36107 m
1 .36107 L
s
.99625 .38352 m
1 .38352 L
s
.99625 .40598 m
1 .40598 L
s
.99625 .42844 m
1 .42844 L
s
.99625 .47335 m
1 .47335 L
s
.99625 .49581 m
1 .49581 L
s
.99625 .51827 m
1 .51827 L
s
.99625 .54073 m
1 .54073 L
s
.99625 .58564 m
1 .58564 L
s
.99625 .6081 m
1 .6081 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02474 .01544 L
.02575 .01622 L
.0267 .01696 L
.02761 .01766 L
.02859 .01842 L
.02952 .01914 L
.03052 .01991 L
.03148 .02065 L
.0324 .02136 L
.03338 .02212 L
.03433 .02285 L
.03524 .02355 L
.03621 .02429 L
.03714 .02501 L
.03813 .02577 L
.03908 .0265 L
.04 .0272 L
.04098 .02795 L
.04192 .02867 L
.04292 .02943 L
.04388 .03017 L
.0448 .03088 L
.04579 .03163 L
.04674 .03235 L
.04765 .03305 L
.04862 .03379 L
.04956 .0345 L
.05055 .03525 L
.05151 .03598 L
.05243 .03668 L
.05341 .03742 L
.05435 .03814 L
.05526 .03882 L
.05622 .03956 L
.05715 .04026 L
.05814 .04101 L
.05909 .04173 L
.06001 .04242 L
.06098 .04315 L
.06192 .04386 L
.06292 .04461 L
.06388 .04533 L
.0648 .04603 L
.06579 .04677 L
.06673 .04748 L
.06764 .04816 L
.06861 .04889 L
.06954 .04959 L
.07054 .05033 L
Mistroke
.07149 .05104 L
.07241 .05173 L
.07339 .05246 L
.07433 .05317 L
.07533 .05391 L
.07629 .05463 L
.07722 .05532 L
.07821 .05606 L
.07916 .05676 L
.08007 .05744 L
.08104 .05817 L
.08198 .05886 L
.08297 .0596 L
.08393 .06031 L
.08485 .06099 L
.08584 .06172 L
.08678 .06242 L
.08769 .06309 L
.08866 .06381 L
.08959 .06449 L
.09058 .06522 L
.09153 .06593 L
.09245 .0666 L
.09342 .06732 L
.09436 .06801 L
.09536 .06875 L
.09632 .06945 L
.09725 .07013 L
.09823 .07085 L
.09918 .07155 L
.10009 .07222 L
.10106 .07293 L
.10199 .07361 L
.10299 .07434 L
.10394 .07504 L
.10486 .07571 L
.10584 .07642 L
.10678 .07711 L
.10769 .07777 L
.10866 .07847 L
.10958 .07915 L
.11057 .07987 L
.11152 .08056 L
.11244 .08123 L
.11341 .08193 L
.11435 .08261 L
.11535 .08333 L
.1163 .08403 L
.11723 .0847 L
.11821 .08541 L
Mistroke
.11916 .08609 L
.12007 .08675 L
.12103 .08745 L
.12197 .08812 L
.12296 .08884 L
.12391 .08952 L
.12483 .09019 L
.12581 .09089 L
.12675 .09157 L
.12775 .09228 L
.12871 .09298 L
.12964 .09364 L
.13062 .09435 L
.13157 .09503 L
.13248 .09568 L
.13345 .09638 L
.13439 .09705 L
.13538 .09776 L
.13634 .09844 L
.13726 .0991 L
.13824 .0998 L
.13919 .10047 L
.14009 .10112 L
.14106 .10181 L
.14199 .10247 L
.14298 .10317 L
.14393 .10385 L
.14485 .1045 L
.14582 .10519 L
.14676 .10586 L
.14776 .10657 L
.14872 .10725 L
.14964 .1079 L
.15063 .1086 L
.15158 .10927 L
.15249 .10991 L
.15346 .1106 L
.15439 .11126 L
.15538 .11196 L
.15634 .11263 L
.15726 .11328 L
.15823 .11397 L
.15918 .11463 L
.16018 .11533 L
.16114 .11601 L
.16207 .11666 L
.16306 .11736 L
.16401 .11802 L
.16492 .11866 L
.16589 .11934 L
Mistroke
.16683 .12 L
.16782 .1207 L
.16878 .12137 L
.16971 .12201 L
.17069 .1227 L
.17163 .12336 L
.17254 .12399 L
.17351 .12467 L
.17444 .12532 L
.17543 .126 L
.17638 .12667 L
.1773 .12731 L
.17828 .12798 L
.17922 .12864 L
.18022 .12933 L
.18118 .13 L
.1821 .13064 L
.18309 .13132 L
.18404 .13198 L
.18495 .13261 L
.18592 .13328 L
.18685 .13393 L
.18785 .13462 L
.1888 .13528 L
.18972 .13591 L
.1907 .13659 L
.19165 .13724 L
.19255 .13786 L
.19352 .13853 L
.19445 .13917 L
.19544 .13984 L
.19639 .1405 L
.1973 .14113 L
.19828 .1418 L
.19922 .14244 L
.20021 .14312 L
.20117 .14378 L
.2021 .14441 L
.20308 .14509 L
.20403 .14573 L
.20494 .14636 L
.2059 .14702 L
.20684 .14765 L
.20783 .14833 L
.20878 .14898 L
.2097 .14961 L
.21068 .15027 L
.21162 .15091 L
.21262 .1516 L
.21358 .15225 L
Mistroke
.21451 .15288 L
.2155 .15355 L
.21645 .1542 L
.21736 .15481 L
.21833 .15547 L
.21927 .15611 L
.22026 .15678 L
.22122 .15743 L
.22214 .15805 L
.22312 .15872 L
.22407 .15936 L
.22497 .15997 L
.22594 .16062 L
.22687 .16125 L
.22786 .16192 L
.22881 .16256 L
.22973 .16318 L
.23071 .16383 L
.23164 .16446 L
.23264 .16514 L
.2336 .16578 L
.23453 .1664 L
.23551 .16706 L
.23646 .1677 L
.23737 .16831 L
.23834 .16896 L
.23928 .16959 L
.24027 .17025 L
.24122 .17089 L
.24214 .17151 L
.24312 .17216 L
.24406 .17279 L
.24497 .17339 L
.24594 .17404 L
.24686 .17466 L
.24785 .17532 L
.2488 .17595 L
.24972 .17656 L
.25069 .17721 L
.25163 .17783 L
.25262 .17849 L
.25358 .17913 L
.25451 .17974 L
.25549 .18039 L
.25643 .18102 L
.25734 .18162 L
.25831 .18227 L
.25924 .18288 L
.26023 .18354 L
.26119 .18417 L
Mistroke
.2621 .18478 L
.26308 .18542 L
.26402 .18604 L
.26502 .1867 L
.26598 .18734 L
.26691 .18795 L
.26789 .1886 L
.26884 .18922 L
.26976 .18982 L
.27073 .19046 L
.27166 .19108 L
.27266 .19173 L
.27361 .19236 L
.27453 .19297 L
.27551 .19361 L
.27646 .19423 L
.27736 .19482 L
.27833 .19546 L
.27926 .19607 L
.28025 .19671 L
.2812 .19734 L
.28212 .19794 L
.28309 .19857 L
.28403 .19919 L
.28503 .19984 L
.28599 .20047 L
.28691 .20107 L
.28789 .20171 L
.28884 .20233 L
.28975 .20292 L
.29072 .20355 L
.29165 .20416 L
.29265 .2048 L
.2936 .20543 L
.29452 .20602 L
.2955 .20666 L
.29644 .20727 L
.29744 .20792 L
.2984 .20854 L
.29933 .20915 L
.30032 .20978 L
.30127 .2104 L
.30218 .21099 L
.30315 .21162 L
.30409 .21223 L
.30509 .21287 L
.30604 .21349 L
.30697 .21408 L
.30795 .21472 L
.30889 .21533 L
Mistroke
.3098 .21591 L
.31077 .21654 L
.3117 .21714 L
.31269 .21777 L
.31364 .21839 L
.31456 .21898 L
.31554 .21961 L
.31647 .22021 L
.31747 .22085 L
.31844 .22147 L
.31936 .22206 L
.32035 .22269 L
.32129 .2233 L
.3222 .22389 L
.32318 .22451 L
.32411 .22511 L
.3251 .22574 L
.32606 .22635 L
.32698 .22694 L
.32796 .22757 L
.3289 .22817 L
.32981 .22875 L
.33077 .22937 L
.3317 .22996 L
.33269 .23059 L
.33364 .23119 L
.33456 .23178 L
.33553 .2324 L
.33647 .23299 L
.33746 .23363 L
.33842 .23424 L
.33935 .23483 L
.34033 .23545 L
.34128 .23605 L
.34218 .23663 L
.34315 .23724 L
.34409 .23783 L
.34508 .23846 L
.34603 .23907 L
.34695 .23965 L
.34793 .24027 L
.34887 .24086 L
.34987 .2415 L
.35083 .2421 L
.35176 .24269 L
.35274 .24331 L
.35369 .24391 L
.3546 .24449 L
.35558 .2451 L
.35651 .24569 L
Mistroke
.35751 .24632 L
.35846 .24692 L
.35939 .2475 L
.36037 .24812 L
.36131 .24871 L
.36222 .24928 L
.36318 .24989 L
.36411 .25048 L
.3651 .2511 L
.36606 .2517 L
.36697 .25227 L
.36795 .25288 L
.36889 .25347 L
.36988 .2541 L
.37084 .2547 L
.37177 .25528 L
.37275 .25589 L
.3737 .25649 L
.37461 .25706 L
.37558 .25766 L
.37651 .25825 L
.37751 .25887 L
.37846 .25946 L
.37938 .26004 L
.38036 .26065 L
.3813 .26123 L
.3823 .26186 L
.38327 .26246 L
.3842 .26304 L
.38518 .26365 L
.38613 .26424 L
.38705 .26481 L
.38802 .26542 L
.38896 .266 L
.38995 .26662 L
.39091 .26721 L
.39183 .26779 L
.39282 .2684 L
.39376 .26898 L
.39467 .26955 L
.39564 .27015 L
.39657 .27072 L
.39756 .27134 L
.39851 .27193 L
.39943 .2725 L
.40041 .2731 L
.40135 .27368 L
.40235 .2743 L
.40331 .27489 L
.40423 .27546 L
Mistroke
.40522 .27607 L
.40617 .27666 L
.40708 .27722 L
.40805 .27782 L
.40899 .2784 L
.40998 .27901 L
.41094 .2796 L
.41186 .28016 L
.41284 .28077 L
.41378 .28135 L
.41469 .28191 L
.41565 .2825 L
.41658 .28307 L
.41757 .28368 L
.41852 .28426 L
.41944 .28482 L
.42041 .28542 L
.42135 .286 L
.42235 .28661 L
.42331 .2872 L
.42423 .28776 L
.42521 .28837 L
.42616 .28895 L
.42707 .2895 L
.42804 .2901 L
.42897 .29067 L
.42996 .29127 L
.43092 .29186 L
.43184 .29242 L
.43282 .29301 L
.43376 .29359 L
.43476 .2942 L
.43572 .29479 L
.43665 .29535 L
.43763 .29595 L
.43858 .29653 L
.4395 .29709 L
.44047 .29768 L
.44141 .29825 L
.4424 .29885 L
.44336 .29944 L
.44428 .3 L
.44526 .30059 L
.44621 .30117 L
.44711 .30172 L
.44808 .30231 L
.44901 .30287 L
.45 .30347 L
.45095 .30405 L
.45187 .30461 L
Mistroke
.45285 .3052 L
.45379 .30577 L
.45478 .30637 L
.45574 .30695 L
.45667 .30751 L
.45765 .30811 L
.4586 .30868 L
.45951 .30923 L
.46048 .30982 L
.46142 .31038 L
.46241 .31098 L
.46337 .31156 L
.46429 .31212 L
.46527 .31271 L
.46621 .31327 L
.46711 .31382 L
.46808 .3144 L
.46901 .31496 L
.46999 .31556 L
.47095 .31613 L
.47186 .31668 L
.47283 .31727 L
.47377 .31783 L
.47477 .31843 L
.47573 .31901 L
.47665 .31956 L
.47763 .32015 L
.47858 .32072 L
.47949 .32126 L
.48046 .32185 L
.48139 .3224 L
.48238 .323 L
.48333 .32357 L
.48425 .32412 L
.48523 .32471 L
.48617 .32527 L
.48717 .32587 L
.48813 .32644 L
.48906 .327 L
.49004 .32759 L
.49099 .32816 L
.4919 .3287 L
.49288 .32928 L
.49381 .32984 L
.4948 .33043 L
.49576 .33101 L
.49668 .33156 L
.49766 .33214 L
.49861 .3327 L
.49951 .33324 L
Mistroke
.50048 .33382 L
.50141 .33437 L
.5024 .33496 L
.50335 .33553 L
.50427 .33608 L
.50524 .33666 L
.50618 .33721 L
.50718 .33781 L
.50814 .33838 L
.50906 .33893 L
.51005 .33951 L
.51099 .34008 L
.5119 .34062 L
.51287 .34119 L
.51381 .34175 L
.5148 .34233 L
.51575 .3429 L
.51667 .34345 L
.51765 .34403 L
.51859 .34458 L
.51959 .34518 L
.52056 .34575 L
.52149 .3463 L
.52247 .34688 L
.52342 .34744 L
.52434 .34799 L
.52531 .34856 L
.52625 .34911 L
.52724 .3497 L
.5282 .35027 L
.52912 .35081 L
.5301 .35139 L
.53105 .35195 L
.53196 .35249 L
.53292 .35306 L
.53386 .35361 L
.53485 .35419 L
.5358 .35475 L
.53672 .35529 L
.53769 .35587 L
.53863 .35642 L
.53963 .35701 L
.54059 .35758 L
.54152 .35812 L
.5425 .3587 L
.54345 .35926 L
.54436 .3598 L
.54533 .36037 L
.54627 .36092 L
.54726 .3615 L
Mistroke
.54822 .36206 L
.54914 .3626 L
.55012 .36318 L
.55106 .36373 L
.55197 .36426 L
.55293 .36483 L
.55386 .36537 L
.55485 .36595 L
.5558 .36651 L
.55672 .36705 L
.55769 .36762 L
.55863 .36817 L
.55962 .36875 L
.56058 .36931 L
.56151 .36985 L
.56249 .37043 L
.56344 .37098 L
.56435 .37151 L
.56532 .37208 L
.56625 .37262 L
.56724 .3732 L
.56819 .37376 L
.56911 .3743 L
.57009 .37487 L
.57103 .37542 L
.57203 .376 L
.57299 .37656 L
.57392 .3771 L
.57491 .37768 L
.57586 .37823 L
.57677 .37876 L
.57774 .37933 L
.57868 .37988 L
.57967 .38045 L
.58063 .38101 L
.58155 .38155 L
.58253 .38212 L
.58348 .38267 L
.58438 .3832 L
.58535 .38376 L
.58628 .3843 L
.58727 .38487 L
.58822 .38543 L
.58914 .38596 L
.59011 .38653 L
.59105 .38707 L
.59205 .38765 L
.59301 .38821 L
.59394 .38875 L
.59492 .38932 L
Mistroke
.59587 .38987 L
.59678 .39039 L
.59775 .39096 L
.59868 .3915 L
.59968 .39207 L
.60063 .39263 L
.60155 .39316 L
.60253 .39373 L
.60347 .39427 L
.60438 .3948 L
.60534 .39535 L
.60627 .39589 L
.60726 .39646 L
.60821 .39701 L
.60912 .39754 L
.6101 .3981 L
.61103 .39864 L
.61203 .39922 L
.61299 .39977 L
.61391 .4003 L
.61489 .40087 L
.61584 .40142 L
.61675 .40194 L
.61772 .4025 L
.61865 .40304 L
.61964 .40361 L
.62059 .40416 L
.62151 .40469 L
.62249 .40525 L
.62343 .40579 L
.62442 .40637 L
.62539 .40692 L
.62631 .40745 L
.6273 .40802 L
.62825 .40857 L
.62916 .40909 L
.63013 .40965 L
.63107 .41019 L
.63206 .41076 L
.63302 .41131 L
.63394 .41184 L
.63492 .4124 L
.63586 .41294 L
.63677 .41346 L
.63773 .41402 L
.63866 .41455 L
.63965 .41512 L
.6406 .41567 L
.64152 .41619 L
.64249 .41675 L
Mistroke
.64343 .41729 L
.64443 .41786 L
.64539 .41841 L
.64631 .41894 L
.6473 .4195 L
.64824 .42005 L
.64915 .42057 L
.65012 .42112 L
.65106 .42166 L
.65205 .42222 L
.653 .42277 L
.65392 .4233 L
.6549 .42386 L
.65584 .42439 L
.65684 .42497 L
.6578 .42552 L
.65873 .42605 L
.65972 .42661 L
.66067 .42715 L
.66158 .42768 L
.66255 .42823 L
.66349 .42877 L
.66449 .42933 L
.66544 .42988 L
.66637 .43041 L
.66735 .43097 L
.66829 .43151 L
.6692 .43202 L
.67017 .43258 L
.6711 .43311 L
.67209 .43367 L
.67304 .43421 L
.67396 .43474 L
.67493 .43529 L
.67587 .43583 L
.67687 .4364 L
.67783 .43694 L
.67876 .43747 L
.67974 .43803 L
.68069 .43857 L
.6816 .43909 L
.68257 .43964 L
.68351 .44017 L
.6845 .44074 L
.68546 .44128 L
.68638 .4418 L
.68736 .44236 L
.6883 .4429 L
.6892 .44341 L
.69017 .44396 L
Mistroke
.6911 .44449 L
.69209 .44505 L
.69304 .44559 L
.69395 .44611 L
.69493 .44666 L
.69586 .44719 L
.69686 .44776 L
.69782 .4483 L
.69874 .44882 L
.69972 .44938 L
.70067 .44992 L
.70158 .45043 L
.70255 .45098 L
.70348 .45151 L
.70447 .45207 L
.70543 .45261 L
.70634 .45313 L
.70732 .45368 L
.70826 .45422 L
.70926 .45478 L
.71022 .45533 L
.71115 .45585 L
.71214 .45641 L
.71309 .45695 L
.714 .45746 L
.71497 .45801 L
.71591 .45854 L
.7169 .4591 L
.71786 .45965 L
.71878 .46017 L
.71976 .46072 L
.7207 .46125 L
.72161 .46177 L
.72258 .46231 L
.72351 .46284 L
.7245 .4634 L
.72545 .46393 L
.72636 .46445 L
.72734 .465 L
.72828 .46553 L
.72928 .46609 L
.73024 .46663 L
.73116 .46716 L
.73215 .46771 L
.73309 .46824 L
.734 .46876 L
.73497 .4693 L
.73591 .46983 L
.7369 .47039 L
.73785 .47093 L
Mistroke
.73877 .47145 L
.73975 .472 L
.74069 .47253 L
.74169 .47309 L
.74266 .47363 L
.74359 .47416 L
.74457 .47471 L
.74552 .47525 L
.74644 .47576 L
.74741 .47631 L
.74835 .47683 L
.74934 .47739 L
.7503 .47793 L
.75122 .47845 L
.75221 .479 L
.75315 .47953 L
.75406 .48005 L
.75503 .48059 L
.75596 .48111 L
.75695 .48167 L
.7579 .4822 L
.75882 .48272 L
.7598 .48327 L
.76074 .4838 L
.76173 .48436 L
.7627 .4849 L
.76362 .48542 L
.76461 .48597 L
.76556 .4865 L
.76647 .48701 L
.76744 .48756 L
.76837 .48808 L
.76937 .48864 L
.77032 .48917 L
.77124 .48969 L
.77222 .49024 L
.77317 .49077 L
.77407 .49128 L
.77504 .49182 L
.77597 .49234 L
.77696 .49289 L
.77791 .49342 L
.77882 .49394 L
.7798 .49448 L
.78074 .49501 L
.78173 .49556 L
.78269 .4961 L
.78362 .49662 L
.7846 .49717 L
.78555 .4977 L
Mistroke
.78646 .49821 L
.78742 .49875 L
.78836 .49927 L
.78935 .49982 L
.7903 .50036 L
.79122 .50087 L
.7922 .50142 L
.79314 .50194 L
.79414 .5025 L
.7951 .50304 L
.79603 .50356 L
.79702 .50411 L
.79797 .50464 L
.79888 .50515 L
.79985 .50569 L
.80079 .50622 L
.80178 .50677 L
.80274 .50731 L
.80366 .50782 L
.80464 .50837 L
.80559 .5089 L
.8065 .5094 L
.80746 .50994 L
.80839 .51046 L
.80938 .51101 L
.81034 .51154 L
.81125 .51206 L
.81223 .5126 L
.81317 .51312 L
.81417 .51368 L
.81513 .51421 L
.81605 .51473 L
.81704 .51528 L
.81798 .51581 L
.81889 .51631 L
.81987 .51686 L
.8208 .51738 L
.82179 .51793 L
.82275 .51846 L
.82367 .51897 L
.82465 .51952 L
.82559 .52004 L
.82649 .52055 L
.82746 .52108 L
.82839 .5216 L
.82938 .52215 L
.83033 .52268 L
.83124 .52319 L
.83221 .52373 L
.83315 .52425 L
Mistroke
.83415 .5248 L
.83511 .52534 L
.83603 .52585 L
.83701 .5264 L
.83796 .52692 L
.83887 .52743 L
.83983 .52797 L
.84077 .52848 L
.84176 .52904 L
.84271 .52957 L
.84363 .53008 L
.84461 .53062 L
.84555 .53114 L
.84655 .5317 L
.84751 .53223 L
.84843 .53274 L
.84942 .53329 L
.85037 .53382 L
.85128 .53433 L
.85225 .53486 L
.85319 .53538 L
.85418 .53594 L
.85514 .53647 L
.85606 .53698 L
.85704 .53752 L
.85798 .53805 L
.85889 .53855 L
.85986 .53908 L
.86079 .5396 L
.86178 .54015 L
.86273 .54068 L
.86364 .54118 L
.86462 .54172 L
.86556 .54224 L
.86655 .5428 L
.86751 .54333 L
.86844 .54384 L
.86942 .54439 L
.87037 .54491 L
.87128 .54542 L
.87225 .54595 L
.87318 .54647 L
.87417 .54702 L
.87513 .54755 L
.87605 .54806 L
.87703 .5486 L
.87797 .54912 L
.87897 .54968 L
.87993 .55021 L
.88086 .55072 L
Mistroke
.88185 .55127 L
.8828 .5518 L
.88371 .5523 L
.88468 .55284 L
.88562 .55336 L
.88661 .55391 L
.88757 .55444 L
.8885 .55495 L
.88948 .55549 L
.89042 .55602 L
.89133 .55652 L
.8923 .55705 L
.89323 .55757 L
.89422 .55811 L
.89517 .55864 L
.89609 .55915 L
.89706 .55969 L
.898 .56021 L
.899 .56076 L
.89996 .56129 L
.90089 .5618 L
.90187 .56235 L
.90282 .56287 L
.90373 .56338 L
.9047 .56391 L
.90564 .56443 L
.90663 .56498 L
.90759 .56551 L
.90851 .56601 L
.90949 .56656 L
.91043 .56708 L
.91134 .56758 L
.9123 .56811 L
.91323 .56862 L
.91422 .56917 L
.91517 .56969 L
.91609 .5702 L
.91706 .57074 L
.918 .57125 L
.91899 .5718 L
.91995 .57233 L
.92088 .57284 L
.92186 .57339 L
.92281 .57391 L
.92372 .57441 L
.92468 .57494 L
.92562 .57546 L
.92661 .57601 L
.92756 .57653 L
.92848 .57704 L
Mistroke
.92946 .57758 L
.9304 .5781 L
.9314 .57865 L
.93236 .57918 L
.93329 .57969 L
.93427 .58023 L
.93522 .58076 L
.93614 .58126 L
.93711 .5818 L
.93804 .58231 L
.93904 .58286 L
.94 .58339 L
.94092 .5839 L
.9419 .58444 L
.94284 .58496 L
.94375 .58546 L
.94472 .58599 L
.94565 .5865 L
.94664 .58705 L
.94759 .58757 L
.94851 .58808 L
.94948 .58861 L
.95042 .58913 L
.95142 .58968 L
.95238 .59021 L
.9533 .59072 L
.95429 .59126 L
.95523 .59178 L
.95614 .59229 L
.95711 .59282 L
.95805 .59333 L
.95904 .59388 L
.96 .59441 L
.96092 .59491 L
.96189 .59545 L
.96284 .59597 L
.96384 .59652 L
.9648 .59705 L
.96573 .59756 L
.96672 .59811 L
.96767 .59863 L
.96858 .59913 L
.96956 .59967 L
.97049 .60018 L
.97149 .60073 L
.97245 .60126 L
.97337 .60177 L
.97435 .60231 L
.9753 .60283 L
.97619 .60332 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{449.563, 277.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007100015B000`400?l00000o`00003oo`3oooo2
0?ooo`00o`3ooolI0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0VP3oool00?l0
oooo603oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo09T0oooo003o0?oooaL0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2H0?ooo`00a03oool00`000000oooo0?oo
o`070?ooo`<00000103oool3000000<0oooo00<000000?ooo`3oool00P0000020?ooo`040000003o
ool0oooo0?ooo`<000000`3oool01@000000oooo0?ooo`3oool0000000D0oooo0`0000030?ooo`03
0000003oool0oooo00D0oooo1P0000030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`2H
0?ooo`00a03oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000`3oool010000000oooo
0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`2H0?ooo`00a03oool00`000000oooo0?oo
o`060?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo0?ooo`0000020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
09P0oooo00340?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000030?oo
o`<000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo09P0oooo00340?ooo`H000000`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`040000003o
ool0oooo000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo09P0oooo00340?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`040000
003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`8000000P3oool01@000000oooo
0?ooo`3oool0000009X0oooo00340?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
oooo0`0000040?ooo`<000000`3oool00`000000oooo0000000200000080oooo00@000000?ooo`3o
ool0oooo0`0000030?ooo`040000003oool00000000000H0oooo0`0000020?ooo`<000001P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00H000000?ooo`3oool0oooo0000
003oool200000080oooo0P0000040?ooo`030000003oool0oooo09P0oooo00340?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo000000090?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0V@3oool00<@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`8000002P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo09X0oooo00340?ooo`H000004@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01P0oooo0P0000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0/@3oool00?l0
oooo`P3oool00?l0oooo`P3oool00?l0oooo`P3oool00?l0oooo`P3oool00?l0oooo`P3oool00?l0
oooo`P3oool00?l0oooo`P3oool003X0oooo100000030?ooo`040000003oool0oooo0?ooo`@00000
;P3oool4000000<0oooo00<000000?ooo`3oool01P00000^0?ooo`@000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02h0oooo1000000d0?ooo`@000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02h0oooo100000030?ooo`030000003oool0oooo00H00000
;@3oool4000000<0oooo00@000000?ooo`3oool0oooo1000000<0?ooo`00>@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`090?ooo`00>@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo000a
0?ooo`L0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0280oooo1`0000000`3oool000000?ooo`030?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool09@3oool7000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool0
03T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`00>@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0`00000]0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0
oooo0`00000<0?ooo`00>@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
000i0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0000
000_0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000;`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool003T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool2000002l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool2000002l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`00>P3oool4000000L0oooo1000000^0?oo
o`@000001`3oool4000002l0oooo100000090?ooo`030000003oool0oooo02h0oooo1000000d0?oo
o`@000002@3oool00`000000oooo0?ooo`0^0?ooo`@000001`3oool4000002h0oooo100000070?oo
o`@00000303oool00?l0oooo`P3oool00?l0oooo`P3oool00?l0oooo`P3oool001h0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`3oool400000?l0ooooU`3oool001h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooU03oool0
01h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0?l0ooooU03oool001h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0ooooo`000025000000T0oooo000N0?ooo`030000003oool0oooo00D0oooo
0P0000030?ooo`030000003oool0oooo00H0oooo100000050?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo
0`0000090?ooo`007P3oool00`000000oooo0?ooo`050?ooo`030000003oool00000008000002@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3o
ool001h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`00703oool00`00
0000oooo000000070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0A03oool00`00
07l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`00
07l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool001d0
oooo0P0000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000
oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000
oooo0?ooo`070?ooo`007P3oool00`000000oooo0?ooo`060?ooo`@000002@3oool00`000000oooo
0?ooo`060?ooo`800000?03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo
00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo
00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool01`3oool2000003/0oooo00<0
001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0
001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000d
0?ooo`030000003oool0oooo00T0oooo0P00000i0?ooo`030000O`3oool0oooo03X0oooo00<0001o
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o
0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`0:0?oo
o`800000>03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?oo
o`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?oo
o`3oool01`3oool003@0oooo0`00000;0?ooo`800000=`3oool00`0007l0oooo0?ooo`0j0?ooo`03
0000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`03
0000O`3oool0oooo0480oooo0P0000090?ooo`00=03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo03@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000
003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000
003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo00h0oooo0P00000d0?ooo`030000O`3o
ool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3o
ool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00=03oool0
0`000000oooo0?ooo`0?0?ooo`800000<`3oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0
oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0
oooo04<0oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0403oool20000
0380oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo
03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo
00L0oooo000d0?ooo`030000003oool0oooo0180oooo0P00000`0?ooo`030000O`3oool0oooo03X0
oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0
oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo
0?ooo`0C0?ooo`800000;`3oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo
00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo
00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0503oool2000002h0oooo00<0
001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0
001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000d
0?ooo`<000005P3oool2000002`0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k
0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`12
0?ooo`8000002@3oool003@0oooo00<000000?ooo`3oool05`3oool2000002/0oooo00<0001o0?oo
o`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?oo
o`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000d0?ooo`03
0000003oool0oooo01P0oooo0P00000Z0?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3o
ool0@`3oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`0J0?ooo`800000
:03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0
>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool0
1`3oool003@0oooo00<000000?ooo`3oool06`3oool2000002L0oooo00<0001o0?ooo`3oool0>P3o
ool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3o
ool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0
oooo01`0oooo0P00000V0?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool0
0`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`0N0?ooo`800000903oool00`00
07l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`00
07l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool003@0
oooo00<000000?ooo`3oool07`3oool2000002<0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0
oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0
oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo
00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo
00<000000?ooo`3oool01`3oool003@0oooo0`00000R0?ooo`800000803oool00`0007l0oooo0?oo
o`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?oo
o`0k0?ooo`030000O`3oool0oooo0480oooo0P0000090?ooo`00=03oool00`000000oooo0?ooo`0S
0?ooo`8000007`3oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<00000
0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<00000
0?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0L0?oo
o`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?oo
o`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?oo
o`00=03oool00`000000oooo0?ooo`0V0?ooo`800000703oool00`0007l0oooo0?ooo`0j0?ooo`03
0000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`03
0000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0
9`3oool2000001/0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000
003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000
003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo02T0oooo0P00000I0?ooo`030000O`3o
ool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3o
ool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00=03oool0
0`000000oooo0?ooo`0Z0?ooo`800000603oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0
oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0
oooo04<0oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0:`3oool20000
01L0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo
03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo
00L0oooo000d0?ooo`030000003oool0oooo02d0oooo0P00000E0?ooo`030000O`3oool0oooo03X0
oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0
oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00=03oool3000002h0oooo
0P00000D0?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo
0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@P3oool2000000T0oooo
000d0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool04@3oool00`0007l0oooo0?oo
o`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?oo
o`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool003@0oooo00<00000
0?ooo`3oool0<@3oool200000140oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k
0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`13
0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo0380oooo0P00000@0?oo
o`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?oo
o`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?oo
o`00=03oool00`000000oooo0?ooo`0d0?ooo`8000003P3oool00`0007l0oooo0?ooo`0j0?ooo`03
0000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`03
0000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool001h0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0=@3oool2000000d0
oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0
oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0
oooo000N0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00X0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo
0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo
0?ooo`130?ooo`030000003oool0oooo00L0oooo000N0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0h0?ooo`8000002P3oool00`0007l0oooo0?oo
o`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?oo
o`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool001h0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`@00000>00007l2000008@0001o00<00000
0000O`0007l0_00007l3000000T0oooo000N0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0k0?ooo`8000001`3oool00`0007l0oooo0?ooo`0j0?oo
o`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?oo
o`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool001h0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03`0oooo0P0000060?ooo`03
0000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`03
0000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00
7P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
?P3oool2000000@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000
003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000
003oool0oooo00L0oooo000L0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0o0?ooo`8000000`3oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3o
ool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3o
ool0oooo04<0oooo00<000000?ooo`3oool01`3oool001d0oooo0P00000;0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0@@3oool010000000oooo0?ooo`0007ll0?ooo`030000O`3o
ool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3o
ool0oooo04<0oooo00<000000?ooo`3oool01`3oool001h0oooo00<000000?ooo`3oool01@3oool6
000000P0oooo00<000000?ooo`3oool0@P3oool2000000030000O`3oool0oooo03X0oooo00<0001o
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o
0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`130?oo
o`800000?03oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?oo
o`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000d0?ooo`03
0000003oool0oooo04@0oooo00<0001o000000000000>P3oool00`0007l0oooo0?ooo`0k0?ooo`03
0000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`03
0000003oool0oooo00L0oooo000d0?ooo`<00000A03oool0100007l0oooo00000000000i0?ooo`03
0000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`03
0000O`3oool0oooo0480oooo0P0000090?ooo`00=03oool00`000000oooo0?ooo`140?ooo`040000
O`3oool0oooo0?ooo`800000=`3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0
oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0
oooo000d0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool00P3oool2000003H0oooo
00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo
00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?oo
o`140?ooo`030000O`3oool0oooo00@0oooo0P00000d0?ooo`030000O`3oool0oooo03/0oooo00<0
00000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<0
00000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`05
0?ooo`800000<`3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o
0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000d0?oo
o`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool01`3oool200000340oooo00<0001o0?oo
o`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?oo
o`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`140?ooo`03
0000O`3oool0oooo00P0oooo0P00000`0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3o
ool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3o
ool01`3oool003@0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0:0?ooo`800000
;P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0
>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003o
ool0oooo04@0oooo00<0001o0?ooo`3oool02`3oool2000002d0oooo00<0001o0?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3o
ool00`000000oooo0?ooo`070?ooo`00=03oool3000004@0oooo00<0001o0?ooo`3oool0303oool3
000002/0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0
oooo03/0oooo00<0001o0?ooo`3oool0@P3oool2000000T0oooo000d0?ooo`030000003oool0oooo
04@0oooo00<0001o0?ooo`3oool03P3oool2000002X0oooo00<0001o0?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`00
0000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo00l0
oooo0`00000X0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0
oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool003@0oooo
00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0A0?ooo`8000009`3oool00`0007l0oooo
0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo
0?ooo`130?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo04@0oooo00<0
001o0?ooo`3oool04P3oool3000002D0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?oo
o`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?oo
o`070?ooo`00=03oool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo01@0oooo0P00000T
0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k
0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?oo
o`3oool0A03oool00`0007l0oooo0?ooo`0E0?ooo`8000008`3oool00`0007l0oooo0?ooo`0k0?oo
o`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?oo
o`030000003oool0oooo00L0oooo00090?ooo`800000:@3oool00`000000oooo0?ooo`140?ooo`03
0000O`3oool0oooo01L0oooo0P00000Q0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3o
ool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3o
ool01`3oool000/0oooo0`00000V0?ooo`<00000A03oool00`0007l0oooo0?ooo`0H0?ooo`800000
803oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0
>`3oool00`0007l0oooo0?ooo`120?ooo`8000002@3oool000h0oooo0`00000S0?ooo`030000003o
ool0oooo04@0oooo00<0001o0?ooo`3oool06P3oool2000001h0oooo00<0001o0?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3o
ool00`000000oooo0?ooo`070?ooo`004@3oool200000240oooo00<000000?ooo`3oool0A03oool0
0`0007l0oooo0?ooo`0K0?ooo`<00000703oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0
oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0
oooo00L0oooo000>0?ooo`<000008`3oool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo
01d0oooo0P00000K0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`00
07l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool000X0
oooo1000000V0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool07`3oool2000001T0
oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0
oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`002@3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0803oool2000001P0oooo
00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo
00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`002P3oool4000002H0oooo00<0
00000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0Q0?ooo`<000005P3oool00`0007l0oooo0?oo
o`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?oo
o`130?ooo`030000003oool0oooo00L0oooo000>0?ooo`<000008`3oool00`000000oooo0?ooo`14
0?ooo`030000O`3oool0oooo02<0oooo0P00000E0?ooo`030000O`3oool0oooo03/0oooo00<00000
0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<00000
0?ooo`3oool01`3oool00140oooo0P00000Q0?ooo`030000003oool0oooo04@0oooo00<0001o0?oo
o`3oool0903oool3000001<0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?oo
o`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?oo
o`003P3oool3000002<0oooo0`0000140?ooo`030000O`3oool0oooo02H0oooo0P00000B0?ooo`03
0000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`03
0000O`3oool0oooo0480oooo0P0000090?ooo`002`3oool3000002H0oooo00<000000?ooo`3oool0
A03oool00`0007l0oooo0?ooo`0W0?ooo`<00000403oool00`0007l0oooo0?ooo`0k0?ooo`030000
003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000
003oool0oooo00L0oooo00090?ooo`800000:@3oool00`000000oooo0?ooo`140?ooo`030000O`3o
ool0oooo02T0oooo0P00000?0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3o
ool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3o
ool000d0oooo00<000000?ooo`3oool00P00000R0?ooo`030000003oool0oooo04@0oooo00<0001o
0?ooo`3oool0:`3oool2000000d0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j
0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`07
0?ooo`00303oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0A03oool00`0007l0oooo0?ooo`0/0?ooo`800000303oool00`0007l0oooo0?ooo`0k
0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`13
0?ooo`030000003oool0oooo00L0oooo000<0?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`@000002@3o
ool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo02h0oooo0P00000:0?ooo`030000O`3o
ool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3o
ool0oooo04<0oooo00<000000?ooo`3oool01`3oool000`0oooo00H000000?ooo`3oool000000?oo
o`00000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0;`3oool3000000P0oooo
00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo
00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`003@3oool6000000/0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0a0?ooo`8000001`3oool00`0007l0oooo0?oo
o`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?oo
o`130?ooo`030000003oool0oooo00L0oooo000N0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04@0oooo00<0001o
0?ooo`3oool0<`3oool2000000D0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j
0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`07
0?ooo`007P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool4000007X0001o0P0000120000O`030000000007l0001o0;`0001o0`0000090?oo
o`002@3oool00`000000oooo0?ooo`07000000/0oooo00<000000?ooo`3oool01P3oool4000000T0
oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0e0?ooo`<000000P3oool00`0007l0
oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0
oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000N0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04@0oooo
00<0001o0?ooo`3oool0=`3oool2000000030?ooo`0007l0oooo03`0oooo00<000000?ooo`3oool0
>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool0
1`3oool001`0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0i0?ooo`800000?@3o
ool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3o
ool00`000000oooo0?ooo`070?ooo`003@3oool200000080oooo00<000000?ooo`3oool02@3oool2
000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo04@0oooo00<0001o0?ooo`3oool0>P3oool2000003`0oooo00<000000?ooo`3oool0>P3oool0
0`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool0
00`0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00H0oooo100000090?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool0
100007l0oooo00000000000j0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3o
ool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000<0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`140?ooo`030000O`3o
ool0oooo03X0oooo00@0001o0?ooo`3oool0oooo0P00000h0?ooo`030000003oool0oooo03X0oooo
00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo
000<0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool00P3oool2000003L0oooo
00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo
00<000000?ooo`3oool01`3oool000d0oooo00<000000?ooo`3oool00P00000R0?ooo`030000003o
ool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`040?ooo`800000=@3o
ool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3o
ool00`000000oooo0?ooo`070?ooo`00=03oool3000004@0oooo00<0001o0?ooo`3oool0>P3oool0
0`0007l0oooo0?ooo`050?ooo`800000=03oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0
oooo03/0oooo00<0001o0?ooo`3oool0@P3oool2000000T0oooo000<0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo
00L0oooo0P00000b0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`00
07l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000:0?ooo`T000008@3oool00`000000
oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0203oool200000340
oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0
oooo00<000000?ooo`3oool01`3oool000`0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo
0?ooo`0:0?ooo`800000;`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo
00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?oo
o`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0303oool2000002d0oooo00<0
00000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<0
00000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j
0?ooo`030000O`3oool0oooo00d0oooo0P00000/0?ooo`030000003oool0oooo03X0oooo00<0001o
0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000d0?oo
o`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0?0?oo
o`800000:P3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?oo
o`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`140?ooo`03
0000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0403oool3000002P0oooo00<000000?ooo`3o
ool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3o
ool01`3oool003@0oooo0`0000140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0
4P3oool2000002L0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000
O`3oool0oooo0480oooo0P0000090?ooo`00303oool:000001h0oooo00<000000?ooo`3oool0A03o
ool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo01@0oooo0P00000U0?ooo`030000003o
ool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003o
ool0oooo00L0oooo000=0?ooo`050000003oool0oooo0?ooo`0000008P3oool00`000000oooo0?oo
o`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool05@3oool2000002@0oooo00<0
00000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<0
00000?ooo`3oool01`3oool000`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0G
0?ooo`8000008P3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o
0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00303oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?oo
o`030000O`3oool0oooo01T0oooo0P00000P0?ooo`030000003oool0oooo03X0oooo00<0001o0?oo
o`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000=0?ooo`D0
00008P3oool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3o
ool06P3oool3000001h0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`03
0000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0
A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo01`0oooo0P00000M0?ooo`030000
003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000
003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3o
ool00`0007l0oooo0?ooo`0M0?ooo`800000703oool00`000000oooo0?ooo`0j0?ooo`030000O`3o
ool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`003@3oool5
00000280oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0
oooo01l0oooo0P00000J0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool0
0`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000<0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool07`3oool3000004@0oooo00<0001o0?ooo`3oool0>P3oool00`00
07l0oooo0?ooo`0Q0?ooo`800000603oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo
03/0oooo00<0001o0?ooo`3oool0@P3oool2000000T0oooo000<0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0
oooo00<0001o0?ooo`3oool08P3oool3000001H0oooo00<000000?ooo`3oool0>P3oool00`0007l0
oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool000`0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo04@0oooo
00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0T0?ooo`8000005@3oool00`000000oooo
0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo
0?ooo`070?ooo`003@3oool500000280oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?oo
o`0j0?ooo`030000O`3oool0oooo02H0oooo0P00000C0?ooo`030000003oool0oooo03X0oooo00<0
001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000d
0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0W
0?ooo`8000004P3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o
0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`140?oo
o`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0:@3oool200000100oooo00<000000?oo
o`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?oo
o`3oool01`3oool000d0oooo0P0000020?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo02X0oooo0`00000>0?ooo`03
0000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`03
0000003oool0oooo00L0oooo000<0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3o
ool0;03oool2000000d0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`03
0000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool000`0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3o
ool0>P3oool00`0007l0oooo0?ooo`0^0?ooo`8000002`3oool00`000000oooo0?ooo`0j0?ooo`03
0000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00
303oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo0`0000140?ooo`03
0000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0;`3oool3000000T0oooo00<000000?ooo`3o
ool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo0480oooo0P0000090?ooo`00
3@3oool00`000000oooo0?ooo`0200000280oooo00<000000?ooo`3oool0A03oool00`0007l0oooo
0?ooo`0j0?ooo`030000O`3oool0oooo0340oooo0P0000080?ooo`030000003oool0oooo03X0oooo
00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo
000d0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?oo
o`0c0?ooo`8000001P3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0
001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`14
0?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0=@3oool2000000@0oooo00<00000
0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<00000
0?ooo`3oool01`3oool000T0oooo00<000000?ooo`3oool01`00000Q0?ooo`030000003oool0oooo
04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0f0?ooo`<000000P3oool00`00
0000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`00
0000oooo0?ooo`070?ooo`007P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?oo
o`<000002P3oool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?oo
o`3oool0>03oool2000000030?ooo`000000oooo03/0oooo00<0001o0?ooo`3oool0>`3oool00`00
07l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000<0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?oo
o`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03T0oooo0`00000l0?oo
o`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?oo
o`002P3oool9000000/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`80
0000>`3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3o
ool01`3oool000`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool400000;h0001o00@000000000O`000000
0000^`0007l3000000T0oooo000N0?ooo`030000003oool0oooo00H0oooo0`0000000`3oool00000
0?ooo`070?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo
0?ooo`0k0?ooo`040000003oool0oooo0?ooo`800000=`3oool00`0007l0oooo0?ooo`0k0?ooo`03
0000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool001h0oooo00<000000?ooo`3oool0
1@3oool010000000oooo0?ooo`3oool2000000P0oooo00<000000?ooo`3oool0A03oool00`0007l0
oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool00P3oool3000003D0
oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0
oooo00090?ooo`030000003oool0oooo00L000002`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`140?ooo`030000
O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`040?ooo`800000
=03oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool0
1`3oool001`0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3o
ool0oooo03/0oooo00<000000?ooo`3oool01@3oool300000380oooo00<0001o0?ooo`3oool0>`3o
ool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000M0?ooo`8000001`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0A03oool0
0`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool01`3oool3
00000300oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0
oooo00L0oooo000=0?ooo`D00000303oool00`000000oooo0?ooo`060?ooo`@000002@3oool00`00
0000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`00
0000oooo0?ooo`090?ooo`800000;`3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo
04<0oooo00<000000?ooo`3oool01`3oool000`0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0
oooo0?ooo`0k0?ooo`030000003oool0oooo00/0oooo0P00000]0?ooo`030000O`3oool0oooo03/0
oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00303oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo
0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0303oool3000002/0oooo
00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo
000<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07`3oool3000004@0oooo00<0
001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo00h0oooo0P00
000Z0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@P3oool2000000T0oooo000=
0?ooo`D000008P3oool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0001o
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0@0?ooo`800000:03oool00`0007l0oooo0?ooo`0k
0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?oo
o`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?oo
o`3oool04P3oool2000002H0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?oo
o`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3o
ool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo01<0oooo0`00000T0?ooo`03
0000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00
303oool700000240oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000
O`3oool0oooo03/0oooo00<000000?ooo`3oool05@3oool2000002<0oooo00<0001o0?ooo`3oool0
>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000<0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3o
ool0oooo03/0oooo00<000000?ooo`3oool05`3oool200000240oooo00<0001o0?ooo`3oool0>`3o
ool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000<0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0
oooo03/0oooo00<000000?ooo`3oool0603oool3000001l0oooo00<0001o0?ooo`3oool0>`3oool0
0`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000<0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo
03/0oooo00<000000?ooo`3oool06P3oool2000001h0oooo00<0001o0?ooo`3oool0>`3oool00`00
07l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000=0?ooo`H000008@3oool00`000000
oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000
oooo0?ooo`0L0?ooo`800000703oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0
oooo00<000000?ooo`3oool01`3oool003@0oooo0`0000140?ooo`030000O`3oool0oooo03X0oooo
00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0M0?ooo`<000006P3oool00`0007l0oooo
0?ooo`0k0?ooo`030000O`3oool0oooo0480oooo0P0000090?ooo`00=03oool00`000000oooo0?oo
o`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?oo
o`0O0?ooo`8000006@3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<0
00000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j
0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool08@3oool2000001L0oooo00<0001o
0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000d0?oo
o`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?oo
o`030000003oool0oooo02<0oooo0P00000E0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?oo
o`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`140?ooo`03
0000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0T0?ooo`<0
00004`3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3o
ool01`3oool000`0oooo2000000P0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0
>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo02H0oooo0P00000B0?ooo`030000
O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`002`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0A03o
ool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0:03o
ool200000100oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003o
ool0oooo00L0oooo000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0Z0?ooo`8000003P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0
oooo04<0oooo00<000000?ooo`3oool01`3oool003@0oooo0`0000140?ooo`030000O`3oool0oooo
03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0[0?ooo`8000003@3oool00`00
07l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo0480oooo0P0000090?ooo`00=03oool00`000000
oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000
oooo0?ooo`0]0?ooo`8000002`3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo04<0
oooo00<000000?ooo`3oool01`3oool000`0oooo1`00000Q0?ooo`030000003oool0oooo04@0oooo
00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo02l0oooo
0P0000090?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo
0?ooo`070?ooo`003@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04@0oooo00<0
001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo0340oooo0P00
00070?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?oo
o`070?ooo`00303oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04@0oooo00<0001o
0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo0380oooo0P000006
0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`07
0?ooo`00303oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04@0oooo00<0001o0?oo
o`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03@0oooo0P0000040?oo
o`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?oo
o`003@3oool600000240oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`03
0000O`3oool0oooo03/0oooo00<000000?ooo`3oool0=P3oool200000080oooo00<0001o0?ooo`3o
ool0>`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000<0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000
O`3oool0oooo03/0oooo00<000000?ooo`3oool0>03oool2000000030000O`3oool0oooo03/0oooo
00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00303oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?oo
o`0k0?ooo`030000003oool0oooo03T0oooo0`00000l0?ooo`030000O`3oool0oooo04<0oooo00<0
00000?ooo`3oool01`3oool000`0oooo00<000000?ooo`3oool09@3oool3000004@0oooo00<0001o
0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o
000000000000>`3oool00`0007l0oooo0?ooo`120?ooo`8000002@3oool000d0oooo1P00000Q0?oo
o`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?oo
o`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool00P00000i0?ooo`030000O`3oool0oooo
04<0oooo00<000000?ooo`3oool01`3oool000X0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0
oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool00P3oool2000003L0
oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`002`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo
0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo
0?ooo`030?ooo`<00000=@3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo
000<0?ooo`P00000803oool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0
001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo00D0oooo0P00
000d0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool002H0oooo1P000008
0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k
0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool01`3oool200000380oooo00<0001o
0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`009`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?oo
o`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool02@3oool200000300oooo00<0001o0?oo
o`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00:03oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`03
0000003oool0oooo03X0oooo00<0001o0?ooo`3oool02P3oool3000002h0oooo00<0001o0?ooo`3o
ool0@`3oool00`000000oooo0?ooo`070?ooo`00:@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000
003oool0oooo03X0oooo00<0001o0?ooo`3oool0303oool2000002d0oooo00<0001o0?ooo`3oool0
@`3oool00`000000oooo0?ooo`070?ooo`00:P3oool00`000000oooo0?ooo`070?ooo`@00000_P00
07l00`000000001o0000O`1;0000O`800000K`0007l3000000T0oooo000[0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0
oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0@0?ooo`800000:@3oool0
0`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000[0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo
03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0A0?ooo`<000009`3oool00`00
07l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000[0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0
oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0C0?ooo`8000009P3oool00`0007l0
oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo
00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo01D0oooo
0P00000T0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool002L0oooo1000
00090?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?oo
o`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool05`3oool200000280oooo00<0
001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`14
0?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j
0?ooo`030000O`3oool0oooo01P0oooo0`00000P0?ooo`030000O`3oool0oooo04<0oooo00<00000
0?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?oo
o`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0J0?oo
o`8000007`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000d0?ooo`<0
0000A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3o
ool0>P3oool00`0007l0oooo0?ooo`0L0?ooo`8000007@3oool00`0007l0oooo0?ooo`120?ooo`80
00002@3oool003@0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000
O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0N0?ooo`800000
6`3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003o
ool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003o
ool0oooo03X0oooo00<0001o0?ooo`3oool07`3oool3000001T0oooo00<0001o0?ooo`3oool0@`3o
ool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`140?ooo`030000O`3oool0
oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0
oooo0240oooo0`00000G0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool0
03@0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo
03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0S0?ooo`8000005P3oool00`00
07l0oooo0?ooo`130?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo04@0
oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0
oooo00<0001o0?ooo`3oool09@3oool2000001@0oooo00<0001o0?ooo`3oool0@`3oool00`000000
oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo
00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo02L0oooo
0P00000B0?ooo`030000O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool003@0oooo00<0
00000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0
00000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0X0?ooo`<00000403oool00`0007l0oooo0?oo
o`130?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo04@0oooo00<0001o
0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o
0?ooo`3oool0:P3oool3000000h0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`07
0?ooo`00=03oool3000004@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?oo
o`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0;03oool3000000`0oooo00<0001o0?oo
o`3oool0@P3oool2000000T0oooo000d0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3o
ool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3o
ool0;P3oool2000000/0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00
=03oool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0
>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo02l0oooo0`0000090?ooo`030000
O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0A03o
ool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3o
ool00`0007l0oooo0?ooo`0a0?ooo`<000001`3oool00`0007l0oooo0?ooo`130?ooo`030000003o
ool0oooo00L0oooo000d0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool0
0`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0<`3oool3
000000D0oooo00<0001o0?ooo`3oool0@`3oool00`000000oooo0?ooo`070?ooo`00=03oool00`00
0000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03D0oooo0P0000040?ooo`030000O`3oool0oooo
04<0oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0A03oool00`0007l0
oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0
oooo0?ooo`0g0?ooo`8000000P3oool00`0007l0oooo0?ooo`130?ooo`030000003oool0oooo00L0
oooo000d0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo
0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>@3oool2000000030000
O`3oool0oooo04<0oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0A03o
ool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3o
ool00`0007l0oooo0?ooo`0j0?ooo`<00000A03oool00`000000oooo0?ooo`070?ooo`00=03oool3
000004@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0
oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l00000000000120?ooo`8000002@3oool0
03@0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo
03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo
00800000@@3oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`140?ooo`03
0000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`03
0000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool00P3oool2000003l0oooo00<000000?ooo`3o
ool01`3oool003@0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000
O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000
O`3oool0oooo00<0oooo0`00000m0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003o
ool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003o
ool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`050?ooo`<00000>`3o
ool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`140?ooo`030000O`3oool0
oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0
oooo03/0oooo00<0001o0?ooo`3oool01`3oool3000003T0oooo00<000000?ooo`3oool01`3oool0
03@0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo
03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo
00T0oooo0P00000h0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo04@0
oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0
oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0;0?ooo`800000=P3oool00`000000
oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo
00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo
00<0001o0?ooo`3oool0303oool3000003@0oooo00<000000?ooo`3oool01`3oool003@0oooo0`00
00140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?oo
o`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool03P3oool300000340oooo0P00
00090?ooo`00=03oool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0001o
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o
0?ooo`3oool0403oool200000340oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?oo
o`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?oo
o`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo0180oooo0P00000_0?oo
o`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3o
ool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3o
ool0>`3oool00`0007l0oooo0?ooo`0D0?ooo`800000;@3oool00`000000oooo0?ooo`070?ooo`00
=03oool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0
>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0
5P3oool2000002/0oooo00<000000?ooo`3oool01`3oool001/0oooo1P0000020?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`140?ooo`030000O`3o
ool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3o
ool0oooo03/0oooo00<0001o0?ooo`3oool05`3oool3000002T0oooo00<000000?ooo`3oool01`3o
ool001`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0
oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0I0?ooo`800000:03oool0
0`000000oooo0?ooo`070?ooo`007@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo
03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo
01/0oooo0P00000V0?ooo`030000003oool0oooo00L0oooo000N0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool400000;h0001o00<000000000O`0007l0V00007l200000280
001o0`0000090?ooo`007`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo
00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo01h0oooo
0`00000R0?ooo`030000003oool0oooo00L0oooo000P0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0
001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0
001o0?ooo`3oool0803oool300000200oooo00<000000?ooo`3oool01`3oool00200oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04@0oooo00<0001o
0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o
0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0R0?ooo`<000007P3oool00`000000oooo0?ooo`07
0?ooo`00803oool00`000000oooo0?ooo`040?ooo`030000003oool0000000X0oooo00<000000?oo
o`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?oo
o`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo02@0oooo0P00000M0?oo
o`030000003oool0oooo00L0oooo000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01@3oool2000000X0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`03
0000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`03
0000O`3oool0oooo02H0oooo0P00000K0?ooo`030000003oool0oooo00L0oooo000L0?ooo`@00000
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0
>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0
>`3oool00`0007l0oooo0?ooo`0X0?ooo`8000006@3oool00`000000oooo0?ooo`070?ooo`00=03o
ool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0:@3o
ool3000001L0oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0A03oool0
0`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool0
0`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo02/0oooo0`00000E0?ooo`030000003oool0
oooo00L0oooo000d0?ooo`<00000A03oool00`0007l0oooo0?ooo`0j0?ooo`030000O`3oool0oooo
03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000O`3oool0oooo
02d0oooo0P00000C0?ooo`8000002@3oool003@0oooo00<000000?ooo`3oool0A03oool00`0007l0
oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0
oooo0?ooo`0k0?ooo`030000O`3oool0oooo02l0oooo0P00000B0?ooo`030000003oool0oooo00L0
oooo000d0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo
0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo
0?ooo`0`0?ooo`<00000403oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?oo
o`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?oo
o`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0<P3oool3000000h0oooo00<0
00000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j
0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k
0?ooo`030000O`3oool0oooo03@0oooo0`00000<0?ooo`030000003oool0oooo00L0oooo000d0?oo
o`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?oo
o`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`0007l0oooo0?ooo`0f0?oo
o`8000002`3oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`140?ooo`03
0000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0j0?ooo`03
0000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0>03oool2000000T0oooo00<000000?ooo`3o
ool01`3oool003@0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0j0?ooo`030000
O`3oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`0k0?ooo`030000
O`3oool0oooo03X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`00=03o
ool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo03/0oooo00<0001o0?ooo`3oool0@`3o
ool00`000000oooo0?ooo`070?ooo`00=03oool3000004@0oooo00<0001o0?ooo`3oool0>P3oool0
0`0007l0oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3oool0>`3oool0
0`0007l0oooo0?ooo`120?ooo`8000002@3oool003@0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`00=03ooooo000008D00000
2@3oool00001\
\>"],
  ImageRangeCache->{{{57.1875, 415.813}, {463.563, 242.313}} -> {-0.517337, \
2.20948, 0.00162928, 0.00230318}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[\(Lensing[{WaistLXY, zWaistLXY}, {f, zL1}, 
            kk]\)\[LeftDoubleBracket]2\[RightDoubleBracket], {f, 0, 10}, 
        GridLines \[Rule] Automatic, Frame \[Rule] True, 
        PlotPoints \[Rule] 1000\[IndentingNewLine], 
        FrameLabel \[Rule] {"\<Focal Length of L1 (m)\>", "\<Waist position \
(m)\>"}, PlotRange \[Rule] All];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.290619 0.0735924 [
[.02381 -0.0125 -5.59375 -16.375 ]
[.02381 -0.0125 5.59375 0 ]
[.21429 -0.0125 -5.59375 -16.375 ]
[.21429 -0.0125 5.59375 0 ]
[.40476 -0.0125 -5.59375 -16.375 ]
[.40476 -0.0125 5.59375 0 ]
[.59524 -0.0125 -5.59375 -16.375 ]
[.59524 -0.0125 5.59375 0 ]
[.78571 -0.0125 -5.59375 -16.375 ]
[.78571 -0.0125 5.59375 0 ]
[.97619 -0.0125 -9.1875 -16.375 ]
[.97619 -0.0125 9.1875 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -67.0938 -32.75 ]
[.5 -0.0125 67.0938 -16.375 ]
[-0.0125 .14343 -20.1875 -8.1875 ]
[-0.0125 .14343 0 8.1875 ]
[-0.0125 .29062 -11.1875 -8.1875 ]
[-0.0125 .29062 0 8.1875 ]
[-0.0125 .4378 -11.1875 -8.1875 ]
[-0.0125 .4378 0 8.1875 ]
[-0.0125 .58499 -11.1875 -8.1875 ]
[-0.0125 .58499 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -53.75 ]
[-0.01875 .30902 -20.1875 53.75 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .61803 L
s
.40476 0 m
.40476 .61803 L
s
.59524 0 m
.59524 .61803 L
s
.78571 0 m
.78571 .61803 L
s
0 .14343 m
1 .14343 L
s
0 .29062 m
1 .29062 L
s
0 .4378 m
1 .4378 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.40476 0 m
.40476 .00625 L
s
gsave
.40476 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.59524 0 m
.59524 .00625 L
s
gsave
.59524 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -128.094 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Focal) show
98.188 16.625 moveto
(Length) show
141.250 16.625 moveto
(of) show
156.063 16.625 moveto
(L1) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
174.000 16.625 moveto
(H) show
178.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
189.000 16.625 moveto
(L) show
193.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .14343 m
.00625 .14343 L
s
gsave
-0.0125 .14343 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .29062 m
.00625 .29062 L
s
gsave
-0.0125 .29062 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .4378 m
.00625 .4378 L
s
gsave
-0.0125 .4378 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .58499 m
.00625 .58499 L
s
gsave
-0.0125 .58499 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03305 m
.00375 .03305 L
s
0 .06984 m
.00375 .06984 L
s
0 .10664 m
.00375 .10664 L
s
0 .18023 m
.00375 .18023 L
s
0 .21703 m
.00375 .21703 L
s
0 .25382 m
.00375 .25382 L
s
0 .32742 m
.00375 .32742 L
s
0 .36421 m
.00375 .36421 L
s
0 .40101 m
.00375 .40101 L
s
0 .4746 m
.00375 .4746 L
s
0 .5114 m
.00375 .5114 L
s
0 .54819 m
.00375 .54819 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -143.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
114.75 12.1875 translate
90 rotate
-114.75 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Waist) show
99.250 16.625 moveto
(position) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
147.313 16.625 moveto
(H) show
151.500 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
162.313 16.625 moveto
(L) show
166.500 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .14343 m
1 .14343 L
s
.99375 .29062 m
1 .29062 L
s
.99375 .4378 m
1 .4378 L
s
.99375 .58499 m
1 .58499 L
s
.125 Mabswid
.99625 .03305 m
1 .03305 L
s
.99625 .06984 m
1 .06984 L
s
.99625 .10664 m
1 .10664 L
s
.99625 .18023 m
1 .18023 L
s
.99625 .21703 m
1 .21703 L
s
.99625 .25382 m
1 .25382 L
s
.99625 .32742 m
1 .32742 L
s
.99625 .36421 m
1 .36421 L
s
.99625 .40101 m
1 .40101 L
s
.99625 .4746 m
1 .4746 L
s
.99625 .5114 m
1 .5114 L
s
.99625 .54819 m
1 .54819 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .29062 m
1 .29062 L
s
.5 Mabswid
.02381 .30902 m
.02474 .30974 L
.02575 .31053 L
.0267 .31128 L
.02761 .312 L
.02859 .31278 L
.02952 .31353 L
.03052 .31434 L
.03148 .31512 L
.0324 .31588 L
.03338 .31669 L
.03433 .31748 L
.03524 .31825 L
.03621 .31907 L
.03714 .31986 L
.03813 .32071 L
.03908 .32154 L
.04 .32234 L
.04098 .3232 L
.04192 .32403 L
.04292 .32492 L
.04388 .32579 L
.0448 .32663 L
.04579 .32753 L
.04674 .3284 L
.04765 .32925 L
.04862 .33016 L
.04956 .33104 L
.05055 .33198 L
.05151 .3329 L
.05243 .33378 L
.05341 .33474 L
.05435 .33566 L
.05526 .33655 L
.05622 .33751 L
.05715 .33844 L
.05814 .33944 L
.05909 .34041 L
.06001 .34135 L
.06098 .34236 L
.06192 .34333 L
.06292 .34438 L
.06388 .3454 L
.0648 .34638 L
.06579 .34744 L
.06673 .34847 L
.06764 .34946 L
.06861 .35053 L
.06954 .35156 L
.07054 .35267 L
Mistroke
.07149 .35375 L
.07241 .35479 L
.07339 .35591 L
.07433 .357 L
.07533 .35816 L
.07629 .3593 L
.07722 .36039 L
.07821 .36157 L
.07916 .36271 L
.08007 .36382 L
.08104 .36501 L
.08198 .36616 L
.08297 .3674 L
.08393 .3686 L
.08485 .36976 L
.08584 .37101 L
.08678 .37222 L
.08769 .3734 L
.08866 .37466 L
.08959 .37588 L
.09058 .37719 L
.09153 .37847 L
.09245 .3797 L
.09342 .38103 L
.09436 .38231 L
.09536 .38369 L
.09632 .38503 L
.09725 .38633 L
.09823 .38772 L
.09918 .38907 L
.10009 .39038 L
.10106 .39179 L
.10199 .39315 L
.10299 .39462 L
.10394 .39604 L
.10486 .39742 L
.10584 .39889 L
.10678 .40033 L
.10769 .40172 L
.10866 .40321 L
.10958 .40465 L
.11057 .40621 L
.11152 .40771 L
.11244 .40917 L
.11341 .41074 L
.11435 .41226 L
.11535 .41388 L
.1163 .41547 L
.11723 .417 L
.11821 .41864 L
Mistroke
.11916 .42024 L
.12007 .42178 L
.12103 .42344 L
.12197 .42505 L
.12296 .42677 L
.12391 .42844 L
.12483 .43007 L
.12581 .4318 L
.12675 .43349 L
.12775 .43529 L
.12871 .43705 L
.12964 .43875 L
.13062 .44057 L
.13157 .44233 L
.13248 .44404 L
.13345 .44587 L
.13439 .44765 L
.13538 .44955 L
.13634 .4514 L
.13726 .45319 L
.13824 .4551 L
.13919 .45696 L
.14009 .45875 L
.14106 .46068 L
.14199 .46254 L
.14298 .46454 L
.14393 .46647 L
.14485 .46834 L
.14582 .47035 L
.14676 .47229 L
.14776 .47436 L
.14872 .47637 L
.14964 .47831 L
.15063 .48039 L
.15158 .4824 L
.15249 .48435 L
.15346 .48643 L
.15439 .48844 L
.15538 .49059 L
.15634 .49267 L
.15726 .49468 L
.15823 .49682 L
.15918 .4989 L
.16018 .50111 L
.16114 .50325 L
.16207 .50531 L
.16306 .50751 L
.16401 .50964 L
.16492 .51169 L
.16589 .51387 L
Mistroke
.16683 .51598 L
.16782 .51822 L
.16878 .52039 L
.16971 .52247 L
.17069 .52469 L
.17163 .52682 L
.17254 .52887 L
.17351 .53106 L
.17444 .53316 L
.17543 .53539 L
.17638 .53753 L
.1773 .53959 L
.17828 .54177 L
.17922 .54386 L
.18022 .54608 L
.18118 .5482 L
.1821 .55023 L
.18309 .55238 L
.18404 .55444 L
.18495 .5564 L
.18592 .55847 L
.18685 .56045 L
.18785 .56253 L
.1888 .56451 L
.18972 .56639 L
.1907 .56837 L
.19165 .57025 L
.19255 .57203 L
.19352 .57389 L
.19445 .57565 L
.19544 .57749 L
.19639 .57923 L
.1973 .58086 L
.19828 .58255 L
.19922 .58413 L
.20021 .58577 L
.20117 .5873 L
.2021 .58872 L
.20308 .59018 L
.20403 .59152 L
.20494 .59276 L
.2059 .59402 L
.20684 .59517 L
.20783 .59632 L
.20878 .59736 L
.2097 .59829 L
.21068 .5992 L
.21162 .6 L
.21262 .60077 L
.21358 .60141 L
Mistroke
.21451 .60195 L
.2155 .60243 L
.21645 .6028 L
.21736 .60306 L
.21783 .60316 L
.21833 .60324 L
.21858 .60327 L
.21871 .60328 L
.21884 .6033 L
.21896 .6033 L
.21909 .60331 L
.21915 .60331 L
.21921 .60331 L
.21927 .60332 L
.21933 .60332 L
.21936 .60332 L
.21939 .60332 L
.21941 .60332 L
.21944 .60332 L
.21947 .60332 L
.21949 .60332 L
.2195 .60332 L
.21953 .60332 L
.21956 .60332 L
.21959 .60332 L
.21962 .60332 L
.21967 .60332 L
.21972 .60332 L
.21978 .60331 L
.21991 .60331 L
.22004 .6033 L
.22028 .60328 L
.2205 .60326 L
.22075 .60322 L
.22118 .60315 L
.22167 .60303 L
.22217 .60288 L
.22309 .60253 L
.22406 .60204 L
.225 .60145 L
.22599 .60069 L
.22695 .59983 L
.22787 .59889 L
.22886 .59774 L
.2298 .59651 L
.23071 .59521 L
.23168 .59368 L
.23261 .59207 L
.2336 .59022 L
.23456 .58829 L
Mistroke
.23547 .58631 L
.23645 .58405 L
.23739 .58173 L
.23839 .57911 L
.23935 .57643 L
.24028 .57371 L
.24126 .57068 L
.24221 .5676 L
.24313 .56451 L
.2441 .56107 L
.24503 .55762 L
.24603 .55381 L
.24698 .54998 L
.2479 .54617 L
.24888 .54197 L
.24983 .5378 L
.25073 .53366 L
.2517 .52912 L
.25263 .52462 L
.25362 .51971 L
.25457 .51486 L
.25549 .51008 L
.25646 .50488 L
.2574 .49976 L
.2584 .49421 L
.25936 .48875 L
.26028 .48341 L
.26126 .47763 L
.26221 .47197 L
.26312 .46645 L
.26409 .4605 L
.26502 .45469 L
.26602 .44845 L
.26697 .44237 L
.26789 .43647 L
.26887 .43014 L
.26981 .424 L
.27081 .41742 L
.27177 .41105 L
.2727 .40489 L
.27369 .39831 L
.27464 .39195 L
.27555 .38583 L
.27652 .37929 L
.27746 .373 L
.27846 .36632 L
.27941 .35988 L
.28034 .3537 L
.28132 .34714 L
.28226 .34084 L
Mistroke
.28317 .33481 L
.28414 .32842 L
.28507 .32229 L
.28606 .31582 L
.28701 .30963 L
.28793 .30372 L
.2889 .29747 L
.28984 .29151 L
.29084 .28523 L
.2918 .27924 L
.29273 .27354 L
.29371 .26754 L
.29466 .26182 L
.29557 .25639 L
.29655 .25067 L
.29748 .24525 L
.29847 .23955 L
.29943 .23414 L
.30035 .22901 L
.30133 .22363 L
.30227 .21853 L
.30318 .2137 L
.30414 .20864 L
.30507 .20385 L
.30606 .19883 L
.30701 .19409 L
.30793 .18961 L
.3089 .18492 L
.30984 .18049 L
.31083 .17587 L
.31179 .17151 L
.31272 .16739 L
.3137 .16309 L
.31465 .15904 L
.31555 .15521 L
.31652 .15123 L
.31746 .14747 L
.31845 .14356 L
.3194 .13987 L
.32032 .13641 L
.3213 .13279 L
.32224 .1294 L
.32324 .12587 L
.3242 .12254 L
.32513 .11942 L
.32611 .11617 L
.32706 .11312 L
.32797 .11025 L
.32895 .10727 L
.32988 .10447 L
Mistroke
.33088 .10157 L
.33183 .09884 L
.33276 .09628 L
.33374 .09363 L
.33468 .09113 L
.33559 .0888 L
.33655 .08637 L
.33748 .08409 L
.33847 .08173 L
.33943 .07952 L
.34034 .07745 L
.34132 .0753 L
.34226 .07329 L
.34325 .07121 L
.34421 .06926 L
.34514 .06743 L
.34612 .06554 L
.34707 .06377 L
.34798 .06212 L
.34895 .0604 L
.34988 .0588 L
.35088 .05714 L
.35183 .05559 L
.35275 .05415 L
.35373 .05265 L
.35467 .05125 L
.35567 .0498 L
.35664 .04845 L
.35757 .04719 L
.35855 .04589 L
.3595 .04468 L
.36042 .04354 L
.36139 .04237 L
.36233 .04128 L
.36332 .04015 L
.36428 .0391 L
.3652 .03812 L
.36619 .03711 L
.36713 .03617 L
.36804 .03529 L
.36901 .03439 L
.36994 .03355 L
.37093 .03268 L
.37188 .03187 L
.3728 .03112 L
.37378 .03035 L
.37472 .02963 L
.37572 .02889 L
.37668 .02821 L
.3776 .02757 L
Mistroke
.37859 .02691 L
.37954 .02631 L
.38045 .02574 L
.38142 .02516 L
.38236 .02463 L
.38335 .02408 L
.38431 .02357 L
.38523 .0231 L
.38621 .02261 L
.38715 .02217 L
.38806 .02175 L
.38902 .02133 L
.38995 .02094 L
.39094 .02054 L
.39189 .02017 L
.39281 .01983 L
.39378 .01949 L
.39472 .01917 L
.39572 .01885 L
.39668 .01855 L
.3976 .01828 L
.39858 .018 L
.39953 .01775 L
.40044 .01752 L
.40141 .01729 L
.40234 .01707 L
.40333 .01686 L
.40429 .01666 L
.40521 .01649 L
.40618 .01631 L
.40713 .01615 L
.40813 .01599 L
.40909 .01585 L
.41002 .01572 L
.411 .01559 L
.41195 .01548 L
.41287 .01538 L
.41384 .01528 L
.41477 .01519 L
.41577 .01511 L
.41673 .01504 L
.41765 .01497 L
.41863 .01492 L
.41958 .01487 L
.42048 .01483 L
.42145 .01479 L
.42238 .01476 L
.42285 .01475 L
.42337 .01474 L
.42387 .01473 L
Mistroke
.42432 .01473 L
.4248 .01472 L
.42505 .01472 L
.4253 .01472 L
.42553 .01472 L
.42565 .01472 L
.42578 .01472 L
.42589 .01472 L
.42595 .01472 L
.42601 .01472 L
.42606 .01472 L
.42609 .01472 L
.42612 .01472 L
.42614 .01472 L
.42617 .01472 L
.4262 .01472 L
.42622 .01472 L
.42625 .01472 L
.42628 .01472 L
.42631 .01472 L
.42634 .01472 L
.4264 .01472 L
.42646 .01472 L
.42658 .01472 L
.42671 .01472 L
.42694 .01472 L
.42715 .01472 L
.4276 .01472 L
.4281 .01473 L
.42857 .01473 L
.42907 .01474 L
.43006 .01476 L
.43101 .01479 L
.43193 .01482 L
.43291 .01485 L
.43385 .01489 L
.43485 .01494 L
.43581 .01499 L
.43674 .01504 L
.43772 .0151 L
.43867 .01517 L
.43958 .01523 L
.44055 .0153 L
.44149 .01537 L
.44248 .01546 L
.44344 .01554 L
.44436 .01562 L
.44534 .01571 L
.44629 .01581 L
.44719 .0159 L
Mistroke
.44816 .016 L
.44909 .0161 L
.45008 .0162 L
.45103 .01631 L
.45195 .01642 L
.45292 .01653 L
.45386 .01665 L
.45486 .01677 L
.45582 .01689 L
.45674 .01701 L
.45773 .01714 L
.45867 .01727 L
.45958 .01739 L
.46055 .01753 L
.46149 .01766 L
.46248 .0178 L
.46343 .01794 L
.46435 .01808 L
.46533 .01822 L
.46627 .01836 L
.46727 .01852 L
.46824 .01866 L
.46916 .01881 L
.47015 .01896 L
.4711 .01911 L
.47202 .01926 L
.47299 .01942 L
.47392 .01957 L
.47492 .01974 L
.47588 .01989 L
.4768 .02005 L
.47778 .02021 L
.47873 .02037 L
.47964 .02053 L
.4806 .0207 L
.48153 .02086 L
.48252 .02103 L
.48348 .0212 L
.4844 .02136 L
.48537 .02153 L
.48631 .0217 L
.48731 .02187 L
.48827 .02205 L
.4892 .02221 L
.49018 .02239 L
.49113 .02256 L
.49204 .02273 L
.49301 .0229 L
.49395 .02308 L
.49494 .02326 L
Mistroke
.4959 .02343 L
.49682 .0236 L
.4978 .02378 L
.49874 .02396 L
.49965 .02413 L
.50061 .02431 L
.50154 .02448 L
.50253 .02467 L
.50348 .02484 L
.5044 .02502 L
.50537 .0252 L
.50631 .02538 L
.5073 .02556 L
.50826 .02574 L
.50919 .02592 L
.51017 .0261 L
.51112 .02628 L
.51203 .02646 L
.51299 .02664 L
.51393 .02682 L
.51492 .027 L
.51587 .02719 L
.51679 .02736 L
.51777 .02755 L
.51871 .02772 L
.51971 .02791 L
.52067 .0281 L
.5216 .02827 L
.52259 .02846 L
.52354 .02864 L
.52445 .02881 L
.52542 .029 L
.52636 .02918 L
.52735 .02937 L
.52831 .02955 L
.52923 .02972 L
.53021 .02991 L
.53116 .03009 L
.53206 .03026 L
.53303 .03044 L
.53396 .03062 L
.53495 .0308 L
.5359 .03098 L
.53682 .03115 L
.53779 .03134 L
.53873 .03151 L
.53973 .0317 L
.54069 .03188 L
.54162 .03206 L
.5426 .03224 L
Mistroke
.54355 .03242 L
.54446 .03259 L
.54543 .03277 L
.54636 .03294 L
.54735 .03313 L
.54831 .0333 L
.54923 .03347 L
.55021 .03365 L
.55115 .03383 L
.55206 .03399 L
.55302 .03417 L
.55395 .03434 L
.55494 .03452 L
.55589 .0347 L
.5568 .03486 L
.55778 .03504 L
.55871 .03521 L
.55971 .03539 L
.56067 .03557 L
.56159 .03574 L
.56257 .03591 L
.56352 .03608 L
.56443 .03625 L
.56539 .03642 L
.56633 .03659 L
.56732 .03677 L
.56827 .03694 L
.56919 .0371 L
.57016 .03727 L
.5711 .03744 L
.5721 .03762 L
.57307 .03779 L
.57399 .03795 L
.57498 .03812 L
.57593 .03829 L
.57684 .03845 L
.57781 .03862 L
.57874 .03878 L
.57974 .03895 L
.5807 .03912 L
.58162 .03928 L
.5826 .03945 L
.58354 .03961 L
.58445 .03977 L
.58541 .03993 L
.58634 .04009 L
.58733 .04026 L
.58828 .04042 L
.5892 .04058 L
.59017 .04074 L
Mistroke
.59111 .0409 L
.59211 .04107 L
.59307 .04123 L
.59399 .04139 L
.59498 .04155 L
.59592 .04171 L
.59683 .04186 L
.5978 .04202 L
.59873 .04218 L
.59973 .04234 L
.60068 .0425 L
.6016 .04265 L
.60258 .04281 L
.60352 .04296 L
.60452 .04313 L
.60548 .04328 L
.60641 .04343 L
.6074 .04359 L
.60835 .04375 L
.60926 .04389 L
.61023 .04405 L
.61117 .0442 L
.61217 .04436 L
.61312 .04451 L
.61405 .04466 L
.61503 .04481 L
.61597 .04496 L
.61688 .0451 L
.61785 .04526 L
.61878 .0454 L
.61977 .04556 L
.62072 .0457 L
.62164 .04585 L
.62261 .046 L
.62355 .04614 L
.62455 .0463 L
.62551 .04644 L
.62644 .04659 L
.62742 .04674 L
.62837 .04688 L
.62928 .04702 L
.63025 .04717 L
.63119 .04731 L
.63218 .04746 L
.63314 .0476 L
.63406 .04774 L
.63504 .04788 L
.63598 .04802 L
.63688 .04816 L
.63785 .0483 L
Mistroke
.63878 .04844 L
.63977 .04858 L
.64072 .04872 L
.64163 .04886 L
.64261 .049 L
.64354 .04914 L
.64454 .04928 L
.6455 .04942 L
.64642 .04955 L
.6474 .0497 L
.64835 .04983 L
.64926 .04996 L
.65023 .0501 L
.65116 .05023 L
.65215 .05037 L
.65311 .05051 L
.65402 .05064 L
.655 .05077 L
.65594 .05091 L
.65694 .05105 L
.6579 .05118 L
.65883 .05131 L
.65982 .05145 L
.66077 .05158 L
.66168 .0517 L
.66265 .05184 L
.66359 .05196 L
.66458 .0521 L
.66554 .05223 L
.66646 .05236 L
.66744 .05249 L
.66838 .05262 L
.66929 .05274 L
.67026 .05287 L
.67119 .05299 L
.67218 .05312 L
.67313 .05325 L
.67404 .05337 L
.67502 .0535 L
.67596 .05363 L
.67696 .05376 L
.67792 .05388 L
.67884 .054 L
.67982 .05413 L
.68077 .05426 L
.68168 .05437 L
.68265 .0545 L
.68359 .05462 L
.68458 .05475 L
.68553 .05487 L
Mistroke
.68645 .05499 L
.68743 .05511 L
.68837 .05523 L
.68937 .05536 L
.69034 .05548 L
.69127 .0556 L
.69225 .05572 L
.6932 .05584 L
.69412 .05595 L
.69509 .05607 L
.69603 .05619 L
.69702 .05631 L
.69798 .05643 L
.6989 .05655 L
.69989 .05667 L
.70083 .05678 L
.70174 .05689 L
.70271 .05701 L
.70364 .05712 L
.70463 .05724 L
.70558 .05736 L
.7065 .05747 L
.70748 .05759 L
.70842 .0577 L
.70941 .05782 L
.71038 .05793 L
.7113 .05804 L
.71229 .05816 L
.71324 .05827 L
.71415 .05838 L
.71512 .05849 L
.71605 .0586 L
.71705 .05872 L
.718 .05883 L
.71892 .05893 L
.7199 .05905 L
.72085 .05915 L
.72175 .05926 L
.72272 .05937 L
.72365 .05948 L
.72464 .05959 L
.72559 .0597 L
.7265 .0598 L
.72748 .05991 L
.72842 .06002 L
.72941 .06013 L
.73037 .06023 L
.7313 .06034 L
.73228 .06045 L
.73323 .06055 L
Mistroke
.73414 .06065 L
.7351 .06076 L
.73604 .06086 L
.73703 .06097 L
.73798 .06108 L
.7389 .06118 L
.73988 .06128 L
.74082 .06138 L
.74182 .06149 L
.74278 .0616 L
.74371 .0617 L
.7447 .0618 L
.74565 .0619 L
.74656 .062 L
.74753 .0621 L
.74847 .0622 L
.74946 .06231 L
.75042 .06241 L
.75134 .06251 L
.75232 .06261 L
.75327 .06271 L
.75418 .0628 L
.75514 .0629 L
.75607 .063 L
.75706 .0631 L
.75802 .0632 L
.75893 .06329 L
.75991 .06339 L
.76085 .06349 L
.76184 .06359 L
.76281 .06369 L
.76373 .06378 L
.76472 .06388 L
.76566 .06398 L
.76657 .06407 L
.76754 .06417 L
.76848 .06426 L
.76947 .06436 L
.77043 .06445 L
.77135 .06455 L
.77233 .06464 L
.77327 .06473 L
.77417 .06482 L
.77514 .06492 L
.77607 .06501 L
.77705 .06511 L
.77801 .0652 L
.77892 .06529 L
.77989 .06538 L
.78083 .06547 L
Mistroke
.78183 .06557 L
.78279 .06566 L
.78371 .06575 L
.78469 .06584 L
.78564 .06593 L
.78655 .06602 L
.78751 .06611 L
.78845 .0662 L
.78944 .06629 L
.79039 .06638 L
.79131 .06647 L
.79229 .06656 L
.79323 .06664 L
.79422 .06674 L
.79519 .06683 L
.79611 .06691 L
.7971 .067 L
.79805 .06709 L
.79896 .06717 L
.79993 .06726 L
.80087 .06735 L
.80186 .06744 L
.80282 .06752 L
.80374 .06761 L
.80472 .0677 L
.80566 .06778 L
.80657 .06786 L
.80754 .06795 L
.80847 .06803 L
.80945 .06812 L
.81041 .0682 L
.81132 .06828 L
.8123 .06837 L
.81324 .06845 L
.81423 .06854 L
.81519 .06862 L
.81612 .0687 L
.8171 .06879 L
.81805 .06887 L
.81896 .06895 L
.81993 .06903 L
.82086 .06912 L
.82185 .0692 L
.82281 .06928 L
.82373 .06936 L
.82471 .06944 L
.82565 .06952 L
.82665 .06961 L
.82761 .06969 L
.82854 .06977 L
Mistroke
.82953 .06985 L
.83048 .06993 L
.83139 .07001 L
.83236 .07009 L
.8333 .07017 L
.83429 .07025 L
.83525 .07033 L
.83617 .0704 L
.83716 .07049 L
.8381 .07056 L
.83901 .07064 L
.83998 .07072 L
.84091 .07079 L
.8419 .07087 L
.84285 .07095 L
.84377 .07102 L
.84474 .0711 L
.84568 .07118 L
.84668 .07126 L
.84764 .07134 L
.84857 .07141 L
.84955 .07149 L
.8505 .07156 L
.85141 .07164 L
.85238 .07171 L
.85332 .07179 L
.85431 .07186 L
.85527 .07194 L
.85619 .07201 L
.85717 .07209 L
.85811 .07216 L
.85902 .07223 L
.85998 .07231 L
.86091 .07238 L
.8619 .07245 L
.86285 .07253 L
.86377 .0726 L
.86474 .07267 L
.86568 .07274 L
.86667 .07282 L
.86763 .07289 L
.86856 .07296 L
.86954 .07304 L
.87049 .07311 L
.8714 .07317 L
.87236 .07325 L
.8733 .07332 L
.87429 .07339 L
.87524 .07346 L
.87616 .07353 L
Mistroke
.87714 .0736 L
.87808 .07367 L
.87908 .07375 L
.88004 .07382 L
.88097 .07388 L
.88195 .07396 L
.8829 .07403 L
.88382 .07409 L
.88479 .07416 L
.88572 .07423 L
.88672 .0743 L
.88768 .07437 L
.8886 .07444 L
.88958 .07451 L
.89052 .07457 L
.89143 .07464 L
.8924 .07471 L
.89333 .07477 L
.89432 .07484 L
.89527 .07491 L
.89618 .07498 L
.89716 .07504 L
.8981 .07511 L
.8991 .07518 L
.90006 .07525 L
.90098 .07531 L
.90197 .07538 L
.90291 .07544 L
.90382 .07551 L
.90479 .07557 L
.90573 .07564 L
.90672 .07571 L
.90768 .07577 L
.9086 .07583 L
.90957 .0759 L
.91052 .07596 L
.91152 .07603 L
.91248 .0761 L
.91341 .07616 L
.9144 .07623 L
.91535 .07629 L
.91626 .07635 L
.91723 .07642 L
.91817 .07648 L
.91917 .07654 L
.92013 .07661 L
.92105 .07667 L
.92203 .07673 L
.92298 .0768 L
.92388 .07686 L
Mistroke
.92485 .07692 L
.92578 .07698 L
.92677 .07704 L
.92773 .07711 L
.92865 .07717 L
.92962 .07723 L
.93056 .07729 L
.93156 .07735 L
.93252 .07742 L
.93345 .07748 L
.93443 .07754 L
.93538 .0776 L
.9363 .07766 L
.93727 .07772 L
.9382 .07778 L
.9392 .07784 L
.94015 .0779 L
.94107 .07796 L
.94205 .07802 L
.943 .07808 L
.9439 .07814 L
.94487 .0782 L
.9458 .07825 L
.94679 .07832 L
.94774 .07837 L
.94865 .07843 L
.94963 .07849 L
.95057 .07855 L
.95156 .07861 L
.95252 .07867 L
.95345 .07872 L
.95443 .07878 L
.95538 .07884 L
.95629 .0789 L
.95726 .07896 L
.95819 .07901 L
.95918 .07907 L
.96014 .07913 L
.96105 .07918 L
.96203 .07924 L
.96297 .0793 L
.96397 .07936 L
.96494 .07941 L
.96586 .07947 L
.96685 .07953 L
.9678 .07958 L
.96871 .07964 L
.96969 .07969 L
.97062 .07975 L
.97162 .07981 L
Mistroke
.97258 .07986 L
.9735 .07992 L
.97448 .07997 L
.97542 .08003 L
.97619 .08007 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{450.625, 278.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007200015R000`400?l00000o`00003oo`3oooo3
0?ooo`00o`3oooo30?ooo`00k`3oool3000003D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`2<0?ooo`00kP3oool01@000000oooo0?ooo`3oool0000003<0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`2;0?ooo`00lP3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0RP3oool00;H0oooo00<000000?ooo`3oool01P3o
ool3000000@0oooo0`0000040?ooo`80000000D0oooo0000003oool0oooo000000050?ooo`H00000
0P3oool3000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`80000000@0oooo0000003o
ool0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000001`3oool3000000<0oooo00<00000
0?ooo`3oool01@3oool6000000<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo08X0oooo
002f0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P0000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo08X0oooo002f0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`04
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0RP3oool00;H0oooo00<000000?ooo`3oool01@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool400000080oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`D000000P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo08X0oooo002f0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo08X0oooo002f0?ooo`D000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`80
00000P3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool010000000oooo0?ooo`3oool2
00000080oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00@0
00000?ooo`3oool0oooo0P0000020?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000008`0
oooo002f0?ooo`030000003oool0oooo00H0oooo0`0000040?ooo`<00000103oool3000000<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`<000000`3oool010000000oooo
0000000000040?ooo`80000000<0oooo0000003oool00`0000020?ooo`040000003oool000000000
00P0oooo0`0000020?ooo`<000001P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00H0oooo00H000000?ooo`3oool0oooo0000003oool200000080oooo0P0000040?ooo`030000003o
ool0oooo08X0oooo002f0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0I0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000002@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo08/0oooo002f0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`050000003oool0oooo0?ooo`0000004@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo0P00000:0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0S03oool00;H0oooo1P00000G0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0@0?ooo`8000001@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0:<0oooo003o0?oool<0oooo003o0?oool<0
oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo003o0?oool<0oooo000k0?ooo`@0
0000A@3oool6000004P0oooo00<000000?ooo`3oool0A03oool4000004D0oooo100000150?ooo`03
0000003oool0oooo0080oooo1000000>0?ooo`00>P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0480oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00/0
oooo000j0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`150?ooo`H00000A03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`120?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`0;0?ooo`00>P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool0A@3oool010000000oooo0?ooo`0000150?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0480oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
00/0oooo000j0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`140?ooo`040000003oool0oooo000004D0oooo0P0000030?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`120?ooo`050000003oool0oooo
0?ooo`000000103oool00`000000oooo0?ooo`0;0?ooo`00>P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool0A03oool00`000000oooo000000150?oo
o`030000003oool0000000800000A@3oool4000004D0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo00/0oooo000j0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`140?ooo`030000003oool0000004D0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0480oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00/0oooo000j0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`150?ooo`800000A@3oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@03oool00`00
0000oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool003X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0A@3oool2000004D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool2000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`00>`3oool4000004H0oooo
100000190?ooo`030000003oool0oooo04@0oooo100000150?ooo`@00000A@3oool00`000000oooo
0?ooo`020?ooo`@000003P3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0
oooo``3oool00?l0oooo``3oool00?l0oooo``3oool00?l0oooo``3oool003@0ooooo`0000260000
00T0oooo000d0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool003@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?oo
o`1@0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?oo
o`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo00<00000
0?ooo`3oool0D03oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o
0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?oo
o`030000003oool0oooo0500oooo00<0001o0?ooo`3oool0A`3oool0100007l0oooo0?ooo`3oool:
000003`0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0
oooo00L0oooo000d0?ooo`030000003oool0oooo0500oooo00<0001o0?ooo`3oool0A@3oool70000
00T0oooo2@00000c0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`00
0000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo0480
oooo100000000`3oool0001o0?ooo`0E0?ooo`L00000;03oool00`0007l0oooo0?ooo`170?ooo`03
0000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0
D03oool00`0007l0oooo0?ooo`100?ooo`<00000103oool00`0007l0oooo0?ooo`0J0?ooo`H00000
9`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool0
1`3oool003@0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0n0?ooo`<000001P3o
ool00`0007l0oooo0?ooo`0P0?ooo`H000008@3oool00`0007l0oooo0?ooo`170?ooo`030000O`3o
ool0oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0D03oool0
0`0007l0oooo0?ooo`0m0?ooo`800000203oool00`0007l0oooo0?ooo`0U0?ooo`H00000703oool0
0`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool0
03@0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0k0?ooo`8000002P3oool00`00
07l0oooo0?ooo`0Z0?ooo`H000005`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo
0500oooo00<000000?ooo`3oool01`3oool003@0oooo0`00001@0?ooo`030000O`3oool0oooo03X0
oooo0P00000;0?ooo`030000O`3oool0oooo0300oooo1P00000A0?ooo`030000O`3oool0oooo04L0
oooo00<0001o0?ooo`3oool0C`3oool2000000T0oooo000d0?ooo`030000003oool0oooo0500oooo
00<0001o0?ooo`3oool0>@3oool2000000`0oooo00<0001o0?ooo`3oool0=@3oool6000000`0oooo
00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo
000d0?ooo`030000003oool0oooo0500oooo00<0001o0?ooo`3oool0>03oool2000000d0oooo00<0
001o0?ooo`3oool0>P3oool7000000H0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?oo
o`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo0500oooo00<0001o
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo0400oooo1`000000
0`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool0
03@0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0f0?ooo`8000003`3oool00`00
07l0oooo0?ooo`160?ooo`H00000A@3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo
00L0oooo000d0?ooo`030000003oool0oooo0500oooo00<0001o0?ooo`3oool0=@3oool200000100
oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`020?ooo`L00000?P3oool00`0007l0
oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo0500oooo
00<0001o0?ooo`3oool0=@3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo04L0oooo
00<0001o0?ooo`3oool0203oool7000003P0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo
0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo03@0oooo00<0
00000?ooo`3oool0403oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo00l0oooo1`00
000a0?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo00<00000
0?ooo`3oool0D03oool00`0007l0oooo0?ooo`0c0?ooo`030000003oool0oooo0140oooo00<0001o
0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`0F0?ooo`P00000:@3oool00`0007l0oooo0?ooo`1@
0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo0500oooo00<0001o0?oo
o`3oool0<`3oool00`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?oo
o`3oool07@3oool900000240oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?oo
o`00=03oool00`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo0380oooo00<000000?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo02D0oooo2@00000I0?ooo`03
0000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0
D03oool00`0007l0oooo0?ooo`0b0?ooo`030000003oool0oooo0180oooo00<0001o0?ooo`3oool0
A`3oool00`0007l0oooo0?ooo`0^0?ooo`T00000403oool00`0007l0oooo0?ooo`1@0?ooo`030000
003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo0500oooo00<0001o0?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0=P3o
ool;000000H0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00=03oool0
0`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3oool0503oool0
0`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0400oooo2`00001?0?ooo`030000003oool0
oooo00L0oooo000d0?ooo`030000003oool0oooo0500oooo00<0001o0?ooo`3oool0<03oool00`00
0000oooo0?ooo`0D0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`00
07l0oooo0?ooo`0<000004@0oooo00<000000?ooo`3oool01`3oool003@0oooo0`00001@0?ooo`03
0000O`3oool0oooo02l0oooo00<000000?ooo`3oool05@3oool00`0007l0oooo0?ooo`170?ooo`03
0000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0303oool=000003H0oooo0P0000090?ooo`00
=03oool00`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo02l0oooo00<000000?ooo`3oool0
5@3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0
603oool>000002X0oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0D03o
ool00`0007l0oooo0?ooo`0_0?ooo`030000003oool0oooo01D0oooo00<0001o0?ooo`3oool0A`3o
ool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo02D0oooo3`00000L0?ooo`030000003o
ool0oooo00L0oooo000d0?ooo`030000003oool0oooo0500oooo00<0001o0?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool0
0`0007l0oooo0?ooo`0d0?oooa4000002`3oool00`000000oooo0?ooo`070?ooo`00=03oool00`00
0000oooo0?ooo`1@0?ooo`030000O`3oool0oooo02d0oooo00<000000?ooo`3oool05`3oool00`00
07l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A03oool40000
00P0oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0D03oool00`0007l0
oooo0?ooo`0]0?ooo`030000003oool0oooo01L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0
oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo
00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0]0?ooo`030000003oool0oooo01L0oooo
00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo
00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?oo
o`0/0?ooo`030000003oool0oooo01P0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?oo
o`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo00<00000
0?ooo`3oool0D03oool00`0007l0oooo0?ooo`0/0?ooo`030000003oool0oooo01P0oooo00<0001o
0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<00000
0?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0/0?oo
o`030000003oool0oooo01P0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?oo
o`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3o
ool0D03oool00`0007l0oooo0?ooo`0[0?ooo`030000003oool0oooo01T0oooo00<0001o0?ooo`3o
ool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3o
ool01`3oool003@0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0[0?ooo`030000
003oool0oooo01T0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000
O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0D03o
ool00`0007l0oooo0?ooo`0[0?ooo`030000003oool0oooo01T0oooo00<0001o0?ooo`3oool0A`3o
ool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3o
ool003@0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0Z0?ooo`030000003oool0
oooo01X0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0
oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo0`00001@0?ooo`030000O`3oool0oooo
02X0oooo00<000000?ooo`3oool06P3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo
04L0oooo00<0001o0?ooo`3oool0C`3oool2000000T0oooo000d0?ooo`030000003oool0oooo0500
oooo00<0001o0?ooo`3oool0:@3oool00`000000oooo0?ooo`0K0?ooo`030000O`3oool0oooo04L0
oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0
oooo000d0?ooo`030000003oool0oooo0500oooo00<0001o0?ooo`3oool0:@3oool00`000000oooo
0?ooo`0K0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo
0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo0500oooo00<0
001o0?ooo`3oool0:@3oool00`000000oooo0?ooo`0K0?ooo`030000O`3oool0oooo04L0oooo00<0
001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d
0?ooo`030000003oool0oooo0500oooo00<0001o0?ooo`3oool0:@3oool00`000000oooo0?ooo`0K
0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@
0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo0500oooo00<0001o0?oo
o`3oool0:03oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?oo
o`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`03
0000003oool0oooo0500oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`03
0000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo0500oooo00<0001o0?ooo`3oool0
:03oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0
A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003o
ool0oooo0500oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3o
ool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003o
ool0oooo00L0oooo000d0?ooo`030000003oool0oooo0500oooo00<0001o0?ooo`3oool09`3oool0
0`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool0
0`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo
0500oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo
04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo
00L0oooo000V0?ooo`H00000203oool00`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo02H0
oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0
oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`009`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0500oooo00<0001o0?ooo`3oool09P3oool00`000000oooo
0?ooo`0N0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo
0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000X0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0V0?ooo`030000003oool0oooo01h0oooo00<0
001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<0
00000?ooo`3oool01`3oool001h0oooo1`0000040?ooo`030000003oool0oooo00P0oooo1000001h
0000O`030000000007l0001o0?l0001o100007l3000000T0oooo000Z0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo
01l0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo
0500oooo00<000000?ooo`3oool01`3oool002/0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`1@0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool07`3oool00`0007l0
oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000
oooo0?ooo`070?ooo`00:`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0500oooo
00<0001o0?ooo`3oool09@3oool00`000000oooo0?ooo`0O0?ooo`030000O`3oool0oooo04L0oooo
00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo
000[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?oo
o`0U0?ooo`030000003oool0oooo01l0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?oo
o`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool002H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0500oooo00<0001o
0?ooo`3oool09@3oool00`000000oooo0?ooo`0O0?ooo`030000O`3oool0oooo04L0oooo00<0001o
0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000W0?oo
o`@000002@3oool00`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo02@0oooo00<000000?oo
o`3oool0803oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?oo
o`3oool0D03oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`1@0?ooo`03
0000O`3oool0oooo02@0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`170?ooo`03
0000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00
=03oool00`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo02@0oooo00<000000?ooo`3oool0
803oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0
D03oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`1@0?ooo`030000O`3o
ool0oooo02<0oooo00<000000?ooo`3oool08@3oool00`0007l0oooo0?ooo`170?ooo`030000O`3o
ool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00=03oool0
0`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo02<0oooo00<000000?ooo`3oool08@3oool0
0`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool0
0`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo
02<0oooo00<000000?ooo`3oool08@3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo
04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000
oooo0?ooo`1@0?ooo`030000O`3oool0oooo02<0oooo00<000000?ooo`3oool08@3oool00`0007l0
oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000
oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo02<0oooo
00<000000?ooo`3oool08@3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo
00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`002`3oool2000002L0oooo00<0
00000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<0
001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<0
00000?ooo`3oool01`3oool000d0oooo0`00000T0?ooo`<00000D03oool00`0007l0oooo0?ooo`0R
0?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`17
0?ooo`030000O`3oool0oooo04l0oooo0P0000090?ooo`00403oool300000240oooo00<000000?oo
o`3oool0D03oool00`0007l0oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<0001o0?oo
o`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?oo
o`3oool01`3oool001<0oooo0P00000O0?ooo`030000003oool0oooo0500oooo00<0001o0?ooo`3o
ool08P3oool00`000000oooo0?ooo`0R0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3o
ool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000@0?ooo`<00000
8@3oool00`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo0280oooo00<000000?ooo`3oool0
8P3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0
D03oool00`000000oooo0?ooo`070?ooo`00303oool4000002@0oooo00<000000?ooo`3oool0D03o
ool00`0007l0oooo0?ooo`0Q0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0A`3o
ool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3o
ool000/0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1@0?ooo`030000O`3oool0
oooo0240oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0
oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00303oool40000
02@0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0Q0?ooo`030000003oool0oooo
02<0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo
0500oooo00<000000?ooo`3oool01`3oool00100oooo0`00000Q0?ooo`030000003oool0oooo0500
oooo00<0001o0?ooo`3oool08@3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo04L0
oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0
oooo000C0?ooo`8000007`3oool00`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo0240oooo
00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo
00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00403oool300000240oooo00<0
00000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0Q0?ooo`030000003oool0oooo02<0oooo00<0
001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<0
00000?ooo`3oool01`3oool000d0oooo0`00000T0?ooo`030000003oool0oooo0500oooo00<0001o
0?ooo`3oool0803oool00`000000oooo0?ooo`0T0?ooo`030000O`3oool0oooo04L0oooo00<0001o
0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000;0?oo
o`8000009`3oool00`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo0200oooo00<000000?oo
o`3oool0903oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?oo
o`3oool0D03oool00`000000oooo0?ooo`070?ooo`003`3oool00`000000oooo0?ooo`0200000200
oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0P0?ooo`030000003oool0oooo02@0
oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500
oooo00<000000?ooo`3oool01`3oool000h0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0500oooo00<0001o0?ooo`3oool0803oool00`000000
oooo0?ooo`0T0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0
oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000>0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool07@3oool300000500oooo00<0001o0?ooo`3oool07`3oool00`000000
oooo0?ooo`0U0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0
oooo0?ooo`1?0?ooo`8000002@3oool000h0oooo00H000000?ooo`3oool000000?ooo`00000P0?oo
o`030000003oool0oooo0500oooo00<0001o0?ooo`3oool07`3oool00`000000oooo0?ooo`0U0?oo
o`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?oo
o`030000003oool0oooo00L0oooo000?0?ooo`H000007`3oool00`000000oooo0?ooo`1@0?ooo`03
0000O`3oool0oooo01l0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`170?ooo`03
0000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00
=03oool00`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo01l0oooo00<000000?ooo`3oool0
9@3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0
D03oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`1@0?ooo`030000O`3o
ool0oooo01l0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`170?ooo`030000O`3o
ool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`002`3oool0
0`000000oooo0?ooo`07000001l0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0N
0?ooo`030000003oool0oooo02H0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`17
0?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?oo
o`3oool0D03oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo02H0oooo00<0001o0?oo
o`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?oo
o`3oool01`3oool003@0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0N0?ooo`03
0000003oool0oooo02H0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`03
0000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool000l0oooo0P0000020?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0N0?ooo`030000
003oool0oooo02H0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000
O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool000h0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0500oooo00<0001o0?ooo`3oool0
7P3oool00`000000oooo0?ooo`0V0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0
A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000>0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1@0?ooo`030000
O`3oool0oooo01h0oooo00<000000?ooo`3oool09P3oool00`0007l0oooo0?ooo`170?ooo`030000
O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`003P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
D03oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo02H0oooo00<0001o0?ooo`3oool0
A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool0
1`3oool000l0oooo00<000000?ooo`3oool00P00000P0?ooo`030000003oool0oooo0500oooo00<0
001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0W0?ooo`030000O`3oool0oooo04L0oooo00<0
001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d
0?ooo`030000003oool0oooo0500oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0W
0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@
0?ooo`030000003oool0oooo00L0oooo000>0?ooo`030000003oool0oooo02<0oooo0`00001@0?oo
o`030000O`3oool0oooo01d0oooo00<000000?ooo`3oool09`3oool00`0007l0oooo0?ooo`170?oo
o`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0C`3oool2000000T0oooo000<0?ooo`T0
00007`3oool00`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo01d0oooo00<000000?ooo`3o
ool09`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3o
ool0D03oool00`000000oooo0?ooo`070?ooo`003P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0L0?ooo`030000
003oool0oooo02P0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000
O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0D03o
ool00`0007l0oooo0?ooo`0L0?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0A`3o
ool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3o
ool003@0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0L0?ooo`030000003oool0
oooo02P0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0
oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0D03oool00`00
07l0oooo0?ooo`0L0?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0A`3oool00`00
07l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool003@0
oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0L0?ooo`030000003oool0oooo02P0
oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500
oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo
0?ooo`0L0?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo
0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool000h0oooo2P00
000L0?ooo`030000003oool0oooo0500oooo00<0001o0?ooo`3oool0703oool00`000000oooo0?oo
o`0X0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?oo
o`1@0?ooo`030000003oool0oooo00L0oooo000?0?ooo`050000003oool0oooo0?ooo`000000803o
ool00`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo01/0oooo00<000000?ooo`3oool0:@3o
ool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03o
ool00`000000oooo0?ooo`070?ooo`003P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0K0?ooo`030000003oool0
oooo02T0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0
oooo0500oooo00<000000?ooo`3oool01`3oool000h0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0@0?ooo`@000002@3oool00`000000oooo0?ooo`1@0?ooo`030000O`3oool0oooo
01/0oooo00<000000?ooo`3oool0:@3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo
04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`003`3oool500000180
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0500
oooo00<0001o0?ooo`3oool06`3oool00`000000oooo0?ooo`0Y0?ooo`030000O`3oool0oooo04L0
oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0
oooo000V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`1@0?ooo`030000O`3oool0oooo01/0oooo00<000000?ooo`3oool0:@3oool00`0007l0oooo
0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo
0?ooo`070?ooo`009P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0ooooo`00
0026000000T0oooo000?0?ooo`D000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0K0?ooo`030000003oool0
oooo02T0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0
oooo0500oooo00<000000?ooo`3oool01`3oool000h0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`1@0?ooo`030000O`3oool0oooo01X0oooo00<000000?ooo`3oool0:P3oool00`00
07l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`00
0000oooo0?ooo`070?ooo`003P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0500
oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0Z0?ooo`030000O`3oool0oooo04L0
oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0
oooo000>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo
0?ooo`0J0?ooo`030000003oool0oooo02X0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo
0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool000l0oooo1@00
000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`1@0?ooo`030000O`3oool0oooo01X0oooo00<000000?ooo`3oool0:P3oool00`0007l0oooo0?oo
o`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?oo
o`070?ooo`009`3oool4000000T0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`0J
0?ooo`030000003oool0oooo02X0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`17
0?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?oo
o`3oool0D03oool00`0007l0oooo0?ooo`0I0?ooo`030000003oool0oooo02/0oooo00<0001o0?oo
o`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?oo
o`3oool01`3oool000l0oooo0P0000020?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool01P3oool2000004P0oooo00<0001o0?ooo`3oool06@3oool00`000000oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`03
0000003oool0oooo00L0oooo000>0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`080?ooo`800000AP3oool00`0007l0oooo0?ooo`0I0?ooo`03
0000003oool0oooo02/0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`03
0000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool000h0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo0P0000150?ooo`03
0000O`3oool0oooo01T0oooo00<000000?ooo`3oool0:`3oool00`0007l0oooo0?ooo`170?ooo`03
0000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00
3P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool02P3oool2000004@0oooo00<0001o0?ooo`3oool06@3oool00`000000oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`03
0000003oool0oooo00L0oooo000?0?ooo`030000003oool0oooo00800000803oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0440oooo00<0001o0?ooo`3oool06@3oool00`000000oooo
0?ooo`0[0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo
0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0@03oool00`0007l0oooo0?ooo`0I0?ooo`030000003oool0oooo02/0oooo00<0
001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<0
00000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0o
0?ooo`030000O`3oool0oooo01P0oooo00<000000?ooo`3oool0;03oool00`0007l0oooo0?ooo`17
0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`07
0?ooo`002`3oool00`000000oooo0?ooo`07000001l0oooo0`00000?0?ooo`800000?`3oool00`00
07l0oooo0?ooo`0H0?ooo`030000003oool0oooo02`0oooo00<0001o0?ooo`3oool0A`3oool00`00
07l0oooo0?ooo`170?ooo`030000O`3oool0oooo04l0oooo0P0000090?ooo`00=03oool00`000000
oooo0?ooo`0@0?ooo`800000?P3oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0oooo02`0
oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500
oooo00<000000?ooo`3oool01`3oool000h0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0603oool00`000000oooo
0?ooo`0/0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo
0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000<0?ooo`T000007`3oool00`000000oooo0?oo
o`0B0?ooo`800000?03oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0oooo02`0oooo00<0
001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<0
00000?ooo`3oool01`3oool000h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo01<0oooo0P00000k0?ooo`030000O`3oool0oooo01P0oooo00<00000
0?ooo`3oool0;03oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o
0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`0D0?oo
o`800000>P3oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0oooo02`0oooo00<0001o0?oo
o`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?oo
o`3oool01`3oool003@0oooo00<000000?ooo`3oool05@3oool2000003T0oooo00<0001o0?ooo`3o
ool05`3oool00`000000oooo0?ooo`0]0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3o
ool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000;0?ooo`030000
003oool0oooo00L000007`3oool00`000000oooo0?ooo`0F0?ooo`800000>03oool00`0007l0oooo
0?ooo`0G0?ooo`030000003oool0oooo02d0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo
0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0f0?ooo`030000O`3oool0oooo01L0oooo00<0
00000?ooo`3oool0;@3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0
001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo03D0oooo00<0001o0?ooo`3oool05`3oool00`000000oooo0?ooo`0]
0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@
0?ooo`030000003oool0oooo00L0oooo000?0?ooo`D00000803oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo03@0oooo00<0001o0?ooo`3oool05`3oool00`000000oooo0?ooo`0]0?oo
o`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?oo
o`030000003oool0oooo00L0oooo000>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03<0oooo00<0001o0?ooo`3o
ool05`3oool00`000000oooo0?ooo`0]0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3o
ool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000>0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`800000
=03oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo02d0oooo00<0001o0?ooo`3oool0
A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool0
1`3oool000h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01/0oooo0P00000c0?ooo`030000O`3oool0oooo01L0oooo00<000000?ooo`3oool0;@3o
ool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03o
ool00`000000oooo0?ooo`070?ooo`003`3oool500000200oooo0`00000L0?ooo`800000<P3oool0
0`0007l0oooo0?ooo`0F0?ooo`030000003oool0oooo02h0oooo00<0001o0?ooo`3oool0A`3oool0
0`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04l0oooo0P0000090?ooo`00=03oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0300oooo00<0001o0?ooo`3oool05P3oool00`00
0000oooo0?ooo`0^0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`00
07l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0;`3oool00`0007l0oooo0?ooo`0F0?ooo`030000003oool0oooo02h0
oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500
oooo00<000000?ooo`3oool01`3oool000h0oooo1`00000O0?ooo`030000003oool0oooo01h0oooo
0P00000`0?ooo`030000O`3oool0oooo01H0oooo00<000000?ooo`3oool0;P3oool00`0007l0oooo
0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo
0?ooo`070?ooo`003P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01l0oooo0P00
000_0?ooo`030000O`3oool0oooo01H0oooo00<000000?ooo`3oool0;P3oool00`0007l0oooo0?oo
o`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?oo
o`070?ooo`003P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0;@3oool00`0007l0oooo0?ooo`0E0?ooo`030000003oool0oooo02l0oooo00<0001o
0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<00000
0?ooo`3oool01`3oool000h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo02`0oooo00<0001o0?ooo`3oool05@3oool00`000000oooo0?ooo`0_0?oo
o`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?oo
o`030000003oool0oooo00L0oooo000?0?ooo`H000007`3oool00`000000oooo0?ooo`0Q0?ooo`80
0000;@3oool00`0007l0oooo0?ooo`0E0?ooo`030000003oool0oooo02l0oooo00<0001o0?ooo`3o
ool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3o
ool01`3oool003@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0[0?ooo`030000
O`3oool0oooo01D0oooo00<000000?ooo`3oool0;`3oool00`0007l0oooo0?ooo`170?ooo`030000
O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00=03o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02X0oooo00<0001o0?ooo`3oool05@3o
ool00`000000oooo0?ooo`0_0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3o
ool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0E0?ooo`030000003oool0
oooo02l0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0
oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0903oool20000
02X0oooo00<0001o0?ooo`3oool05@3oool00`000000oooo0?ooo`0_0?ooo`030000O`3oool0oooo
04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo
00L0oooo000d0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0:03oool00`0007l0
oooo0?ooo`0D0?ooo`030000003oool0oooo0300oooo00<0001o0?ooo`3oool0A`3oool00`0007l0
oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool000h0oooo
2000000N0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`0007l0oooo
0?ooo`0D0?ooo`030000003oool0oooo0300oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo
0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool000d0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`<000009`3oool00`000000oooo0?oo
o`0V0?ooo`030000O`3oool0oooo01@0oooo00<000000?ooo`3oool0<03oool00`0007l0oooo0?oo
o`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0C`3oool2000000T0oooo000<
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo02H0oooo00<0001o0?ooo`3oool0503oool00`000000oooo0?ooo`0`
0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@
0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool09@3oool00`0007l0oooo0?ooo`0D0?ooo`030000003oool0oooo0300oooo00<0001o0?oo
o`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?oo
o`3oool01`3oool000h0oooo1`00000O0?ooo`030000003oool0oooo02P0oooo0P00000V0?ooo`03
0000O`3oool0oooo01@0oooo00<000000?ooo`3oool0<03oool00`0007l0oooo0?ooo`170?ooo`03
0000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00
3`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
903oool00`0007l0oooo0?ooo`0D0?ooo`030000003oool0oooo0300oooo00<0001o0?ooo`3oool0
A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool0
1`3oool000h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Y0?ooo`8000009@3o
ool00`0007l0oooo0?ooo`0D0?ooo`030000003oool0oooo0300oooo00<0001o0?ooo`3oool0A`3o
ool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3o
ool000h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Z0?ooo`800000903oool0
0`0007l0oooo0?ooo`0C0?ooo`030000003oool0oooo0340oooo00<0001o0?ooo`3oool0A`3oool0
0`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool0
00l0oooo1P00000O0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool08P3oool00`00
07l0oooo0?ooo`0C0?ooo`030000003oool0oooo0340oooo00<0001o0?ooo`3oool0A`3oool00`00
07l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool000h0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0[0?ooo`8000008`3oool00`0007l0
oooo0?ooo`0C0?ooo`030000003oool0oooo0340oooo00<0001o0?ooo`3oool0A`3oool00`0007l0
oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool000h0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0240oooo
00<0001o0?ooo`3oool04`3oool00`000000oooo0?ooo`0a0?ooo`030000O`3oool0oooo04L0oooo
00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo
000>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0;03oool200000280oooo00<0
001o0?ooo`3oool04`3oool00`000000oooo0?ooo`0a0?ooo`030000O`3oool0oooo04L0oooo00<0
001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000?
0?ooo`H000004@3oool6000000P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P
0?ooo`030000O`3oool0oooo0180oooo00<000000?ooo`3oool0<P3oool00`0007l0oooo0?ooo`17
0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`07
0?ooo`009`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool07`3oool00`0007l0oooo0?ooo`0B0?ooo`030000003oool0oooo0380oooo00<0001o0?oo
o`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?oo
o`3oool01`3oool000`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0O0?ooo`03
0000O`3oool0oooo0180oooo00<000000?ooo`3oool0<P3oool00`0007l0oooo0?ooo`170?ooo`03
0000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00
3@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool0
4P3oool00`000000oooo0?ooo`0b0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0
A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000>0?ooo`P00000503o
ool00`000000oooo0?ooo`070?ooo`@00000;P0007l00`000000001o0000O`0c0000O`0300000000
07l0001o0?l0001o600007l3000000T0oooo000[0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0M0?ooo`030000O`3oool0oooo0180oooo00<00000
0?ooo`3oool0<P3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o
0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00:`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`0B0?oo
o`030000003oool0oooo0380oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?oo
o`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool002/0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3o
ool04@3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3o
ool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000V0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo01/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0c0?ooo`030000
O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000
003oool0oooo00L0oooo000W0?ooo`@000002@3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo01/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0c0?ooo`030000O`3o
ool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003o
ool0oooo00L0oooo000d0?ooo`030000003oool0oooo0380oooo0P00000L0?ooo`030000O`3oool0
oooo0140oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0
oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00=03oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo01X0oooo00<0001o0?ooo`3oool04@3oool00`00
0000oooo0?ooo`0c0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`00
07l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo03<0
oooo0P00000K0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool0<`3oool00`0007l0
oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000
oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01T0oooo
00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0c0?ooo`030000O`3oool0oooo04L0oooo
00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo
000d0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0603oool00`0007l0oooo0?oo
o`0@0?ooo`030000003oool0oooo03@0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?oo
o`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0H0?ooo`030000O`3oool0oooo0100oooo00<00000
0?ooo`3oool0=03oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o
0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo01L0oooo00<0001o0?ooo`3oool0403oool00`000000oooo0?ooo`0d0?oo
o`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?oo
o`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool05`3oool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0oooo03@0oooo00<0001o0?ooo`3o
ool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3o
ool01`3oool003@0oooo0`00000f0?ooo`030000003oool0oooo01L0oooo00<0001o0?ooo`3oool0
403oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0
A`3oool00`0007l0oooo0?ooo`1?0?ooo`8000002@3oool003@0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool0=03o
ool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03o
ool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo01D0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0e0?ooo`030000O`3oool0
oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0
oooo00L0oooo000d0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool05@3oool00`00
07l0oooo0?ooo`0?0?ooo`030000003oool0oooo03D0oooo00<0001o0?ooo`3oool0A`3oool00`00
07l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool003@0
oooo00<000000?ooo`3oool0>03oool2000001H0oooo00<0001o0?ooo`3oool03`3oool00`000000
oooo0?ooo`0e0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0
oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0503oool00`0007l0oooo0?ooo`0?0?ooo`030000003oool0oooo03D0oooo
00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo
00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`0D0?ooo`030000O`3oool0oooo00h0oooo00<000000?ooo`3oool0=P3oool00`0007l0oooo0?oo
o`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?oo
o`070?ooo`00=03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01<0oooo00<0001o
0?ooo`3oool03P3oool00`000000oooo0?ooo`0f0?ooo`030000O`3oool0oooo04L0oooo00<0001o
0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?oo
o`030000003oool0oooo03X0oooo0P00000D0?ooo`030000O`3oool0oooo00h0oooo00<000000?oo
o`3oool0=P3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?oo
o`3oool0D03oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo0180oooo00<0001o0?ooo`3oool03P3oool00`000000oooo0?ooo`0f0?ooo`03
0000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`03
0000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
4P3oool00`0007l0oooo0?ooo`0>0?ooo`030000003oool0oooo03H0oooo00<0001o0?ooo`3oool0
A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool0
1`3oool003@0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0A0?ooo`030000O`3o
ool0oooo00h0oooo00<000000?ooo`3oool0=P3oool00`0007l0oooo0?ooo`170?ooo`030000O`3o
ool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00=03oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0140oooo00<0001o0?ooo`3oool03P3oool0
0`000000oooo0?ooo`0f0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool0
0`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo
03`0oooo0P00000B0?ooo`030000O`3oool0oooo00d0oooo00<000000?ooo`3oool0=`3oool00`00
07l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`00
0000oooo0?ooo`070?ooo`00=03oool3000003d0oooo00<000000?ooo`3oool0403oool00`0007l0
oooo0?ooo`0=0?ooo`030000003oool0oooo03L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0
oooo0?ooo`170?ooo`030000O`3oool0oooo04l0oooo0P0000090?ooo`00=03oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo0100oooo00<0001o0?ooo`3oool03@3oool00`000000oooo
0?ooo`0g0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo
0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000003oool0oooo03L0oooo00<0
001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<0
00000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0?
0?ooo`030000O`3oool0oooo00d0oooo00<000000?ooo`3oool0=`3oool00`0007l0oooo0?ooo`17
0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`07
0?ooo`00=03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00h0oooo00<0001o0?oo
o`3oool0303oool00`000000oooo0?ooo`0h0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?oo
o`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool03P3oool00`0007l0oooo0?ooo`0<0?ooo`03
0000003oool0oooo03P0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`03
0000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<000000?ooo`3oool0
>03oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0
D03oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0h0?ooo`030000O`3o
ool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003o
ool0oooo00L0oooo000d0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool0
0`0007l0oooo0?ooo`0;0?ooo`030000003oool0oooo03T0oooo00<0001o0?ooo`3oool0A`3oool0
0`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool01`3oool0
03@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo
00/0oooo00<000000?ooo`3oool0>@3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo
04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00/0oooo00<0001o0?ooo`3oool02`3oool00`000000
oooo0?ooo`0i0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0
oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0;0?ooo`030000003oool0oooo03T0oooo
00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo
00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0;0?ooo`030000O`3oool0oooo00/0oooo00<000000?ooo`3oool0>@3oool00`0007l0oooo0?oo
o`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?oo
o`070?ooo`00=03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00X0oooo00<0001o
0?ooo`3oool02P3oool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo04L0oooo00<0001o
0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?oo
o`<00000@`3oool00`000000oooo0?ooo`0:0?ooo`030000O`3oool0oooo00X0oooo00<000000?oo
o`3oool0>P3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?oo
o`3oool0C`3oool2000000T0oooo000d0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool02@3oool00`0007l0oooo0?ooo`0:0?ooo`030000003oool0oooo03X0oooo00<0001o0?ooo`3o
ool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3o
ool01`3oool003@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`090?ooo`030000
O`3oool0oooo00X0oooo00<000000?ooo`3oool0>P3oool00`0007l0oooo0?ooo`170?ooo`030000
O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00=03o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00P0oooo00<0001o0?ooo`3oool02P3o
ool00`000000oooo0?ooo`0j0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3o
ool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?ooo`090?ooo`030000003oool0
oooo03/0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0
oooo0500oooo00<000000?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`070?ooo`030000O`3oool0oooo00T0oooo00<000000?ooo`3oool0>`3oool00`00
07l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`00
0000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00L0
oooo00<0001o0?ooo`3oool0203oool00`000000oooo0?ooo`0l0?ooo`030000O`3oool0oooo04L0
oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0
oooo000d0?ooo`030000003oool0oooo04H0oooo0P0000080?ooo`030000O`3oool0oooo00P0oooo
00<000000?ooo`3oool0?03oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo
00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?oo
o`170?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3oool0203oool00`000000oooo0?oo
o`0l0?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?oo
o`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool01P3oool00`0007l0oooo0?ooo`080?ooo`030000003oool0oooo03`0oooo00<0001o
0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<00000
0?ooo`3oool01`3oool003@0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`050?oo
o`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool0?@3oool00`0007l0oooo0?ooo`170?oo
o`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?oo
o`00:P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool0103oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo03d0oooo00<0001o0?ooo`3o
ool0A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3o
ool01`3oool002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0m0?ooo`030000
O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000
003oool0oooo00L0oooo000V0?ooo`H00000203oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo00<0oooo00<0001o0?ooo`3oool01P3oool00`000000oooo0?ooo`0n0?ooo`030000O`3o
ool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003o
ool0oooo00L0oooo000W0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0BP3o
ool00`000000oooo0?ooo`030?ooo`030000O`3oool0oooo00H0oooo00<000000?ooo`3oool0?P3o
ool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03o
ool00`000000oooo0?ooo`070?ooo`009`3oool010000000oooo0?ooo`0000090?ooo`@00000BP3o
ool00`000000oooo0?ooo`020?ooo`030000O`3oool0oooo00D0oooo00<000000?ooo`3oool0?`3o
ool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0CP3o
ool3000000T0oooo000X0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0B`3oool2
000000<0oooo00<0001o0?ooo`3oool01@3oool00`000000oooo0?ooo`0o0?ooo`030000O`3oool0
oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0
oooo00L0oooo000X0?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0C03oool01@00
0000oooo0?ooo`3oool0001o00H0oooo0P0000110?ooo`030000O`3oool0oooo04L0oooo00<0001o
0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000Y0?oo
o`8000002@3oool00`000000oooo0?ooo`1=0?ooo`040000003oool0oooo0000O`H0oooo00<00000
0?ooo`3oool0@03oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o
0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00:@3oool2000000T0oooo00<000000?oo
o`3oool0C@3oool2000000030?ooo`0007l0oooo00@0oooo0P0000120?ooo`030000O`3oool0oooo
04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo
00L0oooo000Z0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0CP3oool200000003
0000O`3oool0oooo0080oooo0P0000130?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3o
ool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003oool0oooo00L0oooo000d0?ooo`030000
003oool0oooo0500oooo0P0000020?ooo`800000A03oool00`0007l0oooo0?ooo`170?ooo`030000
O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool00`000000oooo0?ooo`070?ooo`00=03o
ool00`000000oooo0?ooo`1@0?ooo`040000O`0000000000000004H0oooo00<0001o0?ooo`3oool0
A`3oool00`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo0500oooo00<000000?ooo`3oool0
1`3oool003@0oooo00<000000?ooo`3oool0D03oool00`0007l0oooo0?ooo`170?ooo`030000O`3o
ool0oooo04L0oooo00<0001o0?ooo`3oool0A`3oool00`0007l0oooo0?ooo`1@0?ooo`030000003o
ool0oooo00L0oooo000d0?ooo`030000003oool0oooo0500oooo00<0001o0?ooo`3oool0A`3oool0
0`0007l0oooo0?ooo`170?ooo`030000O`3oool0oooo04L0oooo00<0001o0?ooo`3oool0D03oool0
0`000000oooo0?ooo`070?ooo`00=03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo000d0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool003@0oooo
o`000026000000T0oooo0000\
\>"],
  ImageRangeCache->{{{57.1875, 416.688}, {355.063, 133.313}} -> {-3.61376, \
0.574163, 0.0270852, 0.0350517}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(LogLinearPlot[\(Lensing[{WaistLXY, zWaistLXY}, {f, zL1}, 
            kk]\)\[LeftDoubleBracket]2\[RightDoubleBracket], {f, 0.2, 
          4}, \[IndentingNewLine]GridLines \[Rule] Automatic, 
        Frame \[Rule] True, PlotPoints \[Rule] 1000, 
        FrameLabel \[Rule] {"\<Focal Length of L1 (m)\>", "\<Waist position \
(m)\>"}, PlotRange \[Rule] All, plotopt];\)\), "\[IndentingNewLine]", 
    \(\(LogLinearPlot[
        1000\ \(Lensing[{WaistLXY, zWaistLXY}, {f, zL1}, 
              kk]\)\[LeftDoubleBracket]1\[RightDoubleBracket], {f, 0.2, 4}, 
        GridLines \[Rule] Automatic, Frame \[Rule] True, 
        PlotPoints \[Rule] 1000, 
        FrameLabel \[Rule] {"\<Focal Length of L1 (m)\>", "\<Waist size \
(mm)\>"}, PlotRange \[Rule] All, plotopt];\)\), "\[IndentingNewLine]", 
    \(\(LogLinearPlot[
        RayleighLength[\(Lensing[{WaistLXY, zWaistLXY}, {f, zL1}, 
              kk]\)\[LeftDoubleBracket]1\[RightDoubleBracket], kk], {f, 0.2, 
          4}, GridLines \[Rule] Automatic, Frame \[Rule] True, 
        PlotPoints \[Rule] 1000, 
        FrameLabel \[Rule] {"\<Focal Length of L1 (m)\>", "\<Rayleigh Range \
(m)\>"}, PlotRange \[Rule] All, plotopt];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.53547 0.732021 0.28963 0.0738252 [
[.02381 -0.0125 -10.9688 -16.375 ]
[.02381 -0.0125 10.9688 0 ]
[.31511 -0.0125 -10.9688 -16.375 ]
[.31511 -0.0125 10.9688 0 ]
[.53547 -0.0125 -5.59375 -16.375 ]
[.53547 -0.0125 5.59375 0 ]
[.75583 -0.0125 -5.59375 -16.375 ]
[.75583 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -67.0938 -32.75 ]
[.5 -0.0125 67.0938 -16.375 ]
[-0.0125 .14198 -20.1875 -8.1875 ]
[-0.0125 .14198 0 8.1875 ]
[-0.0125 .28963 -11.1875 -8.1875 ]
[-0.0125 .28963 0 8.1875 ]
[-0.0125 .43728 -11.1875 -8.1875 ]
[-0.0125 .43728 0 8.1875 ]
[-0.0125 .58493 -11.1875 -8.1875 ]
[-0.0125 .58493 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -53.75 ]
[-0.01875 .30902 -20.1875 53.75 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .61803 L
s
.31511 0 m
.31511 .61803 L
s
.53547 0 m
.53547 .61803 L
s
.75583 0 m
.75583 .61803 L
s
.15271 0 m
.15271 .61803 L
s
.24417 0 m
.24417 .61803 L
s
.37307 0 m
.37307 .61803 L
s
.42208 0 m
.42208 .61803 L
s
.46453 0 m
.46453 .61803 L
s
.50197 0 m
.50197 .61803 L
s
.88473 0 m
.88473 .61803 L
s
.97619 0 m
.97619 .61803 L
s
0 .14198 m
1 .14198 L
s
0 .28963 m
1 .28963 L
s
0 .43728 m
1 .43728 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -71.9688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
80.938 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31511 0 m
.31511 .00625 L
s
gsave
.31511 -0.0125 -71.9688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
80.938 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.53547 0 m
.53547 .00625 L
s
gsave
.53547 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
70.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.75583 0 m
.75583 .00625 L
s
gsave
.75583 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
70.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.15271 0 m
.15271 .00375 L
s
.24417 0 m
.24417 .00375 L
s
.37307 0 m
.37307 .00375 L
s
.42208 0 m
.42208 .00375 L
s
.46453 0 m
.46453 .00375 L
s
.50197 0 m
.50197 .00375 L
s
.88473 0 m
.88473 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -128.094 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Focal) show
98.188 16.625 moveto
(Length) show
141.250 16.625 moveto
(of) show
156.063 16.625 moveto
(L1) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
174.000 16.625 moveto
(H) show
178.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
189.000 16.625 moveto
(L) show
193.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .14198 m
.00625 .14198 L
s
gsave
-0.0125 .14198 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .28963 m
.00625 .28963 L
s
gsave
-0.0125 .28963 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .43728 m
.00625 .43728 L
s
gsave
-0.0125 .43728 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .58493 m
.00625 .58493 L
s
gsave
-0.0125 .58493 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03124 m
.00375 .03124 L
s
0 .06815 m
.00375 .06815 L
s
0 .10507 m
.00375 .10507 L
s
0 .17889 m
.00375 .17889 L
s
0 .2158 m
.00375 .2158 L
s
0 .25272 m
.00375 .25272 L
s
0 .32654 m
.00375 .32654 L
s
0 .36345 m
.00375 .36345 L
s
0 .40037 m
.00375 .40037 L
s
0 .47419 m
.00375 .47419 L
s
0 .51111 m
.00375 .51111 L
s
0 .54802 m
.00375 .54802 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -143.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
114.75 12.1875 translate
90 rotate
-114.75 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Waist) show
99.250 16.625 moveto
(position) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
147.313 16.625 moveto
(H) show
151.500 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
162.313 16.625 moveto
(L) show
166.500 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.31511 .61178 m
.31511 .61803 L
s
.53547 .61178 m
.53547 .61803 L
s
.75583 .61178 m
.75583 .61803 L
s
.001 w
.15271 .61428 m
.15271 .61803 L
s
.24417 .61428 m
.24417 .61803 L
s
.37307 .61428 m
.37307 .61803 L
s
.42208 .61428 m
.42208 .61803 L
s
.46453 .61428 m
.46453 .61803 L
s
.50197 .61428 m
.50197 .61803 L
s
.88473 .61428 m
.88473 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .14198 m
1 .14198 L
s
.99375 .28963 m
1 .28963 L
s
.99375 .43728 m
1 .43728 L
s
.99375 .58493 m
1 .58493 L
s
.125 Mabswid
.99625 .03124 m
1 .03124 L
s
.99625 .06815 m
1 .06815 L
s
.99625 .10507 m
1 .10507 L
s
.99625 .17889 m
1 .17889 L
s
.99625 .2158 m
1 .2158 L
s
.99625 .25272 m
1 .25272 L
s
.99625 .32654 m
1 .32654 L
s
.99625 .36345 m
1 .36345 L
s
.99625 .40037 m
1 .40037 L
s
.99625 .47419 m
1 .47419 L
s
.99625 .51111 m
1 .51111 L
s
.99625 .54802 m
1 .54802 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.007 w
.02381 .32399 m
.02964 .32431 L
.03588 .32466 L
.04164 .32498 L
.04707 .3253 L
.05276 .32563 L
.05814 .32596 L
.06376 .32631 L
.06908 .32664 L
.07411 .32696 L
.07938 .32731 L
.08438 .32764 L
.08911 .32796 L
.09407 .32831 L
.09877 .32864 L
.10369 .32899 L
.10836 .32933 L
.11279 .32966 L
.11744 .33001 L
.12185 .33035 L
.12647 .33071 L
.13086 .33106 L
.13503 .3314 L
.1394 .33175 L
.14356 .3321 L
.1475 .33244 L
.15165 .33279 L
.15559 .33314 L
.15973 .33351 L
.16366 .33386 L
.1674 .3342 L
.17133 .33457 L
.17507 .33492 L
.17863 .33526 L
.18237 .33563 L
.18593 .33598 L
.18967 .33635 L
.19323 .33671 L
.19662 .33706 L
.20019 .33744 L
.20359 .33779 L
.20716 .33818 L
.21056 .33855 L
.21381 .33891 L
.21722 .33929 L
.22047 .33966 L
.22356 .34001 L
.22682 .34039 L
.22993 .34076 L
.23321 .34115 L
Mistroke
.23633 .34152 L
.2393 .34189 L
.24243 .34228 L
.24542 .34265 L
.24856 .34305 L
.25156 .34344 L
.25442 .34381 L
.25744 .34421 L
.26031 .34459 L
.26305 .34496 L
.26595 .34536 L
.26871 .34574 L
.27161 .34615 L
.27439 .34654 L
.27704 .34692 L
.27983 .34733 L
.2825 .34772 L
.28504 .3481 L
.28773 .3485 L
.29029 .34889 L
.29299 .3493 L
.29557 .3497 L
.29804 .35009 L
.30064 .3505 L
.30312 .3509 L
.30574 .35133 L
.30824 .35174 L
.31063 .35213 L
.31316 .35256 L
.31557 .35297 L
.31787 .35336 L
.3203 .35378 L
.32262 .35419 L
.32507 .35462 L
.32742 .35504 L
.32965 .35544 L
.33202 .35587 L
.33428 .35629 L
.33643 .35669 L
.33871 .35712 L
.34089 .35753 L
.3432 .35797 L
.3454 .3584 L
.3475 .35881 L
.34972 .35925 L
.35185 .35967 L
.35409 .36013 L
.35624 .36056 L
.35829 .36099 L
.36046 .36144 L
Mistroke
.36253 .36187 L
.36451 .36229 L
.36661 .36274 L
.36861 .36317 L
.37073 .36363 L
.37276 .36407 L
.37469 .3645 L
.37674 .36496 L
.3787 .36541 L
.38077 .36588 L
.38275 .36633 L
.38465 .36677 L
.38665 .36724 L
.38857 .3677 L
.3904 .36814 L
.39234 .3686 L
.39419 .36905 L
.39615 .36954 L
.39803 .37 L
.39983 .37045 L
.40173 .37093 L
.40354 .37139 L
.40528 .37184 L
.40712 .37231 L
.40888 .37277 L
.41075 .37326 L
.41253 .37374 L
.41424 .3742 L
.41604 .37468 L
.41777 .37515 L
.4196 .37566 L
.42135 .37614 L
.42302 .37661 L
.42479 .37711 L
.42649 .3776 L
.42812 .37806 L
.42983 .37856 L
.43148 .37904 L
.43322 .37955 L
.43489 .38005 L
.43648 .38052 L
.43817 .38103 L
.43979 .38153 L
.4415 .38205 L
.44314 .38256 L
.44471 .38305 L
.44637 .38357 L
.44796 .38408 L
.44949 .38456 L
.4511 .38508 L
Mistroke
.45265 .38558 L
.45428 .38612 L
.45585 .38664 L
.45735 .38714 L
.45893 .38767 L
.46046 .38818 L
.46191 .38868 L
.46346 .38921 L
.46493 .38972 L
.4665 .39027 L
.468 .39079 L
.46943 .3913 L
.47095 .39185 L
.47241 .39237 L
.47395 .39293 L
.47543 .39347 L
.47684 .39399 L
.47834 .39455 L
.47978 .39508 L
.48115 .3956 L
.48261 .39616 L
.48401 .39669 L
.48549 .39726 L
.4869 .39781 L
.48826 .39834 L
.4897 .39891 L
.49108 .39946 L
.4924 .39998 L
.4938 .40055 L
.49514 .40109 L
.49656 .40167 L
.49792 .40223 L
.49922 .40278 L
.5006 .40335 L
.50193 .40391 L
.50333 .40451 L
.50468 .40508 L
.50596 .40564 L
.50733 .40623 L
.50864 .4068 L
.50989 .40735 L
.51122 .40794 L
.51249 .40851 L
.51384 .40911 L
.51514 .4097 L
.51638 .41026 L
.51769 .41087 L
.51895 .41145 L
.52028 .41207 L
.52156 .41267 L
Mistroke
.52279 .41325 L
.52409 .41387 L
.52533 .41446 L
.52653 .41504 L
.52779 .41565 L
.52901 .41625 L
.53029 .41688 L
.53152 .41749 L
.53271 .41808 L
.53396 .41871 L
.53516 .41932 L
.53631 .4199 L
.53753 .42053 L
.5387 .42113 L
.53994 .42178 L
.54113 .4224 L
.54227 .423 L
.54348 .42364 L
.54464 .42426 L
.54587 .42492 L
.54704 .42555 L
.54817 .42617 L
.54937 .42682 L
.55052 .42746 L
.55162 .42807 L
.55279 .42872 L
.55391 .42935 L
.55509 .43002 L
.55623 .43067 L
.55732 .43129 L
.55848 .43196 L
.55959 .4326 L
.56065 .43323 L
.56178 .43389 L
.56286 .43453 L
.56401 .43521 L
.56511 .43587 L
.56617 .43651 L
.56728 .43719 L
.56836 .43784 L
.5695 .43854 L
.57059 .43921 L
.57163 .43987 L
.57274 .44056 L
.57381 .44123 L
.57483 .44188 L
.57591 .44257 L
.57695 .44323 L
.57805 .44394 L
.57911 .44463 L
Mistroke
.58012 .44529 L
.5812 .446 L
.58223 .44668 L
.58332 .4474 L
.58437 .4481 L
.58537 .44878 L
.58644 .4495 L
.58746 .4502 L
.58845 .45087 L
.58949 .45159 L
.59049 .45228 L
.59154 .45302 L
.59256 .45373 L
.59354 .45442 L
.59457 .45515 L
.59556 .45586 L
.59651 .45654 L
.59752 .45726 L
.59849 .45797 L
.59952 .45871 L
.6005 .45944 L
.60145 .46013 L
.60245 .46088 L
.60341 .46159 L
.60443 .46236 L
.60541 .4631 L
.60635 .46381 L
.60735 .46457 L
.60831 .4653 L
.60922 .466 L
.6102 .46676 L
.61113 .46748 L
.61212 .46826 L
.61307 .46901 L
.61398 .46973 L
.61495 .4705 L
.61588 .47124 L
.61686 .47203 L
.61781 .47279 L
.61872 .47353 L
.61968 .47431 L
.6206 .47507 L
.62149 .4758 L
.62243 .47657 L
.62333 .47732 L
.62428 .47812 L
.6252 .4789 L
.62608 .47964 L
.62702 .48043 L
.62792 .4812 L
Mistroke
.62878 .48193 L
.62969 .48272 L
.63057 .48348 L
.6315 .48428 L
.63239 .48506 L
.63324 .48581 L
.63415 .48662 L
.63503 .48739 L
.63595 .48821 L
.63684 .489 L
.63769 .48977 L
.6386 .49058 L
.63946 .49137 L
.6403 .49212 L
.64118 .49293 L
.64203 .49371 L
.64293 .49454 L
.64379 .49534 L
.64462 .49611 L
.6455 .49693 L
.64635 .49772 L
.64716 .49848 L
.64802 .49929 L
.64884 .50007 L
.64972 .50091 L
.65056 .50171 L
.65137 .50248 L
.65222 .50331 L
.65305 .5041 L
.65392 .50495 L
.65476 .50576 L
.65556 .50655 L
.65641 .50739 L
.65723 .50819 L
.65802 .50897 L
.65885 .50979 L
.65965 .51059 L
.6605 .51144 L
.66132 .51226 L
.6621 .51304 L
.66293 .51388 L
.66373 .51469 L
.66458 .51554 L
.66539 .51637 L
.66617 .51717 L
.667 .51801 L
.66779 .51883 L
.66856 .51962 L
.66937 .52045 L
.67014 .52126 L
Mistroke
.67097 .52211 L
.67176 .52294 L
.67252 .52373 L
.67333 .52458 L
.6741 .52539 L
.67485 .52617 L
.67564 .527 L
.6764 .5278 L
.6772 .52866 L
.67797 .52948 L
.67871 .53026 L
.6795 .5311 L
.68026 .53191 L
.68106 .53277 L
.68183 .53359 L
.68257 .53439 L
.68335 .53523 L
.68411 .53604 L
.68483 .53682 L
.6856 .53765 L
.68634 .53845 L
.68712 .5393 L
.68787 .54011 L
.68859 .5409 L
.68936 .54173 L
.69009 .54253 L
.69087 .54338 L
.69162 .5442 L
.69234 .54498 L
.6931 .54581 L
.69384 .54661 L
.69454 .54738 L
.69529 .5482 L
.69601 .54899 L
.69677 .54982 L
.6975 .55062 L
.6982 .55139 L
.69895 .5522 L
.69966 .55298 L
.70035 .55373 L
.70108 .55453 L
.70178 .5553 L
.70253 .55611 L
.70324 .55689 L
.70393 .55763 L
.70465 .55842 L
.70535 .55918 L
.7061 .55999 L
.70681 .56076 L
.70749 .5615 L
Mistroke
.70822 .56228 L
.70892 .56304 L
.70959 .56376 L
.7103 .56452 L
.71098 .56525 L
.71171 .56602 L
.7124 .56677 L
.71307 .56748 L
.71378 .56823 L
.71446 .56895 L
.71512 .56963 L
.71581 .57036 L
.71648 .57106 L
.71719 .5718 L
.71787 .5725 L
.71852 .57318 L
.71922 .57389 L
.71989 .57457 L
.72059 .57529 L
.72127 .57598 L
.72193 .57663 L
.72262 .57733 L
.72328 .57799 L
.72392 .57862 L
.7246 .57929 L
.72525 .57992 L
.72594 .58059 L
.72661 .58123 L
.72725 .58184 L
.72793 .58249 L
.72858 .5831 L
.72927 .58374 L
.72993 .58435 L
.73057 .58494 L
.73124 .58555 L
.73189 .58614 L
.73252 .58669 L
.73318 .58727 L
.73382 .58783 L
.73449 .58841 L
.73514 .58896 L
.73577 .58948 L
.73643 .59003 L
.73706 .59055 L
.73767 .59105 L
.73832 .59156 L
.73895 .59205 L
.73961 .59256 L
.74024 .59304 L
.74085 .5935 L
Mistroke
.7415 .59398 L
.74212 .59442 L
.74278 .59489 L
.74342 .59533 L
.74403 .59575 L
.74468 .59618 L
.7453 .59658 L
.74589 .59696 L
.74653 .59735 L
.74714 .59772 L
.74778 .5981 L
.74841 .59846 L
.749 .59879 L
.74964 .59913 L
.75025 .59944 L
.75083 .59974 L
.75145 .60004 L
.75205 .60032 L
.75268 .6006 L
.75329 .60086 L
.75387 .6011 L
.75449 .60135 L
.75509 .60157 L
.75572 .60179 L
.75633 .60199 L
.75691 .60217 L
.75753 .60235 L
.75813 .6025 L
.7587 .60264 L
.75931 .60278 L
.7599 .60289 L
.76051 .603 L
.76111 .60309 L
.76168 .60316 L
.76229 .60322 L
.76287 .60327 L
.76319 .60329 L
.76349 .6033 L
.76364 .60331 L
.76379 .60331 L
.76392 .60331 L
.76407 .60332 L
.76414 .60332 L
.76418 .60332 L
.76422 .60332 L
.76425 .60332 L
.76428 .60332 L
.7643 .60332 L
.76432 .60332 L
.76434 .60332 L
Mistroke
.76436 .60332 L
.76438 .60332 L
.76439 .60332 L
.7644 .60332 L
.76441 .60332 L
.76443 .60332 L
.76444 .60332 L
.76446 .60332 L
.76448 .60332 L
.76452 .60332 L
.76455 .60332 L
.76459 .60332 L
.76467 .60332 L
.76474 .60332 L
.76482 .60331 L
.76495 .60331 L
.7651 .60331 L
.76526 .6033 L
.76556 .60329 L
.76587 .60327 L
.76648 .60322 L
.76707 .60315 L
.76764 .60308 L
.76824 .60298 L
.76882 .60286 L
.76938 .60274 L
.76997 .60259 L
.77053 .60243 L
.77114 .60224 L
.77172 .60204 L
.77227 .60184 L
.77286 .6016 L
.77343 .60135 L
.77397 .6011 L
.77455 .60081 L
.77511 .60051 L
.7757 .60018 L
.77627 .59984 L
.77681 .5995 L
.77739 .59911 L
.77795 .59872 L
.77854 .59829 L
.77911 .59785 L
.77965 .59741 L
.78023 .59693 L
.78079 .59644 L
.78132 .59595 L
.78189 .59541 L
.78243 .59488 L
.78301 .59428 L
Mistroke
.78357 .59369 L
.7841 .59311 L
.78467 .59246 L
.78522 .59182 L
.78574 .59118 L
.7863 .59049 L
.78683 .5898 L
.7874 .58904 L
.78795 .58829 L
.78847 .58756 L
.78903 .58675 L
.78956 .58595 L
.79013 .58508 L
.79068 .58422 L
.7912 .58337 L
.79176 .58245 L
.79229 .58154 L
.79281 .58065 L
.79335 .57968 L
.79388 .57872 L
.79444 .57768 L
.79497 .57666 L
.79549 .57565 L
.79603 .57456 L
.79656 .57349 L
.79712 .57233 L
.79765 .5712 L
.79817 .57008 L
.79871 .56887 L
.79924 .56768 L
.79975 .56652 L
.80028 .56527 L
.8008 .56404 L
.80134 .56271 L
.80187 .5614 L
.80238 .56013 L
.80291 .55875 L
.80343 .55741 L
.80392 .5561 L
.80445 .55468 L
.80496 .55329 L
.80549 .5518 L
.80601 .55034 L
.80651 .54891 L
.80703 .54738 L
.80754 .54588 L
.80808 .54427 L
.80859 .54269 L
.80909 .54116 L
.80962 .53951 L
Mistroke
.81012 .5379 L
.81061 .53633 L
.81113 .53464 L
.81163 .533 L
.81215 .53123 L
.81266 .52951 L
.81315 .52783 L
.81367 .52604 L
.81416 .52428 L
.81464 .52258 L
.81515 .52076 L
.81564 .51898 L
.81616 .51707 L
.81666 .51521 L
.81713 .51341 L
.81764 .51148 L
.81813 .5096 L
.81865 .50759 L
.81915 .50563 L
.81963 .50373 L
.82014 .5017 L
.82063 .49972 L
.8211 .49781 L
.8216 .49575 L
.82208 .49376 L
.82259 .49163 L
.82308 .48956 L
.82355 .48755 L
.82405 .48541 L
.82453 .48332 L
.82504 .4811 L
.82553 .47894 L
.826 .47685 L
.8265 .47461 L
.82698 .47245 L
.82744 .47035 L
.82794 .46811 L
.82841 .46594 L
.82891 .46363 L
.82939 .46138 L
.82985 .45921 L
.83035 .45689 L
.83082 .45465 L
.83127 .45248 L
.83176 .45017 L
.83222 .44793 L
.83271 .44554 L
.83319 .44323 L
.83364 .441 L
.83412 .43862 L
Mistroke
.83459 .43631 L
.83508 .43386 L
.83556 .43149 L
.83601 .4292 L
.8365 .42676 L
.83696 .4244 L
.83741 .42213 L
.83788 .4197 L
.83834 .41736 L
.83883 .41487 L
.83929 .41246 L
.83974 .41014 L
.84022 .40767 L
.84067 .40528 L
.84116 .40274 L
.84163 .40029 L
.84208 .39793 L
.84255 .39542 L
.84301 .393 L
.84345 .39066 L
.84392 .38818 L
.84437 .38579 L
.84484 .38324 L
.8453 .38079 L
.84575 .37842 L
.84621 .37591 L
.84666 .37349 L
.8471 .37116 L
.84756 .36869 L
.848 .3663 L
.84847 .36377 L
.84892 .36133 L
.84935 .35898 L
.84981 .35649 L
.85026 .35409 L
.85073 .35154 L
.85118 .34909 L
.85161 .34673 L
.85208 .34423 L
.85252 .34182 L
.85295 .33951 L
.8534 .33705 L
.85383 .33469 L
.8543 .33218 L
.85474 .32977 L
.85517 .32745 L
.85562 .325 L
.85606 .32263 L
.85648 .32037 L
.85692 .31796 L
Mistroke
.85735 .31565 L
.85781 .3132 L
.85824 .31084 L
.85866 .30858 L
.85911 .30618 L
.85954 .30388 L
.86 .30144 L
.86043 .2991 L
.86086 .29685 L
.8613 .29446 L
.86173 .29218 L
.86215 .28999 L
.86259 .28766 L
.86301 .28543 L
.86346 .28306 L
.86389 .2808 L
.8643 .27862 L
.86474 .27632 L
.86517 .27411 L
.86561 .27177 L
.86605 .26953 L
.86646 .26738 L
.8669 .2651 L
.86733 .26292 L
.86773 .26083 L
.86817 .25861 L
.86858 .25649 L
.86903 .25424 L
.86945 .25209 L
.86986 .25003 L
.87029 .24785 L
.87071 .24575 L
.87111 .24375 L
.87154 .24163 L
.87195 .2396 L
.87238 .23746 L
.8728 .2354 L
.8732 .23343 L
.87363 .23135 L
.87404 .22935 L
.87448 .22725 L
.8749 .22523 L
.8753 .2233 L
.87573 .22125 L
.87614 .2193 L
.87653 .21743 L
.87696 .21545 L
.87736 .21355 L
.87779 .21155 L
.8782 .20964 L
Mistroke
.8786 .20781 L
.87902 .20587 L
.87942 .20402 L
.87985 .20206 L
.88027 .20019 L
.88067 .1984 L
.88109 .19651 L
.88149 .1947 L
.88188 .19297 L
.8823 .19114 L
.8827 .1894 L
.88312 .18755 L
.88353 .18579 L
.88392 .1841 L
.88434 .18232 L
.88474 .18061 L
.88512 .17899 L
.88553 .17727 L
.88592 .17562 L
.88634 .17389 L
.88674 .17223 L
.88712 .17065 L
.88753 .16897 L
.88793 .16738 L
.88834 .16569 L
.88875 .16408 L
.88913 .16254 L
.88954 .16091 L
.88994 .15936 L
.89032 .15788 L
.89072 .15631 L
.89111 .15482 L
.89152 .15324 L
.89192 .15173 L
.8923 .15029 L
.8927 .14877 L
.89309 .14732 L
.89346 .14594 L
.89386 .14448 L
.89424 .14308 L
.89465 .14161 L
.89504 .14021 L
.89541 .13886 L
.89581 .13745 L
.89619 .1361 L
.8966 .13467 L
.89699 .13331 L
.89736 .13201 L
.89776 .13065 L
.89815 .12934 L
Mistroke
.89851 .12809 L
.89891 .12678 L
.89928 .12552 L
.89968 .1242 L
.90007 .12293 L
.90044 .12173 L
.90083 .12046 L
.90121 .11925 L
.90161 .11797 L
.902 .11675 L
.90237 .11559 L
.90276 .11436 L
.90314 .11319 L
.90351 .11207 L
.90389 .1109 L
.90427 .10978 L
.90466 .10859 L
.90504 .10747 L
.90541 .10639 L
.90579 .10526 L
.90617 .10418 L
.90653 .10314 L
.90691 .10206 L
.90728 .10102 L
.90766 .09993 L
.90804 .09889 L
.9084 .09789 L
.90878 .09685 L
.90915 .09585 L
.90954 .0948 L
.90992 .0938 L
.91028 .09284 L
.91066 .09184 L
.91103 .09088 L
.91138 .08996 L
.91176 .089 L
.91212 .08808 L
.91251 .08711 L
.91288 .08619 L
.91323 .08531 L
.91361 .08438 L
.91398 .0835 L
.91433 .08266 L
.9147 .08177 L
.91505 .08093 L
.91543 .08004 L
.9158 .07919 L
.91615 .07838 L
.91652 .07753 L
.91688 .07672 L
Mistroke
.91726 .07587 L
.91763 .07505 L
.91798 .07428 L
.91835 .07346 L
.91871 .07269 L
.91906 .07195 L
.91942 .07117 L
.91978 .07042 L
.92015 .06964 L
.92051 .0689 L
.92086 .06819 L
.92123 .06744 L
.92158 .06673 L
.92196 .06598 L
.92232 .06526 L
.92267 .06458 L
.92304 .06387 L
.92339 .06319 L
.92373 .06254 L
.9241 .06185 L
.92445 .0612 L
.92482 .06052 L
.92517 .05987 L
.92552 .05925 L
.92588 .05859 L
.92623 .05797 L
.92657 .05738 L
.92693 .05676 L
.92727 .05616 L
.92763 .05554 L
.92799 .05494 L
.92832 .05438 L
.92868 .05378 L
.92903 .05321 L
.9294 .05262 L
.92975 .05205 L
.93009 .05151 L
.93045 .05094 L
.93079 .0504 L
.93113 .04988 L
.93148 .04934 L
.93182 .04882 L
.93218 .04828 L
.93253 .04776 L
.93286 .04727 L
.93322 .04675 L
.93356 .04626 L
.93392 .04574 L
.93427 .04525 L
.93461 .04478 L
Mistroke
.93496 .04429 L
.93531 .04382 L
.93564 .04337 L
.93599 .0429 L
.93632 .04246 L
.93668 .04199 L
.93703 .04154 L
.93736 .04112 L
.93771 .04067 L
.93805 .04024 L
.93837 .03984 L
.93872 .03941 L
.93905 .03901 L
.9394 .03858 L
.93974 .03818 L
.94007 .0378 L
.94041 .03739 L
.94075 .03701 L
.9411 .0366 L
.94144 .03622 L
.94177 .03585 L
.94211 .03547 L
.94245 .0351 L
.94277 .03476 L
.94311 .03439 L
.94344 .03404 L
.94379 .03368 L
.94413 .03333 L
.94445 .033 L
.94479 .03266 L
.94512 .03233 L
.94544 .03202 L
.94577 .03169 L
.9461 .03137 L
.94644 .03105 L
.94677 .03073 L
.94709 .03044 L
.94743 .03013 L
.94776 .02983 L
.9481 .02952 L
.94843 .02922 L
.94875 .02894 L
.94909 .02865 L
.94942 .02837 L
.94973 .0281 L
.95007 .02782 L
.95039 .02756 L
.95073 .02728 L
.95106 .02701 L
.95137 .02676 L
Mistroke
.95171 .0265 L
.95203 .02625 L
.95237 .02598 L
.9527 .02573 L
.95301 .0255 L
.95335 .02525 L
.95367 .02501 L
.95398 .02479 L
.95432 .02455 L
.95463 .02433 L
.95497 .02409 L
.95529 .02387 L
.95561 .02366 L
.95594 .02344 L
.95626 .02323 L
.95656 .02303 L
.95689 .02282 L
.9572 .02262 L
.95754 .02241 L
.95786 .02221 L
.95816 .02202 L
.95849 .02183 L
.9588 .02164 L
.95914 .02144 L
.95946 .02126 L
.95977 .02108 L
.9601 .0209 L
.96041 .02072 L
.96072 .02056 L
.96104 .02038 L
.96135 .02022 L
.96168 .02004 L
.962 .01988 L
.9623 .01973 L
.96263 .01956 L
.96294 .01941 L
.96327 .01925 L
.96359 .0191 L
.96389 .01895 L
.96422 .0188 L
.96453 .01866 L
.96483 .01852 L
.96515 .01838 L
.96546 .01824 L
.96578 .0181 L
.9661 .01797 L
.9664 .01784 L
.96672 .01771 L
.96703 .01759 L
.96733 .01747 L
Mistroke
.96764 .01734 L
.96795 .01723 L
.96827 .0171 L
.96858 .01699 L
.96888 .01688 L
.96919 .01677 L
.9695 .01666 L
.96982 .01654 L
.97013 .01644 L
.97043 .01634 L
.97075 .01623 L
.97105 .01613 L
.97135 .01604 L
.97166 .01594 L
.97196 .01585 L
.97228 .01575 L
.97259 .01566 L
.97288 .01557 L
.9732 .01548 L
.9735 .0154 L
.97379 .01532 L
.9741 .01524 L
.97439 .01516 L
.97471 .01508 L
.97501 .015 L
.9753 .01493 L
.97561 .01485 L
.97591 .01478 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{495.875, 306.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007_0001<R000`400?l00000o`00003oo`3oooo`
0?ooo`00o`3oooo`0?ooo`00o`3oool70?ooo`<00000=@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0:80oooo003o0?ooo`H0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0X@3oool00?l0oooo2P3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0X03oool00<d0oooo00<0
00000?ooo`3oool01P3oool3000000@0oooo0`0000040?ooo`80000000D0oooo0000003oool0oooo
000000050?ooo`H000000P3oool3000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`80
000000@0oooo0000003oool0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000001`3oool3
000000<0oooo00<000000?ooo`3oool01@3oool6000000<0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0:00oooo003=0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0200000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P000002
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0:00oooo003=0?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0X03oool00<d0oooo00<00000
0?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3o
ool400000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`D000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo0:00oooo003=0?ooo`030000003oool0oooo00D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo0:00oooo003=0?ooo`D000000`3oool01@000000oooo0?ooo`3oool0
00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`8000000P3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool01000
0000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`8000000P3oool01@000000oooo
0?ooo`3oool000000:80oooo003=0?ooo`030000003oool0oooo00H0oooo0`0000040?ooo`<00000
103oool3000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`<00000
0`3oool010000000oooo0000000000040?ooo`80000000<0oooo0000003oool00`0000020?ooo`04
0000003oool00000000000P0oooo0`0000020?ooo`<000001P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00H000000?ooo`3oool0oooo0000003oool200000080oooo0P00
00040?ooo`030000003oool0oooo0:00oooo003=0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`050000003oool0oooo0?ooo`0000004@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000002@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0:40oooo003=0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`050000003oool0
oooo0?ooo`0000004@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo0P00
000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0XP3oool00<d0oooo1P00000G
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0@
0?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0;T0oooo003o0?oo
oo00oooo003o0?oooo00oooo003o0?oooo00oooo003o0?oooo00oooo003o0?oooo00oooo003o0?oo
oo00oooo000g0?ooo`@000000`3oool00`000000oooo0?ooo`06000006h0oooo100000030?ooo`04
0000003oool0oooo0?ooo`@00000F03oool00`000000oooo0?ooo`1I0?ooo`H00000L@3oool003H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06l0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo07<0
oooo000f0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1^0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0LP3oool003H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo05D0oooo00<0
00000?ooo`3oool0G03oool00`000000oooo0?ooo`1a0?ooo`00=P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1E
0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0L03oool003H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`D00000F03oool00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo06l0oooo000f0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3o
ool0K`3oool003H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo06/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`000000H03oool00`000000oooo0?ooo`1_0?ooo`00=P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1H0?ooo`800000F`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo06l0oooo000g0?ooo`@000001`3oool4000006l0oooo100000070?ooo`D00000E`3oool0
0`000000oooo0?ooo`1J0?ooo`@00000LP3oool00?l0ooool03oool00?l0ooool03oool00?l0oooo
l03oool00?l0ooool03oool00?l0ooool03oool00?l0ooool03oool00?l0ooool03oool003D0oooo
o`00002b000000T0oooo000e0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool003D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`00
07l0oooo0?ooo`0K0?ooo`030000003oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`00
07l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`00
0000oooo0?ooo`1L0?ooo`030000003oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`00
07l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0
oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0
oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0
001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0
001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0
001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0
001o0?ooo`3oool0803oool60?l000P0oooo00<000000?ooo`3oool01`3oool003D0oooo00<00000
0?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o
0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o
0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o
0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo01d0oooo2@3o0008
0?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?oo
o`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?oo
o`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0L0?ooo`X0o`00203oool00`000000oooo0?ooo`070?oo
o`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3o
ool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool06P3oool90?l000030?ooo`0007l0oooo00P0oooo00<000000?ooo`3oool01`3oool003D0oooo
00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo
00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo
00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo
00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo01T0oooo
1`3o00040?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<0
00000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0
001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0
001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0
001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo01L0oooo203o
00050?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<00000
0?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o
0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o
0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o
0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo01H0oooo1`3o0007
0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?oo
o`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?oo
o`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?oo
o`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?oo
o`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo01D0oooo1P3o00090?oo
o`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo0`0000070?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`03
0000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`03
0000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0503oool60?l000X0oooo00<0001o0?ooo`3o
ool01P3oool2000000T0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool0
5P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool0
3@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0C0?ooo`H0o`002`3oool00`0007l0oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3o
ool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0C0?ooo`D0o`00303oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool0
0`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0B0?ooo`D0o`003@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`00
07l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`00
07l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0A0?ooo`D0o`003P3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0
oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0
oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0
oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0
oooo0?ooo`0@0?ooo`H0o`003P3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0
oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo
0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo
0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo
0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo
0?ooo`0@0?ooo`D0o`003`3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?oo
o`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?oo
o`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?oo
o`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?oo
o`0?0?ooo`D0o`00403oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e
0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U
0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C
0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<
0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0>
0?ooo`D0o`004@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?oo
o`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?oo
o`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?oo
o`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?oo
o`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0>0?oo
o`D0o`004@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`03
0000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`03
0000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`03
0000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`03
0000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0=0?ooo`D0
o`004P3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000
003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000
O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000
O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000
O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0=0?ooo`@0o`00
4`3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003o
ool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3o
ool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3o
ool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0<0?ooo`D0o`004`3o
ool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0
oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0
oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0
oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0
oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0<0?ooo`@0o`00503oool0
0`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo
01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo
00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo
05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0;0?ooo`D0o`00503oool00`00
07l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0
oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0
oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0;0?ooo`@0o`005@3oool00`0007l0
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`<000001`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo00X0oooo1@3o000E0?ooo`030000O`3oool0oooo00H0oooo
0P0000090?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0
001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0
001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0
001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0
001o0?ooo`3oool02P3oool40?l001H0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o
0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o
0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o
0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0001o
0?ooo`3oool02@3oool50?l001H0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?oo
o`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?oo
o`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?oo
o`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?oo
o`3oool02@3oool40?l001L0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3o
ool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0203oool50?l001L0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00
=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0
9@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool0
4`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0
303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0
203oool40?l001P0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3o
ool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3o
ool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3o
ool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303o
ool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0203o
ool40?l001P0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool0
0`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool0
0`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool0
0`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool01`3oool4
0?l001T0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`00
0000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`00
07l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`00
07l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`00
07l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool01`3oool40?l0
01T0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000
oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0
oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0
oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0
oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool01`3oool40?l001T0
oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo
0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo
0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo
0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo
0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool01P3oool40?l001X0oooo
00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?oo
o`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?oo
o`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?oo
o`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?oo
o`1L0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool01P3oool30?l001/0oooo00<0
001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`07
0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K
0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?
0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L
0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool01@3oool40?l001/0oooo00<0001o
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?oo
o`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?oo
o`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?oo
o`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?oo
o`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool01@3oool40?l001/0oooo00<0001o0?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`03
0000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`03
0000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool01@3oool40?l001/0oooo00<0001o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000
O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000
O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0103oool40?l001`0oooo00<0001o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`00=@3oool3000000L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3o
ool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`040?ooo`@0o`00703oool00`0007l0oooo0?ooo`060?ooo`8000002@3o
ool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0
oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0
oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0
oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0
oooo00@0oooo103o000L0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
03D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo
01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo
00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
00<0oooo103o000M0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0
oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0
oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0
oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0
oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo00<0
oooo103o000M0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo
00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo
00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo
00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo
00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo00<0oooo
103o000M0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<0
00000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0
001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0
001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0
001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo0080oooo103o
000N0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<00000
0?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o
0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o
0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o
0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo0080oooo103o000N
0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?oo
o`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?oo
o`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?oo
o`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?oo
o`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo0080oooo103o000N0?oo
o`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3o
ool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3o
ool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3o
ool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3o
ool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo0080oooo0`3o000O0?ooo`03
0000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool0
1`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool0
6`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0
G03oool00`0007l0oooo0?ooo`0e0?ooo`040000O`3oool0oooo0?ooo`@0o`007`3oool00`0007l0
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo
00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo
00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`040?l00200oooo00<0001o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3o
ool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3o
ool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3o
ool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3o
ool0oooo03D0oooo00@0001o0?ooo`3oool0oooo0`3o000P0?ooo`030000O`3oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool002L0oooo1P0000080?ooo`030000003oool0oooo00L0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0
001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0
001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`040?l00200oooo00<0001o0?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`00:03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0
oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0
oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0
oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`030?l00240oooo00<0001o
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00:@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?oo
o`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?oo
o`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?oo
o`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`030?l0
0240oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`007`3oool7000000@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0
oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0
oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0
oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0
oooo00<0001o0?ooo`3oool00`3o000Q0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool002/0oooo00<000000?ooo`3oool01`3oool400000?l0001oOP0007l40?l002T0001o
0`0000090?ooo`00;03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0
001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0
001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?l000020?l00280oooo00<0001o0?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`00;03oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0
oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0
oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0
oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?l000020?l00280oooo00<0001o
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00;03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?oo
o`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?oo
o`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?oo
o`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0o`000?l000020?l0
0280oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`009`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`0007l0
oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0
oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0
oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0
oooo0?ooo`0e0?ooo`030000O`3o0000o`000080o`008P3oool00`0007l0oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo000X0?ooo`@000002@3oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000
O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000
O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?l0003o00000P3o000R0?ooo`030000O`3oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?oo
o`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?oo
o`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?oo
o`0e0?ooo`040000O`3o0000o`000?l002<0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0
001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0
001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0
001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo103o
000S0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<00000
0?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o
0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o
0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o
0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`@0o`008`3oool00`0007l0oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?oo
o`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?oo
o`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?oo
o`3oool0=@3oool40?l002<0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3o
ool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo0`3o000T0?ooo`03
0000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool0
1`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool0
6`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0
G03oool00`0007l0oooo0?ooo`0e0?ooo`<0o`00903oool00`0007l0oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3o
ool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=03o
ool40?l002@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool0
0`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool0
0`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool0
0`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03@0oooo0`3o000U0?ooo`030000O`3oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool01`3oool00`00
07l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`00
07l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`00
07l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`00
07l0oooo0?ooo`0d0?ooo`<0o`009@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo000e0?ooo`<000001`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0
oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0
oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0
oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0d0?ooo`<0o`009@3oool00`0007l0
oooo0?ooo`060?ooo`8000002@3oool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo
0?ooo`0c0?ooo`@0o`009@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?oo
o`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?oo
o`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?oo
o`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0<`3oool30?l002H0oooo00<0
001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`07
0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K
0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?
0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L
0?ooo`030000O`3oool0oooo03<0oooo0`3o000V0?ooo`030000O`3oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?oo
o`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?oo
o`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?oo
o`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0c0?oo
o`<0o`009P3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`03
0000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`03
0000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`03
0000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`03
0000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0<P3oool40?l002H0oooo00<0001o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`002`3oool2000002P0oooo00<000000?ooo`3oool0
1`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool0
6`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0
G03oool00`0007l0oooo0?ooo`0b0?ooo`<0o`0000<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo000=0?ooo`<000009@3oool00`000000oooo0?oo
o`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?oo
o`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?oo
o`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?oo
o`1L0?ooo`030000O`3oool0oooo0380oooo0`3o00000`0007l0oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00100oooo0`00000R0?ooo`030000003oool0
oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0
oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0
oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0
oooo05`0oooo00<0001o0?ooo`3oool0<P3oool30?l000030000O`3oool0oooo02@0oooo00<0001o
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`004`3oool200000200oooo00<000000?oo
o`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?oo
o`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?oo
o`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?oo
o`3oool0G03oool00`0007l0oooo0?ooo`0a0?ooo`@0o`0000<0001o0?ooo`3oool0903oool00`00
07l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000@0?ooo`<000008P3oool00`000000
oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0
oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0
oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0
oooo0?ooo`1L0?ooo`030000O`3oool0oooo0340oooo103o00000`0007l0oooo0?ooo`0T0?ooo`03
0000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool000`0oooo1000000U0?ooo`030000
003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000
O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000
O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000
O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0<@3oool40?l000030000O`3oool0oooo02@0oooo
00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`002`3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?oo
o`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?oo
o`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?oo
o`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0<@3oool30?l000030?ooo`00
07l0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00303oool4
000002D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0
oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0
oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0
oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0a0?ooo`<0o`0000<0oooo
0000O`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000@0?oo
o`<000008P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?oo
o`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?oo
o`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?oo
o`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo0300oooo103o00000`3o
ool0001o0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool001<0
oooo0P00000P0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0
oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0
oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0
oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0<03oool40?l00003
0?ooo`0007l0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00
403oool300000280oooo0`0000070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0
9@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool0
4`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0
303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo0300oooo103o00000`3oool0001o
0?ooo`0U0?ooo`030000O`3oool0oooo00H0oooo0P0000090?ooo`003@3oool3000002D0oooo00<0
00000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0
001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0
001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0
001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0`0?ooo`<0o`000P3oool00`0007l0oooo0?oo
o`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool000/0oooo0P00000X
0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U
0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C
0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<
0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0<03oool30?l00080oooo00<0001o
0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000?0?oo
o`030000003oool0oooo008000008@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo
03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo
01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo
00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo
02l0oooo103o00020?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`003P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo
01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo
00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0_0?ooo`<0o`000`3oool00`00
07l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool000h0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo
01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo
00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo
05`0oooo00<0001o0?ooo`3oool0;`3oool30?l000<0oooo00<0001o0?ooo`3oool0903oool00`00
07l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000>0?ooo`060000003oool0oooo0000
003oool000008@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o
0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o
0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o
0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo02l0oooo0`3o0003
0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`003`3oool600000200oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?oo
o`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?oo
o`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?oo
o`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0_0?oo
o`<0o`000`3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`03
0000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`03
0000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`03
0000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0^0?ooo`@0
o`000`3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000
O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000
O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0^0?ooo`<0o`00
103oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool000/0oooo00<000000?ooo`3oool01`00000P0?ooo`030000003oool0oooo00L0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0
001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0
001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0
001o0?ooo`3oool0;P3oool30?l000@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o
0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o
0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o
0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o
0?ooo`3oool0;P3oool30?l000@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?oo
o`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?oo
o`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?oo
o`3oool0;@3oool40?l000@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo000?0?ooo`8000000P3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`03
0000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`03
0000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`03
0000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0;@3oool40?l000@0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000>0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`03
0000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`03
0000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`03
0000O`3oool0oooo02d0oooo103o00040?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`003P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`03
0000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`03
0000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`03
0000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0]0?ooo`<0
o`001@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool000h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0N0?ooo`<0
00001`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3o
ool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3o
ool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3o
ool0G03oool00`0007l0oooo0?ooo`0]0?ooo`<0o`001@3oool00`0007l0oooo0?ooo`0T0?ooo`03
0000O`3oool0oooo00H0oooo0P0000090?ooo`003`3oool00`000000oooo0?ooo`0200000240oooo
00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo
00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo
00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo
00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0]0?ooo`<0o`001@3oool00`0007l0oooo
0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<0
00000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0
001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0
001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0
001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0/0?ooo`@0o`001@3oool00`0007l0oooo0?oo
o`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool000h0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o
0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o
0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o
0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo02`0oooo0`3o0006
0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`00303oool900000200oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?oo
o`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?oo
o`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?oo
o`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0/0?oo
o`<0o`001P3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool000h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`03
0000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`03
0000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`03
0000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0;03oool30?l000H0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000
003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000
O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000
O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000
O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0;03oool30?l000H0oooo00<0001o0?ooo`3oool0
903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003o
ool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3o
ool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3o
ool0oooo05`0oooo00<0001o0?ooo`3oool0:`3oool40?l000H0oooo00<0001o0?ooo`3oool0903o
ool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0
oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0
oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0
oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0
oooo05`0oooo00<0001o0?ooo`3oool0:`3oool30?l000L0oooo00<0001o0?ooo`3oool0903oool0
0`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo
01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo
00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo
05`0oooo00<0001o0?ooo`3oool0:`3oool30?l000L0oooo00<0001o0?ooo`3oool0903oool00`00
07l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0
oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0
oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0
oooo00<0001o0?ooo`3oool0:`3oool30?l000L0oooo00<0001o0?ooo`3oool0903oool00`0007l0
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000>0?ooo`X000007@3oool00`000000oooo
0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo
0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo
0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo
0?ooo`1L0?ooo`030000O`3oool0oooo02/0oooo0`3o00070?ooo`030000O`3oool0oooo02@0oooo
00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`003`3oool01@000000oooo0?oo
o`3oool000000240oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000
O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000
O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0Z0?ooo`@0o`00
1`3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool000h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`@000002@3o
ool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3o
ool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3o
ool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303o
ool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo02X0oooo0`3o00080?ooo`030000O`3o
ool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`003P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool0
0`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0:P3oool3
0?l000P0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo000?0?ooo`D000004`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo
01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo
00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0Z0?ooo`<0o`00203oool00`00
07l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool002L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`@00000o`0007ma0000O`<0
o`00=`0007l3000000T0oooo000W0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0
9@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool0
4`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0
303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo02T0oooo103o00080?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`003`3o
ool5000001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3o
ool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3o
ool0oooo05`0oooo00<0001o0?ooo`3oool0:@3oool30?l000T0oooo00<0001o0?ooo`3oool0903o
ool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000>0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0
oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0
oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0
oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0Y0?ooo`<0o`002@3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo
03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo
01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo
00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo
02T0oooo0`3o00090?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`003P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0
oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0
oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0
oooo00<0001o0?ooo`3oool0:@3oool30?l000T0oooo00<0001o0?ooo`3oool0903oool00`0007l0
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000?0?ooo`D00000503oool4000000T0oooo
00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo
00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo
00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo
00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0X0?ooo`@0o`002@3oool00`0007l0oooo
0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<0
00000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0
001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0
001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0
001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0X0?ooo`<0o`002P3oool00`0007l0oooo0?oo
o`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<00000
0?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o
0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o
0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o
0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0X0?ooo`<0o`002P3oool00`0007l0oooo0?ooo`0T
0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool000l0oooo0P0000020?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?oo
o`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?oo
o`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?oo
o`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0X0?oo
o`<0o`002P3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool000h0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?oo
o`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?oo
o`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?oo
o`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0:03oool30?l000X0oooo00<0001o0?oo
o`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000>0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?oo
o`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?oo
o`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?oo
o`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?oo
o`030000O`3oool0oooo02P0oooo0`3o000:0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`003P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?oo
o`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?oo
o`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?oo
o`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0W0?oo
o`@0o`002P3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool000l0oooo00<000000?ooo`3oool00P00000Q0?ooo`030000003oool0oooo00L0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0
oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0
oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0
oooo00<0001o0?ooo`3oool09P3oool40?l000/0oooo00<0001o0?ooo`3oool0903oool00`0007l0
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00H0oooo
2@3o000`0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo
0?ooo`0W0?ooo`<0o`002`3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool01P3ooolI0?l00200oooo00<0
001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0
001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0
001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo02L0oooo0`3o
000;0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`002`3oool00`000000oooo0?ooo`0700000200oooo0`0000060?ooobP0o`004@3oool0
0`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool0
0`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool09`3oool3
0?l000/0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`060?ooo`8000002@3oool0
03D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`040?ooob/0o`001P3oool00`00
07l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`00
07l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`00
07l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool09`3oool30?l0
00/0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo000>0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01`3oool00`0007l0
oooo0?ooo`0D0?ooobL0o`008P3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0
oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0
oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo02H0
oooo103o000;0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`00303oool900000200oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0S0?ooob80o`00603oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo
00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo
00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo02H0oooo
0`3o000<0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`003P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0^0?ooob80o`003@3oool00`0007l0oooo0?oo
o`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?oo
o`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?oo
o`1L0?ooo`030000O`3oool0oooo02H0oooo0`3o000<0?ooo`030000O`3oool0oooo02@0oooo00<0
001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`07
0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool00P3ooolN0?l000D0oooo00<0001o
0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o
0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o
0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0V0?ooo`<0o`00303oool00`0007l0oooo0?ooo`0T
0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?oo
o`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo00`0oooo703o000K0?oo
o`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?oo
o`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?oo
o`030000O`3oool0oooo02H0oooo0`3o000<0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`002`3oool00`000000oooo0?ooo`0700000200
oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo01L0
oooo603o000D0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0
oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0
oooo0?ooo`1L0?ooo`030000O`3oool0oooo02D0oooo103o000<0?ooo`030000O`3oool0oooo02@0
oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo
0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool07`3ooolG0?l000d0oooo
00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo
00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo
00<0001o0?ooo`3oool09@3oool30?l000d0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0o`0001D0o`001P3o
ool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3o
ool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03o
ool00`0007l0oooo0?ooo`0U0?ooo`<0o`003@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool000l0oooo1@00000Q0?ooo`030000003oool0
oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0
oooo00H0oooo503o00000`3oool0001o0?ooo`0G0?ooo`030000O`3oool0oooo01<0oooo00<0001o
0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o
0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0U0?ooo`<0o`003@3oool00`0007l0oooo0?ooo`0T
0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool000h0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00d0oooo503o000C0?oo
o`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?oo
o`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0U0?oo
o`<0o`003@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool000h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`03
0000O`3oool0oooo01@0oooo4`3o000=0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3o
ool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3o
ool0G03oool00`0007l0oooo0?ooo`0T0?ooo`@0o`003@3oool00`0007l0oooo0?ooo`0T0?ooo`03
0000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool000h0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01T0oooo4P3o00090?ooo`030000
O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000
O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0T0?ooo`<0o`00
3P3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool000l0oooo1@00000Q0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool00P3o
oolA0?l000<0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3o
ool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3o
ool0oooo02@0oooo0`3o000>0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0
oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0
oooo00H0oooo403o00000`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o
0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o
0?ooo`3oool0903oool30?l000h0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo000e0?ooo`<000001`3oool00`0007l0oooo0?ooo`0e0?oo
o`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0<0?oo
oa40o`003`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?oo
o`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo02@0oooo0`3o000>0?oo
o`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01P3oool2000000T0oooo000>0?ooo`L0
0000803oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo0140oooo403o000;0?ooo`03
0000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`03
0000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0903oool30?l000h0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000>0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0E0?ooo`l0o`00
203oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0
303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo02<0oooo103o000>0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`003P3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3o
ool0100007l0oooo0?ooo`3oool?0?l000<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo
0?ooo`0S0?ooo`<0o`003`3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool000h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?oo
o`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool01@3oool>0?l000030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3o
ool0oooo05`0oooo00<0001o0?ooo`3oool08`3oool30?l000l0oooo00<0001o0?ooo`3oool0903o
ool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000?0?ooo`H00000803oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool0
0`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool02P3oool;
0?l00100oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0
oooo05`0oooo00<0001o0?ooo`3oool08`3oool30?l000l0oooo00<0001o0?ooo`3oool0903oool0
0`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo
01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0=0?ooo``0o`00303oool00`00
07l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`00
07l0oooo0?ooo`0S0?ooo`<0o`003`3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0
oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0
oooo0?ooo`0F0?ooo`030000O`3oool0oooo0100oooo303o00090?ooo`030000O`3oool0oooo00d0
oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo0280
oooo103o000?0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo
00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo
00<0001o0?ooo`3oool04`3oool00`0007l0o`000?l000090?l000H0oooo00<0001o0?ooo`3oool0
3@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0
8P3oool30?l00100oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo0080oooo303o00000`3oool0001o0?oo
o`0>0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?oo
o`0R0?ooo`<0o`00403oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e
0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F
0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool01@3oool:0?l000030000O`3oool0
oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0
oooo0280oooo0`3o000@0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`003P3oool8000001l0oooo00<000000?ooo`3oool01`3oool00`00
07l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`00
07l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool0203oool:0?l0
00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo
0280oooo0`3o000@0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`003@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0
oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0
oooo00<0001o0?ooo`3oool02@3oool00`3o0000oooo0?l000090?l000X0oooo00<0001o0?ooo`3o
ool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo0240oooo103o000@0?ooo`03
0000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00
303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
1`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool0
6`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool0
3P3oool;0?l000H0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`030000
O`3oool0oooo0240oooo0`3o000A0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3o
ool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3o
ool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3o
ool0o`0000P0o`001@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05`0oooo00<0
001o0?ooo`3oool08@3oool30?l00140oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo000>0?ooo`L00000803oool00`000000oooo0?ooo`07
0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K
0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?
0?ooo`030000O`3oool0oooo0080oooo2P3o00000`3oool0001o0?ooo`0=0?ooo`030000O`3oool0
oooo05`0oooo00<0001o0?ooo`3oool08@3oool30?l00140oooo00<0001o0?ooo`3oool0903oool0
0`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000?0?ooo`030000003oool0oooo
02<0oooo0`0000070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`00
07l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`00
07l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00@0oooo2@3o00000`0007l0oooo0?ooo`0<0?oo
o`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool08@3oool30?l00140oooo00<0001o0?oo
o`3oool0903oool00`0007l0oooo0?ooo`060?ooo`8000002@3oool000h0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00L0oooo2P3o000;0?ooo`03
0000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0803oool40?l00140oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000>0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000
O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`090?ooo`T0o`00
2P3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo0200oooo0`3o000B0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`003`3o
ool600000200oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3o
ool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3o
ool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0<0?ooo`P0o`00203o
ool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo0200oooo0`3o000B0?ooo`030000O`3o
ool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`003P3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool0
0`0007l0o`000?l000060?l000H0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0P
0?ooo`<0o`004P3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool000h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`070?oo
o`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?oo
o`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?oo
o`030000O`3oool0oooo00d0oooo00@0001o0?ooo`3oool0oooo1`3o00040?ooo`030000O`3oool0
oooo05`0oooo00<0001o0?ooo`3oool0803oool30?l00180oooo00<0001o0?ooo`3oool0903oool0
0`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000>0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo
01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo
00<0oooo1`3o00020?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0803oool30?l0
0180oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo000?0?ooo`H00000803oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0
oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0
oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0
oooo00<0001o0?ooo`3oool01@3oool70?l000030000O`3oool0oooo05`0oooo00<0001o0?ooo`3o
ool07`3oool40?l00180oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool0
5P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool0
3@3oool00`0007l0oooo0?ooo`060?ooo`P0o`00G@3oool00`0007l0oooo0?ooo`0O0?ooo`<0o`00
4`3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool000`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3o
ool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`090?ooo`L0o`00F`3o
ool00`0007l0oooo0?ooo`0O0?ooo`<0o`004`3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool000d0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool0
0`0007l0oooo0?ooo`0;0?ooo`L0o`00F@3oool00`0007l0oooo0?ooo`0O0?ooo`<0o`004`3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
00h0oooo2000000O0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`00
07l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`00
07l0oooo0?ooo`0<0?ooo`030000O`3o0000o`0000D0o`00E`3oool00`0007l0oooo0?ooo`0O0?oo
o`<0o`004`3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`03
0000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`03
0000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`03
0000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0203o001D0?ooo`030000O`3oool0oooo01h0
oooo103o000C0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`009`3oool6000000P0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool00P3oool60?l005@0oooo
00<0001o0?ooo`3oool07P3oool30?l001@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo000X0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0
001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0
001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0
001o0?ooo`3oool0103oool70?l00540oooo00<0001o0?ooo`3oool07P3oool30?l001@0oooo00<0
001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000Y
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e
0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F
0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=
0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool01@3oool80?l004l0oooo00<0001o
0?ooo`3oool07P3oool30?l001@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo000Z0?ooo`030000003oool0oooo00P0oooo1000003^0000
O`H0o`00L00007l30?l004<0001o0`0000090?ooo`00:`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`03
0000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`03
0000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`03
0000O`3oool0oooo00P0oooo203o001<0?ooo`030000O`3oool0oooo01d0oooo103o000D0?ooo`03
0000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00
;03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool0
5P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool0
3@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo00X0oooo1`3o001;0?ooo`030000
O`3oool0oooo01d0oooo103o000D0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`00;03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3o
ool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3o
ool0oooo00`0oooo1`3o00190?ooo`030000O`3oool0oooo01d0oooo0`3o000E0?ooo`030000O`3o
ool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00;03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool0
0`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo00d0oooo203o00170?ooo`030000O`3oool0
oooo01d0oooo0`3o000E0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`009`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo
01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo
00`0oooo00<0001o0?ooo`3oool03`3oool70?l004H0oooo00<0001o0?ooo`3oool07@3oool30?l0
01D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo000X0?ooo`@000002@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0
oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0
oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0
oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`0@0?ooo`H0o`00AP3oool00`0007l0
oooo0?ooo`0L0?ooo`@0o`005@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool04P3oool70?l004<0oooo
00<0001o0?ooo`3oool0703oool30?l001H0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0
001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0
001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo01<0oooo1P3o
00130?ooo`030000O`3oool0oooo01`0oooo0`3o000F0?ooo`030000O`3oool0oooo02@0oooo00<0
001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`07
0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K
0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?
0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`0E
0?ooo`D0o`00@P3oool00`0007l0oooo0?ooo`0L0?ooo`<0o`005P3oool00`0007l0oooo0?ooo`0T
0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?oo
o`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?oo
o`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?oo
o`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?oo
o`3oool05P3oool70?l003l0oooo00<0001o0?ooo`3oool0703oool30?l001H0oooo00<0001o0?oo
o`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`03
0000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`03
0000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`03
0000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`03
0000O`3oool0oooo01P0oooo1P3o000n0?ooo`030000O`3oool0oooo01/0oooo103o000F0?ooo`03
0000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00
=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0
9@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool0
4`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0
303oool00`0007l0oooo0?ooo`0I0?ooo`D0o`00?P3oool00`0007l0oooo0?ooo`0K0?ooo`<0o`00
5`3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3o
ool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3o
ool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3o
ool0oooo00`0oooo00<0001o0?ooo`3oool06P3oool50?l003d0oooo00<0001o0?ooo`3oool06`3o
ool30?l001L0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool0
0`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo01/0oooo1`3o000j0?ooo`030000O`3oool0
oooo01/0oooo0`3o000G0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo
03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo
01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo
00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`0M0?ooo`D0o`00>P3oool00`00
07l0oooo0?ooo`0J0?ooo`@0o`005`3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool003D0oooo0`0000070?ooo`030000O`3oool0oooo03D0
oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0
oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0
oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`0N0?ooo`L0o`00=`3oool00`0007l0
oooo0?ooo`0J0?ooo`<0o`00603oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00H0
oooo0P0000090?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo
00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo
00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo
00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`0O0?ooo`L0o`00=P3oool00`0007l0oooo
0?ooo`0J0?ooo`<0o`00603oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?oo
o`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?oo
o`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool08@3oool60?l003D0oooo00<0
001o0?ooo`3oool06P3oool30?l001P0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o
0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o
0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o
0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo0280oooo1P3o000d
0?ooo`030000O`3oool0oooo01T0oooo103o000H0?ooo`030000O`3oool0oooo02@0oooo00<0001o
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?oo
o`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?oo
o`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?oo
o`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`0S0?oo
o`D0o`00=03oool00`0007l0oooo0?ooo`0I0?ooo`<0o`006@3oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3o
ool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3o
ool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3o
ool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3o
ool0903oool50?l003<0oooo00<0001o0?ooo`3oool06@3oool30?l001T0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000
003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000
O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000
O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000
O`3oool0oooo02D0oooo1P3o000a0?ooo`030000O`3oool0oooo01T0oooo0`3o000I0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3o
ool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3o
ool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3o
ool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303o
ool00`0007l0oooo0?ooo`0W0?ooo`@0o`00<@3oool00`0007l0oooo0?ooo`0I0?ooo`<0o`006@3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0
oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0
oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0
oooo00`0oooo00<0001o0?ooo`3oool09`3oool50?l00300oooo00<0001o0?ooo`3oool0603oool4
0?l001T0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`00
07l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`00
07l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo02P0oooo1@3o000_0?ooo`030000O`3oool0oooo
01P0oooo0`3o000J0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0
oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0
oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0
oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`0Z0?ooo`H0o`00;03oool00`0007l0
oooo0?ooo`0H0?ooo`<0o`006P3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0:`3oool60?l002/0oooo
00<0001o0?ooo`3oool0603oool30?l001X0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0
001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0
001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo02`0oooo1P3o
000Z0?ooo`030000O`3oool0oooo01L0oooo103o000J0?ooo`030000O`3oool0oooo02@0oooo00<0
001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`07
0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K
0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?
0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`0]
0?ooo`H0o`00:@3oool00`0007l0oooo0?ooo`0G0?ooo`<0o`006`3oool00`0007l0oooo0?ooo`0T
0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?oo
o`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?oo
o`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?oo
o`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?oo
o`3oool0;P3oool60?l002P0oooo00<0001o0?ooo`3oool05`3oool30?l001/0oooo00<0001o0?oo
o`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`03
0000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`03
0000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`03
0000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`03
0000O`3oool0oooo02l0oooo1P3o000W0?ooo`030000O`3oool0oooo01L0oooo0`3o000K0?ooo`03
0000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00
=@3oool3000000L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000
O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000
O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000
O`3oool0oooo0300oooo1P3o000V0?ooo`030000O`3oool0oooo01H0oooo103o000K0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01P3oool2000000T0oooo000e0?ooo`030000003o
ool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3o
ool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3o
ool0oooo0340oooo1P3o000U0?ooo`030000O`3oool0oooo01H0oooo0`3o000L0?ooo`030000O`3o
ool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool0
0`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool0
0`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool0
0`0007l0oooo0?ooo`0b0?ooo`H0o`00903oool00`0007l0oooo0?ooo`0F0?ooo`<0o`00703oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
03D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo
01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo
00`0oooo00<0001o0?ooo`3oool0<`3oool60?l002<0oooo00<0001o0?ooo`3oool05@3oool40?l0
01`0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0
oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0
oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0
oooo0?ooo`0<0?ooo`030000O`3oool0oooo03@0oooo1@3o000S0?ooo`030000O`3oool0oooo01D0
oooo0`3o000M0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo
00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo
00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo
00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`0e0?ooo`@0o`008`3oool00`0007l0oooo
0?ooo`0E0?ooo`<0o`007@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?oo
o`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?oo
o`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0=P3oool40?l00280oooo00<0
001o0?ooo`3oool05@3oool30?l001d0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o
0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o
0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o
0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo03L0oooo103o000Q
0?ooo`030000O`3oool0oooo01@0oooo103o000M0?ooo`030000O`3oool0oooo02@0oooo00<0001o
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?oo
o`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?oo
o`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?oo
o`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`0h0?oo
o`@0o`00803oool00`0007l0oooo0?ooo`0D0?ooo`<0o`007P3oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3o
ool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3o
ool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3o
ool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3o
ool0>@3oool40?l001l0oooo00<0001o0?ooo`3oool0503oool30?l001h0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000
003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000
O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000
O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000
O`3oool0oooo03X0oooo103o000N0?ooo`030000O`3oool0oooo01<0oooo103o000N0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3o
ool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3o
ool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3o
ool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303o
ool00`0007l0oooo0?ooo`0k0?ooo`D0o`00703oool00`0007l0oooo0?ooo`0C0?ooo`<0o`007`3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0
oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0
oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0
oooo00`0oooo00<0001o0?ooo`3oool0?03oool50?l001/0oooo00<0001o0?ooo`3oool04`3oool3
0?l001l0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`00
07l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`00
07l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo03`0oooo1P3o000J0?ooo`030000O`3oool0oooo
0180oooo103o000O0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0
oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0
oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0
oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`0m0?ooo`H0o`006@3oool00`0007l0
oooo0?ooo`0B0?ooo`@0o`007`3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0?P3oool60?l001P0oooo
00<0001o0?ooo`3oool04P3oool40?l001l0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`<000001`3oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?oo
o`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?oo
o`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0?`3oool60?l001L0oooo00<0
001o0?ooo`3oool04@3oool40?l00200oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?oo
o`060?ooo`8000002@3oool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e
0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F
0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=
0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0@03oool60?l001H0oooo00<0001o
0?ooo`3oool04@3oool30?l00240oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?oo
o`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?oo
o`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo0440oooo1@3o000F0?oo
o`030000O`3oool0oooo0140oooo0`3o000Q0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`03
0000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`03
0000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`120?ooo`@0
o`005P3oool00`0007l0oooo0?ooo`0@0?ooo`@0o`008@3oool00`0007l0oooo0?ooo`0T0?ooo`03
0000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool0
1`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool0
6`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0
@`3oool40?l001D0oooo00<0001o0?ooo`3oool0403oool40?l00240oooo00<0001o0?ooo`3oool0
903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003o
ool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3o
ool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3o
ool0oooo04@0oooo103o000D0?ooo`030000O`3oool0oooo00l0oooo1@3o000Q0?ooo`030000O`3o
ool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool0
0`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool0
0`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool0
0`0007l0oooo0?ooo`150?ooo`@0o`004`3oool00`0007l0oooo0?ooo`0?0?ooo`@0o`008P3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
03D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo
01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo
00`0oooo00<0001o0?ooo`3oool0AP3oool40?l00180oooo00<0001o0?ooo`3oool03`3oool40?l0
0280oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0
oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0
oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0
oooo0?ooo`0<0?ooo`030000O`3oool0oooo04L0oooo103o000A0?ooo`030000O`3oool0oooo00h0
oooo103o000S0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo
00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo
00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo
00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`180?ooo`D0o`003`3oool00`0007l0oooo
0?ooo`0>0?ooo`@0o`008`3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?oo
o`0F0?ooo`030000O`3oool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?oo
o`0=0?ooo`030000O`3oool0oooo00`0oooo00<0001o0?ooo`3oool0B@3oool40?l000l0oooo00<0
001o0?ooo`3oool03@3oool50?l002<0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0001o
0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o
0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o
0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo04T0oooo1@3o000>
0?ooo`030000O`3oool0oooo00d0oooo103o000T0?ooo`030000O`3oool0oooo02@0oooo00<0001o
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?oo
o`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?oo
o`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?oo
o`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1:0?oo
o`H0o`00303oool00`0007l0oooo0?ooo`0<0?ooo`D0o`00903oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool002/0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3o
ool0303oool00`0007l0oooo0?ooo`1<0?ooo`D0o`002`3oool00`0007l0oooo0?ooo`0<0?ooo`<0
o`009P3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool002/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000
O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000
O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1<0?ooo`D0o`00
2`3oool00`0007l0oooo0?ooo`0;0?ooo`@0o`009P3oool00`0007l0oooo0?ooo`0T0?ooo`030000
O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool002L0oooo1P0000080?ooo`030000003o
ool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3o
ool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3o
ool0oooo04d0oooo1@3o000:0?ooo`030000O`3oool0oooo00X0oooo1@3o000V0?ooo`030000O`3o
ool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00:03oool0
10000000oooo0?ooo`0000090?ooo`@000001P3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3o
ool0oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3o
ool0oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3o
ool0oooo00`0oooo00<0001o0?ooo`3oool0CP3oool70?l000L0oooo00<0001o0?ooo`3oool02P3o
ool50?l002H0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`050?ooo`<000002@3o
ool002P0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`070?ooo`030000O`3o
ool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3o
ool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3o
ool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1@0?ooo`H0o`001P3o
ool00`0007l0oooo0?ooo`090?ooo`D0o`009`3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool002T0oooo00<000000?ooo`0000002@3oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool0
0`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool0
0`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool0
0`0007l0oooo0?ooo`1A0?ooo`H0o`001@3oool00`0007l0oooo0?ooo`080?ooo`@0o`00:@3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
02T0oooo00<000000?ooo`0000002@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo
03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo
01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo
00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1B0?ooo`D0o`001@3oool00`00
07l0oooo0?ooo`070?ooo`D0o`00:@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool002X0oooo0P0000090?ooo`030000003oool0oooo00L0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0
oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0
oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05<0
oooo1`3o00020?ooo`030000O`3oool0oooo00H0oooo1P3o000Y0?ooo`030000O`3oool0oooo02@0
oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00:P3oool2000000T0oooo
00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo
00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo
00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo
00<0001o0?ooo`3oool0E03oool80?l000030000O`3oool0oooo00D0oooo1P3o000Z0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00:`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03@3o
ool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo05H0oooo1`3o00040?ooo`P0o`00:`3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool003D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0
oooo02D0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0
oooo01<0oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0
oooo00`0oooo00<0001o0?ooo`3oool0E`3ooolA0?l002`0oooo00<0001o0?ooo`3oool0903oool0
0`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo
01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo
00l0oooo00<0001o0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000O`3oool0oooo
05T0oooo303o000_0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0
oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0
oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00d0
oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?ooo`1L0?ooo`P0o`00<03oool00`0007l0
oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool01`3oool003D0oooo
00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo
00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo01<0oooo
00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`030000O`3oool0oooo00`0oooo
00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo
00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`00=@3oool00`000000oooo0?oo
o`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?oo
o`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04`3oool00`0007l0oooo0?oo
o`0?0?ooo`030000O`3oool0oooo00d0oooo00<0001o0?ooo`3oool0303oool00`0007l0oooo0?oo
o`1L0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo000e0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo01/0oooo00<00000
0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o
0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0<0?ooo`030000003oool0oooo05`0oooo00<00000
0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`00=@3ooooo00000;8000002@3oool00001\
\>"],
  ImageRangeCache->{{{57.1875, 452.875}, {319.375, 75.1875}} -> {-1.12744, \
-2.17165, 0.00316366, 0.0313695}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.53547 0.732021 -0.00158464 0.367532 [
[.02381 -0.0125 -10.9688 -16.375 ]
[.02381 -0.0125 10.9688 0 ]
[.31511 -0.0125 -10.9688 -16.375 ]
[.31511 -0.0125 10.9688 0 ]
[.53547 -0.0125 -5.59375 -16.375 ]
[.53547 -0.0125 5.59375 0 ]
[.75583 -0.0125 -5.59375 -16.375 ]
[.75583 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -67.0938 -32.75 ]
[.5 -0.0125 67.0938 -16.375 ]
[-0.0125 .0903 -29.125 -8.1875 ]
[-0.0125 .0903 0 8.1875 ]
[-0.0125 .18218 -21.9375 -8.1875 ]
[-0.0125 .18218 0 8.1875 ]
[-0.0125 .27406 -29.125 -8.1875 ]
[-0.0125 .27406 0 8.1875 ]
[-0.0125 .36595 -11.1875 -8.1875 ]
[-0.0125 .36595 0 8.1875 ]
[-0.0125 .45783 -29.125 -8.1875 ]
[-0.0125 .45783 0 8.1875 ]
[-0.0125 .54971 -21.9375 -8.1875 ]
[-0.0125 .54971 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -45.5 -48.375 ]
[-0.01875 .30902 -29.125 48.375 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .61803 L
s
.31511 0 m
.31511 .61803 L
s
.53547 0 m
.53547 .61803 L
s
.75583 0 m
.75583 .61803 L
s
.15271 0 m
.15271 .61803 L
s
.24417 0 m
.24417 .61803 L
s
.37307 0 m
.37307 .61803 L
s
.42208 0 m
.42208 .61803 L
s
.46453 0 m
.46453 .61803 L
s
.50197 0 m
.50197 .61803 L
s
.88473 0 m
.88473 .61803 L
s
.97619 0 m
.97619 .61803 L
s
0 .0903 m
1 .0903 L
s
0 .18218 m
1 .18218 L
s
0 .27406 m
1 .27406 L
s
0 .36595 m
1 .36595 L
s
0 .45783 m
1 .45783 L
s
0 .54971 m
1 .54971 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -71.9688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
80.938 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31511 0 m
.31511 .00625 L
s
gsave
.31511 -0.0125 -71.9688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
80.938 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.53547 0 m
.53547 .00625 L
s
gsave
.53547 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
70.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.75583 0 m
.75583 .00625 L
s
gsave
.75583 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
70.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.15271 0 m
.15271 .00375 L
s
.24417 0 m
.24417 .00375 L
s
.37307 0 m
.37307 .00375 L
s
.42208 0 m
.42208 .00375 L
s
.46453 0 m
.46453 .00375 L
s
.50197 0 m
.50197 .00375 L
s
.88473 0 m
.88473 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -128.094 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Focal) show
98.188 16.625 moveto
(Length) show
141.250 16.625 moveto
(of) show
156.063 16.625 moveto
(L1) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
174.000 16.625 moveto
(H) show
178.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
189.000 16.625 moveto
(L) show
193.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0903 m
.00625 .0903 L
s
gsave
-0.0125 .0903 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
0 .18218 m
.00625 .18218 L
s
gsave
-0.0125 .18218 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .27406 m
.00625 .27406 L
s
gsave
-0.0125 .27406 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .36595 m
.00625 .36595 L
s
gsave
-0.0125 .36595 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .45783 m
.00625 .45783 L
s
gsave
-0.0125 .45783 -90.125 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
1.000 setlinewidth
grestore
0 .54971 m
.00625 .54971 L
s
gsave
-0.0125 .54971 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01679 m
.00375 .01679 L
s
0 .03517 m
.00375 .03517 L
s
0 .05355 m
.00375 .05355 L
s
0 .07192 m
.00375 .07192 L
s
0 .10867 m
.00375 .10867 L
s
0 .12705 m
.00375 .12705 L
s
0 .14543 m
.00375 .14543 L
s
0 .1638 m
.00375 .1638 L
s
0 .20056 m
.00375 .20056 L
s
0 .21893 m
.00375 .21893 L
s
0 .23731 m
.00375 .23731 L
s
0 .25569 m
.00375 .25569 L
s
0 .29244 m
.00375 .29244 L
s
0 .31082 m
.00375 .31082 L
s
0 .32919 m
.00375 .32919 L
s
0 .34757 m
.00375 .34757 L
s
0 .38432 m
.00375 .38432 L
s
0 .4027 m
.00375 .4027 L
s
0 .42108 m
.00375 .42108 L
s
0 .43945 m
.00375 .43945 L
s
0 .47621 m
.00375 .47621 L
s
0 .49458 m
.00375 .49458 L
s
0 .51296 m
.00375 .51296 L
s
0 .53134 m
.00375 .53134 L
s
0 .56809 m
.00375 .56809 L
s
0 .58647 m
.00375 .58647 L
s
0 .60484 m
.00375 .60484 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -146.688 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
109.375 12.1875 translate
90 rotate
-109.375 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Waist) show
99.250 16.625 moveto
(size) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.750 16.625 moveto
(H) show
129.938 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
151.563 16.625 moveto
(L) show
155.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.31511 .61178 m
.31511 .61803 L
s
.53547 .61178 m
.53547 .61803 L
s
.75583 .61178 m
.75583 .61803 L
s
.001 w
.15271 .61428 m
.15271 .61803 L
s
.24417 .61428 m
.24417 .61803 L
s
.37307 .61428 m
.37307 .61803 L
s
.42208 .61428 m
.42208 .61803 L
s
.46453 .61428 m
.46453 .61803 L
s
.50197 .61428 m
.50197 .61803 L
s
.88473 .61428 m
.88473 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0903 m
1 .0903 L
s
.99375 .18218 m
1 .18218 L
s
.99375 .27406 m
1 .27406 L
s
.99375 .36595 m
1 .36595 L
s
.99375 .45783 m
1 .45783 L
s
.99375 .54971 m
1 .54971 L
s
.125 Mabswid
.99625 .01679 m
1 .01679 L
s
.99625 .03517 m
1 .03517 L
s
.99625 .05355 m
1 .05355 L
s
.99625 .07192 m
1 .07192 L
s
.99625 .10867 m
1 .10867 L
s
.99625 .12705 m
1 .12705 L
s
.99625 .14543 m
1 .14543 L
s
.99625 .1638 m
1 .1638 L
s
.99625 .20056 m
1 .20056 L
s
.99625 .21893 m
1 .21893 L
s
.99625 .23731 m
1 .23731 L
s
.99625 .25569 m
1 .25569 L
s
.99625 .29244 m
1 .29244 L
s
.99625 .31082 m
1 .31082 L
s
.99625 .32919 m
1 .32919 L
s
.99625 .34757 m
1 .34757 L
s
.99625 .38432 m
1 .38432 L
s
.99625 .4027 m
1 .4027 L
s
.99625 .42108 m
1 .42108 L
s
.99625 .43945 m
1 .43945 L
s
.99625 .47621 m
1 .47621 L
s
.99625 .49458 m
1 .49458 L
s
.99625 .51296 m
1 .51296 L
s
.99625 .53134 m
1 .53134 L
s
.99625 .56809 m
1 .56809 L
s
.99625 .58647 m
1 .58647 L
s
.99625 .60484 m
1 .60484 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.007 w
.02381 .01472 m
.02964 .01504 L
.03588 .0154 L
.04164 .01573 L
.04707 .01606 L
.05276 .0164 L
.05814 .01673 L
.06376 .01709 L
.06908 .01743 L
.07411 .01777 L
.07938 .01812 L
.08438 .01846 L
.08911 .01879 L
.09407 .01914 L
.09877 .01948 L
.10369 .01984 L
.10836 .02019 L
.11279 .02053 L
.11744 .02089 L
.12185 .02124 L
.12647 .02161 L
.13086 .02197 L
.13503 .02231 L
.1394 .02268 L
.14356 .02304 L
.1475 .02338 L
.15165 .02375 L
.15559 .0241 L
.15973 .02448 L
.16366 .02485 L
.1674 .0252 L
.17133 .02557 L
.17507 .02594 L
.17863 .02629 L
.18237 .02666 L
.18593 .02702 L
.18967 .02741 L
.19323 .02778 L
.19662 .02814 L
.20019 .02852 L
.20359 .02889 L
.20716 .02928 L
.21056 .02966 L
.21381 .03003 L
.21722 .03042 L
.22047 .0308 L
.22356 .03117 L
.22682 .03156 L
.22993 .03194 L
.23321 .03234 L
Mistroke
.23633 .03273 L
.2393 .0331 L
.24243 .0335 L
.24542 .03389 L
.24856 .0343 L
.25156 .0347 L
.25442 .03508 L
.25744 .03549 L
.26031 .03589 L
.26305 .03627 L
.26595 .03668 L
.26871 .03707 L
.27161 .03749 L
.27439 .0379 L
.27704 .03829 L
.27983 .0387 L
.2825 .03911 L
.28504 .0395 L
.28773 .03991 L
.29029 .04032 L
.29299 .04074 L
.29557 .04116 L
.29804 .04156 L
.30064 .04198 L
.30312 .04239 L
.30574 .04283 L
.30824 .04326 L
.31063 .04367 L
.31316 .0441 L
.31557 .04453 L
.31787 .04493 L
.3203 .04537 L
.32262 .04579 L
.32507 .04624 L
.32742 .04667 L
.32965 .04709 L
.33202 .04753 L
.33428 .04796 L
.33643 .04838 L
.33871 .04882 L
.34089 .04925 L
.3432 .04971 L
.3454 .05015 L
.3475 .05058 L
.34972 .05103 L
.35185 .05147 L
.35409 .05194 L
.35624 .05239 L
.35829 .05283 L
.36046 .0533 L
Mistroke
.36253 .05375 L
.36451 .05418 L
.36661 .05465 L
.36861 .05509 L
.37073 .05557 L
.37276 .05604 L
.37469 .05648 L
.37674 .05696 L
.3787 .05742 L
.38077 .05791 L
.38275 .05838 L
.38465 .05884 L
.38665 .05933 L
.38857 .0598 L
.3904 .06026 L
.39234 .06074 L
.39419 .06121 L
.39615 .06172 L
.39803 .0622 L
.39983 .06267 L
.40173 .06317 L
.40354 .06365 L
.40528 .06411 L
.40712 .06461 L
.40888 .06509 L
.41075 .0656 L
.41253 .0661 L
.41424 .06658 L
.41604 .06709 L
.41777 .06758 L
.4196 .0681 L
.42135 .06861 L
.42302 .0691 L
.42479 .06962 L
.42649 .07013 L
.42812 .07062 L
.42983 .07114 L
.43148 .07164 L
.43322 .07218 L
.43489 .0727 L
.43648 .0732 L
.43817 .07373 L
.43979 .07425 L
.4415 .0748 L
.44314 .07533 L
.44471 .07585 L
.44637 .0764 L
.44796 .07693 L
.44949 .07744 L
.4511 .07799 L
Mistroke
.45265 .07851 L
.45428 .07908 L
.45585 .07962 L
.45735 .08015 L
.45893 .08071 L
.46046 .08125 L
.46191 .08177 L
.46346 .08233 L
.46493 .08287 L
.4665 .08345 L
.468 .08401 L
.46943 .08454 L
.47095 .08512 L
.47241 .08567 L
.47395 .08626 L
.47543 .08684 L
.47684 .08739 L
.47834 .08798 L
.47978 .08855 L
.48115 .0891 L
.48261 .08968 L
.48401 .09025 L
.48549 .09086 L
.4869 .09144 L
.48826 .092 L
.4897 .09261 L
.49108 .09319 L
.4924 .09375 L
.4938 .09435 L
.49514 .09493 L
.49656 .09555 L
.49792 .09615 L
.49922 .09673 L
.5006 .09734 L
.50193 .09794 L
.50333 .09858 L
.50468 .09919 L
.50596 .09978 L
.50733 .10042 L
.50864 .10103 L
.50989 .10162 L
.51122 .10225 L
.51249 .10286 L
.51384 .10351 L
.51514 .10414 L
.51638 .10475 L
.51769 .1054 L
.51895 .10602 L
.52028 .10669 L
.52156 .10734 L
Mistroke
.52279 .10796 L
.52409 .10863 L
.52533 .10927 L
.52653 .10989 L
.52779 .11056 L
.52901 .1112 L
.53029 .11188 L
.53152 .11254 L
.53271 .11318 L
.53396 .11386 L
.53516 .11452 L
.53631 .11516 L
.53753 .11584 L
.5387 .1165 L
.53994 .1172 L
.54113 .11787 L
.54227 .11853 L
.54348 .11923 L
.54464 .1199 L
.54587 .12062 L
.54704 .12132 L
.54817 .12199 L
.54937 .12271 L
.55052 .1234 L
.55162 .12407 L
.55279 .12479 L
.55391 .12548 L
.55509 .12622 L
.55623 .12693 L
.55732 .12762 L
.55848 .12835 L
.55959 .12906 L
.56065 .12975 L
.56178 .13048 L
.56286 .13119 L
.56401 .13194 L
.56511 .13267 L
.56617 .13338 L
.56728 .13413 L
.56836 .13486 L
.5695 .13564 L
.57059 .13639 L
.57163 .13711 L
.57274 .13789 L
.57381 .13863 L
.57483 .13936 L
.57591 .14013 L
.57695 .14087 L
.57805 .14167 L
.57911 .14244 L
Mistroke
.58012 .14318 L
.5812 .14397 L
.58223 .14474 L
.58332 .14556 L
.58437 .14635 L
.58537 .14711 L
.58644 .14793 L
.58746 .14872 L
.58845 .14948 L
.58949 .15029 L
.59049 .15108 L
.59154 .15191 L
.59256 .15272 L
.59354 .15351 L
.59457 .15434 L
.59556 .15515 L
.59651 .15593 L
.59752 .15676 L
.59849 .15757 L
.59952 .15843 L
.6005 .15926 L
.60145 .16006 L
.60245 .16092 L
.60341 .16174 L
.60443 .16263 L
.60541 .16348 L
.60635 .1643 L
.60735 .16519 L
.60831 .16604 L
.60922 .16686 L
.6102 .16774 L
.61113 .16858 L
.61212 .16949 L
.61307 .17036 L
.61398 .17121 L
.61495 .17211 L
.61588 .17298 L
.61686 .17391 L
.61781 .17481 L
.61872 .17568 L
.61968 .17661 L
.6206 .17751 L
.62149 .17837 L
.62243 .1793 L
.62333 .18019 L
.62428 .18115 L
.6252 .18207 L
.62608 .18296 L
.62702 .18391 L
.62792 .18483 L
Mistroke
.62878 .18572 L
.62969 .18667 L
.63057 .18758 L
.6315 .18856 L
.63239 .18951 L
.63324 .19042 L
.63415 .19139 L
.63503 .19234 L
.63595 .19334 L
.63684 .19431 L
.63769 .19525 L
.6386 .19625 L
.63946 .19722 L
.6403 .19816 L
.64118 .19916 L
.64203 .20012 L
.64293 .20115 L
.64379 .20215 L
.64462 .20311 L
.6455 .20414 L
.64635 .20513 L
.64716 .20609 L
.64802 .20711 L
.64884 .2081 L
.64972 .20915 L
.65056 .21017 L
.65137 .21116 L
.65222 .21221 L
.65305 .21323 L
.65392 .21431 L
.65476 .21536 L
.65556 .21637 L
.65641 .21745 L
.65723 .2185 L
.65802 .21951 L
.65885 .22058 L
.65965 .22162 L
.6605 .22273 L
.66132 .22381 L
.6621 .22484 L
.66293 .22595 L
.66373 .22702 L
.66458 .22816 L
.66539 .22926 L
.66617 .23033 L
.667 .23147 L
.66779 .23257 L
.66856 .23363 L
.66937 .23476 L
.67014 .23586 L
Mistroke
.67097 .23702 L
.67176 .23815 L
.67252 .23924 L
.67333 .24041 L
.6741 .24153 L
.67485 .24262 L
.67564 .24378 L
.6764 .2449 L
.6772 .24609 L
.67797 .24725 L
.67871 .24836 L
.6795 .24955 L
.68026 .2507 L
.68106 .25193 L
.68183 .25312 L
.68257 .25426 L
.68335 .25548 L
.68411 .25666 L
.68483 .2578 L
.6856 .25902 L
.68634 .2602 L
.68712 .26145 L
.68787 .26266 L
.68859 .26383 L
.68936 .26508 L
.69009 .26629 L
.69087 .26758 L
.69162 .26882 L
.69234 .27002 L
.6931 .2713 L
.69384 .27254 L
.69454 .27373 L
.69529 .27501 L
.69601 .27624 L
.69677 .27756 L
.6975 .27883 L
.6982 .28005 L
.69895 .28136 L
.69966 .28262 L
.70035 .28384 L
.70108 .28515 L
.70178 .2864 L
.70253 .28774 L
.70324 .28904 L
.70393 .29029 L
.70465 .29162 L
.70535 .29291 L
.7061 .29428 L
.70681 .29561 L
.70749 .29689 L
Mistroke
.70822 .29826 L
.70892 .29958 L
.70959 .30085 L
.7103 .30221 L
.71098 .30352 L
.71171 .30492 L
.7124 .30627 L
.71307 .30758 L
.71378 .30897 L
.71446 .31031 L
.71512 .3116 L
.71581 .31299 L
.71648 .31432 L
.71719 .31574 L
.71787 .31712 L
.71852 .31844 L
.71922 .31986 L
.71989 .32122 L
.72059 .32268 L
.72127 .32408 L
.72193 .32544 L
.72262 .32688 L
.72328 .32828 L
.72392 .32962 L
.7246 .33106 L
.72525 .33245 L
.72594 .33392 L
.72661 .33535 L
.72725 .33672 L
.72793 .33819 L
.72858 .3396 L
.72927 .34111 L
.72993 .34257 L
.73057 .34397 L
.73124 .34547 L
.73189 .34691 L
.73252 .3483 L
.73318 .34979 L
.73382 .35122 L
.73449 .35274 L
.73514 .35422 L
.73577 .35563 L
.73643 .35715 L
.73706 .35861 L
.73767 .36001 L
.73832 .36151 L
.73895 .36296 L
.73961 .3645 L
.74024 .36599 L
.74085 .36742 L
Mistroke
.7415 .36895 L
.74212 .37042 L
.74278 .37198 L
.74342 .3735 L
.74403 .37495 L
.74468 .37651 L
.7453 .378 L
.74589 .37945 L
.74653 .38098 L
.74714 .38246 L
.74778 .38404 L
.74841 .38556 L
.749 .38703 L
.74964 .38859 L
.75025 .39009 L
.75083 .39154 L
.75145 .39308 L
.75205 .39457 L
.75268 .39615 L
.75329 .39768 L
.75387 .39915 L
.75449 .40071 L
.75509 .40222 L
.75572 .40382 L
.75633 .40537 L
.75691 .40686 L
.75753 .40844 L
.75813 .40996 L
.7587 .41143 L
.75931 .413 L
.7599 .4145 L
.76051 .4161 L
.76111 .41764 L
.76168 .41913 L
.76229 .42071 L
.76287 .42223 L
.76349 .42384 L
.76409 .4254 L
.76466 .4269 L
.76527 .42849 L
.76585 .43003 L
.76641 .4315 L
.76701 .43307 L
.76758 .43458 L
.76819 .43619 L
.76877 .43773 L
.76933 .43922 L
.76993 .4408 L
.7705 .44232 L
.77105 .44378 L
Mistroke
.77163 .44533 L
.77219 .44682 L
.77279 .44841 L
.77336 .44994 L
.77391 .4514 L
.77449 .45296 L
.77505 .45446 L
.77565 .45605 L
.77622 .45759 L
.77677 .45906 L
.77735 .46062 L
.77791 .46212 L
.77845 .46356 L
.77902 .4651 L
.77957 .46657 L
.78016 .46813 L
.78072 .46963 L
.78126 .47107 L
.78183 .47261 L
.78238 .47408 L
.78296 .47563 L
.78352 .47713 L
.78406 .47857 L
.78463 .4801 L
.78518 .48156 L
.78571 .48297 L
.78627 .48446 L
.78681 .48589 L
.78738 .48741 L
.78793 .48887 L
.78846 .49026 L
.78902 .49175 L
.78956 .49317 L
.79008 .49453 L
.79063 .49598 L
.79116 .49736 L
.79172 .49883 L
.79226 .50024 L
.79278 .50159 L
.79333 .50302 L
.79386 .50439 L
.79442 .50585 L
.79496 .50724 L
.79548 .50857 L
.79603 .50998 L
.79656 .51134 L
.79707 .51263 L
.79761 .514 L
.79813 .51532 L
.79868 .51671 L
Mistroke
.79921 .51804 L
.79972 .51931 L
.80026 .52066 L
.80078 .52195 L
.80128 .52318 L
.80181 .52449 L
.80232 .52574 L
.80286 .52706 L
.80338 .52833 L
.80388 .52953 L
.80441 .53081 L
.80492 .53203 L
.80546 .53332 L
.80598 .53456 L
.80648 .53574 L
.80701 .53698 L
.80752 .53817 L
.80801 .53931 L
.80853 .54051 L
.80903 .54165 L
.80956 .54286 L
.81007 .54402 L
.81057 .54512 L
.81109 .54628 L
.81159 .5474 L
.81212 .54857 L
.81263 .54968 L
.81312 .55075 L
.81364 .55187 L
.81415 .55294 L
.81463 .55396 L
.81514 .55504 L
.81563 .55606 L
.81615 .55714 L
.81666 .55817 L
.81714 .55915 L
.81765 .56018 L
.81814 .56117 L
.81862 .5621 L
.81912 .56309 L
.8196 .56402 L
.82011 .56501 L
.82061 .56594 L
.82108 .56684 L
.82159 .56777 L
.82207 .56866 L
.82258 .5696 L
.82308 .57049 L
.82355 .57133 L
.82405 .57222 L
Mistroke
.82454 .57306 L
.825 .57386 L
.8255 .5747 L
.82597 .5755 L
.82648 .57633 L
.82696 .57712 L
.82743 .57787 L
.82792 .57866 L
.8284 .5794 L
.82886 .58011 L
.82934 .58085 L
.82981 .58155 L
.83031 .58228 L
.83078 .58298 L
.83124 .58363 L
.83173 .58432 L
.83219 .58497 L
.83269 .58564 L
.83317 .58628 L
.83363 .58689 L
.83411 .58752 L
.83458 .58811 L
.83503 .58867 L
.83551 .58926 L
.83597 .58981 L
.83646 .59038 L
.83693 .59092 L
.83738 .59143 L
.83786 .59196 L
.83832 .59246 L
.83881 .59297 L
.83928 .59346 L
.83973 .59391 L
.84021 .59438 L
.84067 .59482 L
.84111 .59524 L
.84158 .59567 L
.84203 .59607 L
.84251 .59648 L
.84298 .59687 L
.84342 .59723 L
.84389 .5976 L
.84434 .59795 L
.84478 .59827 L
.84524 .5986 L
.84569 .59891 L
.84616 .59922 L
.84661 .59952 L
.84705 .59979 L
.84751 .60006 L
Mistroke
.84796 .60032 L
.84843 .60058 L
.84889 .60082 L
.84932 .60104 L
.84979 .60126 L
.85023 .60146 L
.85066 .60164 L
.85112 .60183 L
.85156 .60199 L
.85202 .60216 L
.85247 .60231 L
.8529 .60245 L
.85336 .60258 L
.85379 .60269 L
.85426 .60281 L
.85471 .6029 L
.85514 .60299 L
.8556 .60307 L
.85604 .60313 L
.85646 .60319 L
.85691 .60323 L
.85734 .60327 L
.85756 .60328 L
.8578 .6033 L
.85803 .60331 L
.85814 .60331 L
.85824 .60331 L
.85835 .60331 L
.85845 .60332 L
.8585 .60332 L
.85855 .60332 L
.85861 .60332 L
.85864 .60332 L
.85867 .60332 L
.85869 .60332 L
.8587 .60332 L
.85871 .60332 L
.85873 .60332 L
.85874 .60332 L
.85874 .60332 L
.85875 .60332 L
.85876 .60332 L
.85877 .60332 L
.85878 .60332 L
.85879 .60332 L
.8588 .60332 L
.85881 .60332 L
.85884 .60332 L
.85887 .60332 L
.8589 .60332 L
Mistroke
.85895 .60332 L
.85901 .60332 L
.8591 .60332 L
.85921 .60331 L
.85932 .60331 L
.85952 .6033 L
.85976 .60329 L
.85998 .60328 L
.8604 .60325 L
.86085 .60321 L
.86128 .60316 L
.86169 .60311 L
.86213 .60304 L
.86256 .60296 L
.863 .60287 L
.86344 .60278 L
.86385 .60268 L
.86429 .60257 L
.86472 .60245 L
.86517 .60231 L
.8656 .60217 L
.86601 .60203 L
.86646 .60187 L
.86688 .60171 L
.86729 .60155 L
.86772 .60137 L
.86814 .60119 L
.86858 .60099 L
.86901 .60079 L
.86942 .60059 L
.86985 .60036 L
.87027 .60014 L
.87067 .59992 L
.8711 .59968 L
.87151 .59944 L
.87194 .59918 L
.87236 .59892 L
.87276 .59867 L
.87319 .59839 L
.8736 .59812 L
.87404 .59782 L
.87446 .59752 L
.87486 .59723 L
.87529 .59692 L
.8757 .59661 L
.8761 .59631 L
.87652 .59598 L
.87693 .59566 L
.87736 .59531 L
.87777 .59496 L
Mistroke
.87817 .59463 L
.87859 .59427 L
.87899 .59391 L
.87942 .59353 L
.87984 .59316 L
.88024 .59279 L
.88066 .5924 L
.88107 .59202 L
.88146 .59164 L
.88187 .59124 L
.88227 .59085 L
.8827 .59042 L
.8831 .59001 L
.8835 .58961 L
.88391 .58918 L
.88431 .58876 L
.8847 .58835 L
.88511 .58791 L
.8855 .58749 L
.88592 .58703 L
.88632 .58658 L
.8867 .58615 L
.88711 .58569 L
.88751 .58524 L
.88793 .58475 L
.88833 .58428 L
.88872 .58383 L
.88913 .58334 L
.88952 .58287 L
.8899 .58241 L
.89031 .58192 L
.89069 .58144 L
.89111 .58093 L
.8915 .58044 L
.89188 .57996 L
.89229 .57945 L
.89268 .57895 L
.89305 .57847 L
.89345 .57796 L
.89383 .57746 L
.89424 .57693 L
.89463 .57641 L
.895 .57591 L
.8954 .57538 L
.89578 .57486 L
.89619 .57431 L
.89658 .57378 L
.89696 .57327 L
.89736 .57272 L
.89774 .57219 L
Mistroke
.89811 .57167 L
.8985 .57112 L
.89888 .57059 L
.89928 .57003 L
.89967 .56948 L
.90004 .56895 L
.90043 .56839 L
.90081 .56784 L
.90121 .56726 L
.9016 .5667 L
.90197 .56616 L
.90236 .56558 L
.90274 .56502 L
.90311 .56449 L
.90349 .56391 L
.90387 .56336 L
.90426 .56277 L
.90464 .5622 L
.90501 .56165 L
.9054 .56106 L
.90577 .5605 L
.90613 .55995 L
.90651 .55937 L
.90688 .55881 L
.90727 .55821 L
.90765 .55764 L
.90801 .55708 L
.90839 .55649 L
.90876 .55592 L
.90915 .55531 L
.90953 .55473 L
.90989 .55416 L
.91027 .55356 L
.91064 .55298 L
.911 .55242 L
.91137 .55183 L
.91174 .55126 L
.91212 .55065 L
.91249 .55006 L
.91285 .54949 L
.91323 .54889 L
.91359 .54831 L
.91394 .54775 L
.91431 .54716 L
.91467 .54659 L
.91505 .54598 L
.91542 .54539 L
.91577 .54483 L
.91614 .54422 L
.9165 .54364 L
Mistroke
.91688 .54303 L
.91725 .54244 L
.9176 .54187 L
.91797 .54126 L
.91833 .54067 L
.91868 .54011 L
.91904 .53951 L
.9194 .53894 L
.91977 .53832 L
.92013 .53773 L
.92048 .53717 L
.92085 .53656 L
.92121 .53598 L
.92158 .53537 L
.92194 .53477 L
.92229 .5342 L
.92266 .53359 L
.92302 .53301 L
.92336 .53245 L
.92372 .53185 L
.92407 .53127 L
.92444 .53066 L
.9248 .53007 L
.92514 .52951 L
.92551 .52891 L
.92586 .52833 L
.9262 .52777 L
.92656 .52718 L
.9269 .52661 L
.92727 .52601 L
.92762 .52543 L
.92796 .52487 L
.92832 .52428 L
.92866 .5237 L
.92903 .5231 L
.92938 .52251 L
.92972 .52195 L
.93008 .52136 L
.93043 .52078 L
.93076 .52023 L
.93112 .51965 L
.93146 .51908 L
.93182 .51849 L
.93217 .51791 L
.9325 .51736 L
.93286 .51677 L
.9332 .51621 L
.93356 .51561 L
.93391 .51503 L
.93425 .51448 L
Mistroke
.9346 .51389 L
.93495 .51333 L
.93528 .51278 L
.93563 .51221 L
.93596 .51165 L
.93632 .51106 L
.93667 .5105 L
.937 .50995 L
.93735 .50937 L
.93769 .50882 L
.93801 .50829 L
.93836 .50772 L
.93869 .50718 L
.93904 .5066 L
.93938 .50604 L
.93971 .50551 L
.94006 .50494 L
.94039 .5044 L
.94074 .50382 L
.94109 .50326 L
.94141 .50273 L
.94176 .50216 L
.9421 .50162 L
.94242 .50109 L
.94276 .50054 L
.94309 .5 L
.94344 .49944 L
.94377 .49889 L
.9441 .49837 L
.94444 .49781 L
.94477 .49728 L
.94509 .49677 L
.94543 .49622 L
.94575 .4957 L
.94609 .49515 L
.94643 .49461 L
.94674 .4941 L
.94708 .49356 L
.94741 .49303 L
.94775 .49248 L
.94809 .49195 L
.94841 .49144 L
.94875 .49089 L
.94907 .49037 L
.94939 .48987 L
.94972 .48934 L
.95004 .48883 L
.95038 .48829 L
.95071 .48777 L
.95103 .48727 L
Mistroke
.95136 .48674 L
.95169 .48623 L
.95203 .48569 L
.95236 .48517 L
.95267 .48467 L
.95301 .48414 L
.95333 .48363 L
.95364 .48314 L
.95398 .48262 L
.95429 .48212 L
.95463 .4816 L
.95496 .48109 L
.95527 .4806 L
.9556 .48008 L
.95592 .47959 L
.95623 .47911 L
.95655 .47861 L
.95687 .47812 L
.9572 .4776 L
.95752 .47711 L
.95783 .47663 L
.95815 .47613 L
.95847 .47564 L
.9588 .47513 L
.95913 .47463 L
.95944 .47416 L
.95976 .47366 L
.96008 .47317 L
.96038 .47271 L
.96071 .47222 L
.96102 .47174 L
.96135 .47124 L
.96167 .47076 L
.96197 .4703 L
.96229 .46981 L
.96261 .46934 L
.96294 .46884 L
.96326 .46836 L
.96356 .4679 L
.96389 .46741 L
.9642 .46694 L
.9645 .46649 L
.96482 .46601 L
.96513 .46555 L
.96546 .46506 L
.96577 .46459 L
.96607 .46414 L
.96639 .46367 L
.9667 .46321 L
.967 .46277 L
Mistroke
.96732 .4623 L
.96762 .46185 L
.96794 .46138 L
.96825 .46092 L
.96855 .46048 L
.96887 .46002 L
.96917 .45957 L
.9695 .4591 L
.96981 .45864 L
.97011 .45821 L
.97043 .45775 L
.97073 .4573 L
.97103 .45687 L
.97134 .45642 L
.97164 .45599 L
.97196 .45553 L
.97227 .45508 L
.97256 .45466 L
.97288 .45421 L
.97318 .45377 L
.97347 .45336 L
.97378 .45292 L
.97407 .45249 L
.97439 .45204 L
.97469 .45161 L
.97498 .4512 L
.97529 .45076 L
.97559 .45034 L
.97591 .44989 L
.97619 .44949 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{495.875, 306.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007_0001<R000`400?l00000o`00003oo`3oooo`
0?ooo`00o`3oooo`0?ooo`00o`3oool<0?ooo`<00000=@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo09d0oooo003o0?ooo`/0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0W03oool00?l0oooo3`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0V`3oool00=80oooo00<0
00000?ooo`3oool01P3oool3000000@0oooo0`0000040?ooo`80000000D0oooo0000003oool0oooo
000000050?ooo`H000000P3oool3000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`80
000000@0oooo0000003oool0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000001`3oool3
000000<0oooo00<000000?ooo`3oool01@3oool6000000<0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo09/0oooo003B0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0200000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P000002
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo09/0oooo003B0?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0V`3oool00=80oooo00<00000
0?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3o
ool400000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`D000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo09/0oooo003B0?ooo`030000003oool0oooo00D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo09/0oooo003B0?ooo`D000000`3oool01@000000oooo0?ooo`3oool0
00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`8000000P3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool01000
0000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`8000000P3oool01@000000oooo
0?ooo`3oool0000009d0oooo003B0?ooo`030000003oool0oooo00H0oooo0`0000040?ooo`<00000
103oool3000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`<00000
0`3oool010000000oooo0000000000040?ooo`80000000<0oooo0000003oool00`0000020?ooo`04
0000003oool00000000000P0oooo0`0000020?ooo`<000001P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00H000000?ooo`3oool0oooo0000003oool200000080oooo0P00
00040?ooo`030000003oool0oooo09/0oooo003B0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`050000003oool0oooo0?ooo`0000004@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000002@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo09`0oooo003B0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`050000003oool0
oooo0?ooo`0000004@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo0P00
000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0W@3oool00=80oooo1P00000G
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0@
0?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0;@0oooo003o0?oo
oo00oooo003o0?oooo00oooo003o0?oooo00oooo003o0?oooo00oooo003o0?oooo00oooo003o0?oo
oo00oooo000l0?ooo`@000000`3oool00`000000oooo0?ooo`06000006h0oooo100000030?ooo`04
0000003oool0oooo0?ooo`@00000E`3oool00`000000oooo0?ooo`1J0?ooo`H00000K03oool003/0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06l0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo06h0
oooo000k0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1^0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0K@3oool003/0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool0G@3oool00`000000oooo0?ooo`1/0?ooo`00>`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0J`3oool003/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`D00000E`3oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo06X0oooo000k0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3o
ool0JP3oool003/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo06/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`000000H@3oool00`000000oooo0?ooo`1Z0?ooo`00>`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1G0?ooo`800000G03oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo06X0oooo000l0?ooo`@000001`3oool4000006l0oooo100000070?ooo`D00000EP3oool0
0`000000oooo0?ooo`1K0?ooo`@00000K@3oool00?l0ooool03oool00?l0ooool03oool00?l0oooo
l03oool00?l0ooool03oool00?l0ooool03oool00?l0ooool03oool00?l0ooool03oool003X0oooo
o`00002b000000@0oooo000j0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool003X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`00
07l0oooo0?ooo`0L0?ooo`030000003oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`00
07l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`00
0000oooo0?ooo`1L0?ooo`030000003oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`00
07l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0
oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0
oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo
0?ooo`020?ooo`00>P3oool00`000000oooo0?ooo`060?oooa80o`009`3oool00`0007l0oooo0?oo
o`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?oo
o`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?oo
o`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?oo
o`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool003X0oooo0P000007
0?ooob40o`00603oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o
0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o
0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o
0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00D0oooo0`000004
0?ooo`00>P3oool00`000000oooo0?ooo`060?ooobl0o`002P3oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?oo
o`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?oo
o`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?oo
o`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3o
ool01`3oool00`0007l0oooo0?ooo`0=0?ooobT0o`009P3oool00`0007l0oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`03
0000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0
703ooolT0?l001`0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000
O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000
O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00>P3o
ool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo02X0oooo8@3o000A0?ooo`030000O`3o
ool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3o
ool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool0
0`0007l0oooo0?ooo`0e0?oooah0o`002@3oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0
oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0
oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0
oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`070?oooa`0o`0000<0oooo0000O`3oool07@3oool00`0007l0oooo0?ooo`0F0?oo
o`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?oo
o`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?oo
o`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?oo
o`00>P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool04P3ooolI0?l001P0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`03
0000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`03
0000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`03
0000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool003X0oooo0P0000080?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool06P3ooolG0?l00180oooo00<0001o0?ooo`3oool0
5P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool0
3P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00D0oooo0`0000040?ooo`00>P3o
ool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool08P3o
oolF0?l000/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3o
ool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool0
0`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool00`3ooolE
0?l000@0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0
oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0
oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`00
07l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool02@3ooolD0?l0
01P0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo
00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo
03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo
0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0
oooo0?ooo`0T0?ooo`030000O`3oool0oooo0100oooo4P3o000C0?ooo`030000O`3oool0oooo0180
oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0
oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0
oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`000000oooo
0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`0G0?oooa40o`003@3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo
00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703ooolA0?l000P0oooo00<0
001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0
001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0
001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000j
0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T
0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool00P3oool@0?l000@0oooo00<0001o
0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o
0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0001o
0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000j0?oo
o`800000203oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?oo
o`3oool0703oool00`0007l0oooo0?ooo`080?ooo`l0o`00503oool00`0007l0oooo0?ooo`0?0?oo
o`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?oo
o`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`050?oo
o`<00000103oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`03
0000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0=0?ooo`h0
o`00403oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000j0?ooo`030000
003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000
O`3oool0oooo01`0oooo00<0001o0?ooo`3oool04@3oool>0?l000`0oooo00<0001o0?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0
G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`000000oooo0?ooo`070?ooo`030000O`3o
ool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo01H0oooo3@3o00080?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3o
ool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0
oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`040000O`3oool0
oooo0?ooo``0o`001@3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0
001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0
001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000j
0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T
0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`05
0?ooo``0o`0000<0oooo0000O`3oool0403oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0
oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0
oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`00
0000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`00
07l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool02@3oool<0?l0
00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo
05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0
oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0
oooo0?ooo`0F0?ooo`030000O`3oool0oooo00`0oooo303o000<0?ooo`030000O`3oool0oooo00h0
oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0
oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080
oooo000j0?ooo`800000203oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo
00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0100oooo
2`3o00090?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo
0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo
0?ooo`050?ooo`<00000103oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?oo
o`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3o00002@3o00060?ooo`030000O`3o
ool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3o
ool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo0080oooo2P3o00030?ooo`030000O`3oool0
oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0
oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`00
07l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00D0oooo2P3o00000`0007l0oooo0?ooo`0>0?oo
o`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?oo
o`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?oo
o`00>P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`080?ooo`/0o`003@3oool00`0007l0oooo0?ooo`0;0?ooo`03
0000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`03
0000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool001X0oooo100000030?ooo`030000
003oool0oooo00H000000P3oool4000000X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool02`3oool90?l000`0oooo
00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo
00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo
000I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?oo
o`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?oo
o`0>0?ooo`T0o`002@3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<0
00000?ooo`3oool00P3oool001T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L
0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?
0?ooo`030000O`3o0000o`0000L0o`001`3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0
oooo05`0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool001T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool30000
0<T0001o2P3o003G0000O`@00000103oool001T0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`00
07l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`00
07l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00@0oooo203o00020?ooo`030000O`3oool0oooo
00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`006@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000001000000:0?ooo`03
0000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`03
0000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`03
0000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool01P3oool:0?l000`0oooo00<0001o0?ooo`3o
ool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`006@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000
O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000
O`3oool0oooo00P0oooo203o000<0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool0
0P3oool001T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`040000003o
ool0oooo000000d0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000
O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0;0?ooo`T0o`00
203oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0
9@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000I0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000d0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000
O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0=0?ooo`T0o`00
1P3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0
9@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000J0?ooo`@000001`3o
ool4000000<0oooo1@0000090?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3o
ool00`0007l0o`000?l000050?l000H0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`00>P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o
0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o
0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o
0?ooo`3oool02@3o00020?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
03X0oooo0P0000080?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`00
07l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`00
07l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool00P3oool70?l0
0080oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02D0oooo00<0001o0?ooo`3oool01@3oool3000000@0oooo000j0?ooo`030000003oool0oooo00L0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0
oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0
oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`040?ooo`L0o`0000<0001o0?ooo`3o
ool0G03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000
O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000
O`3oool0oooo00h0oooo00<0001o0?ooo`3oool01@3oool90?l005`0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool0
0P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3o
ool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3o
ool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3o
ool0oooo00P0oooo203o001J0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3o
ool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000j0?ooo`030000003oool0
oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0
oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0
oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0:0?ooo`P0o`00F03oool0
0`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`00>P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo
03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo
01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo
00h0oooo00<0001o0?ooo`3oool02`3oool90?l005H0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool003X0
oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0
oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180
oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0
oooo00<0001o0?ooo`3o00001`3o001E0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000j0?ooo`030000
003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000
O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000
O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`040000
O`3oool0oooo0?ooo`H0o`00E@3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0
oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool2000000P0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo
00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo
00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo00<0oooo
1`3o001B0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo
0?ooo`050?ooo`<00000103oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?oo
o`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?oo
o`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0103oool80?l00500oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<0
00000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e
0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F
0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>
0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool01P3oool60?l00500oooo00<0001o
0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?oo
o`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?oo
o`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?oo
o`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool01`3oool80?l004d0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`03
0000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`03
0000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`03
0000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool02@3oool70?l004`0oooo00<0001o0?ooo`3o
ool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000
O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000
O`3oool0oooo00/0oooo00<0001o0?ooo`3oool02`3oool50?l004`0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool0
0P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3o
ool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3o
ool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3o
ool0oooo00/0oooo00<0001o0?ooo`3oool0303oool70?l004T0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0
oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0
oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0
oooo00/0oooo00<0001o0?ooo`3oool03@3oool60?l004T0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
03X0oooo0P0000080?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`00
07l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`00
07l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`00
07l0oooo0?ooo`0?0?ooo`D0o`00B03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02D0oooo00<0001o0?ooo`3oool01@3oool3000000@0oooo000j0?ooo`030000003oool0oooo00L0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0
oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0
oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo0100
oooo1`3o00150?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo
00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo
00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo0180oooo
1P3o00140?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0
001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0
001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo01<0oooo1P3o
00130?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?oo
o`070?ooo`030000003oool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o
0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o
0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o
0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo01@0oooo1@3o0013
0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?oo
o`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?oo
o`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo01D0oooo1`3o00100?oo
o`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?oo
o`030000003oool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3o
ool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3o
ool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3o
ool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo01H0oooo1`3o000o0?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool0
5P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool0
3P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo01P0oooo1P3o000n0?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo000j0?ooo`800000203oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3o
ool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3o
ool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3o
ool0oooo00/0oooo00<0001o0?ooo`3oool06@3oool60?l003d0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00D0oooo0`0000040?ooo`00>P3oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool0
0`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool0
0`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool0
0`0007l0oooo0?ooo`0J0?ooo`D0o`00?@3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0
oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`00
0000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`00
07l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`00
07l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`00
07l0oooo0?ooo`0K0?ooo`D0o`00?03oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`000000
oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0
oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0
oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0
oooo0?ooo`0L0?ooo`D0o`00>`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0
oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`008@3oool4000000<0oooo
00@000000?ooo`3oool0oooo1000000:0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3o
ool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3o
ool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3o
ool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo01h0oooo103o000j0?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0
703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0
7P3oool50?l003T0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000
O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00200oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703o
ool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3o
ool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0803o
ool40?l003P0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool00200oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool0
0`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool0
0`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool08@3oool4
0?l003L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool00200oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool30000
0?l0001o2P0007l40?l009d0001o100000040?ooo`00803oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo1@00000:0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3o
ool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3o
ool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3o
ool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo02<0oooo103o000e0?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo000P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool0
5P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool0
3P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo02@0oooo103o000d0?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo000P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3o
ool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo02D0oooo103o000c0?ooo`030000O`3o
ool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo0080oooo000P0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool0
0`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo02H0oooo1@3o000a0?ooo`030000O`3oool0
oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo000Q0?ooo`@000001`3oool5000000T0oooo00<000000?ooo`3oool01`3oool00`00
07l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`00
07l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`00
07l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool09`3oool50?l0
0300oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0
oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0
oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0
oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool09`3oool60?l002l0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0:03oool50?l002l0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool003X0oooo0P0000080?ooo`030000O`3oool0oooo03D0oooo00<0
001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0
001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0
001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`0Y0?ooo`H0o`00;@3oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01@3oool3000000@0oooo0007
0?ooo`800000<@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o
0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o
0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o
0?ooo`3oool02`3oool00`0007l0oooo0?ooo`0Z0?ooo`D0o`00;@3oool00`0007l0oooo0?ooo`0e
0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`002@3oool3000002h0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?oo
o`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?oo
o`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?oo
o`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0:`3oool40?l002d0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool000`0oooo0`00000[0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3o
ool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3o
ool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3o
ool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo02`0oooo1@3o000[0?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo000?0?ooo`800000:@3oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000
O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000
O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`0]0?ooo`D0o`00
:P3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`00303oool3000002/0oooo00<000000?ooo`3oool01`3o
ool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703o
ool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3o
ool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0;@3o
ool60?l002T0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool000P0oooo1000000^0?ooo`030000003oool0
oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0
oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0
oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0
oooo02h0oooo1@3o000Y0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool0
0`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00070?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo
0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo
00/0oooo00<0001o0?ooo`3oool0;`3oool40?l002T0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool000P0
oooo1000000^0?ooo`800000203oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0
oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180
oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0
oooo00<0001o0?ooo`3oool0<03oool40?l002P0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0
oooo0?ooo`0U0?ooo`030000O`3oool0oooo00D0oooo0`0000040?ooo`00303oool3000002/0oooo
00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo
00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo
00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo
00<0001o0?ooo`3oool0<@3oool50?l002H0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo
0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool000l0oooo0P00
000Y0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?oo
o`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?oo
o`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?oo
o`0;0?ooo`030000O`3oool0oooo0380oooo103o000V0?ooo`030000O`3oool0oooo03D0oooo00<0
001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000<
0?ooo`<00000:`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o
0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o
0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o
0?ooo`3oool02`3oool00`0007l0oooo0?ooo`0b0?ooo`@0o`009P3oool00`0007l0oooo0?ooo`0e
0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`002@3oool3000002h0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?oo
o`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?oo
o`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?oo
o`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0<`3oool40?l002D0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool000L0oooo0P00000a0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3o
ool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3o
ool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3o
ool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo03@0oooo1@3o000S0?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo000;0?ooo`030000003oool0oooo00800000:P3oool00`000000oooo
0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo
0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo
0?ooo`0e0?ooo`@0o`008`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo
00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`002P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0=@3oool40?l002<0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo
00<000000?ooo`3oool00P3oool000X0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0W0?ooo`800000203oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo
00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo
00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo
00<0001o0?ooo`3oool0=P3oool50?l00240oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo
0?ooo`0U0?ooo`030000O`3oool0oooo00D0oooo0`0000040?ooo`002P3oool01P000000oooo0?oo
o`000000oooo000002X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`03
0000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`03
0000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`03
0000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0=`3oool40?l00240oooo00<0001o0?ooo`3o
ool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool000/0oooo1P00000Y0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool0
5P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool0
3P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo03L0oooo103o000Q0?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3o
ool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo03P0oooo1@3o000O0?ooo`030000O`3o
ool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool0
0`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo03T0oooo103o000O0?ooo`030000O`3oool0
oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00070?ooo`030000003oool0oooo00L00000:@3oool00`000000oooo0?ooo`070?oo
o`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?oo
o`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?oo
o`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`0i0?oo
o`@0o`007`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?oo
o`3oool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`000000oooo0?ooo`070?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`03
0000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`0j0?ooo`D0
o`007@3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000
O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000
O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`0k0?ooo`@0o`00
7@3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`002`3oool200000080oooo00<000000?ooo`3oool0:03o
ool2000000P0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3o
ool0oooo03/0oooo103o000M0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3o
ool00`0007l0oooo0?ooo`050?ooo`<00000103oool000X0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3o
ool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo03`0oooo1@3o000K0?ooo`030000O`3o
ool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo0080oooo000:0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903o
ool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3o
ool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3o
ool00`0007l0oooo0?ooo`0m0?ooo`@0o`006`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3o
ool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`002P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool01`3o
ool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703o
ool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3o
ool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0?@3o
ool40?l001/0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool000/0oooo00<000000?ooo`3oool00P00000:
0?ooo`@000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo1000000:0?ooo`030000003o
ool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3o
ool0oooo03h0oooo1@3o000I0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3o
ool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000I0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0
oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0
oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0
oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`0o0?ooo`@0o`006@3oool0
0`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`002P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo
0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo
00/0oooo00<0001o0?ooo`3oool0?`3oool50?l001P0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool000P0
oooo2@0000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`0007l0
oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0
oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0
oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0@03oool40?l001P0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool000X0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool300000?l0001o
:00007l50?l007h0001o100000040?ooo`006@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`3oool0oooo1@00000:0?ooo`030000003oool0oooo00L0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo
00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo
00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo0440oooo
103o000G0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo0080oooo000I0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool0
1`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0
703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0
@@3oool40?l001L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000
O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool001T0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000oooo
0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo
0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo
0?ooo`120?ooo`D0o`005@3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo
00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`006@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000
003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000
O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000
O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000
O`3oool0oooo04<0oooo103o000E0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0
9@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000J0?ooo`@000001P3o
ool600000080oooo1@0000090?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3o
ool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo04<0oooo1@3o000D0?ooo`030000O`3o
ool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool0
0`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo04@0oooo103o000D0?ooo`030000O`3oool0
oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo000;0?ooo`8000000P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo
01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo
00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo
04@0oooo1@3o000C0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`00
07l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000:0?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool09`3oool2000000P0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`00
07l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`00
07l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo04D0oooo103o000C0?ooo`030000O`3oool0oooo
03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`050?ooo`<00000103oool000X0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo
01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo
00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo
04D0oooo103o000C0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`00
07l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000:0?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo
03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo
01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo
00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`160?ooo`@0o`004P3oool00`00
07l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`002`3oool00`000000oooo0?ooo`02000002X0oooo00<000000?ooo`3o
ool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3o
ool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3o
ool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3o
ool0A`3oool30?l00180oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`03
0000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool0
1`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0
703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0
A`3oool40?l00140oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000
O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3o
ool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703o
ool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3o
ool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0B03o
ool40?l00100oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool000L0oooo00<000000?ooo`3oool01`00000Y
0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T
0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B
0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;
0?ooo`030000O`3oool0oooo04P0oooo103o000@0?ooo`030000O`3oool0oooo03D0oooo00<0001o
0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000j0?oo
o`800000203oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?oo
o`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?oo
o`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?oo
o`3oool0B03oool40?l00100oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?oo
o`030000O`3oool0oooo00D0oooo0`0000040?ooo`00>P3oool00`000000oooo0?ooo`070?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`03
0000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`190?ooo`@0
o`003`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`002P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000
O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000
O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0BP3oool30?l000l0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool0
0P3oool000X0oooo00@000000?ooo`3oool0oooo0`00000Y0?ooo`030000003oool0oooo00L0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo
00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo
00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo04X0oooo
103o000>0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo0080oooo000:0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo
00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo
00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo
00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1;0?ooo`<0o`003P3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo
0?ooo`020?ooo`002P3oool3000000<0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?oo
o`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?oo
o`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?oo
o`1;0?ooo`@0o`003@3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0
001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`002P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e
0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F
0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>
0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0C03oool30?l000d0oooo00<0001o
0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?oo
o`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?oo
o`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?oo
o`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0C03oool40?l000`0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool003X0oooo0P0000080?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1=0?ooo`@0o`002`3oool00`0007l0oooo0?ooo`0e0?ooo`03
0000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01@3oool3000000@0oooo000;0?ooo`D00000
:P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0
903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool0
4P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool0
2`3oool00`0007l0oooo0?ooo`1=0?ooo`@0o`002`3oool00`0007l0oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`002P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
1`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0
703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0
C@3oool40?l000/0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000
O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool000X0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool0
5P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool0
3P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo04h0oooo103o000:0?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo000:0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0
903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool0
4P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool0
2`3oool00`0007l0oooo0?ooo`1?0?ooo`<0o`002P3oool00`0007l0oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`002`3o
ool3000000030?ooo`000000oooo02T0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?oo
o`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?oo
o`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0C`3oool30?l000X0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<0
00000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e
0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F
0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>
0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0C`3oool50?l000P0oooo00<0001o
0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?oo
o`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?oo
o`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?oo
o`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0D03oool40?l000P0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool003X0oooo0P0000080?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1@0?ooo`@0o`00203oool00`0007l0oooo0?ooo`0e0?ooo`03
0000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01@3oool3000000@0oooo000j0?ooo`030000
003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000
O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000
O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000
O`3oool0oooo0540oooo0`3o00080?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0
9@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000:0?ooo`P00000:03o
ool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903o
ool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3o
ool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3o
ool00`0007l0oooo0?ooo`1A0?ooo`@0o`001`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3o
ool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`002@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01`3oool0
0`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool0
0`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool0
0`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0DP3oool3
0?l000L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool000P0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`00
07l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`00
07l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo0580oooo103o00060?ooo`030000O`3oool0oooo
03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo
0080oooo000^0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`0007l0
oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0
oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0
oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0D`3oool40?l000D0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool000X0oooo1`00000M0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo
00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo
00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo
00<0001o0?ooo`3oool0D`3oool40?l000D0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo
0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool000/0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0
001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0
001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05<0oooo1@3o
00040?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?oo
o`070?ooo`030000003oool0oooo0080oooo000:0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool02@3oool300000?l0001o?00007l40?l006/0001o100000040?ooo`002P3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`00
07l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`00
07l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`00
07l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0E03oool40?l0
00@0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool000/0oooo1P00000M0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0
oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180
oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0
oooo00<0001o0?ooo`3oool0E@3oool30?l000@0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0
oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool000X0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo
00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo
00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05D0oooo
103o00030?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo0080oooo000:0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`0000002`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0
001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0
001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0
001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1F0?ooo`<0o`000`3oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`002P3oool00`000000oooo0?ooo`0P0?ooo`8000002`3oool00`000000oooo0?ooo`07
0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L
0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?
0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1F
0?ooo`<0o`000`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02D0oooo00<0001o
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`002`3oool6000001d0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?oo
o`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?oo
o`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?oo
o`3oool02`3oool00`0007l0oooo0?ooo`1F0?ooo`@0o`000P3oool00`0007l0oooo0?ooo`0e0?oo
o`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?oo
o`00>P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1G0?ooo`<0o`000P3oool00`0007l0oooo0?ooo`0e0?ooo`03
0000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00
>P3oool2000000P0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000
O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000
O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000
O`3oool0oooo05L0oooo103o00000`3oool0001o0?ooo`0f0?ooo`030000O`3oool0oooo02D0oooo
00<0001o0?ooo`3oool01@3oool3000000@0oooo000:0?ooo`L00000:@3oool00`000000oooo0?oo
o`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?oo
o`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?oo
o`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?oo
o`1H0?ooo`<0o`0000<0oooo0000O`3oool0=P3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool000/0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool0
0`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool0
0`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool0
0`0007l0oooo0?ooo`1H0?ooo`@0o`0000<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0U
0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool000X0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?oo
o`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?oo
o`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?oo
o`3oool02`3oool00`0007l0oooo0?ooo`1I0?ooo`<0o`0000<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool000X0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0
oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0
oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0
oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1I0?ooo`<0o`0000<0001o0?ooo`3o
ool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool000/0oooo1P00000Y0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool0
5P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool0
3P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05T0oooo103o000g0?ooo`030000
O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`002P3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3o
ool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05X0oooo103o000f0?ooo`030000O`3o
ool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`002P3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool0
0`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05X0oooo103o000f0?ooo`030000O`3oool0
oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`002P3oool00`00
0000oooo0?ooo`0]0?ooo`800000203oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo
0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo
00/0oooo00<0001o0?ooo`3oool0FP3oool40?l003H0oooo00<0001o0?ooo`3oool09@3oool00`00
07l0oooo0?ooo`050?ooo`<00000103oool000/0oooo1P00000Y0?ooo`030000003oool0oooo00L0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0
oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0
oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05/0
oooo0`3o000f0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000
oooo0?ooo`020?ooo`00>P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo
00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo
00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo
00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1K0?ooo`@0o`00=@3oool00`0007l0oooo
0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool000P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00L0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0
001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0
001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo0`3o
000e0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o
0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o
0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o
0?ooo`3oool0G03oool30?l003D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo000:0?ooo`P00000:03oool00`000000oooo0?ooo`070?oo
o`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?oo
o`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?oo
o`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?oo
o`@0o`00=03oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`03
0000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`03
0000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`03
0000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool0100007l0o`000?l0003o000d0?oo
o`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?oo
o`00>P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3o0000o`000080o`00<`3oool00`0007l0
oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool003X0oooo
0P0000080?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo
0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo
0?ooo`1L0?ooo`030000O`3oool0o`0000<0o`00<P3oool00`0007l0oooo0?ooo`0U0?ooo`030000
O`3oool0oooo00D0oooo0`0000040?ooo`00>P3oool00`000000oooo0?ooo`070?ooo`030000O`3o
ool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3o
ool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3o
ool0o`0000<0o`00<P3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<0
00000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e
0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F
0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>
0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?l00003
0?l00380oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`00
07l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`00
07l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool00`3o000b0?oo
o`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?oo
o`00>P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo00@0o`00<@3oool00`0007l0
oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool003X0oooo
00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo
00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo
00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo
00<0001o0?ooo`3oool0G03oool0100007l0oooo0?ooo`3oool30?l00340oooo00<0001o0?ooo`3o
ool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000j0?ooo`030000
003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000
O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000
O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000
O`3oool0oooo05`0oooo00@0001o0?ooo`3oool0oooo0`3o000a0?ooo`030000O`3oool0oooo02D0
oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`000000oooo
0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo
0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo
0?ooo`1L0?ooo`040000O`3oool0oooo0?ooo`@0o`00<03oool00`0007l0oooo0?ooo`0U0?ooo`03
0000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool003X0oooo0P0000080?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000
O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000
O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000
O`3oool0oooo0080oooo103o000_0?ooo`030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool0
1@3oool3000000@0oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3o
ool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool00P3o
ool40?l002l0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool0
0`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool00P3oool4
0?l002l0oooo00<0001o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`00
07l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`00
07l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool00`3oool30?l0
02l0oooo00<0001o0?ooo`3oool0903oool30?l000P0oooo00<000000?ooo`3oool00P3oool003X0
oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0
oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180
oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0
oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`030?ooo`@0o`00;P3oool00`0007l0
oooo0?ooo`0S0?ooo`@0o`00203oool00`000000oooo0?ooo`020?ooo`00703oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H000000P3oool4000000X0oooo00<000000?ooo`3oool0
1`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0
703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0
G03oool00`0007l0oooo0?ooo`040?ooo`<0o`00;P3oool00`0007l0oooo0?ooo`0R0?ooo`@0o`00
2@3oool00`000000oooo0?ooo`020?ooo`00703oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3o
ool0oooo05`0oooo00<0001o0?ooo`3oool0103oool30?l002h0oooo00<0001o0?ooo`3oool08@3o
ool50?l000T0oooo00<000000?ooo`3oool00P3oool001`0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool0
0`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool0
0`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool0
0`0007l0oooo0?ooo`040?ooo`@0o`00;@3oool00`0007l0oooo0?ooo`0Q0?ooo`D0o`002@3oool0
0`000000oooo0?ooo`020?ooo`00703oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool300000?l0001oC00007l40?l004l0001o1@3o00070000
O`@00000103oool001`0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?oo
o`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?oo
o`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?oo
o`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`050?oo
o`@0o`00;03oool00`0007l0oooo0?ooo`0O0?ooo`D0o`0000<0oooo0000O`3oool0203oool00`00
0000oooo0?ooo`020?ooo`00703oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000@0
00002P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo00D0oooo103o000/0?ooo`03
0000O`3oool0oooo01l0oooo1@3o00000`3oool0001o0?ooo`080?ooo`030000003oool0oooo0080
oooo000L0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`0000003P3oool00`000000oooo
0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo
0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo
0?ooo`1L0?ooo`030000O`3oool0oooo00H0oooo0`3o000/0?ooo`030000O`3oool0oooo01h0oooo
1@3o00020?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool001X0oooo00<0
00000?ooo`000000303oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00L0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo
00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo
00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo
00<0001o0?ooo`3oool01P3oool40?l002/0oooo00<0001o0?ooo`3oool07@3oool50?l000<0oooo
00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`006`3oool2000000L0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00L0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo
00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo
00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo
00<0001o0?ooo`3oool01`3oool30?l002/0oooo00<0001o0?ooo`3oool07@3oool50?l000<0oooo
00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00703oool00`000000oooo0?oo
o`060?ooo`@000000`3oool5000000T0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?oo
o`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?oo
o`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?oo
o`070?ooo`<0o`00:`3oool00`0007l0oooo0?ooo`0L0?ooo`D0o`00103oool00`0007l0oooo0?oo
o`070?ooo`030000003oool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o
0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o
0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o
0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o
0?ooo`3oool01`3oool40?l002X0oooo00<0001o0?ooo`3oool06`3oool50?l000D0oooo00<0001o
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool2000000P0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?oo
o`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?oo
o`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?oo
o`3oool0203oool30?l002X0oooo00<0001o0?ooo`3oool06`3oool50?l000D0oooo00<0001o0?oo
o`3oool01@3oool3000000@0oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3o
ool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3o
ool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3o
ool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3o
ool0203oool30?l002X0oooo00<0001o0?ooo`3oool06P3oool50?l000H0oooo00<0001o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000
O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000
O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000
O`3oool0oooo00P0oooo103o000Y0?ooo`030000O`3oool0oooo01T0oooo1@3o00070?ooo`030000
O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3o
ool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703o
ool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3o
ool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03o
ool00`0007l0oooo0?ooo`090?ooo`@0o`00:03oool00`0007l0oooo0?ooo`0I0?ooo`D0o`001`3o
ool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000j0?ooo`030000003oool0
oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0
oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0
oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0
oooo05`0oooo00<0001o0?ooo`3oool02@3oool40?l002P0oooo00<0001o0?ooo`3oool0603oool5
0?l000P0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`00
0000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`00
07l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`00
07l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`00
07l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo00T0oooo103o000X0?ooo`030000O`3oool0oooo
01P0oooo103o00090?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool003X0
oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0
oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180
oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0
oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0:0?ooo`<0o`00:03oool00`0007l0
oooo0?ooo`0G0?ooo`D0o`002@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080
oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo
0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo
0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo
0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool02P3oool40?l002L0oooo
00<0001o0?ooo`3oool05P3oool40?l000/0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo
0?ooo`020?ooo`00>P3oool2000000P0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?oo
o`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?oo
o`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?oo
o`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool02`3oool40?l002H0oooo00<0
001o0?ooo`3oool05P3oool40?l000/0oooo00<0001o0?ooo`3oool01@3oool3000000@0oooo000j
0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T
0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B
0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;
0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool02`3oool40?l002H0oooo00<0001o
0?ooo`3oool05@3oool50?l000/0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`00>P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?oo
o`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?oo
o`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?oo
o`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo00/0oooo103o000V0?oo
o`030000O`3oool0oooo01@0oooo1@3o000<0?ooo`030000O`3oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`03
0000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`03
0000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`03
0000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0<0?ooo`@0
o`009@3oool00`0007l0oooo0?ooo`0D0?ooo`D0o`00303oool00`0007l0oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool0
5P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool0
3P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0
303oool40?l002D0oooo00<0001o0?ooo`3oool04`3oool50?l000d0oooo00<0001o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`000000oooo0?ooo`070?ooo`030000O`3o
ool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3o
ool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3o
ool0oooo00`0oooo103o000U0?ooo`030000O`3oool0oooo01<0oooo103o000>0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool0
0`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool0
0`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool0
0`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool0
0`0007l0oooo0?ooo`0=0?ooo`<0o`009@3oool00`0007l0oooo0?ooo`0B0?ooo`D0o`003P3oool0
0`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000j0?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo
01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo
00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo
05`0oooo00<0001o0?ooo`3oool03@3oool40?l002@0oooo00<0001o0?ooo`3oool04P3oool40?l0
00l0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool2000000P0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0
oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0
oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0
oooo00<0001o0?ooo`3oool03P3oool40?l002<0oooo00<0001o0?ooo`3oool04@3oool50?l000l0
oooo00<0001o0?ooo`3oool01@3oool3000000@0oooo000j0?ooo`030000003oool0oooo00L0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo
00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo
00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo
00<0001o0?ooo`3oool03P3oool40?l002<0oooo00<0001o0?ooo`3oool0403oool40?l00140oooo
00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`000000oooo0?oo
o`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?oo
o`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?oo
o`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?oo
o`1L0?ooo`030000O`3oool0oooo00l0oooo0`3o000S0?ooo`030000O`3oool0oooo0100oooo103o
000A0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool003X0oooo00<00000
0?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o
0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o
0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o
0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0?0?ooo`<0o`008`3oool00`0007l0oooo0?ooo`0?
0?ooo`D0o`004@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000j0?oo
o`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?oo
o`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?oo
o`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool03`3oool40?l00280oooo00<0001o0?oo
o`3oool03`3oool30?l001<0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?oo
o`00>P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo0100oooo0`3o000R0?ooo`03
0000O`3oool0oooo00h0oooo103o000C0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000
O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000
O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0@0?ooo`@0o`00
8@3oool00`0007l0oooo0?ooo`0=0?ooo`@0o`00503oool00`0007l0oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3o
ool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool04@3o
ool30?l00240oooo00<0001o0?ooo`3oool03@3oool40?l001@0oooo00<0001o0?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`00>P3oool2000000P0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool0
0`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool04@3oool3
0?l00240oooo00<0001o0?ooo`3oool0303oool50?l001@0oooo00<0001o0?ooo`3oool01@3oool3
000000@0oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`00
07l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`00
07l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool04@3oool40?l0
0200oooo00<0001o0?ooo`3oool02`3oool50?l001D0oooo00<0001o0?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`00>P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0
oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0
oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0
oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo0180
oooo0`3o000P0?ooo`030000O`3oool0oooo00/0oooo1@3o000E0?ooo`030000O`3oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo
0?ooo`0B0?ooo`@0o`007`3oool00`0007l0oooo0?ooo`0:0?ooo`D0o`005P3oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo0080oooo000S0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool0oooo1000000:0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool0
5P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool0
3P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0
4`3oool40?l001h0oooo00<0001o0?ooo`3oool02P3oool40?l001L0oooo00<0001o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`008`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000O`3o
ool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3o
ool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3o
ool0oooo01<0oooo103o000N0?ooo`030000O`3oool0oooo00T0oooo1@3o000G0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool002<0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool0
0`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool04`3oool5
0?l001d0oooo00<0001o0?ooo`3oool0203oool50?l001P0oooo00<0001o0?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`008`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo
0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo
00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0D0?ooo`@0o`007@3oool00`00
07l0oooo0?ooo`080?ooo`@0o`006@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo
0080oooo000S0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`<00000o`0007mK0000O`@0o`009`0007l50?l00200001o100000040?ooo`00
8`3oool00`000000oooo0?ooo`050?ooo`D000002P3oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000
O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000
O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000
O`3oool0oooo01D0oooo0`3o000M0?ooo`030000O`3oool0oooo00H0oooo103o000K0?ooo`030000
O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool002<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3o
ool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool05@3o
ool50?l001/0oooo00<0001o0?ooo`3oool01P3oool40?l001/0oooo00<0001o0?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`008@3oool00`000000oooo000000080?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0
oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0
oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0
oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0F0?ooo`@0o`006`3oool0
0`0007l0oooo0?ooo`050?ooo`D0o`006`3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo000R0?ooo`800000203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo
01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo
00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo
05`0oooo00<0001o0?ooo`3oool05P3oool40?l001/0oooo00<0001o0?ooo`3oool0103oool50?l0
01`0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`008`3oool00`000000
oooo0?ooo`060?ooo`D000002@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0
oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0
oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0
oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo01L0
oooo0`3o000K0?ooo`030000O`3oool0oooo00@0oooo1@3o000L0?ooo`030000O`3oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo
0?ooo`0G0?ooo`@0o`006P3oool00`0007l0oooo0?ooo`030?ooo`D0o`007@3oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0
001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0
001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0
001o0?ooo`3oool0603oool30?l001X0oooo00<0001o0?ooo`3oool00P3oool50?l001h0oooo00<0
001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool2000000P0oooo00<0001o
0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o
0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o
0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o
0?ooo`3oool0603oool50?l001P0oooo00<0001o0?ooo`3oool00P3oool50?l001h0oooo00<0001o
0?ooo`3oool01@3oool3000000@0oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?oo
o`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?oo
o`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?oo
o`3oool06@3oool40?l001P0oooo00@0001o0?ooo`3oool0oooo1@3o000O0?ooo`030000O`3oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`00
07l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`00
07l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`00
07l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`00
07l0oooo0?ooo`0I0?ooo`D0o`005`3oool00`0007l0oooo0?ooo`050?l00200oooo00<0001o0?oo
o`3oool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`000000oooo0?ooo`070?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`03
0000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`03
0000O`3oool0oooo01X0oooo103o000G0?ooo`030000O`3oool0o`0000@0o`008@3oool00`0007l0
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo
00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo
00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo
00<0001o0?ooo`3oool06P3oool40?l001L0oooo00<0001o0?ooo`3o0000103o000Q0?ooo`030000
O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool003X0oooo00<000000?ooo`3oool01`3o
ool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703o
ool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3o
ool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03o
ool00`0007l0oooo0?ooo`0K0?ooo`D0o`005@3oool00`0007l0o`000?l000030?l00280oooo00<0
001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`000000oooo0?ooo`07
0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L
0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?
0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L
0?ooo`030000O`3oool0oooo01`0oooo103o000E0?ooo`@0o`00903oool00`0007l0oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?oo
o`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?oo
o`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?oo
o`3oool0703oool40?l001@0oooo1@3o000T0?ooo`030000O`3oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool003X0oooo0P0000080?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo01d0oooo1@3o000A0?ooo`H0
o`00903oool00`0007l0oooo0?ooo`050?ooo`<00000103oool003X0oooo00<000000?ooo`3oool0
1`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0
703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0
G03oool00`0007l0oooo0?ooo`0N0?ooo`D0o`003`3oool60?l002D0oooo00<0001o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`00>P3oool00`000000oooo0?ooo`070?ooo`030000O`3o
ool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3o
ool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3o
ool0oooo01h0oooo1P3o000=0?ooo`H0o`009P3oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool0
0`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool07`3oool5
0?l000`0oooo1P3o000W0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
03X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02@0oooo00<0001o0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo
0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo
00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0P0?ooo`L0o`001`3oool70?l0
00030000O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?oo
o`00>P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0L0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo0240oooo203o00030?ooo`P0
o`0000<0oooo0000O`3oool09P3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080
oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo
0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo
0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo
0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool08`3oool>0?l000@0oooo
00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo
000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?oo
o`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?oo
o`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?oo
o`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0903oool=0?l000@0oooo00<0
001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000j
0?ooo`800000203oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o
0?ooo`3oool0703oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o
0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o
0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0V0?ooo`L0o`00203oool00`0007l0oooo0?ooo`0U
0?ooo`030000O`3oool0oooo00D0oooo0`0000040?ooo`00>P3oool00`000000oooo0?ooo`070?oo
o`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0L0?oo
o`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?oo
o`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?oo
o`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool09@3oool00`0007l0oooo0?ooo`070?oo
o`030000003oool0oooo0080oooo000j0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3o
ool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01`0oooo00<0001o0?ooo`3o
ool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3o
ool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3o
ool0=@3oool00`0007l0oooo0?ooo`0U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool003X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0703oool00`000000oooo0?ooo`0F0?ooo`030000
O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000
O`3oool0oooo00/0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00>P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000j0?ooool00000/P000004
0?ooo`00\
\>"],
  ImageRangeCache->{{{57.1875, 452.875}, {570.938, 326.75}} -> {-1.14158, \
2.33754, 0.00316366, 0.00630112}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.53547 0.732021 0.0142874 0.0736459 [
[.02381 -0.0125 -10.9688 -16.375 ]
[.02381 -0.0125 10.9688 0 ]
[.31511 -0.0125 -10.9688 -16.375 ]
[.31511 -0.0125 10.9688 0 ]
[.53547 -0.0125 -5.59375 -16.375 ]
[.53547 -0.0125 5.59375 0 ]
[.75583 -0.0125 -5.59375 -16.375 ]
[.75583 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -67.0938 -32.75 ]
[.5 -0.0125 67.0938 -16.375 ]
[-0.0125 .01429 -11.1875 -8.1875 ]
[-0.0125 .01429 0 8.1875 ]
[-0.0125 .16158 -11.1875 -8.1875 ]
[-0.0125 .16158 0 8.1875 ]
[-0.0125 .30887 -11.1875 -8.1875 ]
[-0.0125 .30887 0 8.1875 ]
[-0.0125 .45616 -11.1875 -8.1875 ]
[-0.0125 .45616 0 8.1875 ]
[-0.0125 .60345 -11.1875 -8.1875 ]
[-0.0125 .60345 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -27.5625 -59.3438 ]
[-0.01875 .30902 -11.1875 59.3438 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .61803 L
s
.31511 0 m
.31511 .61803 L
s
.53547 0 m
.53547 .61803 L
s
.75583 0 m
.75583 .61803 L
s
.15271 0 m
.15271 .61803 L
s
.24417 0 m
.24417 .61803 L
s
.37307 0 m
.37307 .61803 L
s
.42208 0 m
.42208 .61803 L
s
.46453 0 m
.46453 .61803 L
s
.50197 0 m
.50197 .61803 L
s
.88473 0 m
.88473 .61803 L
s
.97619 0 m
.97619 .61803 L
s
0 .16158 m
1 .16158 L
s
0 .30887 m
1 .30887 L
s
0 .45616 m
1 .45616 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -71.9688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
80.938 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31511 0 m
.31511 .00625 L
s
gsave
.31511 -0.0125 -71.9688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
80.938 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.53547 0 m
.53547 .00625 L
s
gsave
.53547 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
70.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.75583 0 m
.75583 .00625 L
s
gsave
.75583 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
70.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.15271 0 m
.15271 .00375 L
s
.24417 0 m
.24417 .00375 L
s
.37307 0 m
.37307 .00375 L
s
.42208 0 m
.42208 .00375 L
s
.46453 0 m
.46453 .00375 L
s
.50197 0 m
.50197 .00375 L
s
.88473 0 m
.88473 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -128.094 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Focal) show
98.188 16.625 moveto
(Length) show
141.250 16.625 moveto
(of) show
156.063 16.625 moveto
(L1) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
174.000 16.625 moveto
(H) show
178.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
189.000 16.625 moveto
(L) show
193.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01429 m
.00625 .01429 L
s
gsave
-0.0125 .01429 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .16158 m
.00625 .16158 L
s
gsave
-0.0125 .16158 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .30887 m
.00625 .30887 L
s
gsave
-0.0125 .30887 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
0 .45616 m
.00625 .45616 L
s
gsave
-0.0125 .45616 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
0 .60345 m
.00625 .60345 L
s
gsave
-0.0125 .60345 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05111 m
.00375 .05111 L
s
0 .08793 m
.00375 .08793 L
s
0 .12476 m
.00375 .12476 L
s
0 .1984 m
.00375 .1984 L
s
0 .23523 m
.00375 .23523 L
s
0 .27205 m
.00375 .27205 L
s
0 .34569 m
.00375 .34569 L
s
0 .38252 m
.00375 .38252 L
s
0 .41934 m
.00375 .41934 L
s
0 .49299 m
.00375 .49299 L
s
0 .52981 m
.00375 .52981 L
s
0 .56663 m
.00375 .56663 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -139.719 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
120.344 12.1875 translate
90 rotate
-120.344 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Rayleigh) show
116.813 16.625 moveto
(Range) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
158.500 16.625 moveto
(H) show
162.688 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
173.500 16.625 moveto
(L) show
177.688 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.31511 .61178 m
.31511 .61803 L
s
.53547 .61178 m
.53547 .61803 L
s
.75583 .61178 m
.75583 .61803 L
s
.001 w
.15271 .61428 m
.15271 .61803 L
s
.24417 .61428 m
.24417 .61803 L
s
.37307 .61428 m
.37307 .61803 L
s
.42208 .61428 m
.42208 .61803 L
s
.46453 .61428 m
.46453 .61803 L
s
.50197 .61428 m
.50197 .61803 L
s
.88473 .61428 m
.88473 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01429 m
1 .01429 L
s
.99375 .16158 m
1 .16158 L
s
.99375 .30887 m
1 .30887 L
s
.99375 .45616 m
1 .45616 L
s
.99375 .60345 m
1 .60345 L
s
.125 Mabswid
.99625 .05111 m
1 .05111 L
s
.99625 .08793 m
1 .08793 L
s
.99625 .12476 m
1 .12476 L
s
.99625 .1984 m
1 .1984 L
s
.99625 .23523 m
1 .23523 L
s
.99625 .27205 m
1 .27205 L
s
.99625 .34569 m
1 .34569 L
s
.99625 .38252 m
1 .38252 L
s
.99625 .41934 m
1 .41934 L
s
.99625 .49299 m
1 .49299 L
s
.99625 .52981 m
1 .52981 L
s
.99625 .56663 m
1 .56663 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.007 w
.02381 .01472 m
.02964 .01473 L
.03588 .01475 L
.04164 .01477 L
.04707 .01479 L
.05276 .01481 L
.05814 .01483 L
.06376 .01485 L
.06908 .01487 L
.07411 .01489 L
.07938 .01491 L
.08438 .01493 L
.08911 .01496 L
.09407 .01498 L
.09877 .015 L
.10369 .01503 L
.10836 .01505 L
.11279 .01507 L
.11744 .0151 L
.12185 .01513 L
.12647 .01515 L
.13086 .01518 L
.13503 .01521 L
.1394 .01524 L
.14356 .01526 L
.1475 .01529 L
.15165 .01532 L
.15559 .01535 L
.15973 .01538 L
.16366 .01541 L
.1674 .01544 L
.17133 .01547 L
.17507 .01551 L
.17863 .01554 L
.18237 .01557 L
.18593 .0156 L
.18967 .01564 L
.19323 .01568 L
.19662 .01571 L
.20019 .01575 L
.20359 .01578 L
.20716 .01582 L
.21056 .01586 L
.21381 .0159 L
.21722 .01594 L
.22047 .01598 L
.22356 .01601 L
.22682 .01606 L
.22993 .0161 L
.23321 .01614 L
Mistroke
.23633 .01618 L
.2393 .01622 L
.24243 .01627 L
.24542 .01631 L
.24856 .01636 L
.25156 .01641 L
.25442 .01645 L
.25744 .0165 L
.26031 .01655 L
.26305 .01659 L
.26595 .01664 L
.26871 .01669 L
.27161 .01675 L
.27439 .0168 L
.27704 .01685 L
.27983 .0169 L
.2825 .01695 L
.28504 .017 L
.28773 .01706 L
.29029 .01711 L
.29299 .01717 L
.29557 .01723 L
.29804 .01728 L
.30064 .01734 L
.30312 .0174 L
.30574 .01746 L
.30824 .01752 L
.31063 .01758 L
.31316 .01765 L
.31557 .01771 L
.31787 .01777 L
.3203 .01784 L
.32262 .0179 L
.32507 .01797 L
.32742 .01804 L
.32965 .0181 L
.33202 .01817 L
.33428 .01824 L
.33643 .01831 L
.33871 .01838 L
.34089 .01845 L
.3432 .01852 L
.3454 .0186 L
.3475 .01867 L
.34972 .01874 L
.35185 .01882 L
.35409 .0189 L
.35624 .01898 L
.35829 .01905 L
.36046 .01914 L
Mistroke
.36253 .01922 L
.36451 .01929 L
.36661 .01938 L
.36861 .01946 L
.37073 .01955 L
.37276 .01963 L
.37469 .01972 L
.37674 .0198 L
.3787 .01989 L
.38077 .01999 L
.38275 .02008 L
.38465 .02017 L
.38665 .02026 L
.38857 .02035 L
.3904 .02044 L
.39234 .02054 L
.39419 .02064 L
.39615 .02074 L
.39803 .02084 L
.39983 .02093 L
.40173 .02104 L
.40354 .02114 L
.40528 .02124 L
.40712 .02134 L
.40888 .02144 L
.41075 .02155 L
.41253 .02166 L
.41424 .02177 L
.41604 .02188 L
.41777 .02199 L
.4196 .02211 L
.42135 .02222 L
.42302 .02233 L
.42479 .02245 L
.42649 .02257 L
.42812 .02268 L
.42983 .0228 L
.43148 .02292 L
.43322 .02305 L
.43489 .02317 L
.43648 .02329 L
.43817 .02342 L
.43979 .02355 L
.4415 .02368 L
.44314 .02381 L
.44471 .02394 L
.44637 .02408 L
.44796 .02421 L
.44949 .02434 L
.4511 .02448 L
Mistroke
.45265 .02462 L
.45428 .02476 L
.45585 .0249 L
.45735 .02504 L
.45893 .02519 L
.46046 .02533 L
.46191 .02547 L
.46346 .02562 L
.46493 .02577 L
.4665 .02593 L
.468 .02608 L
.46943 .02623 L
.47095 .02639 L
.47241 .02654 L
.47395 .02671 L
.47543 .02687 L
.47684 .02703 L
.47834 .0272 L
.47978 .02736 L
.48115 .02752 L
.48261 .0277 L
.48401 .02786 L
.48549 .02804 L
.4869 .02822 L
.48826 .02839 L
.4897 .02857 L
.49108 .02875 L
.4924 .02892 L
.4938 .0291 L
.49514 .02928 L
.49656 .02948 L
.49792 .02966 L
.49922 .02985 L
.5006 .03004 L
.50193 .03023 L
.50333 .03044 L
.50468 .03064 L
.50596 .03083 L
.50733 .03104 L
.50864 .03124 L
.50989 .03143 L
.51122 .03164 L
.51249 .03185 L
.51384 .03207 L
.51514 .03228 L
.51638 .03249 L
.51769 .03271 L
.51895 .03293 L
.52028 .03316 L
.52156 .03339 L
Mistroke
.52279 .03361 L
.52409 .03384 L
.52533 .03407 L
.52653 .03429 L
.52779 .03453 L
.52901 .03476 L
.53029 .03501 L
.53152 .03526 L
.53271 .03549 L
.53396 .03574 L
.53516 .03599 L
.53631 .03623 L
.53753 .03648 L
.5387 .03673 L
.53994 .037 L
.54113 .03726 L
.54227 .03751 L
.54348 .03778 L
.54464 .03805 L
.54587 .03833 L
.54704 .0386 L
.54817 .03887 L
.54937 .03916 L
.55052 .03943 L
.55162 .0397 L
.55279 .04 L
.55391 .04028 L
.55509 .04058 L
.55623 .04087 L
.55732 .04116 L
.55848 .04147 L
.55959 .04176 L
.56065 .04205 L
.56178 .04236 L
.56286 .04267 L
.56401 .04299 L
.56511 .0433 L
.56617 .04361 L
.56728 .04394 L
.56836 .04426 L
.5695 .0446 L
.57059 .04493 L
.57163 .04525 L
.57274 .0456 L
.57381 .04594 L
.57483 .04626 L
.57591 .04662 L
.57695 .04696 L
.57805 .04732 L
.57911 .04768 L
Mistroke
.58012 .04802 L
.5812 .04839 L
.58223 .04875 L
.58332 .04914 L
.58437 .04952 L
.58537 .04988 L
.58644 .05027 L
.58746 .05065 L
.58845 .05102 L
.58949 .05142 L
.59049 .0518 L
.59154 .05222 L
.59256 .05262 L
.59354 .05301 L
.59457 .05343 L
.59556 .05383 L
.59651 .05423 L
.59752 .05465 L
.59849 .05506 L
.59952 .0555 L
.6005 .05593 L
.60145 .05635 L
.60245 .0568 L
.60341 .05723 L
.60443 .0577 L
.60541 .05815 L
.60635 .05859 L
.60735 .05906 L
.60831 .05952 L
.60922 .05996 L
.6102 .06044 L
.61113 .0609 L
.61212 .0614 L
.61307 .06188 L
.61398 .06235 L
.61495 .06286 L
.61588 .06334 L
.61686 .06387 L
.61781 .06438 L
.61872 .06487 L
.61968 .0654 L
.6206 .06592 L
.62149 .06642 L
.62243 .06696 L
.62333 .06748 L
.62428 .06804 L
.6252 .06858 L
.62608 .06911 L
.62702 .06968 L
.62792 .07023 L
Mistroke
.62878 .07076 L
.62969 .07134 L
.63057 .07189 L
.6315 .07249 L
.63239 .07307 L
.63324 .07363 L
.63415 .07424 L
.63503 .07482 L
.63595 .07545 L
.63684 .07606 L
.63769 .07666 L
.6386 .07729 L
.63946 .07791 L
.6403 .07851 L
.64118 .07916 L
.64203 .07978 L
.64293 .08045 L
.64379 .0811 L
.64462 .08174 L
.6455 .08241 L
.64635 .08307 L
.64716 .08371 L
.64802 .0844 L
.64884 .08506 L
.64972 .08578 L
.65056 .08647 L
.65137 .08714 L
.65222 .08787 L
.65305 .08857 L
.65392 .08932 L
.65476 .09005 L
.65556 .09076 L
.65641 .09152 L
.65723 .09226 L
.65802 .09297 L
.65885 .09374 L
.65965 .09449 L
.6605 .09529 L
.66132 .09607 L
.6621 .09682 L
.66293 .09763 L
.66373 .09842 L
.66458 .09926 L
.66539 .10007 L
.66617 .10087 L
.667 .10172 L
.66779 .10255 L
.66856 .10335 L
.66937 .10421 L
.67014 .10504 L
Mistroke
.67097 .10594 L
.67176 .10681 L
.67252 .10765 L
.67333 .10856 L
.6741 .10943 L
.67485 .11029 L
.67564 .1112 L
.6764 .11209 L
.6772 .11304 L
.67797 .11396 L
.67871 .11486 L
.6795 .11582 L
.68026 .11675 L
.68106 .11775 L
.68183 .11872 L
.68257 .11966 L
.68335 .12067 L
.68411 .12165 L
.68483 .1226 L
.6856 .12362 L
.68634 .1246 L
.68712 .12566 L
.68787 .12669 L
.68859 .12769 L
.68936 .12876 L
.69009 .1298 L
.69087 .13091 L
.69162 .13199 L
.69234 .13304 L
.6931 .13416 L
.69384 .13525 L
.69454 .13631 L
.69529 .13744 L
.69601 .13854 L
.69677 .13972 L
.6975 .14087 L
.6982 .14197 L
.69895 .14316 L
.69966 .14432 L
.70035 .14543 L
.70108 .14663 L
.70178 .1478 L
.70253 .14904 L
.70324 .15025 L
.70393 .15142 L
.70465 .15268 L
.70535 .1539 L
.7061 .1552 L
.70681 .15647 L
.70749 .1577 L
Mistroke
.70822 .15902 L
.70892 .16029 L
.70959 .16153 L
.7103 .16286 L
.71098 .16414 L
.71171 .16552 L
.7124 .16686 L
.71307 .16815 L
.71378 .16954 L
.71446 .17088 L
.71512 .17219 L
.71581 .17358 L
.71648 .17494 L
.71719 .17639 L
.71787 .1778 L
.71852 .17916 L
.71922 .18062 L
.71989 .18203 L
.72059 .18355 L
.72127 .18502 L
.72193 .18644 L
.72262 .18797 L
.72328 .18945 L
.72392 .19088 L
.7246 .19241 L
.72525 .1939 L
.72594 .19549 L
.72661 .19704 L
.72725 .19853 L
.72793 .20013 L
.72858 .20168 L
.72927 .20334 L
.72993 .20495 L
.73057 .20651 L
.73124 .20818 L
.73189 .20979 L
.73252 .21136 L
.73318 .21303 L
.73382 .21466 L
.73449 .21639 L
.73514 .21807 L
.73577 .2197 L
.73643 .22145 L
.73706 .22314 L
.73767 .22477 L
.73832 .22652 L
.73895 .22821 L
.73961 .23003 L
.74024 .23178 L
.74085 .23348 L
Mistroke
.7415 .2353 L
.74212 .23706 L
.74278 .23894 L
.74342 .24076 L
.74403 .24252 L
.74468 .24441 L
.7453 .24624 L
.74589 .248 L
.74653 .24989 L
.74714 .25172 L
.74778 .25367 L
.74841 .25557 L
.749 .2574 L
.74964 .25935 L
.75025 .26125 L
.75083 .26307 L
.75145 .26503 L
.75205 .26692 L
.75268 .26895 L
.75329 .2709 L
.75387 .2728 L
.75449 .27482 L
.75509 .27677 L
.75572 .27886 L
.75633 .28088 L
.75691 .28284 L
.75753 .28492 L
.75813 .28694 L
.7587 .28889 L
.75931 .29097 L
.7599 .29298 L
.76051 .29513 L
.76111 .29721 L
.76168 .29922 L
.76229 .30136 L
.76287 .30343 L
.76349 .30564 L
.76409 .30778 L
.76466 .30984 L
.76527 .31204 L
.76585 .31417 L
.76641 .31622 L
.76701 .31842 L
.76758 .32053 L
.76819 .32279 L
.76877 .32497 L
.76933 .32708 L
.76993 .32932 L
.7705 .33149 L
.77105 .33358 L
Mistroke
.77163 .33581 L
.77219 .33796 L
.77279 .34026 L
.77336 .34248 L
.77391 .34461 L
.77449 .34689 L
.77505 .34909 L
.77565 .35143 L
.77622 .35369 L
.77677 .35587 L
.77735 .35819 L
.77791 .36043 L
.77845 .36258 L
.77902 .36488 L
.77957 .3671 L
.78016 .36946 L
.78072 .37173 L
.78126 .37392 L
.78183 .37626 L
.78238 .3785 L
.78296 .3809 L
.78352 .3832 L
.78406 .38542 L
.78463 .38778 L
.78518 .39006 L
.78571 .39225 L
.78627 .39458 L
.78681 .39683 L
.78738 .39921 L
.78793 .40151 L
.78846 .40372 L
.78902 .40607 L
.78956 .40833 L
.79008 .4105 L
.79063 .41282 L
.79116 .41504 L
.79172 .4174 L
.79226 .41968 L
.79278 .42186 L
.79333 .42418 L
.79386 .42641 L
.79442 .42878 L
.79496 .43106 L
.79548 .43325 L
.79603 .43557 L
.79656 .4378 L
.79707 .43994 L
.79761 .44222 L
.79813 .4444 L
.79868 .44672 L
Mistroke
.79921 .44894 L
.79972 .45107 L
.80026 .45334 L
.80078 .45551 L
.80128 .45759 L
.80181 .4598 L
.80232 .46192 L
.80286 .46417 L
.80338 .46632 L
.80388 .46838 L
.80441 .47057 L
.80492 .47267 L
.80546 .47489 L
.80598 .47701 L
.80648 .47905 L
.80701 .48121 L
.80752 .48327 L
.80801 .48525 L
.80853 .48734 L
.80903 .48935 L
.80956 .49146 L
.81007 .49349 L
.81057 .49543 L
.81109 .49748 L
.81159 .49944 L
.81212 .50151 L
.81263 .50349 L
.81312 .50538 L
.81364 .50738 L
.81415 .50929 L
.81463 .51112 L
.81514 .51304 L
.81563 .51488 L
.81615 .51682 L
.81666 .51868 L
.81714 .52044 L
.81765 .52231 L
.81814 .52409 L
.81862 .52578 L
.81912 .52757 L
.8196 .52927 L
.82011 .53107 L
.82061 .53278 L
.82108 .53441 L
.82159 .53613 L
.82207 .53776 L
.82258 .53948 L
.82308 .54111 L
.82355 .54267 L
.82405 .54431 L
Mistroke
.82454 .54586 L
.825 .54734 L
.8255 .5489 L
.82597 .55038 L
.82648 .55193 L
.82696 .5534 L
.82743 .5548 L
.82792 .55627 L
.8284 .55766 L
.82886 .55899 L
.82934 .56037 L
.82981 .56169 L
.83031 .56306 L
.83078 .56437 L
.83124 .5656 L
.83173 .5669 L
.83219 .56812 L
.83269 .5694 L
.83317 .57061 L
.83363 .57175 L
.83411 .57295 L
.83458 .57407 L
.83503 .57514 L
.83551 .57625 L
.83597 .5773 L
.83646 .57839 L
.83693 .57942 L
.83738 .58039 L
.83786 .5814 L
.83832 .58235 L
.83881 .58334 L
.83928 .58427 L
.83973 .58514 L
.84021 .58604 L
.84067 .58689 L
.84111 .58768 L
.84158 .58851 L
.84203 .58928 L
.84251 .59008 L
.84298 .59082 L
.84342 .59152 L
.84389 .59223 L
.84434 .5929 L
.84478 .59352 L
.84524 .59417 L
.84569 .59476 L
.84616 .59537 L
.84661 .59594 L
.84705 .59646 L
.84751 .597 L
Mistroke
.84796 .59749 L
.84843 .59799 L
.84889 .59846 L
.84932 .59888 L
.84979 .59931 L
.85023 .5997 L
.85066 .60006 L
.85112 .60042 L
.85156 .60074 L
.85202 .60107 L
.85247 .60136 L
.8529 .60162 L
.85336 .60187 L
.85379 .6021 L
.85426 .60232 L
.85471 .60251 L
.85514 .60267 L
.8556 .60283 L
.85604 .60296 L
.85646 .60306 L
.85691 .60315 L
.85734 .60322 L
.85756 .60325 L
.8578 .60327 L
.85803 .60329 L
.85814 .6033 L
.85824 .60331 L
.85835 .60331 L
.85845 .60331 L
.8585 .60332 L
.85855 .60332 L
.85861 .60332 L
.85864 .60332 L
.85867 .60332 L
.85869 .60332 L
.8587 .60332 L
.85871 .60332 L
.85873 .60332 L
.85874 .60332 L
.85874 .60332 L
.85875 .60332 L
.85876 .60332 L
.85877 .60332 L
.85878 .60332 L
.85879 .60332 L
.8588 .60332 L
.85881 .60332 L
.85884 .60332 L
.85887 .60332 L
.8589 .60332 L
Mistroke
.85895 .60332 L
.85901 .60332 L
.8591 .60331 L
.85921 .60331 L
.85932 .6033 L
.85952 .60329 L
.85976 .60327 L
.85998 .60325 L
.8604 .60319 L
.86085 .60311 L
.86128 .60301 L
.86169 .6029 L
.86213 .60277 L
.86256 .60262 L
.863 .60245 L
.86344 .60227 L
.86385 .60208 L
.86429 .60185 L
.86472 .60162 L
.86517 .60136 L
.8656 .60109 L
.86601 .60082 L
.86646 .60051 L
.86688 .6002 L
.86729 .59988 L
.86772 .59953 L
.86814 .59918 L
.86858 .59879 L
.86901 .5984 L
.86942 .59801 L
.86985 .59758 L
.87027 .59715 L
.87067 .59672 L
.8711 .59626 L
.87151 .5958 L
.87194 .59529 L
.87236 .59479 L
.87276 .5943 L
.87319 .59376 L
.8736 .59323 L
.87404 .59265 L
.87446 .59209 L
.87486 .59153 L
.87529 .59092 L
.8757 .59033 L
.8761 .58974 L
.87652 .58911 L
.87693 .58849 L
.87736 .58782 L
.87777 .58716 L
Mistroke
.87817 .58652 L
.87859 .58582 L
.87899 .58515 L
.87942 .58441 L
.87984 .5837 L
.88024 .583 L
.88066 .58225 L
.88107 .58151 L
.88146 .5808 L
.88187 .58003 L
.88227 .57928 L
.8827 .57847 L
.8831 .57769 L
.8835 .57692 L
.88391 .5761 L
.88431 .57531 L
.8847 .57453 L
.88511 .5737 L
.8855 .57289 L
.88592 .57202 L
.88632 .57118 L
.8867 .57036 L
.88711 .56948 L
.88751 .56863 L
.88793 .56772 L
.88833 .56683 L
.88872 .56597 L
.88913 .56506 L
.88952 .56416 L
.8899 .5633 L
.89031 .56238 L
.89069 .56148 L
.89111 .56053 L
.8915 .5596 L
.89188 .5587 L
.89229 .55774 L
.89268 .55682 L
.89305 .55592 L
.89345 .55496 L
.89383 .55403 L
.89424 .55304 L
.89463 .55208 L
.895 .55115 L
.8954 .55016 L
.89578 .54921 L
.89619 .54819 L
.89658 .5472 L
.89696 .54625 L
.89736 .54523 L
.89774 .54425 L
Mistroke
.89811 .5433 L
.8985 .54229 L
.89888 .54131 L
.89928 .54027 L
.89967 .53926 L
.90004 .53829 L
.90043 .53725 L
.90081 .53626 L
.90121 .53519 L
.9016 .53416 L
.90197 .53317 L
.90236 .53212 L
.90274 .5311 L
.90311 .53012 L
.90349 .52907 L
.90387 .52806 L
.90426 .52699 L
.90464 .52596 L
.90501 .52496 L
.9054 .5239 L
.90577 .52287 L
.90613 .52189 L
.90651 .52084 L
.90688 .51982 L
.90727 .51875 L
.90765 .51771 L
.90801 .51671 L
.90839 .51565 L
.90876 .51462 L
.90915 .51353 L
.90953 .51248 L
.90989 .51147 L
.91027 .5104 L
.91064 .50936 L
.911 .50837 L
.91137 .50731 L
.91174 .50629 L
.91212 .50521 L
.91249 .50416 L
.91285 .50316 L
.91323 .50209 L
.91359 .50106 L
.91394 .50007 L
.91431 .49902 L
.91467 .49801 L
.91505 .49694 L
.91542 .4959 L
.91577 .49491 L
.91614 .49385 L
.9165 .49283 L
Mistroke
.91688 .49175 L
.91725 .49072 L
.9176 .48972 L
.91797 .48865 L
.91833 .48763 L
.91868 .48665 L
.91904 .48561 L
.9194 .48461 L
.91977 .48354 L
.92013 .48252 L
.92048 .48153 L
.92085 .48049 L
.92121 .47948 L
.92158 .47841 L
.92194 .47739 L
.92229 .4764 L
.92266 .47535 L
.92302 .47435 L
.92336 .47338 L
.92372 .47235 L
.92407 .47136 L
.92444 .47032 L
.9248 .46931 L
.92514 .46834 L
.92551 .46731 L
.92586 .46633 L
.9262 .46538 L
.92656 .46437 L
.9269 .4634 L
.92727 .46238 L
.92762 .46139 L
.92796 .46044 L
.92832 .45944 L
.92866 .45847 L
.92903 .45745 L
.92938 .45646 L
.92972 .45551 L
.93008 .45451 L
.93043 .45355 L
.93076 .45262 L
.93112 .45164 L
.93146 .45069 L
.93182 .44969 L
.93217 .44873 L
.9325 .44781 L
.93286 .44683 L
.9332 .44589 L
.93356 .44489 L
.93391 .44393 L
.93425 .44301 L
Mistroke
.9346 .44203 L
.93495 .44109 L
.93528 .44019 L
.93563 .43924 L
.93596 .43832 L
.93632 .43735 L
.93667 .43642 L
.937 .43552 L
.93735 .43457 L
.93769 .43365 L
.93801 .43278 L
.93836 .43185 L
.93869 .43096 L
.93904 .43001 L
.93938 .4291 L
.93971 .42823 L
.94006 .4273 L
.94039 .42642 L
.94074 .42548 L
.94109 .42457 L
.94141 .4237 L
.94176 .42278 L
.9421 .4219 L
.94242 .42105 L
.94276 .42015 L
.94309 .41929 L
.94344 .41838 L
.94377 .4175 L
.9441 .41666 L
.94444 .41576 L
.94477 .41491 L
.94509 .41408 L
.94543 .41321 L
.94575 .41237 L
.94609 .41149 L
.94643 .41063 L
.94674 .40982 L
.94708 .40895 L
.94741 .40812 L
.94775 .40724 L
.94809 .40639 L
.94841 .40558 L
.94875 .40472 L
.94907 .40389 L
.94939 .4031 L
.94972 .40226 L
.95004 .40145 L
.95038 .40059 L
.95071 .39977 L
.95103 .39899 L
Mistroke
.95136 .39815 L
.95169 .39735 L
.95203 .3965 L
.95236 .39569 L
.95267 .39491 L
.95301 .39408 L
.95333 .39328 L
.95364 .39252 L
.95398 .39171 L
.95429 .39094 L
.95463 .39011 L
.95496 .38932 L
.95527 .38857 L
.9556 .38777 L
.95592 .387 L
.95623 .38626 L
.95655 .38547 L
.95687 .38472 L
.9572 .38393 L
.95752 .38316 L
.95783 .38243 L
.95815 .38165 L
.95847 .38091 L
.9588 .38012 L
.95913 .37936 L
.95944 .37863 L
.95976 .37786 L
.96008 .37712 L
.96038 .37642 L
.96071 .37566 L
.96102 .37494 L
.96135 .37418 L
.96167 .37345 L
.96197 .37274 L
.96229 .372 L
.96261 .37128 L
.96294 .37053 L
.96326 .3698 L
.96356 .3691 L
.96389 .36836 L
.9642 .36765 L
.9645 .36697 L
.96482 .36625 L
.96513 .36556 L
.96546 .36483 L
.96577 .36413 L
.96607 .36345 L
.96639 .36274 L
.9667 .36205 L
.967 .36139 L
Mistroke
.96732 .3607 L
.96762 .36003 L
.96794 .35932 L
.96825 .35864 L
.96855 .35799 L
.96887 .3573 L
.96917 .35663 L
.9695 .35593 L
.96981 .35526 L
.97011 .35461 L
.97043 .35393 L
.97073 .35327 L
.97103 .35264 L
.97134 .35197 L
.97164 .35133 L
.97196 .35065 L
.97227 .35 L
.97256 .34937 L
.97288 .34871 L
.97318 .34808 L
.97347 .34747 L
.97378 .34682 L
.97407 .3462 L
.97439 .34555 L
.97469 .34492 L
.97498 .34431 L
.97529 .34367 L
.97559 .34306 L
.97591 .34241 L
.97619 .34183 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{495.875, 306.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007_0001<R000`400?l00000o`00003oo`3oooo`
0?ooo`00o`3oooo`0?ooo`00o`3oool30?ooo`<00000=@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0:H0oooo003o0?ooo`80oooo00D000000?ooo`3oool0oooo0000000c0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0Y@3oool00?l0oooo1P3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0Y03oool00<T0oooo00<0
00000?ooo`3oool01P3oool3000000@0oooo0`0000040?ooo`80000000D0oooo0000003oool0oooo
000000050?ooo`H000000P3oool3000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`80
000000@0oooo0000003oool0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000001`3oool3
000000<0oooo00<000000?ooo`3oool01@3oool6000000<0oooo00<000000?ooo`3oool01P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0:@0oooo00390?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0200000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P000002
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0:@0oooo00390?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0Y03oool00<T0oooo00<00000
0?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3o
ool400000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`D000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo0:@0oooo00390?ooo`030000003oool0oooo00D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo0:@0oooo00390?ooo`D000000`3oool01@000000oooo0?ooo`3oool0
00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`8000000P3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool01000
0000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`8000000P3oool01@000000oooo
0?ooo`3oool000000:H0oooo00390?ooo`030000003oool0oooo00H0oooo0`0000040?ooo`<00000
103oool3000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`<00000
0`3oool010000000oooo0000000000040?ooo`80000000<0oooo0000003oool00`0000020?ooo`04
0000003oool00000000000P0oooo0`0000020?ooo`<000001P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00H000000?ooo`3oool0oooo0000003oool200000080oooo0P00
00040?ooo`030000003oool0oooo0:@0oooo00390?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`050000003oool0oooo0?ooo`0000004@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000002@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0:D0oooo00390?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`050000003oool0
oooo0?ooo`0000004@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo0P00
000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0YP3oool00<T0oooo1P00000G
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0@
0?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0;d0oooo003o0?oo
oo00oooo003o0?oooo00oooo003o0?oooo00oooo003o0?oooo00oooo003o0?oooo00oooo003o0?oo
oo00oooo000d0?ooo`@000000`3oool00`000000oooo0?ooo`06000006d0oooo100000030?ooo`04
0000003oool0oooo0?ooo`@00000E`3oool00`000000oooo0?ooo`1I0?ooo`H00000MP3oool003<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo07P0
oooo000c0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1]0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0M`3oool003<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06`0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool0G03oool00`000000oooo0?ooo`1f0?ooo`00<`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0M@3oool003<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`D00000E`3oool00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo07@0oooo000c0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3o
ool0M03oool003<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo06X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`000000H03oool00`000000oooo0?ooo`1d0?ooo`00<`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1G0?ooo`800000F`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo07@0oooo000d0?ooo`@000001`3oool4000006h0oooo100000070?ooo`D00000EP3oool0
0`000000oooo0?ooo`1J0?ooo`@00000M`3oool00?l0ooool03oool00?l0ooool03oool00?l0oooo
l03oool00?l0ooool03oool00?l0ooool03oool00?l0ooool03oool00?l0ooool03oool00380oooo
o`00002_000000l0oooo000b0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3o
ool00380oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00903oool40000
00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02@0oooo00<0001o0?ooo`3oool06`3oool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo
0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo
00/0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo
02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`008`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`0007l0
oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0
oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0
oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0
oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000
oooo0?ooo`0=0?ooo`008`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01P3ooolD0?l002D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo
0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo
0?ooo`1L0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo00d0oooo000S0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool4000000D0ooooMP3o00080?ooo`030000O`3oool0oooo01H0oooo00<0
001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0
001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03@0oooo00<0
001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`050?ooo`<000003`3oool002<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0ooooUP3o0000
0`3oool0001o0?ooo`0C0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool0
0`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=03oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool0
02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool03`3ooonG0?l00080oooo00<0001o0?ooo`3oool03`3oool00`00
07l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`00
07l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`008`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0
oooo00<0001o0?ooo`3oool04P3ooom40?l000D0oooo00<0001o0?ooo`3oool03P3oool00`0007l0
oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0=03oool00`0007l0
oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool002<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo
00<0001o0?ooo`3oool0503oool]0?l000d0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo
0?ooo`1L0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo00d0oooo000S0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0
001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0
001o0?ooo`3oool03`3ooolS0?l000<0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?oo
o`1L0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?oo
o`070?ooo`030000003oool0oooo00d0oooo000T0?ooo`@000002P3oool00`000000oooo0?ooo`07
0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K
0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`07
0?oooad0o`002P3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03@0oooo00<0001o
0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?oo
o`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?oo
o`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool0603o00040?ooo`030000O`3oool0oooo
05`0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo
00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0
oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0
oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0
oooo0?ooo`080?oooa@0o`0000<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0d0?ooo`03
0000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00
<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0
903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool0
4P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?l0003o0000
4@3o001I0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0
001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0
001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`040?oooa40o`00E@3oool00`0007l0oooo0?oo
o`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?oo
o`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o
0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o
0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o
0?ooo`3oool02P3oool?0?l00540oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T
0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?oo
o`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?oo
o`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?oo
o`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?oo
o`3oool03P3o001>0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`00
07l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0
oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0
oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo00@0
oooo303o001<0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0
oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo
00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo
00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo00P0oooo
303o00180?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0
001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0
001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo00/0oooo303o
00150?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?oo
o`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`<000001`3oool00`0007l0oooo0?ooo`0e
0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F
0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>
0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool03`3oool90?l004@0oooo00<0001o
0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00H0oooo0P00000?
0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?oo
o`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?oo
o`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?oo
o`3oool02`3oool00`0007l0oooo0?ooo`0@0?ooo`X0o`00@P3oool00`0007l0oooo0?ooo`0d0?oo
o`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?oo
o`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`0D0?ooo`X0o`00?P3oool00`0007l0oooo0?ooo`0d0?ooo`03
0000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00
<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0
903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool0
4P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool0
2`3oool00`0007l0oooo0?ooo`0G0?ooo`T0o`00?03oool00`0007l0oooo0?ooo`0d0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3o
ool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903o
ool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3o
ool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3o
ool00`0007l0oooo0?ooo`0I0?ooo`L0o`00?03oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3o
ool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool0
0`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool0
0`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool0
0`0007l0oooo0?ooo`0K0?ooo`L0o`00>P3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0
oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`00
0000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`00
07l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`00
07l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`00
07l0oooo0?ooo`0M0?ooo`P0o`00=`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo
02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000
oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0
oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0
oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0
oooo0?ooo`0O0?ooo`P0o`00=@3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0
oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo
0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo
0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo
0?ooo`0Q0?ooo`H0o`00=@3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo
00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?oo
o`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?oo
o`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?oo
o`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?oo
o`0R0?ooo`P0o`00<P3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0
001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`07
0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K
0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?
0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`0T
0?ooo`H0o`00<P3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o
0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?oo
o`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?oo
o`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?oo
o`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`0V0?oo
o`L0o`00;`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`03
0000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`03
0000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`0W0?ooo`L0
o`00;P3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000
O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000
O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`0Y0?ooo`D0o`00
;P3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0
1`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3o
ool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3o
ool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3o
ool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`0Z0?ooo`D0o`00;@3o
ool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3o
ool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0
oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0
oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0
oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`0[0?ooo`L0o`00:P3oool0
0`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool0
0`000000oooo0?ooo`0=0?ooo`00<P3oool3000000L0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`00
07l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`00
07l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo02d0oooo1P3o000Y0?ooo`030000O`3oool0oooo
03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`060?ooo`8000003`3oool00380
oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0
oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180
oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0
oooo00<0001o0?ooo`3oool0;P3oool60?l002P0oooo00<0001o0?ooo`3oool0=03oool00`0007l0
oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo
00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo
00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo
00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo
00<0001o0?ooo`3oool0;`3oool60?l002L0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo
0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<0
00000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0
001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0
001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0
001o0?ooo`3oool0<03oool60?l002H0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?oo
o`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<00000
0?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o
0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o
0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o
0?ooo`3oool0<@3oool60?l002D0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T
0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?oo
o`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?oo
o`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?oo
o`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?oo
o`3oool0<P3oool60?l002@0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3o
ool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3o
ool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3o
ool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3o
ool0<`3oool60?l002<0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`03
0000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool0
1`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0
6`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0
=03oool60?l00280oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`030000
O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3o
ool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3o
ool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3o
ool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0=@3o
ool60?l00240oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool0
0`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool0
0`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool0
0`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0=P3oool5
0?l00240oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0
oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`00
07l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`00
07l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`00
07l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0=`3oool40?l0
0240oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo
00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0
oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0
oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0
oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0>03oool40?l00200
oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0
oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0>@3oool50?l001h0oooo
00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo
00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?oo
o`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?oo
o`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0>P3oool50?l001d0oooo00<0
001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<0
00000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e
0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F
0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>
0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0>P3oool50?l001d0oooo00<0001o
0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<00000
0?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?oo
o`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?oo
o`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?oo
o`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0>`3oool40?l001d0oooo00<0001o0?oo
o`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?oo
o`3oool03@3oool00380oooo0`0000070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`0l0?ooo`D0o`006`3oool00`0007l0oooo0?ooo`0d0?ooo`03
0000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01P3oool2000000l0oooo000b0?ooo`030000
003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000
O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000
O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000
O`3oool0oooo03d0oooo1@3o000J0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0
903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003o
ool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3o
ool0oooo03d0oooo1@3o000J0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903o
ool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0
oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0
oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0
oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0
oooo03h0oooo103o000J0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool0
0`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo
01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo
00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo
03l0oooo1@3o000H0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`00
07l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0
oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0
oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo0400
oooo103o000H0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0
oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo
00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo
00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo0400oooo
103o000H0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0
001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0
001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo0440oooo103o
000G0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?oo
o`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o
0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o
0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o
0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo0480oooo0`3o000G
0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`07
0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?oo
o`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?oo
o`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo0480oooo1@3o000E0?oo
o`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?oo
o`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3o
ool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3o
ool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3o
ool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo04<0oooo103o000E0?ooo`03
0000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`03
0000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool0
5P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool0
3P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo04<0oooo103o000E0?ooo`030000
O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000
003oool0oooo00d0oooo000S0?ooo`H000002@3oool00`000000oooo0?ooo`070?ooo`030000O`3o
ool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3o
ool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3o
ool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`140?ooo`D0o`004`3o
ool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3o
ool00`000000oooo0?ooo`0=0?ooo`00903oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0
oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0
oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0
oooo04D0oooo103o000C0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool0
0`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000U0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo
0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo
00/0oooo00<0001o0?ooo`3oool0A@3oool50?l00180oooo00<0001o0?ooo`3oool0=03oool00`00
07l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool002H0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0
oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0
oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0
oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`160?ooo`@0o`004P3oool00`0007l0
oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000
oooo0?ooo`0=0?ooo`009`3oool00`000000oooo0?ooo`080?ooo`@00000o`0007l/0000O`D0o`00
M`0007l3000000l0oooo000X0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3o
ool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3o
ool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0A`3o
ool40?l00140oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool03@3oool002P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool0
0`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool0
0`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool0
0`0007l0oooo0?ooo`170?ooo`@0o`004@3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0
oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00:03oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`00
07l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`00
07l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo04P0oooo103o000@0?ooo`030000O`3oool0oooo
03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo
00d0oooo000S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0
oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0
oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0
oooo0?ooo`190?ooo`@0o`003`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0
oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00903oool4000000X0oooo
00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo
00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo
00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo
00<0001o0?ooo`3oool0B@3oool40?l000l0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo
0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<0
00000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0
001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0
001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0
001o0?ooo`3oool0B@3oool40?l000l0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?oo
o`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<00000
0?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o
0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o
0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o
0?ooo`3oool0BP3oool40?l000h0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T
0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00140oooo2P00000G0?oo
o`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?oo
o`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?oo
o`030000O`3oool0oooo04/0oooo0`3o000>0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?oo
o`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000A0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`070?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`03
0000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`03
0000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1;0?ooo`<0
o`003P3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`0=0?ooo`004@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000
O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000
O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0B`3oool50?l000`0oooo00<0001o0?ooo`3oool0
=03oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool0
3@3oool00140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3o
ool0oooo04`0oooo103o000<0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903o
ool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000A0?ooo`030000003oool0
oooo0080oooo0P00000J0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool0
0`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo04`0oooo103o000<0?ooo`030000O`3oool0
oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0
oooo00d0oooo000A0?ooo`030000003oool0oooo0080oooo00@000000?ooo`0000000000603oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool0
0`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool0
0`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool0
0`0007l0oooo0?ooo`1=0?ooo`<0o`00303oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0
oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`004P3oool40000
00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo
03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo
01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo
00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1=0?ooo`@0o`002`3oool00`00
07l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`00<P3oool3000000L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0
oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0
oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0
oooo0?ooo`0;0?ooo`030000O`3oool0oooo04h0oooo0`3o000;0?ooo`030000O`3oool0oooo03@0
oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`060?ooo`8000003`3oool00380oooo
00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo
00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo
00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo
00<0001o0?ooo`3oool0CP3oool40?l000X0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo
0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool001D0oooo00<0
00000?ooo`3oool00P00000H0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3o
ool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo04l0oooo0`3o000:0?ooo`030000O`3o
ool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo00d0oooo000D0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903o
ool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3o
ool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3o
ool00`0007l0oooo0?ooo`1?0?ooo`<0o`002P3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3o
ool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00503oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01`3o
ool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3o
ool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3o
ool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0C`3o
ool40?l000T0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool03@3oool001@0oooo00H000000?ooo`3oool000000?oo
o`00000H0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo
0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo
0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo
0?ooo`0;0?ooo`030000O`3oool0oooo0500oooo0`3o00090?ooo`030000O`3oool0oooo03@0oooo
00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo
000E0?ooo`H000005`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0
001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0
001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0
001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1@0?ooo`@0o`00203oool00`0007l0oooo0?oo
o`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?oo
o`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o
0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o
0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o
0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1A0?ooo`<0o`00203oool00`0007l0oooo0?ooo`0d
0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=
0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?oo
o`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?oo
o`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?oo
o`3oool02`3oool00`0007l0oooo0?ooo`1A0?ooo`<0o`00203oool00`0007l0oooo0?ooo`0d0?oo
o`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?oo
o`00503oool2000000L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`070?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`03
0000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`03
0000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1A0?ooo`@0
o`001`3oool00`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`0=0?ooo`005P3oool3000000@0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0
903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool0
4P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool0
2`3oool00`0007l0oooo0?ooo`1B0?ooo`<0o`001`3oool00`0007l0oooo0?ooo`0d0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`006@3o
ool4000001D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3o
ool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3o
ool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3o
ool0oooo00/0oooo00<0001o0?ooo`3oool0DP3oool40?l000H0oooo00<0001o0?ooo`3oool0=03o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3o
ool001H0oooo0`00000I0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool0
0`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05<0oooo0`3o00060?ooo`030000O`3oool0
oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0
oooo00d0oooo000D0?ooo`800000703oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo
03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo
01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo
00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1C0?ooo`<0o`001P3oool00`00
07l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0
oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0
oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0
oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1C0?ooo`@0o`001@3oool00`0007l0
oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000
oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo
00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo
00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo
00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1D0?ooo`<0o`001@3oool00`0007l0oooo
0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo
0?ooo`0=0?ooo`004@3oool:000001L0oooo0`0000070?ooo`030000O`3oool0oooo03D0oooo00<0
001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0
001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0
001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1D0?ooo`<0o`001@3oool00`0007l0oooo0?oo
o`0d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01P3oool2000000l0oooo000b
0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T
0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B
0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;
0?ooo`030000O`3oool0oooo05@0oooo103o00040?ooo`030000O`3oool0oooo03@0oooo00<0001o
0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?oo
o`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?oo
o`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?oo
o`030000O`3oool0oooo05D0oooo0`3o00040?ooo`030000O`3oool0oooo03@0oooo00<0001o0?oo
o`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000E0?ooo`D0
0000603oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1E0?ooo`<0o`00103oool00`0007l0oooo0?ooo`0d0?ooo`03
0000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00
503oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3o
ool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3o
ool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3o
ool0E@3oool40?l000<0oooo00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`03
0000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool001@0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3o
ool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3o
ool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3o
ool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05H0oooo103o00020?ooo`03
0000O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`03
0000003oool0oooo00d0oooo000D0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1F0?ooo`@0o`000P3oool00`0007l0oooo0?ooo`0d0?ooo`03
0000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00
5@3oool3000000030?ooo`000000oooo01L0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0EP3oool40?l00080oooo
00<0001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo
00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?oo
o`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?oo
o`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0E`3oool30?l00080oooo00<0
001o0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<0
00000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e
0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F
0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>
0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0E`3oool30?l00080oooo00<0001o
0?ooo`3oool0=03oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<00000
0?ooo`3oool03@3oool00140oooo00<000000?ooo`3oool01`00000G0?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo
01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo
00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo
05L0oooo103o00000`3oool0001o0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`03
0000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`03
0000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`03
0000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1H0?ooo`<0
o`0000<0oooo0000O`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0
oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0F03oool30?l000030?oo
o`0007l0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000
003oool0oooo00d0oooo000E0?ooo`D000000P3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3o
ool0oooo05P0oooo103o00000`0007l0oooo0?ooo`0d0?ooo`030000O`3oool0oooo02@0oooo00<0
001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00503oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000001@0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?oo
o`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?oo
o`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0F@3oool30?l000030000O`3o
ool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo00d0oooo000D0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000503o
ool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903o
ool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3o
ool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3o
ool00`0007l0oooo0?ooo`1I0?ooo`<0o`0000<0001o0?ooo`3oool0=03oool00`0007l0oooo0?oo
o`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool001D0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0180oooo0`0000070?ooo`030000O`3o
ool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3o
ool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3o
ool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1I0?ooo`@0o`00=P3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00H0oooo0P00000?0?ooo`00503oool9
000001D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0
oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0
oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0
oooo00/0oooo00<0001o0?ooo`3oool0FP3oool30?l003H0oooo00<0001o0?ooo`3oool0903oool0
0`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo
01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo
00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo
05X0oooo0`3o000f0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0
oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0
oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0
oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1J0?ooo`@0o`00=@3oool00`0007l0
oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00140oooo
2P00000G0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo
0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo
0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo
0?ooo`0;0?ooo`030000O`3oool0oooo05/0oooo0`3o000e0?ooo`030000O`3oool0oooo02@0oooo
00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00503oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?oo
o`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?oo
o`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?oo
o`0;0?ooo`030000O`3oool0oooo05/0oooo0`3o000e0?ooo`030000O`3oool0oooo02@0oooo00<0
001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00503oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T
0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B
0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;
0?ooo`030000O`3oool0oooo05/0oooo103o000d0?ooo`030000O`3oool0oooo02@0oooo00<0001o
0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00503oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?oo
o`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?oo
o`030000O`3oool0oooo05`0oooo0`3o000d0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`005@3oool6000001L0oooo00<000000?ooo`3o
ool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3o
ool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3o
ool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3o
ool0G03oool30?l003@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`03
0000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool0
5P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool0
3P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo0`3o000d0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3o
ool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903o
ool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3o
ool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3o
ool00`0007l0oooo0?ooo`1L0?ooo`@0o`00<`3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool0
0`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool0
0`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool0
0`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool0
100007l0o`000?l0003o000c0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3o
ool00`000000oooo0?ooo`0=0?ooo`009`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0
oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0
oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0
oooo05`0oooo00<0001o0?l0003o00000P3o000b0?ooo`030000O`3oool0oooo02@0oooo00<0001o
0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`009`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?oo
o`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?oo
o`030000O`3oool0oooo05`0oooo00<0001o0?l0003o00000P3o000b0?ooo`030000O`3oool0oooo
02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`004@3oool:000000P0
oooo1P0000090?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0
oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0
oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0
oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?l0003o00000P3o000b0?ooo`03
0000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00
4@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0o`000080o`00<P3oool00`0007l0
oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00140oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000X0
oooo1000003o0000Od@0001o0`3o001Q0000O`<000003`3oool00140oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0
1`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool0
6`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool0
3`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0
G03oool00`0007l0oooo0?l000030?l00340oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo00d0oooo000A0?ooo`030000003oool0oooo0080oooo0P00
000=0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?oo
o`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?oo
o`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?oo
o`030?l00340oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo00d0oooo000A0?ooo`030000003oool0oooo0080oooo00@000000?ooo`0000000000303o
ool2000000X0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3o
ool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3o
ool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3o
ool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`030?l00340oooo00<0
001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000B
0?ooo`@00000103oool00`000000oooo0?ooo`090?ooo`8000002P3oool00`000000oooo0?ooo`07
0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K
0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?
0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L
0?ooo`030000O`3oool0oooo00<0o`00<@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0
oooo00L0oooo00<000000?ooo`3oool03@3oool002L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`00
07l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`00
07l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`00
07l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo00@0o`00<03oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3o
ool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3o
ool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3o
ool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3o
ool0G03oool0100007l0oooo0?ooo`3oool30?l00300oooo00<0001o0?ooo`3oool0903oool00`00
07l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000E0?ooo`030000003oool0oooo0080
0000603oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1L0?ooo`040000O`3oool0oooo0?ooo`<0o`00<03oool00`00
07l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool001@0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo
01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo
00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo
05`0oooo00@0001o0?ooo`3oool0oooo0`3o000`0?ooo`030000O`3oool0oooo02@0oooo00<0001o
0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00503oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e
0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F
0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>
0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool0100007l0oooo0?ooo`3o
ool40?l002l0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo00d0oooo000D0?ooo`060000003oool0oooo0000003oool00000603oool00`000000oooo
0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo
0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo
0?ooo`1L0?ooo`030000O`3oool0oooo0080oooo0`3o000_0?ooo`030000O`3oool0oooo02@0oooo
00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`005@3oool6000001L0oooo00<0
00000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0
001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0
001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0
001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`020?ooo`<0o`00;`3oool00`0007l0oooo0?oo
o`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<00000
0?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o
0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o
0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o
0?ooo`3oool0G03oool00`0007l0oooo0?ooo`020?ooo`@0o`00;P3oool00`0007l0oooo0?ooo`0T
0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?oo
o`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?oo
o`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?oo
o`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?oo
o`3oool0G03oool00`0007l0oooo0?ooo`030?ooo`<0o`00;P3oool00`0007l0oooo0?ooo`0S0?oo
o`<0o`00203oool00`000000oooo0?ooo`0=0?ooo`00503oool7000001L0oooo00<000000?ooo`3o
ool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3o
ool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3o
ool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3o
ool0G03oool00`0007l0oooo0?ooo`030?ooo`<0o`00;P3oool00`0007l0oooo0?ooo`0S0?ooo`<0
o`00203oool00`000000oooo0?ooo`0=0?ooo`00503oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000
O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000
O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000
O`3oool0oooo05`0oooo00<0001o0?ooo`3oool00`3oool30?l002h0oooo00<0001o0?ooo`3oool0
8P3oool40?l000P0oooo00<000000?ooo`3oool03@3oool001@0oooo00<000000?ooo`3oool06`3o
ool3000000L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3o
ool0oooo05`0oooo00<0001o0?ooo`3oool00`3oool40?l002d0oooo00<0001o0?ooo`3oool08P3o
ool30?l000P0oooo0P00000?0?ooo`00503oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0
oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0
oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0
oooo05`0oooo00<0001o0?ooo`3oool0103oool30?l002d0oooo00<0001o0?ooo`3oool08@3oool4
0?l000T0oooo00<000000?ooo`3oool03@3oool001D0oooo1P00000G0?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo
01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo
00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo
05`0oooo00<0001o0?ooo`3oool0103oool30?l002d0oooo00<0001o0?ooo`3oool08@3oool30?l0
00030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3o
ool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3o
ool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3o
ool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3o
ool0G03oool00`0007l0oooo0?ooo`040?ooo`<0o`00;@3oool00`0007l0oooo0?ooo`0P0?ooo`@0
o`0000<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo
0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo
0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo
0?ooo`1L0?ooo`030000O`3oool0oooo00@0oooo103o000/0?ooo`030000O`3oool0oooo0200oooo
0`3o00000`3oool0001o0?ooo`080?ooo`030000003oool0oooo00d0oooo000E0?ooo`D000000P3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3o
ool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool01@3o
ool30?l002`0oooo00<0001o0?ooo`3oool07`3oool40?l000030?ooo`0007l0oooo00P0oooo00<0
00000?ooo`3oool03@3oool001@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
000D0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?oo
o`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?oo
o`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?oo
o`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool01@3oool30?l002`0oooo00<0
001o0?ooo`3oool07`3oool40?l000030?ooo`0007l0oooo00P0oooo00<000000?ooo`3oool03@3o
ool001@0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000D0?ooo`030000003o
ool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3o
ool0oooo05`0oooo00<0001o0?ooo`3oool01@3oool30?l002`0oooo00<0001o0?ooo`3oool07P3o
ool50?l000030?ooo`0007l0oooo00P0oooo00<000000?ooo`3oool03@3oool001D0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01`3o
ool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3o
ool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3o
ool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03o
ool00`0007l0oooo0?ooo`050?ooo`@0o`00:`3oool00`0007l0oooo0?ooo`0N0?ooo`@0o`000P3o
ool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000D0?ooo`T000005@3oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool0
0`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool0
0`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool0
0`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo00H0oooo0`3o000[0?ooo`030000O`3oool0
oooo01h0oooo103o00020?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool0
0380oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo
0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo
00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`060?ooo`<0o`00:`3oool00`00
07l0oooo0?ooo`0M0?ooo`@0o`000`3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo
00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0
oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0
oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0
oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool01P3oool30?l002/0
oooo00<0001o0?ooo`3oool07@3oool30?l000@0oooo00<0001o0?ooo`3oool01`3oool00`000000
oooo0?ooo`0=0?ooo`005@3oool5000001P0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo
0?ooo`060?ooo`<0o`00:`3oool00`0007l0oooo0?ooo`0L0?ooo`@0o`00103oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo00d0oooo000D0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo
00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo
00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo
00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo00H0oooo
103o000Z0?ooo`030000O`3oool0oooo01`0oooo0`3o00050?ooo`030000O`3oool0oooo00L0oooo
00<000000?ooo`3oool03@3oool001@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo
0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo
0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo
0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool01`3oool30?l002X0oooo
00<0001o0?ooo`3oool06`3oool40?l000D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo
0?ooo`0=0?ooo`00503oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01D0oooo
0`0000070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo
0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo
0?ooo`1L0?ooo`030000O`3oool0oooo00L0oooo0`3o000Z0?ooo`030000O`3oool0oooo01/0oooo
103o00050?ooo`030000O`3oool0oooo00H0oooo0P00000?0?ooo`005@3oool3000000030?ooo`00
0000oooo01L0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3o
ool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3o
ool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3o
ool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`070?ooo`<0o`00:P3o
ool00`0007l0oooo0?ooo`0K0?ooo`@0o`001@3oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool0
0`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool01`3oool4
0?l002T0oooo00<0001o0?ooo`3oool06P3oool40?l000H0oooo00<0001o0?ooo`3oool01`3oool0
0`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo
03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo
01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo
00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo
00P0oooo0`3o000Y0?ooo`030000O`3oool0oooo01X0oooo0`3o00070?ooo`030000O`3oool0oooo
00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0
oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0
oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0
oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0
oooo0?ooo`080?ooo`<0o`00:@3oool00`0007l0oooo0?ooo`0I0?ooo`@0o`001`3oool00`0007l0
oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo
00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo
00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo
00<0001o0?ooo`3oool0203oool30?l002T0oooo00<0001o0?ooo`3oool06@3oool40?l000L0oooo
00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?oo
o`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?oo
o`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?oo
o`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?oo
o`1L0?ooo`030000O`3oool0oooo00P0oooo103o000X0?ooo`030000O`3oool0oooo01P0oooo1@3o
00070?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<00000
0?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o
0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o
0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o
0?ooo`3oool0G03oool00`0007l0oooo0?ooo`090?ooo`<0o`00:03oool00`0007l0oooo0?ooo`0H
0?ooo`@0o`00203oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?oo
o`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?oo
o`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?oo
o`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool02@3oool30?l002P0oooo00<0001o0?oo
o`3oool0603oool40?l000P0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?oo
o`00503oool8000001H0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`03
0000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`03
0000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`03
0000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`090?ooo`<0
o`00:03oool00`0007l0oooo0?ooo`0G0?ooo`@0o`002@3oool00`0007l0oooo0?ooo`070?ooo`03
0000003oool0oooo00d0oooo000C0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0
903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool0
4P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool0
2`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo00T0oooo103o000W0?ooo`030000
O`3oool0oooo01L0oooo103o00090?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool0
3@3oool00180oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3o
ool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3o
ool0oooo05`0oooo00<0001o0?ooo`3oool02P3oool30?l002L0oooo00<0001o0?ooo`3oool05P3o
ool50?l000T0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool0
0`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool0
0`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool0
0`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo00X0oooo0`3o000W0?ooo`030000O`3oool0
oooo01H0oooo103o000:0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool0
01@0oooo1`00000G0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`00
07l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`00
07l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool02P3oool40?l0
02H0oooo00<0001o0?ooo`3oool05P3oool40?l000X0oooo00<0001o0?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`005@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00L0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0
oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0
oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0
oooo00<0001o0?ooo`3oool02`3oool30?l002H0oooo00<0001o0?ooo`3oool05@3oool40?l000/0
oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00503oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo
0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo
0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo
0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool02`3oool30?l002H0oooo
00<0001o0?ooo`3oool05@3oool40?l000/0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo
0?ooo`0=0?ooo`00503oool00`000000oooo0?ooo`0K0?ooo`<000001`3oool00`0007l0oooo0?oo
o`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?oo
o`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?oo
o`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?oo
o`0;0?ooo`<0o`009P3oool00`0007l0oooo0?ooo`0E0?ooo`@0o`002`3oool00`0007l0oooo0?oo
o`060?ooo`8000003`3oool001D0oooo1P00000G0?ooo`030000003oool0oooo00L0oooo00<0001o
0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o
0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o
0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o
0?ooo`3oool02`3oool30?l002H0oooo00<0001o0?ooo`3oool0503oool40?l000`0oooo00<0001o
0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00503oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?oo
o`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?oo
o`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool02`3oool40?l002D0oooo00<0001o0?oo
o`3oool0503oool30?l000d0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?oo
o`00503oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3o
ool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3o
ool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3o
ool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3o
ool0303oool30?l002D0oooo00<0001o0?ooo`3oool04`3oool40?l000d0oooo00<0001o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`0=0?ooo`00503oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000
O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000
O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000
O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0303oool30?l002D0oooo00<0001o0?ooo`3oool0
4`3oool40?l000d0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`005@3o
ool6000001L0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3o
ool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3o
ool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3o
ool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0<0?ooo`<0o`009@3o
ool00`0007l0oooo0?ooo`0C0?ooo`@0o`003@3oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool0
0`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0303oool4
0?l002@0oooo00<0001o0?ooo`3oool04P3oool40?l000h0oooo00<0001o0?ooo`3oool01`3oool0
0`000000oooo0?ooo`0=0?ooo`004P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo
02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo
0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo
00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0=0?ooo`<0o`00903oool00`00
07l0oooo0?ooo`0B0?ooo`@0o`003P3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo
00d0oooo000C0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0
oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0
oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0
oooo0?ooo`1L0?ooo`030000O`3oool0oooo00d0oooo0`3o000T0?ooo`030000O`3oool0oooo0180
oooo103o000>0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool001@0oooo
2000000F0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo
0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo
0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo
0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool03@3oool30?l002@0oooo
00<0001o0?ooo`3oool04@3oool40?l000l0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo
0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0
001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0
001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0
001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo00d0oooo103o
000S0?ooo`030000O`3oool0oooo0140oooo103o000?0?ooo`030000O`3oool0oooo00L0oooo00<0
00000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e
0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F
0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>
0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0>
0?ooo`<0o`008`3oool00`0007l0oooo0?ooo`0@0?ooo`D0o`003`3oool00`0007l0oooo0?ooo`07
0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?oo
o`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?oo
o`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?oo
o`3oool03P3oool30?l002<0oooo00<0001o0?ooo`3oool0403oool40?l00100oooo00<0001o0?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00903oool4000000X0oooo00<000000?ooo`3o
ool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3o
ool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3o
ool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3o
ool0G03oool00`0007l0oooo0?ooo`0>0?ooo`<0o`008`3oool00`0007l0oooo0?ooo`0@0?ooo`@0
o`00403oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000S0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000
O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000
O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000
O`3oool0oooo00h0oooo0`3o000S0?ooo`030000O`3oool0oooo00l0oooo103o000A0?ooo`030000
O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool002<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3o
ool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool03P3o
ool40?l00280oooo00<0001o0?ooo`3oool03`3oool40?l00140oooo00<0001o0?ooo`3oool01`3o
ool00`000000oooo0?ooo`0=0?ooo`008`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo1000003o0000Oe@0001o0`3o000d0000O`@0o`006@0007l3000000l0oooo000S0?oo
o`8000000`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0001o0?oo
o`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?oo
o`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?oo
o`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?oo
o`3oool03`3oool30?l00280oooo00<0001o0?ooo`3oool03P3oool40?l00180oooo00<0001o0?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`008`3oool00`000000oooo00000002000000X0
oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0
oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180
oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0
oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0?0?ooo`<0o`008P3oool00`0007l0
oooo0?ooo`0>0?ooo`@0o`004P3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0
oooo000S0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo
0?ooo`0?0?ooo`@0o`008@3oool00`0007l0oooo0?ooo`0>0?ooo`@0o`004P3oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo00d0oooo000S0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0
001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0
001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0
001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0@0?ooo`<0o`008@3oool00`0007l0oooo0?oo
o`0=0?ooo`@0o`004`3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000S
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K
0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?
0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L
0?ooo`030000O`3oool0oooo0100oooo0`3o000Q0?ooo`030000O`3oool0oooo00d0oooo0`3o000D
0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool002@0oooo1000000:0?oo
o`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?oo
o`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?oo
o`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0403oool30?l00240oooo00<0001o0?oo
o`3oool03@3oool30?l001@0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?oo
o`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo0100oooo103o000P0?ooo`03
0000O`3oool0oooo00`0oooo103o000D0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3o
ool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000
O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000
O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0A0?ooo`<0o`00
803oool00`0007l0oooo0?ooo`0<0?ooo`<0o`005@3oool00`0007l0oooo0?ooo`070?ooo`030000
003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3o
ool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool04@3o
ool30?l00200oooo00<0001o0?ooo`3oool02`3oool40?l001D0oooo00<0001o0?ooo`3oool01`3o
ool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0
oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0
oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0
oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0
oooo0140oooo0`3o000P0?ooo`030000O`3oool0oooo00/0oooo103o000E0?ooo`030000O`3oool0
oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`00
07l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`00
07l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`00
07l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`00
07l0oooo0?ooo`0A0?ooo`@0o`007`3oool00`0007l0oooo0?ooo`0;0?ooo`@0o`005@3oool00`00
07l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0
oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0
oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0
oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0
oooo00<0001o0?ooo`3oool04P3oool30?l001l0oooo00<0001o0?ooo`3oool02`3oool30?l001H0
oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo
0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo
0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo
0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo
0?ooo`1L0?ooo`030000O`3oool0oooo0180oooo0`3o000O0?ooo`030000O`3oool0oooo00X0oooo
103o000F0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<0
00000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0
001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0
001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0
001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0B0?ooo`<0o`007`3oool00`0007l0oooo0?oo
o`0:0?ooo`<0o`005`3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b
0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T
0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B
0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;
0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool04P3oool40?l001h0oooo00<0001o
0?ooo`3oool02@3oool40?l001L0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=
0?ooo`00<P3oool3000000L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?oo
o`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?oo
o`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool04`3oool30?l001h0oooo00<0001o0?oo
o`3oool02@3oool40?l001L0oooo00<0001o0?ooo`3oool01P3oool2000000l0oooo000b0?ooo`03
0000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`03
0000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`03
0000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`03
0000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool04`3oool30?l001h0oooo00<0001o0?ooo`3o
ool02@3oool40?l001L0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00
<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0
903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool0
4P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool0
2`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo01<0oooo0`3o000N0?ooo`030000
O`3oool0oooo00P0oooo103o000H0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool0
3@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3o
ool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3o
ool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3o
ool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0C0?ooo`@0o`007@3o
ool00`0007l0oooo0?ooo`080?ooo`<0o`006@3oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool0
0`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0503oool3
0?l001d0oooo00<0001o0?ooo`3oool0203oool30?l001T0oooo00<0001o0?ooo`3oool01`3oool0
0`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo
03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo
01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo
00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo
01@0oooo0`3o000M0?ooo`030000O`3oool0oooo00L0oooo103o000I0?ooo`030000O`3oool0oooo
00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0
oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0
oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0
oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0
oooo0?ooo`0D0?ooo`<0o`007@3oool00`0007l0oooo0?ooo`070?ooo`@0o`006@3oool00`0007l0
oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo
00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo
00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo
00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo
00<0001o0?ooo`3oool0503oool40?l001`0oooo00<0001o0?ooo`3oool01`3oool40?l001T0oooo
00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?oo
o`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?oo
o`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?oo
o`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?oo
o`1L0?ooo`030000O`3oool0oooo01D0oooo0`3o000L0?ooo`030000O`3oool0oooo00H0oooo103o
000J0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<00000
0?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o
0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o
0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o
0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0E0?ooo`<0o`00703oool00`0007l0oooo0?ooo`06
0?ooo`<0o`006`3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?oo
o`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?oo
o`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?oo
o`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool05@3oool30?l001`0oooo00<0001o0?oo
o`3oool01@3oool40?l001/0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?oo
o`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo01D0oooo103o000K0?ooo`03
0000O`3oool0oooo00D0oooo103o000K0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3o
ool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000
O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000
O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0F0?ooo`<0o`00
6`3oool00`0007l0oooo0?ooo`050?ooo`@0o`006`3oool00`0007l0oooo0?ooo`070?ooo`030000
003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3o
ool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3o
ool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3o
ool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool05P3o
ool30?l001/0oooo00<0001o0?ooo`3oool0103oool40?l001`0oooo00<0001o0?ooo`3oool01`3o
ool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0
oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0
oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0
oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0
oooo01H0oooo103o000J0?ooo`030000O`3oool0oooo00@0oooo103o000L0?ooo`030000O`3oool0
oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`00
07l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`00
07l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`00
07l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`00
07l0oooo0?ooo`0G0?ooo`<0o`006P3oool00`0007l0oooo0?ooo`040?ooo`@0o`00703oool00`00
07l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`<000001`3oool00`0007l0
oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0
oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0
oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0
oooo0?ooo`0G0?ooo`<0o`006P3oool00`0007l0oooo0?ooo`030?ooo`@0o`007@3oool00`0007l0
oooo0?ooo`060?ooo`8000003`3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0oooo
0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo
0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo
0?ooo`0G0?ooo`<0o`006P3oool00`0007l0oooo0?ooo`030?ooo`@0o`007@3oool00`0007l0oooo
0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0
001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0
001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0
001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0
001o0?ooo`3oool05`3oool40?l001T0oooo00<0001o0?ooo`3oool00`3oool40?l001d0oooo00<0
001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`07
0?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K
0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?
0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L
0?ooo`030000O`3oool0oooo01P0oooo0`3o000I0?ooo`030000O`3oool0oooo0080oooo103o000N
0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?oo
o`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?oo
o`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?oo
o`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?oo
o`3oool0G03oool00`0007l0oooo0?ooo`0H0?ooo`@0o`00603oool00`0007l0oooo0?ooo`020?oo
o`<0o`007`3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`03
0000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`03
0000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`03
0000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`03
0000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0603oool40?l001P0oooo00@0001o0?ooo`3o
ool0oooo103o000O0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00380
oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0
oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180
oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0
oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0H0?ooo`@0o`00603oool0100007l0
oooo0?ooo`3oool40?l001l0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?oo
o`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo01T0oooo0`3o000H0?ooo`04
0000O`3oool0oooo0?ooo`@0o`007`3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo
00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0
oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0
oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0
oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool06@3oool30?l001P0
oooo00<0001o0?ooo`3oool0103o000P0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3o
ool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000
O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000
O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0I0?ooo`@0o`00
5`3oool00`0007l0oooo0?ooo`030?l00240oooo00<0001o0?ooo`3oool01`3oool00`000000oooo
0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0
001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0
001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0
001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo01X0oooo0`3o
000G0?ooo`030000O`3oool0o`0000<0o`008@3oool00`0007l0oooo0?ooo`070?ooo`030000003o
ool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool0
0`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool0
0`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool0
0`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool06P3oool4
0?l001H0oooo00<0001o0?ooo`3o00000`3o000Q0?ooo`030000O`3oool0oooo00L0oooo00<00000
0?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?oo
o`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?oo
o`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?oo
o`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0K0?oo
o`<0o`005P3oool00`0007l0o`000?l000030?l00240oooo00<0001o0?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0
oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0
oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0
oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo01/0
oooo0`3o000F0?ooo`030000O`3o0000o`000080o`008P3oool00`0007l0oooo0?ooo`070?ooo`03
0000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool0
5P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool0
3P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool0
6`3oool40?l001D0oooo00<0001o0?l0003o00000P3o000R0?ooo`030000O`3oool0oooo00L0oooo
00<000000?ooo`3oool03@3oool00380oooo0`0000070?ooo`030000O`3oool0oooo03D0oooo00<0
001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0
001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0
001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo01`0oooo0`3o
000E0?ooo`@0o`008`3oool00`0007l0oooo0?ooo`060?ooo`8000003`3oool00380oooo00<00000
0?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o
0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o
0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o
0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0L0?ooo`<0o`005@3oool30?l002@0oooo00<0001o
0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?oo
o`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?oo
o`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?oo
o`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?oo
o`030000O`3oool0oooo01`0oooo103o000C0?ooo`@0o`00903oool00`0007l0oooo0?ooo`070?oo
o`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3o
ool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3o
ool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3o
ool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3o
ool07@3oool40?l00180oooo0`3o000U0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3o
ool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000
O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000
O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000
O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0M0?ooo`@0o`00
4@3oool40?l002D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`00<P3o
ool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903o
ool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3o
ool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3o
ool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo01d0oooo1@3o000@0?ooo`@0o`009@3o
ool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0
oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0
oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0
oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0
oooo05`0oooo00<0001o0?ooo`3oool07P3oool40?l000l0oooo1@3o000U0?ooo`030000O`3oool0
oooo00L0oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`3oool01`3oool00`00
07l0oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`00
07l0oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`00
07l0oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`00
07l0oooo0?ooo`0N0?ooo`D0o`003@3oool50?l002H0oooo00<0001o0?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0
oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0
oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0
oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo01l0
oooo103o000=0?ooo`D0o`009P3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0
oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo
0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo
0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo
0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool07`3oool50?l000/0oooo
1@3o00000`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool0
3@3oool00380oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0e0?ooo`030000O`3o
ool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0oooo0?ooo`0F0?ooo`030000O`3o
ool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0oooo0?ooo`0>0?ooo`030000O`3o
ool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0oooo0?ooo`0P0?ooo`@0o`002`3o
ool40?l000030?ooo`0007l0oooo02D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?oo
o`0=0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o
0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o
0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o
0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo0200oooo103o000:
0?ooo`D0o`0000<0oooo0000O`3oool09@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0
oooo00d0oooo000b0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`00
07l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`00
07l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`00
07l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool08@3oool50?l0
00L0oooo103o00030?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`00903oool4000000X0oooo00<000000?ooo`3oool01`3oool00`0007l0
oooo0?ooo`0e0?ooo`030000O`3oool0oooo02@0oooo00<0001o0?ooo`3oool06`3oool00`0007l0
oooo0?ooo`0F0?ooo`030000O`3oool0oooo0180oooo00<0001o0?ooo`3oool03`3oool00`0007l0
oooo0?ooo`0>0?ooo`030000O`3oool0oooo00/0oooo00<0001o0?ooo`3oool0G03oool00`0007l0
oooo0?ooo`0R0?ooo`D0o`001@3oool50?l000<0oooo00<0001o0?ooo`3oool0903oool00`0007l0
oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000S0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo
00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo
00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo
00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo0280oooo
1P3o00030?ooo`H0o`000`3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo00L0oooo
00<000000?ooo`3oool03@3oool002<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?oo
o`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?oo
o`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?oo
o`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool08`3oool=0?l000@0oooo00<0
001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000S
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool4000000H0oooo00<0001o
0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?ooo`030000O`3oool0oooo01/0oooo00<0001o
0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?ooo`030000O`3oool0oooo00l0oooo00<0001o
0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?ooo`030000O`3oool0oooo05`0oooo00<0001o
0?ooo`3oool0903oool;0?l000D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`05
0?ooo`<000003`3oool002<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0=@3oool00`0007l0oooo0?ooo`0T0?oo
o`030000O`3oool0oooo01/0oooo00<0001o0?ooo`3oool05P3oool00`0007l0oooo0?ooo`0B0?oo
o`030000O`3oool0oooo00l0oooo00<0001o0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0;0?oo
o`030000O`3oool0oooo05`0oooo00<0001o0?ooo`3oool09@3oool70?l000P0oooo00<0001o0?oo
o`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000T0?ooo`@0
00002P3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03D0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000O`3oool0oooo01H0oooo00<0001o0?ooo`3o
ool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3o
ool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000O`3oool0oooo03@0oooo00<0001o0?ooo`3o
ool0903oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000S0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo03D0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`0K0?ooo`030000
O`3oool0oooo01H0oooo00<0001o0?ooo`3oool04P3oool00`0007l0oooo0?ooo`0?0?ooo`030000
O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3oool00`0007l0oooo0?ooo`1L0?ooo`030000
O`3oool0oooo03@0oooo00<0001o0?ooo`3oool0903oool00`0007l0oooo0?ooo`070?ooo`030000
003oool0oooo00d0oooo000S0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03D0oooo00<0001o0?ooo`3oool0903o
ool00`0007l0oooo0?ooo`0K0?ooo`030000003oool0oooo01H0oooo00<0001o0?ooo`3oool04P3o
ool00`0007l0oooo0?ooo`0?0?ooo`030000O`3oool0oooo00h0oooo00<0001o0?ooo`3oool02`3o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo03@0oooo00<0001o0?ooo`3oool0903o
ool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo000S0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00d0oooo000T0?ooo`@000002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00d0oooo000b0?ooool00000[`00000?0?ooo`00o`3oooo`0?ooo`00\
\>"],
  ImageRangeCache->{{{57.1875, 452.875}, {319.375, 75.1875}} -> {-1.11987, \
1.57401, 0.00318372, 0.0316453}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input Beam Profile (Average Michelson)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TelescopePlot[{zETM, 5.0}, {CavityWaist, 
          zCavityWaist}, {{ITMFocalLength, zITM}, {fLXY, zLXY}, {fL1, zL1}}, 
        kk];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.226284 0.149981 0.2 0.0748881 [
[.0763 -0.0125 -10.0938 -16.375 ]
[.0763 -0.0125 10.0938 0 ]
[.22628 -0.0125 -5.59375 -16.375 ]
[.22628 -0.0125 5.59375 0 ]
[.37627 -0.0125 -5.59375 -16.375 ]
[.37627 -0.0125 5.59375 0 ]
[.52625 -0.0125 -5.59375 -16.375 ]
[.52625 -0.0125 5.59375 0 ]
[.67623 -0.0125 -5.59375 -16.375 ]
[.67623 -0.0125 5.59375 0 ]
[.82621 -0.0125 -5.59375 -16.375 ]
[.82621 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -16.375 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -43.1563 -32.75 ]
[.5 -0.0125 43.1563 -16.375 ]
[-0.0125 .05022 -20.1875 -8.1875 ]
[-0.0125 .05022 0 8.1875 ]
[-0.0125 .12511 -20.1875 -8.1875 ]
[-0.0125 .12511 0 8.1875 ]
[-0.0125 .2 -11.1875 -8.1875 ]
[-0.0125 .2 0 8.1875 ]
[-0.0125 .27489 -11.1875 -8.1875 ]
[-0.0125 .27489 0 8.1875 ]
[-0.0125 .34978 -11.1875 -8.1875 ]
[-0.0125 .34978 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .2 -36.5625 -44.3438 ]
[-0.01875 .2 -20.1875 44.3438 ]
[ 0 .4 .125 0 ]
[.5 .4125 -39 0 ]
[.5 .4125 39 16.375 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.0763 0 m
.0763 .4 L
s
.22628 0 m
.22628 .4 L
s
.37627 0 m
.37627 .4 L
s
.52625 0 m
.52625 .4 L
s
.67623 0 m
.67623 .4 L
s
.82621 0 m
.82621 .4 L
s
0 .05022 m
1 .05022 L
s
0 .12511 m
1 .12511 L
s
0 .2 m
1 .2 L
s
0 .27489 m
1 .27489 L
s
0 .34978 m
1 .34978 L
s
0 g
.0763 0 m
.0763 .00625 L
s
gsave
.0763 -0.0125 -71.0938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22628 0 m
.22628 .00625 L
s
gsave
.22628 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.37627 0 m
.37627 .00625 L
s
gsave
.37627 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.52625 0 m
.52625 .00625 L
s
gsave
.52625 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.67623 0 m
.67623 .00625 L
s
gsave
.67623 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.82621 0 m
.82621 .00625 L
s
gsave
.82621 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.1063 0 m
.1063 .00375 L
s
.1363 0 m
.1363 .00375 L
s
.16629 0 m
.16629 .00375 L
s
.19629 0 m
.19629 .00375 L
s
.25628 0 m
.25628 .00375 L
s
.28628 0 m
.28628 .00375 L
s
.31627 0 m
.31627 .00375 L
s
.34627 0 m
.34627 .00375 L
s
.40626 0 m
.40626 .00375 L
s
.43626 0 m
.43626 .00375 L
s
.46625 0 m
.46625 .00375 L
s
.49625 0 m
.49625 .00375 L
s
.55624 0 m
.55624 .00375 L
s
.58624 0 m
.58624 .00375 L
s
.61624 0 m
.61624 .00375 L
s
.64623 0 m
.64623 .00375 L
s
.70622 0 m
.70622 .00375 L
s
.73622 0 m
.73622 .00375 L
s
.76622 0 m
.76622 .00375 L
s
.79621 0 m
.79621 .00375 L
s
.85621 0 m
.85621 .00375 L
s
.8862 0 m
.8862 .00375 L
s
.9162 0 m
.9162 .00375 L
s
.94619 0 m
.94619 .00375 L
s
.04631 0 m
.04631 .00375 L
s
.01631 0 m
.01631 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -104.156 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.438 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.875 16.625 moveto
(@) show
130.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
141.000 16.625 moveto
(D) show
145.313 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05022 m
.00625 .05022 L
s
gsave
-0.0125 .05022 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .12511 m
.00625 .12511 L
s
gsave
-0.0125 .12511 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
gsave
-0.0125 .2 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .27489 m
.00625 .27489 L
s
gsave
-0.0125 .27489 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .34978 m
.00625 .34978 L
s
gsave
-0.0125 .34978 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0652 m
.00375 .0652 L
s
0 .08018 m
.00375 .08018 L
s
0 .09516 m
.00375 .09516 L
s
0 .11013 m
.00375 .11013 L
s
0 .14009 m
.00375 .14009 L
s
0 .15507 m
.00375 .15507 L
s
0 .17004 m
.00375 .17004 L
s
0 .18502 m
.00375 .18502 L
s
0 .21498 m
.00375 .21498 L
s
0 .22996 m
.00375 .22996 L
s
0 .24493 m
.00375 .24493 L
s
0 .25991 m
.00375 .25991 L
s
0 .28987 m
.00375 .28987 L
s
0 .30484 m
.00375 .30484 L
s
0 .31982 m
.00375 .31982 L
s
0 .3348 m
.00375 .3348 L
s
0 .03525 m
.00375 .03525 L
s
0 .02027 m
.00375 .02027 L
s
0 .00529 m
.00375 .00529 L
s
0 .36475 m
.00375 .36475 L
s
0 .37973 m
.00375 .37973 L
s
0 .39471 m
.00375 .39471 L
s
.25 Mabswid
0 0 m
0 .4 L
s
gsave
-0.01875 .2 -133.719 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
105.344 12.1875 translate
90 rotate
-105.344 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(spot) show
90.938 16.625 moveto
(size) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.438 16.625 moveto
(@) show
121.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
143.375 16.625 moveto
(D) show
147.688 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.0763 .39375 m
.0763 .4 L
s
.22628 .39375 m
.22628 .4 L
s
.37627 .39375 m
.37627 .4 L
s
.52625 .39375 m
.52625 .4 L
s
.67623 .39375 m
.67623 .4 L
s
.82621 .39375 m
.82621 .4 L
s
.97619 .39375 m
.97619 .4 L
s
.125 Mabswid
.1063 .39625 m
.1063 .4 L
s
.1363 .39625 m
.1363 .4 L
s
.16629 .39625 m
.16629 .4 L
s
.19629 .39625 m
.19629 .4 L
s
.25628 .39625 m
.25628 .4 L
s
.28628 .39625 m
.28628 .4 L
s
.31627 .39625 m
.31627 .4 L
s
.34627 .39625 m
.34627 .4 L
s
.40626 .39625 m
.40626 .4 L
s
.43626 .39625 m
.43626 .4 L
s
.46625 .39625 m
.46625 .4 L
s
.49625 .39625 m
.49625 .4 L
s
.55624 .39625 m
.55624 .4 L
s
.58624 .39625 m
.58624 .4 L
s
.61624 .39625 m
.61624 .4 L
s
.64623 .39625 m
.64623 .4 L
s
.70622 .39625 m
.70622 .4 L
s
.73622 .39625 m
.73622 .4 L
s
.76622 .39625 m
.76622 .4 L
s
.79621 .39625 m
.79621 .4 L
s
.85621 .39625 m
.85621 .4 L
s
.8862 .39625 m
.8862 .4 L
s
.9162 .39625 m
.9162 .4 L
s
.94619 .39625 m
.94619 .4 L
s
.04631 .39625 m
.04631 .4 L
s
.01631 .39625 m
.01631 .4 L
s
.25 Mabswid
0 .4 m
1 .4 L
s
gsave
.5 .4125 -100 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
100.375 16.625 moveto
(Profile) show
137.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .05022 m
1 .05022 L
s
.99375 .12511 m
1 .12511 L
s
.99375 .2 m
1 .2 L
s
.99375 .27489 m
1 .27489 L
s
.99375 .34978 m
1 .34978 L
s
.125 Mabswid
.99625 .0652 m
1 .0652 L
s
.99625 .08018 m
1 .08018 L
s
.99625 .09516 m
1 .09516 L
s
.99625 .11013 m
1 .11013 L
s
.99625 .14009 m
1 .14009 L
s
.99625 .15507 m
1 .15507 L
s
.99625 .17004 m
1 .17004 L
s
.99625 .18502 m
1 .18502 L
s
.99625 .21498 m
1 .21498 L
s
.99625 .22996 m
1 .22996 L
s
.99625 .24493 m
1 .24493 L
s
.99625 .25991 m
1 .25991 L
s
.99625 .28987 m
1 .28987 L
s
.99625 .30484 m
1 .30484 L
s
.99625 .31982 m
1 .31982 L
s
.99625 .3348 m
1 .3348 L
s
.99625 .03525 m
1 .03525 L
s
.99625 .02027 m
1 .02027 L
s
.99625 .00529 m
1 .00529 L
s
.99625 .36475 m
1 .36475 L
s
.99625 .37973 m
1 .37973 L
s
.99625 .39471 m
1 .39471 L
s
.25 Mabswid
1 0 m
1 .4 L
s
.977 .121 .023 r
.0075 w
.17379 .12973 m
.17379 .27027 L
s
.19989 .09553 m
.19989 .30447 L
s
.26378 .07675 m
.26378 .32325 L
s
0 .133 .859 r
.02381 .12973 m
.02381 .27027 L
s
.97619 .00952 m
.97619 .39048 L
s
0 g
.5 Mabswid
.02381 .27027 m
.04262 .25343 L
.06244 .23614 L
.07216 .22809 L
.0775 .22394 L
.08255 .22032 L
.08542 .21847 L
.08693 .21758 L
.08852 .21671 L
.08987 .21604 L
.09135 .21539 L
.092 .21513 L
.0927 .21488 L
.09396 .21448 L
.09466 .2143 L
.09532 .21415 L
.09603 .21401 L
.0968 .2139 L
.09753 .21383 L
.09822 .21379 L
.0995 .2138 L
.10077 .2139 L
.10194 .21408 L
.10322 .21437 L
.10387 .21455 L
.10458 .21477 L
.10588 .21524 L
.10709 .21575 L
.10982 .2171 L
.11223 .2185 L
.11478 .22014 L
.12409 .22702 L
.145 .24464 L
.1546 .25309 L
.1647 .2621 L
.16887 .26584 L
.17116 .2679 L
.17228 .26892 L
.17332 .26985 L
.17455 .27127 L
.17588 .27301 L
.17821 .27605 L
.18275 .282 L
.19197 .29407 L
.19449 .29739 L
.1972 .30094 L
.19852 .30267 L
.19976 .30431 L
.20088 .30476 L
.2021 .30511 L
Mistroke
.21223 .30806 L
.22296 .3112 L
.24432 .31749 L
.25439 .32047 L
.25881 .32178 L
.26132 .32252 L
.26254 .32289 L
.26366 .32322 L
.26483 .32281 L
.26594 .32235 L
.26838 .32133 L
.27336 .31924 L
.28384 .31485 L
.30284 .30693 L
.34122 .29109 L
.38205 .27459 L
.42137 .25934 L
.45917 .24585 L
.47856 .23977 L
.48945 .23675 L
.49428 .23553 L
.49943 .23432 L
.50458 .23321 L
.50926 .23231 L
.51396 .23151 L
.51839 .23085 L
.52091 .23053 L
.52357 .23023 L
.52584 .23 L
.52834 .22979 L
.52974 .22968 L
.53102 .2296 L
.5325 .22952 L
.53318 .22948 L
.53391 .22945 L
.5352 .2294 L
.5364 .22936 L
.53768 .22933 L
.53842 .22932 L
.53911 .22931 L
.54028 .2293 L
.54153 .2293 L
.54272 .22931 L
.54379 .22933 L
.54506 .22936 L
.54577 .22938 L
.54643 .2294 L
.54764 .22945 L
.54892 .22951 L
.55015 .22958 L
Mistroke
.55146 .22966 L
.55384 .22984 L
.5553 .22997 L
.55668 .2301 L
.55926 .23037 L
.56149 .23064 L
.56385 .23095 L
.56811 .23159 L
.57317 .23248 L
.57776 .23338 L
.5878 .23566 L
.59702 .23808 L
.61785 .24437 L
.65736 .25829 L
.69535 .27296 L
.73579 .28925 L
.77472 .30528 L
.8161 .32257 L
.85597 .33936 L
.89432 .3556 L
.93512 .37296 L
.9744 .38971 L
.97619 .39048 L
Mfstroke
.02381 .12973 m
.04262 .14657 L
.06244 .16386 L
.07216 .17191 L
.0775 .17606 L
.08255 .17968 L
.08542 .18153 L
.08693 .18242 L
.08852 .18329 L
.08987 .18396 L
.09135 .18461 L
.092 .18487 L
.0927 .18512 L
.09396 .18552 L
.09466 .1857 L
.09532 .18585 L
.09603 .18599 L
.0968 .1861 L
.09753 .18617 L
.09822 .18621 L
.0995 .1862 L
.10077 .1861 L
.10194 .18592 L
.10322 .18563 L
.10387 .18545 L
.10458 .18523 L
.10588 .18476 L
.10709 .18425 L
.10982 .1829 L
.11223 .1815 L
.11478 .17986 L
.12409 .17298 L
.145 .15536 L
.1546 .14691 L
.1647 .1379 L
.16887 .13416 L
.17116 .1321 L
.17228 .13108 L
.17332 .13015 L
.17455 .12873 L
.17588 .12699 L
.17821 .12395 L
.18275 .118 L
.19197 .10593 L
.19449 .10261 L
.1972 .09906 L
.19852 .09733 L
.19976 .09569 L
.20088 .09524 L
.2021 .09489 L
Mistroke
.21223 .09194 L
.22296 .0888 L
.24432 .08251 L
.25439 .07953 L
.25881 .07822 L
.26132 .07748 L
.26254 .07711 L
.26366 .07678 L
.26483 .07719 L
.26594 .07765 L
.26838 .07867 L
.27336 .08076 L
.28384 .08515 L
.30284 .09307 L
.34122 .10891 L
.38205 .12541 L
.42137 .14066 L
.45917 .15415 L
.47856 .16023 L
.48945 .16325 L
.49428 .16447 L
.49943 .16568 L
.50458 .16679 L
.50926 .16769 L
.51396 .16849 L
.51839 .16915 L
.52091 .16947 L
.52357 .16977 L
.52584 .17 L
.52834 .17021 L
.52974 .17032 L
.53102 .1704 L
.5325 .17048 L
.53318 .17052 L
.53391 .17055 L
.5352 .1706 L
.5364 .17064 L
.53768 .17067 L
.53842 .17068 L
.53911 .17069 L
.54028 .1707 L
.54153 .1707 L
.54272 .17069 L
.54379 .17067 L
.54506 .17064 L
.54577 .17062 L
.54643 .1706 L
.54764 .17055 L
.54892 .17049 L
.55015 .17042 L
Mistroke
.55146 .17034 L
.55384 .17016 L
.5553 .17003 L
.55668 .1699 L
.55926 .16963 L
.56149 .16936 L
.56385 .16905 L
.56811 .16841 L
.57317 .16752 L
.57776 .16662 L
.5878 .16434 L
.59702 .16192 L
.61785 .15563 L
.65736 .14171 L
.69535 .12704 L
.73579 .11075 L
.77472 .09472 L
.8161 .07743 L
.85597 .06064 L
.89432 .0444 L
.93512 .02704 L
.9744 .01029 L
.97619 .00952 L
Mfstroke
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{614, 245.563},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009V0000mB000`400?l00000o`00003oo`3ooooo
0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0oooo<03oool00`000000oooo0?ooo`0/0?ooo`<0
00003@3oool300000?D0oooo003o0?oooc00oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0?<0oooo003o0?oooc00oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?<0oooo003o0?ooob40oooo1@00000:
0?ooo`040000003oool00000000000@0oooo0`0000040?ooo`<000000`3oool00`000000oooo0?oo
o`0200000080oooo00@000000?ooo`3oool0oooo0`0000030?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000?D0oooo003o0?ooob80oooo00<000000?ooo`3oool02`3oool20000
0080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`040000003o
ool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000003e0?ooo`00o`3o
oolR0?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000001P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`000000m@3oool00?l0oooo8`3oool00`000000oooo0?ooo`020?ooo`L0
000000<0oooo0000003oool00P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo
0?ooo`<000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000m@3oool0
0?l0oooo903oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000030?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`000000m@3oool00?l0oooo903oool00`000000oooo0?ooo`09
0?ooo`8000000P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo
00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo0P0000020?ooo`8000000P3oool01@000000oooo0?ooo`3oool000000?D0oooo003o
0?ooob40oooo1@00000:0?ooo`040000003oool00000000000@0oooo0`0000040?ooo`<000000`3o
ool00`000000oooo0000000200000080oooo00@000000?ooo`3oool0oooo0`0000030?ooo`040000
003oool00000000000D0oooo00<000000?ooo`3oool00`3oool010000000oooo0000000000020?oo
o`800000103oool00`000000oooo0?ooo`3c0?ooo`00o`3ooom80?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3c0?ooo`00o`3ooom80?ooo`030000
003oool0oooo01@0oooo0`00000=0?ooo`<00000m@3oool00?l0ooooA@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0?l0oooo6@3oool00?l0ooooo`3ooomX0?ooo`00o`3ooooo0?oo
ofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00o`3ooooo0?ooofP0oooo003o
0?ooool0ooooJ03oool008X0oooo00<000000?ooo`3oool0>`3oool4000004<0oooo00<000000?oo
o`3oool0?`3oool600000400oooo100000140?ooo`030000003oool0oooo03l0oooo100000110?oo
o`00RP3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0n0?ooo`00RP3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool0?@3oool6000004@0oooo00<000000?ooo`3oool0
?P3oool007l0oooo1`0000040?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0n0?ooo`040000003oool0oooo000004D0oooo00<000000?ooo`3oool0
?P3oool008X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo03h0oooo00@000000?ooo`3oool00000@03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo03h0oooo002:0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0?`3o
ool300000480oooo00<000000?ooo`000000@03oool500000440oooo002:0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
00000400oooo00<000000?ooo`3oool0@`3oool008P0oooo00<000000?ooo`000000?03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo03h0oooo00<000000?ooo`000000AP3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo0400oooo0P0000110?ooo`030000003oool0oooo
0480oooo00290?ooo`800000?03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03l0
oooo0P0000110?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0400oooo0P0000110?ooo`030000003oool0oooo0480
oooo002:0?ooo`030000003oool0oooo03/0oooo100000130?ooo`030000003oool0oooo0400oooo
100000110?ooo`@00000A03oool00`000000oooo0?ooo`0o0?ooo`D00000@03oool00?l0ooooo`3o
oomX0?ooo`00o`3ooooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00
o`3ooooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00H`3ooooo0000
0<d00000=`3oool006<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0e0?ooo`00
H`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03D0oooo001S0?ooo`8000008@3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`060?ooo`800000=`3oool006<0oooo00<000000?ooo`3oool0803oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3
000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@03oool30000
0003000Rf`3oool0oooo00H0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<000000?ooo`3o
ool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0?P3oool2000000040?ooo`008]/002;K000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0
oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0?03oool2000000<0oooo0`008]/80?ooo`030000003oool0oooo03D0
oooo001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo03X0oooo0P0000050?ooo`<002;K203oool00`000000oooo
0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0g0?ooo`<000001`3oool3000Rf`P0oooo00<0
00000?ooo`3oool0=@3oool006<0oooo0P00000Q0?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0e0?ooo`8000002P3oool3000Rf`L0oooo0P00000g
0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`0c0?ooo`800000303oool3000Rf`P0oooo00<000000?oo
o`3oool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0<@3oool2000000h0oooo0`008]/80?ooo`03
0000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo02h0oooo0`00000@0?ooo`<002;K
203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0/0?ooo`8000004`3o
ool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<000000?ooo`3oool0803oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0:P3oool2
000001D0oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo
0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
02L0oooo0`00000G0?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool200000240
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo02D0
oooo0P00000J0?ooo`<002;K1`3oool2000003L0oooo001S0?ooo`030000003oool0oooo0200oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0280oooo
0`00000L0?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?oo
o`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`0P0?ooo`8000007`3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool005@0oooo1P000009
0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo01h0oooo0P00000Q0?ooo`<002;K203oool00`000000oooo0?ooo`0e
0?ooo`00E@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0200oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo01/0oooo0`00000S0?oo
o`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00EP3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo01T0oooo0P00000V0?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00
C03oool7000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0P0?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0F0?ooo`<00000
:03oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool005P0oooo00<000000?ooo`3oool0203o
ool300000?l0001oT@0007l2000002/0001o0`008]/60000O`<00000=`3oool005T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0A0?ooo`<00000;@3oool3000Rf`P0oooo00<00000
0?ooo`3oool0=@3oool005T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0>0?oo
o`<00000<03oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool005T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`0<0?ooo`800000<`3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool005@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo00T0oooo0`00000e0?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00E@3o
ool4000000X0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool01`3oool2000003P0oooo0`008]/80?ooo`030000003o
ool0oooo03D0oooo001S0?ooo`8000008@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool01@3oool2000003X0oooo0`008]/70?ooo`800000=`3oool0
06<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool00`3oool2000003`0oooo0`008]/80?ooo`030000003oool0oooo
03D0oooo001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo00<00000?P3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o000000000000@@3oool3000Rf`P0oooo00<000000?ooo`3oool0
=@3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo0P0000130?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool0
0`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool03@3oool3
0?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo03l0oooo0P0000000`3oool0001o0?ooo`120?ooo`<002;K203oool00`000000oooo0?ooo`0e
0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0303oool400000380oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo03`0oooo0`0000030?ooo`030000O`3oool0oooo0440oooo0`008]/80?oo
o`030000003oool0oooo03D0oooo001S0?ooo`8000008@3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo00P0oooo100000001@3oool0nQh50?XN1@3j7PD000000340oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo03X0oooo0P0000060?oo
o`030000O`3oool0oooo0440oooo0`008]/70?ooo`800000=`3oool006<0oooo00<000000?ooo`3o
ool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo00@0oooo100000050?ooo`<0
nQh500@0oooo0000000000000000;P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0>03oool2000000P0oooo00<0001o0?ooo`3oool0@@3oool3000R
f`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0
oooo0?ooo`120?ooo`040000O`3oool0oooo0?ooo`<000002@3oool30?XN1@@0oooo0P00000/0?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0e0?oo
o`<000002P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?oo
o`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo1000000<0?ooo`<0
nQh51P3oool3000002T0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo03<0oooo0P00000=0?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`03
0000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0
?`3oool3000000030000O`3oool0oooo00d0oooo0`3j7PD90?ooo`<000009P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0<03oool3000000l0oooo
00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<0
00000?ooo`3oool0803oool00`0007l0oooo0?ooo`0m0?ooo`8000000`3oool00`0007l0oooo0?oo
o`0=0?ooo`<0nQh5303oool3000002<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo02h0oooo0P00000B0?ooo`030000O`3oool0oooo0440oooo0`00
8]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo0200oooo00<0001o
0?ooo`3oool0=@3oool30?XN1@80oooo0`0000050?ooo`030000O`3oool0oooo00d0oooo0`3j7PD?
0?ooo`<00000803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0;03oool2000001@0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<00000
0?ooo`3oool0=@3oool006<0oooo0P00000Q0?ooo`030000O`3oool0oooo03D0oooo1@0000080?oo
o`030000O`3oool0oooo00d0oooo0`3j7PDB0?ooo`8000007P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0:@3oool3000001H0oooo00<0001o0?oo
o`3oool0@@3oool3000Rf`L0oooo0P00000g0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`03
0000O`3oool0oooo03D0oooo00<000000?XN1@3j7PD02P3oool00`0007l0oooo0?ooo`0=0?ooo`<0
nQh5503oool2000001`0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo02L0oooo0P00000I0?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`03
0000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0
=03oool010000000nQh50?XN1@3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDF0?ooo`80
00006P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0903oool3000001/0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`0c0?ooo`030000
003oool0nQh50080nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5603oool3000001L0oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0280oooo
0P00000N0?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo
001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0<`3oool00`000000oooo0?XN
1@020?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1A/0oooo0P00000E0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0O0?ooo`<00000803o
ool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool0
0`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0380oooo00<000000?ooo`3oool00`3j7PD:
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDM0?ooo`8000004`3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0703oool3000002<0oooo00<0001o
0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<000000?oo
o`3oool0803oool00`0007l0oooo0?ooo`0a0?ooo`040000003oool0oooo0?ooo`<0nQh52P3oool0
0`0007l0oooo0?ooo`0=0?ooo`<0nQh57`3oool200000140oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo01X0oooo0P00000V0?ooo`030000O`3oool0
oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`8000008@3oool00`00
07l0oooo0?ooo`0a0?ooo`040000003oool0oooo0?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=
0?ooo`<0nQh58@3oool3000000h0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo01L0oooo0`00000X0?ooo`030000O`3oool0oooo0440oooo0`008]/7
0?ooo`800000=`3oool003`0oooo0P0000020?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0803oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0080oooo0`3j7PD:0?oo
o`030000O`3oool0oooo00d0oooo0`3j7PDT0?ooo`800000303oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool05@3oool2000002/0oooo00<0001o0?oo
o`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool003/0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0200oooo00<0001o0?oo
o`3oool0;`3oool00`000000oooo0?ooo`030?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?oo
o`<0nQh59P3oool3000000T0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo01<0oooo0P00000]0?ooo`030000O`3oool0oooo0440oooo0`008]/80?oo
o`030000003oool0oooo03D0oooo000k0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo02l0oooo00<000000?oo
o`3oool00`3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1BT0oooo0P0000070?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0@0?oo
o`<00000;`3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?oo
o`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo02h0oooo00<000000?oo
o`3oool0103oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1B/0oooo0`0000040?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0>0?oo
o`800000<P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?oo
o`00?03oool00`000000oooo0?ooo`02000001H0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0P0?ooo`030000O`3oool0oooo02d0oooo00<000000?ooo`3oool01@3oool30?XN1@X0
oooo00<0001o0?ooo`3oool03@3oool30?XN1Bh0oooo0`0000000`3oool0001o0?ooo`130?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool02`3oool3000003@0oooo00<0001o0?ooo`3o
ool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool005L0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo02`0oooo00<000000?ooo`3oool0
1P3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo0P0000140?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool02@3oool2000003L0oooo00<0001o0?ooo`3oool0
@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool004`0oooo1`0000040?ooo`030000003o
ool0oooo00T0oooo0`00001>0000O`030000000007l0001o00L0001o0`3j7PDJ0000O`<0nQh5<`00
07l300000900001o0P00001m0000O`<002;K1P0007l3000003L0oooo000k0?ooo`X000004P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`030000O`3oool0
oooo02T0oooo00<0nQh50000003j7PD02@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool3
0?XN1C80oooo00@0001o0?ooo`3oool0oooo0P00000o0?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0103oool3000003/0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<0
00000?ooo`3oool0=@3oool003`0oooo00D000000?ooo`3oool0oooo0000000F0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`008]/00000000Rf`0F0?ooo`030000O`3o
ool0oooo02T0oooo0P0000000`3j7PD0oooo0?ooo`070?ooo`<0nQh52P3oool00`0007l0oooo0?oo
o`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`030?ooo`<00000?03oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0080oooo0P00000n0?ooo`030000O`3oool0oooo0440oooo0`00
8]/80?ooo`030000003oool0oooo03D0oooo000k0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo0P008]/0
0`000000oooo0?ooo`0D0?ooo`030000O`3oool0oooo02P0oooo0P0000020?XN1@T0oooo0`3j7PD:
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo00H0oooo0P00000j
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`0000000P0000100?ooo`030000O`3oool0
oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo000k0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo
00L0oooo0`008]/00`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo02L0oooo00<000000?oo
o`3j7PD00P3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`00
07l0oooo0?ooo`080?ooo`<00000=`3oool00`0007l0oooo0?ooo`120?ooo`800000@`3oool00`00
07l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00?03oool5000001D0
oooo0P00000;0?ooo`030000003oool0oooo00L0oooo0`008]/00`3oool000000?ooo`0C0?ooo`03
0000O`3oool0oooo02H0oooo00<000000?ooo`3oool00`3j7PD90?ooo`<0nQh52P3oool00`0007l0
oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`0;0?ooo`<00000=03oool00`0007l0
oooo0?ooo`100?ooo`80000000<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<0
02;K203oool00`000000oooo0?ooo`0e0?ooo`00E`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00L0oooo0`008]/20?ooo`030000003oool0oooo0140oooo00<0001o0?ooo`3oool0
9@3oool010000000oooo0?ooo`3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0
oooo0`3j7PDb0?ooo`030000O`3oool0oooo00h0oooo0P00000b0?ooo`030000O`3oool0oooo03d0
oooo0`0000020?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0
oooo00<000000?ooo`3oool0=@3oool006<0oooo0P0000080?ooo`<002;K0`3oool00`000000oooo
0?ooo`0@0?ooo`030000O`3oool0oooo02@0oooo00<000000?ooo`3oool00P3oool30?XN1@T0oooo
0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0100oooo
0`00000_0?ooo`030000O`3oool0oooo03/0oooo0P0000050?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@@3oool3000Rf`L0oooo0P00000g0?ooo`00?03oool500000280oooo00<0
00000?ooo`3oool01`3oool3000Rf`@0oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?oo
o`0S0?ooo`030000003oool0oooo00<0oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?oo
o`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`0C0?ooo`<00000;03oool00`0007l0oooo0?oo
o`0h0?ooo`<000001`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`00
8]/80?ooo`030000003oool0oooo03D0oooo000k0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`<002;K1@3oool00`000000oooo0?ooo`0>
0?ooo`030000O`3oool0oooo0280oooo00<000000?ooo`3oool0103oool30?XN1@T0oooo0`3j7PD:
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo01H0oooo0`00000Y
0?ooo`030000O`3oool0oooo03D0oooo0`00000:0?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool003/0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo0`008]/60?oo
o`030000003oool0oooo00d0oooo00<0001o0?ooo`3oool08@3oool00`000000oooo0?ooo`050?oo
o`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?oo
o`3oool06@3oool3000002H0oooo00<0001o0?ooo`3oool0<P3oool3000000d0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?oo
o`00>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool01`3oool3000Rf`L0oooo00<000000?ooo`3oool0303oool00`0007l0oooo0?ooo`0P0?ooo`03
0000003oool0oooo00H0oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0
nQh5<P3oool00`0007l0oooo0?ooo`0L0?ooo`<000008`3oool00`0007l0oooo0?ooo`0_0?ooo`<0
0000403oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`03
0000003oool0oooo03D0oooo000l0?ooo`D000008P3oool00`000000oooo0?ooo`070?ooo`<002;K
203oool00`000000oooo0?ooo`0;0?ooo`030000O`3oool0oooo01h0oooo0P0000090?ooo`<0nQh5
2@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0
7`3oool300000200oooo00<0001o0?ooo`3oool0;03oool3000001<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3o
ool00`000000oooo0?ooo`070?ooo`<002;K2@3oool00`000000oooo0?ooo`0:0?ooo`030000O`3o
ool0oooo01d0oooo00<000000?ooo`3oool02@3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3o
ool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0280oooo0`00000M0?ooo`030000O`3o
ool0oooo02T0oooo0`00000F0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool003/0oooo00<000000?ooo`3oool09@3oool2
000000P0oooo0`008]/:0?ooo`8000002P3oool00`0007l0oooo0?ooo`0L0?ooo`030000003oool0
oooo00X0oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool0
0`0007l0oooo0?ooo`0U0?ooo`<000006P3oool00`0007l0oooo0?ooo`0V0?ooo`<000006@3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/70?ooo`800000=`3oool0
03T0oooo2@00000Q0?ooo`030000003oool0oooo00L0oooo0`008]/<0?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool06`3oool00`000000oooo0?ooo`0;0?ooo`<0nQh52@3oool30?XN
1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0:03oool30000
01L0oooo00<0001o0?ooo`3oool08`3oool3000001`0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00>`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool3000Rf`d0
oooo00<000000?ooo`3oool01P3oool00`0007l0oooo0?ooo`0J0?ooo`030000003oool0oooo00`0
oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0
oooo0?ooo`0[0?ooo`<00000503oool00`0007l0oooo0?ooo`0O0?ooo`@000007`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0
oooo001S0?ooo`030000003oool0oooo00L0oooo0`008]/>0?ooo`030000003oool0oooo00D0oooo
00<0001o0?ooo`3oool06@3oool00`000000oooo0?ooo`0=0?ooo`<0nQh52@3oool30?XN1@X0oooo
00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0;P3oool200000180oooo
00<0001o0?ooo`3oool0703oool3000002<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?oo
o`070?ooo`<002;K3`3oool00`000000oooo0?ooo`040?ooo`030000O`3oool0oooo01L0oooo0P00
000@0?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0
001o0?ooo`3oool0<03oool4000000h0oooo00<0001o0?ooo`3oool05`3oool5000002H0oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?oo
o`0e0?ooo`00H`3oool00`000000oooo0?ooo`070?ooo`<002;K403oool2000000@0oooo00<0001o
0?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o
0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0=03oool5000000T0oooo00<0001o
0?ooo`3oool04P3oool5000002/0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`070?oo
o`<002;K4P3oool200000080oooo00<0001o0?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?oo
o`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?oo
o`3oool0>@3oool700000080oooo00<0001o0?ooo`3oool0303oool600000300oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?oo
o`00H`3oool2000000P0oooo0`008]/D0?ooo`030000003oool0001o01H0oooo00<000000?ooo`3o
ool04P3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`03
0000O`3oool0oooo0400oooo4@00000f0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool3000Rf`L0oooo0P00000g0?ooo`00?03oool200000080oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`070?ooo`<002;K5@3oool00`000000001o0?ooo`0D0?ooo`030000
003oool0oooo01<0oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5
<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00>`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
1`3oool3000RfaH0oooo00<000000?ooo`3oool04@3oool2000001H0oooo0`3j7PD90?ooo`<0nQh5
2P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K
203oool00`000000oooo0?ooo`0e0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool3000RfaH0oooo00<0001o000000000000
3`3oool2000001P0oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5
<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00>`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
1`3oool3000RfaH0oooo00@0001o0?ooo`3oool000003@3oool00`000000oooo0?ooo`0H0?ooo`<0
nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool003`0oooo00<000000?ooo`3oool0
0P00000R0?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`040000O`3oool0oooo0?ooo`80
00002P3oool00`000000oooo0?ooo`0I0?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3o
ool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool006<0oooo00<000000?ooo`3oool01`3oool3000RfaH0oooo00<0001o0?ooo`3oool0
0P3oool3000000D0oooo0`00000L0?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0
=@3oool006<0oooo0P0000080?ooo`<002;K5P3oool00`0007l0oooo0?ooo`040?ooo`L000007P3o
ool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo0`008]/70?ooo`800000=`3oool003P0oooo00<000000?ooo`3oool01`00000Q
0?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`030000O`3oool0oooo02T0oooo0`3j7PD9
0?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`070?oo
o`<002;K5P3oool00`0007l0oooo0?ooo`0Y0?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o0?oo
o`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?oo
o`3oool0=@3oool005D0oooo1000000:0?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`03
0000O`3oool0oooo02T0oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0
nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00
>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`030000
O`3oool0oooo02T0oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5
<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00>`3o
ool010000000oooo0?ooo`3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`030000O`3oool0oooo02T0oooo
0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00>`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`<000001`0007l3000Rfd80001o0`3j7PD90000O`<0nQh56P0007l30?XN1Ol0001o
AP0007l3000Rf`H0001o0`00000g0?ooo`00>`3oool3000000<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool3000RfaH0oooo00<0001o0?ooo`3oool0:@3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3o
ool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003o
ool0oooo03D0oooo000k0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool3
000RfaH0oooo00<0001o0?ooo`3oool0:@3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0
oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003oool0
oooo03D0oooo001D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`<002;K5P3oool00`0007l0oooo0?ooo`0Y0?ooo`<0nQh52@3oool30?XN
1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000R
f`P0oooo00<000000?ooo`3oool0=@3oool005@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`030000O`3oool0oooo02T0
oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00?03oool5000001<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
0`008]/F0?ooo`030000O`3oool0oooo02T0oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo
0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo
0?ooo`0e0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0140oooo
1000000:0?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`030000O`3oool0oooo02T0oooo
0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00>`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo01l0oooo0P0000080?ooo`<002;K5P3oool00`0007l0oooo
0?ooo`040?ooo`L000007P3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo
0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/70?ooo`800000=`3oool003/0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo
0`008]/F0?ooo`030000O`3oool0oooo0080oooo0P0000070?ooo`800000703oool30?XN1@T0oooo
0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo
0`008]/80?ooo`030000003oool0oooo03D0oooo000l0?ooo`<0000000<0oooo0000003oool08@3o
ool00`000000oooo0?ooo`070?ooo`<002;K5P3oool01@0007l0oooo0?ooo`3oool0000000/0oooo
00<000000?ooo`3oool06@3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo
0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo
001S0?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`040000O`3oool00000000000d0oooo
00<000000?ooo`3oool0603oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo
0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo
001S0?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`800000403oool2000001P0oooo0`3j
7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`07
0?ooo`<002;K5@3oool00`000000001o0?ooo`0B0?ooo`8000005P3oool30?XN1@T0oooo0`3j7PD:
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/8
0?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo00L0oooo0`008]/D0?oo
o`030000003oool0001o01D0oooo00<000000?ooo`3oool04`3oool30?XN1@T0oooo0`3j7PD:0?oo
o`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/80?oo
o`030000003oool0oooo03D0oooo000i0?ooo``000007P3oool2000000P0oooo0`008]/C0?ooo`04
0000003oool0oooo0000OaH0oooo00<000000?ooo`3oool04P3oool30?XN1@T0oooo0`3j7PD:0?oo
o`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo03l0oooo5000000d0?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`L0oooo0P00000g0?oo
o`00>@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool01`3oool3000Rfa40oooo0P0000030?ooo`030000O`3oool0oooo01D0oooo00<000000?ooo`3o
ool04@3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`03
0000O`3oool0oooo03X0oooo1@0000030?ooo`030000O`3oool0oooo00h0oooo1@00000_0?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool003T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00L0oooo0`008]/@0?ooo`030000003oool0oooo00<0oooo00<0001o0?ooo`3oool0
5P3oool00`000000oooo0?ooo`0@0?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C80oooo00<0001o0?ooo`3oool0=@3oool5000000P0oooo00<0001o0?ooo`3oool0
4`3oool4000002/0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K
203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`070?ooo`<002;K3`3o
ool00`000000oooo0?ooo`040?ooo`030000O`3oool0oooo01L0oooo0P00000@0?ooo`<0nQh52@3o
ool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0<03o
ool5000000d0oooo00<0001o0?ooo`3oool05`3oool4000002L0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool0
0`000000oooo0?ooo`070?ooo`<002;K3P3oool00`000000oooo0?ooo`050?ooo`030000O`3oool0
oooo01T0oooo00<000000?ooo`3oool03@3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0
oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo02h0oooo0P00000B0?ooo`030000O`3oool0
oooo01/0oooo1000000S0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3
000Rf`P0oooo00<000000?ooo`3oool0=@3oool003/0oooo1`00000Q0?ooo`030000003oool0oooo
00L0oooo0`008]/=0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3oool06P3oool00`00
0000oooo0?ooo`0<0?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN
1C80oooo00<0001o0?ooo`3oool0:P3oool4000001@0oooo00<0001o0?ooo`3oool07`3oool30000
0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`00
0000oooo0?ooo`0e0?ooo`00?03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00L0
oooo0`008]/<0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool06`3oool00`000000
oooo0?ooo`0;0?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80
oooo00<0001o0?ooo`3oool09P3oool4000001P0oooo00<0001o0?ooo`3oool08P3oool4000001`0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000
oooo0?ooo`0e0?ooo`00>`3oool00`000000oooo0?ooo`0U0?ooo`800000203oool3000Rf`X0oooo
0P00000:0?ooo`030000O`3oool0oooo01`0oooo00<000000?ooo`3oool02P3oool30?XN1@T0oooo
0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0280oooo
1000000L0?ooo`030000O`3oool0oooo02H0oooo0`00000I0?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@@3oool3000Rf`L0oooo0P00000g0?ooo`00>`3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00L0oooo0`008]/90?ooo`030000003oool0oooo00X0oooo00<0
001o0?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`<0nQh52@3oool30?XN1@X0oooo00<0
001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0803oool200000200oooo00<0
001o0?ooo`3oool0:@3oool3000001H0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00?03oool600000240oooo00<00000
0?ooo`3oool01`3oool3000Rf`P0oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0N
0?ooo`8000002@3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb
0?ooo`030000O`3oool0oooo01d0oooo0`00000R0?ooo`030000O`3oool0oooo02`0oooo0`00000C
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<00000
0?ooo`3oool0=@3oool003/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`070?oo
o`<002;K1`3oool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo0200oooo00<000000?oo
o`3oool01P3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?oo
o`030000O`3oool0oooo01/0oooo0P00000U0?ooo`030000O`3oool0oooo02l0oooo0`00000@0?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?oo
o`3oool0=@3oool003/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`070?ooo`<0
02;K1P3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo0240oooo00<000000?ooo`3o
ool01@3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`03
0000O`3oool0oooo01P0oooo0`00000W0?ooo`030000O`3oool0oooo0380oooo0`00000=0?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool003/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`070?ooo`<002;K
1@3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo0280oooo00<000000?ooo`3oool0
103oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000
O`3oool0oooo01D0oooo0`00000Z0?ooo`030000O`3oool0oooo03D0oooo0`00000:0?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0
=@3oool003`0oooo1P00000Q0?ooo`030000003oool0oooo00L0oooo0`008]/40?ooo`030000003o
ool0oooo00l0oooo00<0001o0?ooo`3oool08`3oool00`000000oooo0?ooo`030?ooo`<0nQh52@3o
ool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool04`3o
ool2000002d0oooo00<0001o0?ooo`3oool0>03oool3000000L0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool2
000000P0oooo0`008]/30?ooo`030000003oool0oooo0100oooo00<0001o0?ooo`3oool0903oool0
0`000000oooo0?ooo`020?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool3
0?XN1C80oooo00<0001o0?ooo`3oool0403oool3000002l0oooo00<0001o0?ooo`3oool0>`3oool2
000000D0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K1`3oool2
000003L0oooo001S0?ooo`030000003oool0oooo00L0oooo0`008]/20?ooo`030000003oool0oooo
0140oooo00<0001o0?ooo`3oool09@3oool010000000oooo0?ooo`3oool30?XN1@T0oooo0`3j7PD:
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo00h0oooo0P00000b
0?ooo`030000O`3oool0oooo03d0oooo0`0000020?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool003/0oooo1`00000Q0?oo
o`030000003oool0oooo00L0oooo0`008]/00`3oool000000?ooo`0C0?ooo`030000O`3oool0oooo
02H0oooo00<000000?ooo`3oool00`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?oo
o`<0nQh5<P3oool00`0007l0oooo0?ooo`0;0?ooo`<00000=03oool00`0007l0oooo0?ooo`100?oo
o`80000000<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`00
0000oooo0?ooo`0e0?ooo`00?03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01`3oool3000Rf`030000003oool0oooo01<0oooo00<0001o0?ooo`3o
ool09`3oool00`000000oooo0?XN1@020?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0
oooo0`3j7PDb0?ooo`030000O`3oool0oooo00T0oooo0P00000g0?ooo`030000O`3oool0oooo0480
oooo0P0000130?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0
oooo000k0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`070?ooo`8002;K00<000000?ooo`3oool0503oool00`0007l0oooo0?ooo`0X0?ooo`800000
0P3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo
0?ooo`060?ooo`<00000>@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0000000800000
@03oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00>`3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`008]/00000000Rf`0F0?ooo`030000O`3oool0oooo02T0oooo0P0000000`3j7PD0oooo0?oo
o`070?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?oo
o`030?ooo`<00000?03oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0080oooo0P00
000n0?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo000l
0?ooo`H000005@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo0`008]/F
0?ooo`030000O`3oool0oooo02T0oooo00<0nQh50000003j7PD02@3oool30?XN1@X0oooo00<0001o
0?ooo`3oool03@3oool30?XN1C80oooo00@0001o0?ooo`3oool0oooo0P00000o0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0103oool3000003/0oooo00<0001o0?ooo`3oool0@@3o
ool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool003/0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`090?ooo`<00000CP0007l2000000P0001o0`3j7PDJ0000O`<0nQh5<`0007l3
00000900001o0`00001l0000O`<002;K1P0007l3000003L0oooo000k0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo
02d0oooo00<000000?ooo`3oool01@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN
1C40oooo0P0000140?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool02P3oool20000
03H0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool003/0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0200
oooo00<0001o0?ooo`3oool0;@3oool00`000000oooo0?ooo`050?ooo`<0nQh52P3oool00`0007l0
oooo0?ooo`0=0?ooo`<0nQh5;P3oool3000000030?ooo`0007l0oooo04<0oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`0<0?ooo`<00000<`3oool00`0007l0oooo0?ooo`110?ooo`<0
02;K203oool00`000000oooo0?ooo`0e0?ooo`00?03oool6000001<0oooo00<000000?ooo`000000
2`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo02h0oooo00<000000?ooo`3oool0
103oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1B`0oooo0P0000040?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0?0?ooo`<00000
<03oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00EP3o
ool2000000/0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`0_0?ooo`030000003o
ool0oooo00<0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDY0?ooo`<000001P3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool04P3o
ool2000002h0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3o
ool003T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`0_0?ooo`030000003oool0
oooo00<0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDV0?ooo`<000002@3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0503oool3
000002/0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool0
03T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0200oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`020?ooo`<0nQh52P3oool00`00
07l0oooo0?ooo`0=0?ooo`<0nQh5903oool2000000`0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo01L0oooo0`00000X0?ooo`030000O`3oool0oooo
0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo000i0?ooo``000007P3oool200000240
oooo00<0001o0?ooo`3oool0<@3oool010000000oooo0?ooo`3oool30?XN1@X0oooo00<0001o0?oo
o`3oool03@3oool30?XN1B40oooo0`00000>0?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`0J0?ooo`8000009P3oool00`0007l0oooo0?ooo`110?oo
o`<002;K1`3oool2000003L0oooo001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3o
ool0<@3oool010000000oooo0?ooo`3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN
1Al0oooo0P00000A0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`0L0?ooo`800000903oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`00
0000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0380
oooo00<000000?ooo`3oool00`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDM0?ooo`80
00004`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool07P3oool200000280oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`0c0?ooo`030000
003oool0nQh50080nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh56`3oool2000001D0oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0200oooo
0`00000O0?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo
001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0<`3oool00`000000oooo0?XN
1@020?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1AP0oooo0`00000G0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0S0?ooo`8000007@3o
ool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool0
0`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo03@0oooo00@000000?XN1@3j7PD0nQh52P3o
ool00`0007l0oooo0?ooo`0=0?ooo`<0nQh55P3oool2000001X0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo02D0oooo0P00000K0?ooo`030000O`3o
ool0oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0
oooo0200oooo00<0001o0?ooo`3oool0=@3oool00`000000nQh50?XN1@0:0?ooo`030000O`3oool0
oooo00d0oooo0`3j7PDD0?ooo`800000703oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool09`3oool2000001T0oooo00<0001o0?ooo`3oool0@@3oool3
000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo0P00000Q0?ooo`030000O`3oool0oooo
03D0oooo00@0nQh500000000000000002@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh54P3oool2
000001h0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo02T0oooo0`00000F0?ooo`030000O`3oool0oooo0440oooo0`008]/70?ooo`800000=`3oool0
06<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`0i0?ooo`@000001@3oool00`00
07l0oooo0?ooo`0=0?ooo`<0nQh53`3oool300000200oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo02`0oooo0P00000D0?ooo`030000O`3oool0oooo
0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo0200
oooo00<0001o0?ooo`3oool0?@3oool2000000<0oooo00<0001o0?ooo`3oool03@3oool30?XN1@`0
oooo0`00000S0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`0^0?ooo`8000004P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000
oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo03l0oooo
1000000?0?ooo`<0nQh52@3oool3000002H0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0300oooo0`00000?0?ooo`030000O`3oool0oooo0440oooo
0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo0200oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0000000000003000000X0oooo0`3j7PD60?ooo`<00000:@3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0<`3o
ool2000000d0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3o
ool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo00<0oooo100000060?ooo`<0nQh5103oool2000002`0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo03D0oooo0`00000:0?ooo`030000O`3oool0
oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo
0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`070?ooo`800000103oool30?XN
1@80oooo0P00000^0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`0h0?ooo`800000203oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`00
0000oooo0?ooo`0e0?ooo`00H`3oool200000240oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`090?ooo`@000000`3j7PD200000300oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo03X0oooo0P0000060?ooo`030000O`3oool0oooo0440
oooo0`008]/70?ooo`800000=`3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo00d0oooo0`00000b0?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0l0?ooo`<000000`3oool00`0007l0oooo
0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?oo
o`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo03l0oooo0P00
00000`3oool0001o0?ooo`120?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool0
0`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3
00000480oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo
0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`040000O`3oool00000
00000400oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo
0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`040000O`3oool0oooo
0?ooo`<00000?@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo0P00000Q0?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`040?oo
o`<00000>P3oool3000Rf`L0oooo0P00000g0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`070?ooo`80
0000>03oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<000000?ooo`3oool0
803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
2@3oool3000003D0oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003o
ool0oooo0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo00`0oooo0P00000c0?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00E03oool6
000000T0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool03P3oool200000340oooo0`008]/80?ooo`030000003oool0
oooo03D0oooo001E0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0803oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0403oool20000
02l0oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001F0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool04P3oool3000002`0oooo0`008]/80?ooo`030000003oool0oooo03D0
oooo001G0?ooo`030000003oool0oooo00T0oooo0`00003o0000Oi80001o0P00000Z0000O`<002;K
1P0007l3000003L0oooo001H0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0803o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool05`3o
ool2000002P0oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001I0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool06@3oool2000002H0oooo0`008]/80?ooo`030000003oool0
oooo03D0oooo001I0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0803oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool06`3oool30000
02<0oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001I0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool07P3oool200000240oooo0`008]/80?ooo`030000003oool0oooo03D0
oooo001D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`0P0?ooo`8000007`3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool005D0oooo1000
000:0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0280oooo0`00000L0?ooo`<002;K203oool00`000000oooo0?oo
o`0e0?ooo`00H`3oool200000240oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo02D0oooo0P00000J0?ooo`<002;K1`3oool2000003L0oooo001S0?oo
o`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo02L0oooo0`00000G0?ooo`<002;K203oool00`000000oooo0?ooo`0e0?oo
o`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`0Z0?ooo`8000005@3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0;03oool2000001<0oooo0`008]/80?ooo`030000
003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo02h0oooo0`00000@0?ooo`<002;K203o
ool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0a0?ooo`8000003P3oool3
000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0<`3oool20000
00`0oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`8000008@3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0=@3oool2000000X0
oooo0`008]/70?ooo`800000=`3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0=`3oool3000000L0oooo
0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo0200oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo03X0oooo0P00
00050?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`0P
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0l
0?ooo`8000000`3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<000000?oo
o`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0?P3oool2000000040?ooo`008]/002;K000Rf`P0oooo00<000000?ooo`3oool0=@3oool0
06<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@03oool300000003000Rf`3oool0oooo00H0oooo00<000000?oo
o`3oool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool006<0oooo0P00000Q0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00H0oooo0P00000g0?ooo`00H`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03D0oooo001S0?ooool00000c@00000g
0?ooo`00o`3ooooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00o`3o
oooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00o`3ooooo0?ooofP0
oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00o`3ooooo0?ooofP0oooo003o0?oo
obH0oooo1P0000040?ooo`<00000103oool2000000050?ooo`000000oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`<000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0?ooo`<0
0000n`3oool00?l0oooo9P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0
oooo00@000000?ooo`3oool000000P3oool200000080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`05
0000003oool0oooo0?ooo`000000nP3oool00?l0oooo9P3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`3l0?ooo`00o`3ooolV0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@0000030?ooo`@000000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
1@00003j0?ooo`00o`3ooolV0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`H000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`00
0000nP3oool00?l0oooo9P3oool6000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool200000080oooo0P0000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0200000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`3h0?ooo`00o`3ooolV0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool0oooo0`0000040?ooo`<000000`3oool010000000oooo0000000000020?ooo`80
00001P3oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool000000P3oool3
00000080oooo0`0000001@3oool000000?ooo`3oool0000000<0oooo0`00003k0?ooo`00o`3ooolV
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o
0?ooo`00o`3ooolV0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooo`00o`3ooolV0?ooo`H000007`3oool6000000l0oooo0`0000020?ooo`03
0000003oool0oooo0?l0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00\
\>"],
  ImageRangeCache->{{{57.1875, 547.375}, {611.313, 415.875}} -> {-3.98809, \
11.3261, 0.0145191, 0.0290779}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input Beam Profile (X-Arm of Michelson)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TelescopePlot[{zETM + MichelsonAsymmetry/2, 5.0}, {CavityWaist, 
          zCavityWaist + MichelsonAsymmetry/2}, {{ITMFocalLength, 
            zITM + MichelsonAsymmetry/2}, {fLX, zLX}, {fL1, zL1}}, 
        kk];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.220333 0.151172 0.2 0.0765308 [
[.06916 -0.0125 -10.0938 -16.375 ]
[.06916 -0.0125 10.0938 0 ]
[.22033 -0.0125 -5.59375 -16.375 ]
[.22033 -0.0125 5.59375 0 ]
[.3715 -0.0125 -5.59375 -16.375 ]
[.3715 -0.0125 5.59375 0 ]
[.52268 -0.0125 -5.59375 -16.375 ]
[.52268 -0.0125 5.59375 0 ]
[.67385 -0.0125 -5.59375 -16.375 ]
[.67385 -0.0125 5.59375 0 ]
[.82502 -0.0125 -5.59375 -16.375 ]
[.82502 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -16.375 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -43.1563 -32.75 ]
[.5 -0.0125 43.1563 -16.375 ]
[-0.0125 .04694 -20.1875 -8.1875 ]
[-0.0125 .04694 0 8.1875 ]
[-0.0125 .12347 -20.1875 -8.1875 ]
[-0.0125 .12347 0 8.1875 ]
[-0.0125 .2 -11.1875 -8.1875 ]
[-0.0125 .2 0 8.1875 ]
[-0.0125 .27653 -11.1875 -8.1875 ]
[-0.0125 .27653 0 8.1875 ]
[-0.0125 .35306 -11.1875 -8.1875 ]
[-0.0125 .35306 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .2 -36.5625 -44.3438 ]
[-0.01875 .2 -20.1875 44.3438 ]
[ 0 .4 .125 0 ]
[.5 .4125 -39 0 ]
[.5 .4125 39 16.375 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.06916 0 m
.06916 .4 L
s
.22033 0 m
.22033 .4 L
s
.3715 0 m
.3715 .4 L
s
.52268 0 m
.52268 .4 L
s
.67385 0 m
.67385 .4 L
s
.82502 0 m
.82502 .4 L
s
0 .04694 m
1 .04694 L
s
0 .12347 m
1 .12347 L
s
0 .2 m
1 .2 L
s
0 .27653 m
1 .27653 L
s
0 .35306 m
1 .35306 L
s
0 g
.06916 0 m
.06916 .00625 L
s
gsave
.06916 -0.0125 -71.0938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22033 0 m
.22033 .00625 L
s
gsave
.22033 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.3715 0 m
.3715 .00625 L
s
gsave
.3715 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.52268 0 m
.52268 .00625 L
s
gsave
.52268 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.67385 0 m
.67385 .00625 L
s
gsave
.67385 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.82502 0 m
.82502 .00625 L
s
gsave
.82502 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.0994 0 m
.0994 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.15986 0 m
.15986 .00375 L
s
.1901 0 m
.1901 .00375 L
s
.25057 0 m
.25057 .00375 L
s
.2808 0 m
.2808 .00375 L
s
.31104 0 m
.31104 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.43197 0 m
.43197 .00375 L
s
.46221 0 m
.46221 .00375 L
s
.49244 0 m
.49244 .00375 L
s
.55291 0 m
.55291 .00375 L
s
.58314 0 m
.58314 .00375 L
s
.61338 0 m
.61338 .00375 L
s
.64361 0 m
.64361 .00375 L
s
.70408 0 m
.70408 .00375 L
s
.73432 0 m
.73432 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79478 0 m
.79478 .00375 L
s
.85525 0 m
.85525 .00375 L
s
.88549 0 m
.88549 .00375 L
s
.91572 0 m
.91572 .00375 L
s
.94596 0 m
.94596 .00375 L
s
.03893 0 m
.03893 .00375 L
s
.00869 0 m
.00869 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -104.156 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.438 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.875 16.625 moveto
(@) show
130.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
141.000 16.625 moveto
(D) show
145.313 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .04694 m
.00625 .04694 L
s
gsave
-0.0125 .04694 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .12347 m
.00625 .12347 L
s
gsave
-0.0125 .12347 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
gsave
-0.0125 .2 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .27653 m
.00625 .27653 L
s
gsave
-0.0125 .27653 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .35306 m
.00625 .35306 L
s
gsave
-0.0125 .35306 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06224 m
.00375 .06224 L
s
0 .07755 m
.00375 .07755 L
s
0 .09286 m
.00375 .09286 L
s
0 .10816 m
.00375 .10816 L
s
0 .13878 m
.00375 .13878 L
s
0 .15408 m
.00375 .15408 L
s
0 .16939 m
.00375 .16939 L
s
0 .18469 m
.00375 .18469 L
s
0 .21531 m
.00375 .21531 L
s
0 .23061 m
.00375 .23061 L
s
0 .24592 m
.00375 .24592 L
s
0 .26122 m
.00375 .26122 L
s
0 .29184 m
.00375 .29184 L
s
0 .30714 m
.00375 .30714 L
s
0 .32245 m
.00375 .32245 L
s
0 .33776 m
.00375 .33776 L
s
0 .03163 m
.00375 .03163 L
s
0 .01633 m
.00375 .01633 L
s
0 .00102 m
.00375 .00102 L
s
0 .36837 m
.00375 .36837 L
s
0 .38367 m
.00375 .38367 L
s
0 .39898 m
.00375 .39898 L
s
.25 Mabswid
0 0 m
0 .4 L
s
gsave
-0.01875 .2 -133.719 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
105.344 12.1875 translate
90 rotate
-105.344 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(spot) show
90.938 16.625 moveto
(size) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.438 16.625 moveto
(@) show
121.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
143.375 16.625 moveto
(D) show
147.688 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.06916 .39375 m
.06916 .4 L
s
.22033 .39375 m
.22033 .4 L
s
.3715 .39375 m
.3715 .4 L
s
.52268 .39375 m
.52268 .4 L
s
.67385 .39375 m
.67385 .4 L
s
.82502 .39375 m
.82502 .4 L
s
.97619 .39375 m
.97619 .4 L
s
.125 Mabswid
.0994 .39625 m
.0994 .4 L
s
.12963 .39625 m
.12963 .4 L
s
.15986 .39625 m
.15986 .4 L
s
.1901 .39625 m
.1901 .4 L
s
.25057 .39625 m
.25057 .4 L
s
.2808 .39625 m
.2808 .4 L
s
.31104 .39625 m
.31104 .4 L
s
.34127 .39625 m
.34127 .4 L
s
.40174 .39625 m
.40174 .4 L
s
.43197 .39625 m
.43197 .4 L
s
.46221 .39625 m
.46221 .4 L
s
.49244 .39625 m
.49244 .4 L
s
.55291 .39625 m
.55291 .4 L
s
.58314 .39625 m
.58314 .4 L
s
.61338 .39625 m
.61338 .4 L
s
.64361 .39625 m
.64361 .4 L
s
.70408 .39625 m
.70408 .4 L
s
.73432 .39625 m
.73432 .4 L
s
.76455 .39625 m
.76455 .4 L
s
.79478 .39625 m
.79478 .4 L
s
.85525 .39625 m
.85525 .4 L
s
.88549 .39625 m
.88549 .4 L
s
.91572 .39625 m
.91572 .4 L
s
.94596 .39625 m
.94596 .4 L
s
.03893 .39625 m
.03893 .4 L
s
.00869 .39625 m
.00869 .4 L
s
.25 Mabswid
0 .4 m
1 .4 L
s
gsave
.5 .4125 -100 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
100.375 16.625 moveto
(Profile) show
137.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .04694 m
1 .04694 L
s
.99375 .12347 m
1 .12347 L
s
.99375 .2 m
1 .2 L
s
.99375 .27653 m
1 .27653 L
s
.99375 .35306 m
1 .35306 L
s
.125 Mabswid
.99625 .06224 m
1 .06224 L
s
.99625 .07755 m
1 .07755 L
s
.99625 .09286 m
1 .09286 L
s
.99625 .10816 m
1 .10816 L
s
.99625 .13878 m
1 .13878 L
s
.99625 .15408 m
1 .15408 L
s
.99625 .16939 m
1 .16939 L
s
.99625 .18469 m
1 .18469 L
s
.99625 .21531 m
1 .21531 L
s
.99625 .23061 m
1 .23061 L
s
.99625 .24592 m
1 .24592 L
s
.99625 .26122 m
1 .26122 L
s
.99625 .29184 m
1 .29184 L
s
.99625 .30714 m
1 .30714 L
s
.99625 .32245 m
1 .32245 L
s
.99625 .33776 m
1 .33776 L
s
.99625 .03163 m
1 .03163 L
s
.99625 .01633 m
1 .01633 L
s
.99625 .00102 m
1 .00102 L
s
.99625 .36837 m
1 .36837 L
s
.99625 .38367 m
1 .38367 L
s
.99625 .39898 m
1 .39898 L
s
.25 Mabswid
1 0 m
1 .4 L
s
.977 .121 .023 r
.0075 w
.17498 .12818 m
.17498 .27182 L
s
.20144 .09304 m
.20144 .30696 L
s
.25813 .07627 m
.25813 .32373 L
s
0 .133 .859 r
.02381 .12818 m
.02381 .27182 L
s
.97619 .00952 m
.97619 .39048 L
s
0 g
.5 Mabswid
.02381 .27182 m
.04262 .25474 L
.06244 .2372 L
.07216 .22902 L
.0775 .22479 L
.08255 .22108 L
.08542 .21918 L
.08693 .21826 L
.08852 .21735 L
.08987 .21665 L
.09135 .21595 L
.0927 .21541 L
.09396 .21497 L
.09461 .21477 L
.09533 .21459 L
.09663 .21432 L
.0979 .21415 L
.09907 .21409 L
.09979 .21409 L
.10047 .21412 L
.10174 .21425 L
.10245 .21437 L
.1031 .2145 L
.10382 .21468 L
.10458 .21489 L
.1058 .2153 L
.10713 .21582 L
.10838 .21638 L
.10954 .21696 L
.11406 .21962 L
.11898 .22305 L
.12422 .22708 L
.14255 .2426 L
.1803 .27887 L
.19052 .29244 L
.19609 .29985 L
.19881 .30346 L
.19999 .30504 L
.20128 .30675 L
.20246 .30726 L
.20356 .30758 L
.20572 .30821 L
.21046 .3096 L
.22051 .31256 L
.24049 .31848 L
.24551 .31997 L
.25026 .32138 L
.25454 .32266 L
.25571 .32301 L
.25695 .32338 L
Mistroke
.25813 .32373 L
.25919 .32328 L
.26824 .31953 L
.27796 .31551 L
.2986 .307 L
.33871 .29065 L
.37732 .27528 L
.41837 .25963 L
.43883 .25229 L
.45791 .24591 L
.47628 .24038 L
.48657 .23765 L
.49594 .23546 L
.50076 .23446 L
.50588 .23351 L
.51024 .23279 L
.51506 .23211 L
.51775 .23178 L
.52022 .23151 L
.52293 .23125 L
.52429 .23114 L
.52578 .23103 L
.52708 .23094 L
.5283 .23087 L
.52971 .2308 L
.53099 .23074 L
.5322 .23069 L
.53332 .23066 L
.53454 .23063 L
.53583 .23061 L
.53705 .2306 L
.53774 .2306 L
.53837 .2306 L
.53954 .23061 L
.54078 .23063 L
.54189 .23066 L
.54293 .23068 L
.54407 .23072 L
.5453 .23078 L
.54653 .23084 L
.54787 .23091 L
.54928 .231 L
.55059 .2311 L
.55294 .23129 L
.55545 .23153 L
.55781 .23179 L
.56038 .23211 L
.56505 .23277 L
.56958 .23351 L
.57377 .23429 L
Mistroke
.58345 .23635 L
.59251 .23858 L
.61314 .24452 L
.65194 .25775 L
.69318 .27334 L
.73291 .28911 L
.77112 .30465 L
.81179 .32143 L
.85094 .33774 L
.89254 .35518 L
.93263 .37207 L
.9712 .38836 L
.97619 .39048 L
Mfstroke
.02381 .12818 m
.04262 .14526 L
.06244 .1628 L
.07216 .17098 L
.0775 .17521 L
.08255 .17892 L
.08542 .18082 L
.08693 .18174 L
.08852 .18265 L
.08987 .18335 L
.09135 .18405 L
.0927 .18459 L
.09396 .18503 L
.09461 .18523 L
.09533 .18541 L
.09663 .18568 L
.0979 .18585 L
.09907 .18591 L
.09979 .18591 L
.10047 .18588 L
.10174 .18575 L
.10245 .18563 L
.1031 .1855 L
.10382 .18532 L
.10458 .18511 L
.1058 .1847 L
.10713 .18418 L
.10838 .18362 L
.10954 .18304 L
.11406 .18038 L
.11898 .17695 L
.12422 .17292 L
.14255 .1574 L
.1803 .12113 L
.19052 .10756 L
.19609 .10015 L
.19881 .09654 L
.19999 .09496 L
.20128 .09325 L
.20246 .09274 L
.20356 .09242 L
.20572 .09179 L
.21046 .0904 L
.22051 .08744 L
.24049 .08152 L
.24551 .08003 L
.25026 .07862 L
.25454 .07734 L
.25571 .07699 L
.25695 .07662 L
Mistroke
.25813 .07627 L
.25919 .07672 L
.26824 .08047 L
.27796 .08449 L
.2986 .093 L
.33871 .10935 L
.37732 .12472 L
.41837 .14037 L
.43883 .14771 L
.45791 .15409 L
.47628 .15962 L
.48657 .16235 L
.49594 .16454 L
.50076 .16554 L
.50588 .16649 L
.51024 .16721 L
.51506 .16789 L
.51775 .16822 L
.52022 .16849 L
.52293 .16875 L
.52429 .16886 L
.52578 .16897 L
.52708 .16906 L
.5283 .16913 L
.52971 .1692 L
.53099 .16926 L
.5322 .16931 L
.53332 .16934 L
.53454 .16937 L
.53583 .16939 L
.53705 .1694 L
.53774 .1694 L
.53837 .1694 L
.53954 .16939 L
.54078 .16937 L
.54189 .16934 L
.54293 .16932 L
.54407 .16928 L
.5453 .16922 L
.54653 .16916 L
.54787 .16909 L
.54928 .169 L
.55059 .1689 L
.55294 .16871 L
.55545 .16847 L
.55781 .16821 L
.56038 .16789 L
.56505 .16723 L
.56958 .16649 L
.57377 .16571 L
Mistroke
.58345 .16365 L
.59251 .16142 L
.61314 .15548 L
.65194 .14225 L
.69318 .12666 L
.73291 .11089 L
.77112 .09535 L
.81179 .07857 L
.85094 .06226 L
.89254 .04482 L
.93263 .02793 L
.9712 .01164 L
.97619 .00952 L
Mfstroke
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{612.625, 245},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009T0000mB000`400?l00000o`00003oo`3ooooo
0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo;`3oool00`000000oooo0?ooo`0]0?ooo`<0
00003@3oool300000?<0oooo003o0?ooobl0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0?40oooo003o0?ooobl0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?40oooo003o0?ooob40oooo1@000009
0?ooo`040000003oool00000000000@0oooo0`0000040?ooo`<000000`3oool00`000000oooo0?oo
o`0200000080oooo00@000000?ooo`3oool0oooo0`0000030?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob80oooo00<000000?ooo`3o
ool02P3oool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000003
0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3a0?ooo`00o`3ooolR0?ooo`030000003oool0oooo00X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo0?oo
o`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0l@3o
ool00?l0oooo8`3oool010000000oooo0?ooo`3oool7000000030?ooo`000000oooo0080oooo00@0
00000?ooo`3oool000000`3oool010000000oooo0?ooo`3oool3000000<0oooo00@000000?ooo`3o
ool000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob@0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob@0oooo00<000000?ooo`3oool0203o
ool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3a0?ooo`00o`3ooolQ0?ooo`D000002@3oool010000000oooo0000000000040?ooo`<00000103o
ool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`040000003oool0oooo0?ooo`<00000
0`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0080oooo00@000000?ooo`00
000000000P3oool2000000D0oooo00<000000?ooo`3oool0l@3oool00?l0ooooA`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0l@3oool00?l0oooo
A`3oool00`000000oooo0?ooo`0E0?ooo`<000003@3oool300000?<0oooo003o0?oood@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooaP0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3o
oomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool008H0oooo00<000000?ooo`3o
ool0?03oool4000004<0oooo00<000000?ooo`3oool0@03oool600000400oooo100000140?ooo`03
0000003oool0oooo0400oooo100000100?ooo`00QP3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0m0?ooo`00QP3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0?@3o
ool6000004D0oooo00<000000?ooo`3oool0?@3oool007/0oooo1`0000040?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0n0?ooo`040000003oool0
oooo000004H0oooo00<000000?ooo`3oool0?@3oool008H0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo03h0oooo00@000000?ooo`3oool00000@@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo00260?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool0?`3oool300000480oooo00<000000?ooo`000000@@3oool5
00000400oooo00260?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool000000440oooo00<000000?ooo`3oool0@P3oool008@0
oooo00<000000?ooo`000000?@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`000000A`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0400
oooo0P0000120?ooo`030000003oool0oooo0440oooo00250?ooo`800000?@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03l0oooo0P0000120?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo
0P0000120?ooo`030000003oool0oooo0440oooo00260?ooo`030000003oool0oooo03`0oooo1000
00130?ooo`030000003oool0oooo0440oooo100000110?ooo`@00000A03oool00`000000oooo0?oo
o`100?ooo`D00000?`3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0
ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00H`3ooooo00000<`00000=P3oool006<0oooo00D000000?ooo`3oool0
oooo0000000<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0d0?ooo`00H`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003o
ool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo00<002;K000000008]/02@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool0
0`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`0o0?ooo`<000000P008]/90?ooo`030000003oool0oooo03@0oooo001S0?oo
o`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo03d0oooo0P0000020?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00H`3oool2000001d0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo03/0oooo0P0000040?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000
003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo03T0oooo0P0000060?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3o
ool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`0f0?ooo`<00000203oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0=03oool2000000/0oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0380oooo0P00000=0?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0`0?ooo`8000003`3oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo
0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0;@3oool300000140oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`8000007@3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0:`3oool2000001@0oooo0`00
8]/70?ooo`<00000=P3oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0:@3oool2000001H0oooo0`008]/9
0?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo02L0oooo0P00000H0?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0T0?ooo`<0
00006P3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005@0oooo1P0000090?ooo`030000
003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0280oooo0P00000M0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0200oooo0P00000O0?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00EP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo01h0oooo0P00000Q0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00C03oool70000
00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0K0?ooo`<000008`3oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool005P0oooo00<000000?ooo`3oool0203oool300000?l0
001oU00007l2000002H0001o0`008]/60000O`@00000=P3oool005T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`0G0?ooo`800000:03oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool005T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0D0?ooo`<00000:P3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`0B0?ooo`800000;@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
05@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
00l0oooo0`00000_0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E@3oool4000000X0
oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool03@3oool200000380oooo0`008]/90?ooo`030000003oool0oooo03@0
oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo00/0oooo0P00000d0?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00H`3oool2000001d0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo00P0oooo0`00000f0?ooo`<002;K1`3oool3000003H0oooo001S
0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo00H0oooo0P00000i0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`030?ooo`<00000>`3oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`03
0000O`3oool0oooo0480oooo00@0001o0?ooo`3oool0oooo0P00000n0?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool0100007l000000000000000100?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`130?ooo`030000O`3oool0oooo0400oooo0`0000130?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo
00<0001o0?ooo`3oool0303oool400000380oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`130?ooo`030000O`3oool0oooo03h0oooo0P0000020?ooo`030000O`3oool0oooo0440oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`8000007@3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo00X0oooo0P000000103oool0nQh50?XN1@3j7PD200000300oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo03/0oooo
0`0000040?ooo`030000O`3oool0oooo0440oooo0`008]/70?ooo`<00000=P3oool006<0oooo00<0
00000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo00D0oooo1@00
00030?ooo`<0nQh50P3oool2000002h0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo03T0oooo0P0000070?ooo`030000O`3oool0oooo0440oooo0`00
8]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`020?ooo`<00000203oool30?XN1@@0oooo0P00000/
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0g
0?ooo`8000002@3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`0000000P00000;0?ooo`<0nQh51P3oool3000002T0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`130?ooo`030000O`3oool0oooo03@0oooo0`00000;0?ooo`030000O`3oool0oooo
0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0
oooo00<0001o0?ooo`3oool0@@3oool4000000h0oooo0`3j7PD90?ooo`8000009`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0<P3oool2000000h0
oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo
00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`0n0?ooo`<000000P3oool00`0007l0oooo
0?ooo`0=0?ooo`<0nQh52`3oool2000002D0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`130?ooo`030000O`3oool0oooo02l0oooo0`00000@0?ooo`030000O`3oool0oooo0440oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0
001o0?ooo`3oool0>@3oool20?XN1@<000001@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh53@3o
ool2000002<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3o
ool0oooo02d0oooo0P00000C0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo001S0?ooo`8000007@3oool00`0007l0oooo0?ooo`0i0?ooo`030?XN1@000000
nQh500L0oooo00<0001o0?ooo`3oool03@3oool30?XN1@l0oooo0`00000P0?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0[0?ooo`8000005@3oool0
0`0007l0oooo0?ooo`110?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000003oool0oooo
01`0oooo00<0001o0?ooo`3oool0>@3oool00`000000nQh50?XN1@070?ooo`030000O`3oool0oooo
00d0oooo0`3j7PDB0?ooo`<000007@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0:03oool3000001L0oooo00<0001o0?ooo`3oool0@@3oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0
oooo0?ooo`0h0?ooo`040000003j7PD0nQh50?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN
1AD0oooo0P00000K0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`0V0?ooo`8000006P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo03L0
oooo00<000000?ooo`3j7PD00P3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDG0?ooo`<0
0000603oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3o
ool08`3oool3000001`0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`0f0?ooo`030000
003oool0oooo00<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh56P3oool3000001D0oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0240oooo
0P00000O0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0=P3oool00`000000oooo0?oo
o`030?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1Ad0oooo0P00000C0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0O0?ooo`8000008@3o
ool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool0
0`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo03D0oooo00@000000?ooo`3oool0oooo0`3j
7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDO0?ooo`<00000403oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0703oool3000002<0oooo00<0
001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo0P00000M
0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool00P3oool30?XN1@L0oooo00<0001o
0?ooo`3oool03@3oool30?XN1B80oooo0`00000=0?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0J0?ooo`8000009P3oool00`0007l0oooo0?ooo`11
0?ooo`<002;K1`3oool3000003H0oooo000l0?ooo`8000000P3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`020?oo
o`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh59@3oool2000000/0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo01L0oooo0`00000X0?oo
o`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0L0?oo
o`030000O`3oool0oooo03<0oooo00<000000?ooo`3oool00`3oool30?XN1@L0oooo00<0001o0?oo
o`3oool03@3oool30?XN1BL0oooo0`0000080?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`0D0?ooo`<00000:`3oool00`0007l0oooo0?ooo`110?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?oo
o`030000O`3oool0oooo0380oooo00<000000?ooo`3oool0103oool30?XN1@L0oooo00<0001o0?oo
o`3oool03@3oool30?XN1BX0oooo0P0000060?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`0B0?ooo`800000;P3oool00`0007l0oooo0?ooo`110?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?oo
o`030000O`3oool0oooo0340oooo00<000000?ooo`3oool01@3oool30?XN1@L0oooo00<0001o0?oo
o`3oool03@3oool30?XN1B`0oooo0`0000030?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`0?0?ooo`<00000<03oool00`0007l0oooo0?ooo`110?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool00`000000oooo0?ooo`02000001H0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo0340
oooo00<000000?ooo`3oool01@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1Bl0
oooo0`0000000`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3o
ool0303oool3000003<0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool004`0oooo1`0000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
703oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo00H0oooo0`3j7PD70?ooo`030000
O`3oool0oooo00d0oooo0`3j7PDb0?ooo`800000@`3oool00`0007l0oooo0?ooo`130?ooo`030000
O`3oool0oooo00X0oooo0P00000f0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000
003oool0oooo03@0oooo001G0?ooo`030000003oool0oooo00T0oooo0`00001>0000O`0300000000
07l0001o00L0001o0`3j7PDG0000O`<0nQh5=00007l300000900001o0`00001l0000O`<002;K1P00
07l4000003H0oooo000k0?ooo`X000004P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00H0oooo0`008]/C0?ooo`030000O`3oool0oooo02d0oooo00<0nQh50000003j7PD02@3oool3
0?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool00P3oool2
000003h0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`040?ooo`<00000>`3oool0
0`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool01@00
0000oooo0?ooo`3oool0000001H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`06
0?ooo`03000Rf`00000002;K01<0oooo00<0001o0?ooo`3oool0;@3oool00`000000nQh50?XN1@09
0?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`04
0?ooo`<00000>`3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0080oooo0P00000n
0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0000000;0?oo
o`030000003oool0oooo00H0oooo0P008]/00`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo
02`0oooo00@000000?XN1@3j7PD0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool3
0?XN1C80oooo00<0001o0?ooo`3oool01`3oool2000003T0oooo00<0001o0?ooo`3oool0@`3oool0
0`0007l0oooo0000000200000400oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<00000
0?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?oo
o`8000002`3oool00`000000oooo0?ooo`060?ooo`<002;K00<000000?ooo`3oool0403oool00`00
07l0oooo0?ooo`0[0?ooo`030000003oool0nQh50080nQh52@3oool30?XN1@L0oooo00<0001o0?oo
o`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool02@3oool3000003H0oooo00<0001o0?oo
o`3oool0@`3oool2000004<0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool003`0oooo1@00000F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01P3oool3000Rf`030?ooo`000000oooo0100oooo00<0001o0?ooo`3oool0:P3oool00`000000
oooo0?ooo`030?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`03
0000O`3oool0oooo00`0oooo0`00000c0?ooo`030000O`3oool0oooo0400oooo0`0000000`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0
oooo001S0?ooo`030000003oool0oooo00H0oooo0`008]/20?ooo`8000003`3oool00`0007l0oooo
0?ooo`0Y0?ooo`040000003oool0oooo0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3o
ool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool03`3oool200000340oooo00<0001o0?ooo`3o
ool0?@3oool3000000<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000000L0oooo0`008]/40?ooo`030000
003oool0oooo00`0oooo00<0001o0?ooo`3oool09`3oool2000000@0oooo0`3j7PD90?ooo`<0nQh5
1`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`0A0?ooo`<00000
;P3oool00`0007l0oooo0?ooo`0k0?ooo`8000001P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo0`008]/70?ooo`<00000=P3oool003`0oooo1@00000R0?ooo`030000003o
ool0oooo00H0oooo0`008]/50?ooo`030000003oool0oooo00/0oooo00<0001o0?ooo`3oool09P3o
ool00`000000oooo0?ooo`040?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3o
ool30?XN1C80oooo00<0001o0?ooo`3oool0503oool2000002`0oooo00<0001o0?ooo`3oool0>03o
ool3000000P0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool01P3oool3000Rf`H0oooo00<000000?ooo`3oool02P3oool0
0`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo0`3j7PD90?ooo`<0nQh51`3oool0
0`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`0F0?ooo`<00000:@3oool0
0`0007l0oooo0?ooo`0e0?ooo`<000002`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`<002;K1`3oool00`00
0000oooo0?ooo`090?ooo`030000O`3oool0oooo02@0oooo00<000000?ooo`3oool01P3oool30?XN
1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo
01T0oooo0P00000W0?ooo`030000O`3oool0oooo0380oooo0`00000>0?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00H0
oooo0`008]/80?ooo`030000003oool0oooo00P0oooo00<0001o0?ooo`3oool08`3oool00`000000
oooo0?ooo`070?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80
oooo00<0001o0?ooo`3oool06`3oool3000002@0oooo00<0001o0?ooo`3oool0;`3oool300000140
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00?03oool500000280oooo00<000000?ooo`3oool01P3oool3000Rf`T0oooo
00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo
0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo
0?ooo`0N0?ooo`<000008@3oool00`0007l0oooo0?ooo`0/0?ooo`<00000503oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
001S0?ooo`030000003oool0oooo00H0oooo0`008]/:0?ooo`030000003oool0oooo00H0oooo00<0
001o0?ooo`3oool08@3oool00`000000oooo0?ooo`090?ooo`<0nQh52@3oool30?XN1@L0oooo00<0
001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool08@3oool3000001h0oooo00<0
001o0?ooo`3oool0:@3oool3000001L0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`0U
0?ooo`8000001`3oool3000Rf`/0oooo0P0000060?ooo`030000O`3oool0oooo0200oooo00<00000
0?ooo`3oool02P3oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb
0?ooo`030000O`3oool0oooo02@0oooo0`00000K0?ooo`030000O`3oool0oooo02H0oooo0`00000J
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`L0oooo0`00000f
0?ooo`00>@3oool900000240oooo00<000000?ooo`3oool01P3oool3000Rf`d0oooo00<000000?oo
o`3oool00`3oool00`0007l0oooo0?ooo`0O0?ooo`030000003oool0oooo00/0oooo0`3j7PD90?oo
o`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`0W0?oo
o`@000005`3oool00`0007l0oooo0?ooo`0S0?ooo`<000007@3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`<0
02;K3P3oool00`000000oooo0?ooo`020?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3o
ool0303oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`03
0000O`3oool0oooo02/0oooo1@00000B0?ooo`030000O`3oool0oooo01l0oooo1000000P0?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool006<0oooo00<000000?ooo`3oool01P3oool3000Rf`l0oooo00D000000?ooo`3oool0
oooo0000O`0O0?ooo`030000003oool0oooo00d0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0
oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`0`0?ooo`@000003P3oool00`0007l0
oooo0?ooo`0L0?ooo`<00000903oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo00H0oooo
0`008]/@0?ooo`040000003oool0oooo0000Oah0oooo00<000000?ooo`3oool03P3oool30?XN1@T0
oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo03@0
oooo0`00000;0?ooo`030000O`3oool0oooo01P0oooo1000000W0?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo
00<000000?ooo`3oool01P3oool3000Rfa40oooo0P0000000`0007l0oooo0?ooo`0J0?ooo`800000
4@3oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000
O`3oool0oooo03L0oooo1@0000060?ooo`030000O`3oool0oooo01<0oooo1@00000[0?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool006<0oooo00<000000?ooo`3oool01P3oool3000Rfa<0oooo0P00000J0?ooo`030000003o
ool0oooo0140oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3o
ool00`0007l0oooo0?ooo`0l0?ooo`T000002@3oool:00000300oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2
000000L0oooo0`008]/C0?ooo`030000O`3oool0000001P0oooo00<000000?ooo`3oool04P3oool3
0?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool02P00000i0?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@@3oool3000Rf`L0oooo0`00000f0?ooo`00?03oool200000080oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`060?ooo`<002;K4`3oool0100007l0oooo0?ooo`00000F
0?ooo`030000003oool0oooo01<0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=
0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool01P3oool3000Rfa<0oooo00D0001o0?ooo`3oool0oooo0000000C0?ooo`8000005P3o
ool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`<002;K4`3o
ool00`0007l0oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05P3o
ool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`<002;K4`3o
ool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05`3o
ool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`030000003oool0
oooo008000008P3oool00`000000oooo0?ooo`060?ooo`<002;K4`3oool00`0007l0oooo0?ooo`04
0?ooo`800000303oool00`000000oooo0?ooo`0H0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o
0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<00000
0?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool01P3oool3000Rfa<0oooo00<0001o0?oo
o`3oool01P3oool2000000L0oooo0`00000K0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?oo
o`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool006<0oooo0P0000070?ooo`<002;K4`3oool00`0007l0oooo0?ooo`080?ooo`L0
00007P3oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0440oooo0`008]/70?ooo`<00000=P3oool003P0oooo00<000000?ooo`3oool0
1`00000Q0?ooo`030000003oool0oooo00H0oooo0`008]/C0?ooo`030000O`3oool0oooo02d0oooo
0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?oo
o`060?ooo`<002;K4`3oool00`0007l0oooo0?ooo`0]0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0
001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool005D0oooo1000000:0?ooo`030000003oool0oooo00H0oooo0`008]/C
0?ooo`030000O`3oool0oooo02d0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=
0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo0`008]/C0?oo
o`030000O`3oool0oooo02d0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?oo
o`<0nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00>`3oool010000000oooo0?ooo`3oool300000180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo0`008]/C0?ooo`030000O`3oool0oooo
02d0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo0`008]/C0?ooo`030000O`3oool0oooo
02d0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool3000000<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0
oooo0`0000060000O`<002;K@`0007l30?XN1@T0001o0`3j7PDG0000O`<0nQh5o`0007m70000O`<0
02;K1P0007l4000003H0oooo000k0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool3000Rfa<0oooo00<0001o0?ooo`3oool0;@3oool30?XN1@T0oooo0`3j7PD70?ooo`030000
O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000
003oool0oooo03@0oooo001D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`<002;K4`3oool00`0007l0oooo0?ooo`0]0?ooo`<0nQh52@3o
ool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo0`008]/C0?ooo`030000O`3oool0
oooo02d0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool50000
01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo0`008]/C0?ooo`030000O`3oool0oooo02d0oooo0`3j7PD90?ooo`<0nQh51`3oool00`00
07l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0140oooo1000000:0?ooo`030000003oool0oooo00H0oooo0`008]/C0?ooo`030000O`3oool0oooo
02d0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool3000R
fa<0oooo00<0001o0?ooo`3oool02@3oool5000001l0oooo0`3j7PD90?ooo`<0nQh51`3oool00`00
07l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
01l0oooo0P0000070?ooo`<002;K4`3oool00`0007l0oooo0?ooo`070?ooo`<00000103oool30000
01`0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`<002;K1`3oool3000003H0oooo000l0?ooo`<0000000<0oooo0000003o
ool08@3oool00`000000oooo0?ooo`060?ooo`<002;K4`3oool00`0007l0oooo0?ooo`050?ooo`80
00002P3oool00`000000oooo0?ooo`0I0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3o
ool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool006<0oooo00<000000?ooo`3oool01P3oool3000Rfa<0oooo00<0001o0?ooo`3oool0
0`3oool2000000d0oooo00<000000?ooo`3oool0603oool30?XN1@T0oooo0`3j7PD70?ooo`030000
O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000
003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo00H0oooo0`008]/C0?ooo`030000O`3o
ool0oooo0080oooo00<000000?ooo`3oool03P3oool2000001P0oooo0`3j7PD90?ooo`<0nQh51`3o
ool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`060?ooo`<002;K4`3oool0
1@0007l0oooo0?ooo`3oool0000001<0oooo0P00000F0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0
001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool01P3oool3000Rfa<0oooo00@0001o
0?ooo`3oool000005P3oool00`000000oooo0?ooo`0C0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0
001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool003T0oooo3000000N0?ooo`030000003oool0oooo00H0oooo0`008]/C
0?ooo`030000O`3oool0000001P0oooo00<000000?ooo`3oool04P3oool30?XN1@T0oooo0`3j7PD7
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/9
0?ooo`030000003oool0oooo03@0oooo000i0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0703oool2000000L0oooo0`008]/C0?ooo`030000O`000000oooo01T0oooo00<000000?oo
o`3oool04@3oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?oo
o`030000O`3oool0oooo03l0oooo5P00000c0?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool3000Rf`L0oooo0`00000f0?ooo`00>@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool3000Rfa80oooo0P00000L0?ooo`03
0000003oool0oooo0100oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0
nQh5<P3oool00`0007l0oooo0?ooo`0h0?ooo`L000000`3oool00`0007l0oooo0?ooo`0@0?ooo`L0
0000;03oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`03
0000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo00H0oooo0`008]/A0?ooo`030000
003oool0001o01d0oooo0P00000@0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C80oooo00<0001o0?ooo`3oool0=@3oool3000000X0oooo00<0001o0?ooo`3oool0
5`3oool4000002P0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`060?ooo`<002;K403o
ool010000000oooo0?ooo`0007lO0?ooo`030000003oool0oooo00d0oooo0`3j7PD90?ooo`<0nQh5
1`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`0`0?ooo`D00000
3@3oool00`0007l0oooo0?ooo`0K0?ooo`@00000903oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`L000008@3o
ool00`000000oooo0?ooo`060?ooo`<002;K3`3oool01@000000oooo0?ooo`3oool0001o0200oooo
00<000000?ooo`3oool0303oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo
0`3j7PDb0?ooo`030000O`3oool0oooo02`0oooo1000000B0?ooo`030000O`3oool0oooo01l0oooo
0`00000Q0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool003`0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`060?ooo`<002;K3P3oool00`000000oooo0?ooo`020?ooo`030000O`3oool0oooo01l0oooo00<0
00000?ooo`3oool02`3oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j
7PDb0?ooo`030000O`3oool0oooo02X0oooo0P00000F0?ooo`030000O`3oool0oooo0280oooo1000
000M0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`06
0?ooo`<002;K3@3oool00`000000oooo0?ooo`030?ooo`030000O`3oool0oooo0200oooo00<00000
0?ooo`3oool02P3oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb
0?ooo`030000O`3oool0oooo02L0oooo0`00000H0?ooo`030000O`3oool0oooo02H0oooo0`00000J
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<00000
0?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool09@3oool2000000L0oooo0`008]/;0?oo
o`8000001P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000003oool0oooo00T0oooo0`3j7PD90?oo
o`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`0T0?oo
o`<000006`3oool00`0007l0oooo0?ooo`0Y0?ooo`<000005`3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0440oooo0`008]/70?ooo`<00000=P3oool003`0oooo1P00000Q0?ooo`03
0000003oool0oooo00H0oooo0`008]/:0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3o
ool08P3oool00`000000oooo0?ooo`080?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3o
ool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool08@3oool3000001h0oooo00<0001o0?ooo`3o
ool0;03oool3000001@0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00H0oooo0`008]/90?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0
8`3oool00`000000oooo0?ooo`070?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C80oooo00<0001o0?ooo`3oool07P3oool300000240oooo00<0001o0?ooo`3oool0
;`3oool300000140oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00H0oooo0`008]/80?ooo`030000003oool0oooo00P0oooo00<0001o0?ooo`3oool0903o
ool00`000000oooo0?ooo`060?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3o
ool30?XN1C80oooo00<0001o0?ooo`3oool06`3oool3000002@0oooo00<0001o0?ooo`3oool0<P3o
ool3000000h0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00H0oooo0`008]/70?ooo`030000003oool0oooo00T0oooo00<0001o0?ooo`3oool09@3oool0
0`000000oooo0?ooo`050?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool3
0?XN1C80oooo00<0001o0?ooo`3oool0603oool3000002L0oooo00<0001o0?ooo`3oool0=@3oool3
000000/0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0d0?ooo`00?03oool600000240oooo00<000000?ooo`3oool01P3oool3000R
f`H0oooo00<000000?ooo`3oool02P3oool00`0007l0oooo0?ooo`0V0?ooo`030000003oool0oooo
00@0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`00
07l0oooo0?ooo`0D0?ooo`@00000:P3oool00`0007l0oooo0?ooo`0h0?ooo`<00000203oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo001S0?ooo`030000003oool0oooo00H0oooo0`008]/50?ooo`030000003oool0oooo00/0
oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`030?ooo`<0nQh52@3oool30?XN1@L0
oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool04@3oool3000002h0
oooo00<0001o0?ooo`3oool0>`3oool2000000H0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000000L0oooo
0`008]/40?ooo`030000003oool0oooo00`0oooo00<0001o0?ooo`3oool0:03oool00`000000oooo
0?ooo`020?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo
00<0001o0?ooo`3oool03`3oool200000340oooo00<0001o0?ooo`3oool0?@3oool3000000<0oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K1`3oool3000003H0oooo
000k0?ooo`L000008@3oool00`000000oooo0?ooo`060?ooo`<002;K0P3oool2000000l0oooo00<0
001o0?ooo`3oool0:@3oool010000000oooo0?ooo`3oool30?XN1@T0oooo0`3j7PD70?ooo`030000
O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo00`0oooo0`00000c0?ooo`030000
O`3oool0oooo0400oooo0P0000000`3oool0001o0?ooo`130?ooo`030000O`3oool0oooo0440oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool01P3oool3000Rf`030?ooo`000000oooo0100oooo00<0001o0?ooo`3oool0:P3o
ool00`000000oooo0?ooo`030?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j
7PDb0?ooo`030000O`3oool0oooo00X0oooo0P00000f0?ooo`030000O`3oool0oooo0480oooo0`00
00130?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`06
0?ooo`<002;K00<000000?ooo`3oool0403oool00`0007l0oooo0?ooo`0[0?ooo`030000003oool0
nQh50080nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o
0?ooo`3oool01`3oool3000003P0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo00000002
00000400oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
03/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00H0oooo0P008]/00`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo02`0oooo00@000000?XN
1@3j7PD0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o
0?ooo`3oool0103oool3000003/0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`02
0?ooo`800000?P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00?03oool6000001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?oo
o`03000Rf`00000002;K01<0oooo00<0001o0?ooo`3oool0;@3oool00`000000nQh50?XN1@090?oo
o`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`020?oo
o`800000?P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo00@0oooo0`00000k0?oo
o`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`<0
02;K4`3oool00`0007l0oooo0?ooo`0]0?ooo`030?XN1@000000nQh500T0oooo0`3j7PD70?ooo`03
0000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0000000800000@03oool00`0007l0
oooo0?ooo`130?ooo`030000O`3oool0oooo00L0oooo0P00000i0?ooo`030000O`3oool0oooo0440
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool02@3oool3000004h0001o00<000000000O`0007l01`0007l30?XN1AL0001o
0`3j7PDb0000O`800000U@0007l2000007/0001o0`008]/60000O`@00000=P3oool003/0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01`0oooo00<0
001o0?ooo`3oool0<03oool00`000000oooo0?ooo`060?ooo`<0nQh51`3oool00`0007l0oooo0?oo
o`0=0?ooo`<0nQh5;`3oool3000000030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3o
ool00`0007l0oooo0?ooo`0;0?ooo`<00000=03oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00?03oool6000001D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo0340oooo00<000000?ooo`3oool01@3oool3
0?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1Bd0oooo0P0000030?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0>0?ooo`800000<P3oool0
0`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E@3oool00`00
0000oooo0000000;0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0<P3oool00`00
0000oooo0?ooo`040?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5:P3oool30000
00D0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo
0100oooo0`00000_0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo001F0?ooo`8000002`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo0380
oooo00<000000?ooo`3oool0103oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1BL0
oooo0`0000080?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`0C0?ooo`800000;@3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00>@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo03<0oooo
00<000000?ooo`3oool00`3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1BD0oooo
0P00000;0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`0E0?ooo`800000:`3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00>@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0703oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo0080oooo0`3j
7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDR0?ooo`<000003@3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool05`3oool3000002P0oooo00<0
001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003T0oooo3000000N
0?ooo`8000007@3oool00`0007l0oooo0?ooo`0e0?ooo`040000003oool0oooo0?ooo`<0nQh51`3o
ool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5803oool200000100oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo01X0oooo0P00000V0?ooo`030000O`3o
ool0oooo0440oooo0`008]/70?ooo`<00000=P3oool006<0oooo00<000000?ooo`3oool0703oool0
0`0007l0oooo0?ooo`0f0?ooo`030000003oool0oooo00<0nQh51`3oool00`0007l0oooo0?ooo`0=
0?ooo`<0nQh57P3oool200000180oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo01`0oooo0`00000S0?ooo`030000O`3oool0oooo0440oooo0`008]/9
0?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?oo
o`3oool0=P3oool00`000000oooo0?ooo`030?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN
1A/0oooo0`00000D0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`0O0?ooo`8000008@3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo03L0
oooo00<000000?ooo`3j7PD00P3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDI0?ooo`80
00005`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3o
ool08@3oool2000001l0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`0h0?ooo`040000
003j7PD0nQh50?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1AH0oooo0`00000I0?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0S0?ooo`<0
0000703oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo03T0oooo00<000000?XN1@3j7PD0
1`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5503oool2000001`0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo02H0oooo0P00000J0?ooo`030000
O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003o
ool0oooo01`0oooo00<0001o0?ooo`3oool0>@3oool00`000000nQh50?XN1@070?ooo`030000O`3o
ool0oooo00d0oooo0`3j7PDB0?ooo`8000007P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0:03oool3000001L0oooo00<0001o0?ooo`3oool0@@3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo0P00000M0?ooo`030000O`3oool0
oooo03T0oooo00@0nQh500000000000000001P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh53`3o
ool300000200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3o
ool0oooo02/0oooo0`00000D0?ooo`030000O`3oool0oooo0440oooo0`008]/70?ooo`<00000=P3o
ool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`0i0?ooo`<0nQh500<0oooo
0000000000000P0000020?ooo`030000O`3oool0oooo00d0oooo0`3j7PD=0?ooo`8000008`3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0;P3oool2
00000180oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
06<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`110?ooo`@000003P3oool30?XN
1@/0oooo0P00000U0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`0`0?ooo`<000003`3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`0000000P00000;0?ooo`<0nQh52@3oool2000002L0oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo03<0oooo0`00000<0?ooo`03
0000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000
003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`020?ooo`<00000
203oool30?XN1@H0oooo0`00000Y0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@`3oool00`0007l0oooo0?ooo`0f0?ooo`8000002P3oool00`0007l0oooo0?ooo`110?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool01@3oool2000000H0oooo0`3j7PD20?ooo`@00000;03o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0>03o
ool3000000L0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo00L0oooo100000020?ooo`<0nQh50P00000`0?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0k0?ooo`<00000103oool00`0007l0oooo0?ooo`11
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000001d0oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`0;0?ooo`D00000<P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0?P3oool200000080oooo00<0001o0?oo
o`3oool0@@3oool3000Rf`L0oooo0`00000f0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0400oooo0P0000000`0007l0
oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo
0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool200000480oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0
001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0000000800000?`3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool00P3oool2
000003d0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo
01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
00@0oooo0P00000k0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000
oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`060?ooo`800000>@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo
0P00000M0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`080?ooo`<00000=P3oool3000Rf`L0oooo0`00000f0?ooo`00H`3oool00`000000oooo0?oo
o`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`0;0?ooo`800000=03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<00000
0?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool03@3oool200000380oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001D0?oo
o`H000002@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`0?0?ooo`<00000;`3oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool005D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0B0?ooo`80
0000;@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005H0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`0D0?ooo`<00000:P3oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool005L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0G0?ooo`800000:03o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005P0oooo00<000000?ooo`3oool0203oool3
00000?l0001oU00007l2000002H0001o0`008]/60000O`@00000=P3oool005T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`0K0?ooo`<000008`3oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool005T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0N0?ooo`80
00008@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`0P0?ooo`8000007`3oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool005@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0280oooo0P00000M0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E@3oool4
000000X0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0903oool3000001X0oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo02L0oooo0P00000H0?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool2000001d0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo02T0oooo0P00000F0?ooo`<002;K1`3oool3000003H0
oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo02/0oooo0P00000D0?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0]0?ooo`<000004@3oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0<03oool2000000l0oooo0`008]/9
0?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0380oooo0`00000<0?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0e0?ooo`80
00002P3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0
703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
=`3oool3000000L0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`8000007@3o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0>P3o
ool3000000@0oooo0`008]/70?ooo`<00000=P3oool006<0oooo00<000000?ooo`3oool0703oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0?@3oool2
00000080oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo
01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
03l0oooo0P000003000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3o
ool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool200000003000Rf`3oool0oooo00L0oooo00<000000?ooo`3oool0=03oool006<0oooo
00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03@0oooo001S
0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0=03oool006<0ooooo`00003<000003H0oooo003o0?oo
ool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3o
ool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo
o`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo9@3oool60000
00@0oooo0`0000040?ooo`80000000D0oooo0000003oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0`00
00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0oooo0`00003j0?ooo`00
o`3ooolU0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool010000000
oooo0?ooo`0000020?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3o
ool0oooo0000003i0?ooo`00o`3ooolU0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0?/0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`05000000<0oooo100000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool500000?T0oooo
003o0?ooobD0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool00000
00D0oooo1P0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000003i0?ooo`00
o`3ooolU0?ooo`H000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo008000000P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo0?L0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`3oool3000000@0oooo0`0000030?ooo`040000003oool0000000000080oooo0P0000060?ooo`03
0000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`<000000P3oool3
000000050?ooo`000000oooo0?ooo`0000000`3oool300000?X0oooo003o0?ooobD0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?h0oooo003o0?oo
obD0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0?h0oooo003o0?ooobD0oooo1P00000O0?ooo`H000003`3oool300000080oooo00<000000?ooo`3o
ool0oP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo0000\
\>"],
  ImageRangeCache->{{{57.1875, 546.25}, {372, 177}} -> {-3.92318, 2.60192, \
0.0144452, 0.0285337}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input Beam Profile (Y-Arm of Michelson)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TelescopePlot[{zETM - MichelsonAsymmetry/2, 5.0}, {CavityWaist, 
          zCavityWaist - MichelsonAsymmetry/2}, {{ITMFocalLength, 
            zITM - MichelsonAsymmetry/2}, {fLY, zLY}, {fL1, zL1}}, 
        kk];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.232143 0.14881 0.2 0.0732447 [
[.08333 -0.0125 -10.0938 -16.375 ]
[.08333 -0.0125 10.0938 0 ]
[.23214 -0.0125 -5.59375 -16.375 ]
[.23214 -0.0125 5.59375 0 ]
[.38095 -0.0125 -5.59375 -16.375 ]
[.38095 -0.0125 5.59375 0 ]
[.52976 -0.0125 -5.59375 -16.375 ]
[.52976 -0.0125 5.59375 0 ]
[.67857 -0.0125 -5.59375 -16.375 ]
[.67857 -0.0125 5.59375 0 ]
[.82738 -0.0125 -5.59375 -16.375 ]
[.82738 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -16.375 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -43.1563 -32.75 ]
[.5 -0.0125 43.1563 -16.375 ]
[-0.0125 .05351 -20.1875 -8.1875 ]
[-0.0125 .05351 0 8.1875 ]
[-0.0125 .12676 -20.1875 -8.1875 ]
[-0.0125 .12676 0 8.1875 ]
[-0.0125 .2 -11.1875 -8.1875 ]
[-0.0125 .2 0 8.1875 ]
[-0.0125 .27324 -11.1875 -8.1875 ]
[-0.0125 .27324 0 8.1875 ]
[-0.0125 .34649 -11.1875 -8.1875 ]
[-0.0125 .34649 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .2 -36.5625 -44.3438 ]
[-0.01875 .2 -20.1875 44.3438 ]
[ 0 .4 .125 0 ]
[.5 .4125 -39 0 ]
[.5 .4125 39 16.375 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .4 L
s
.23214 0 m
.23214 .4 L
s
.38095 0 m
.38095 .4 L
s
.52976 0 m
.52976 .4 L
s
.67857 0 m
.67857 .4 L
s
.82738 0 m
.82738 .4 L
s
0 .05351 m
1 .05351 L
s
0 .12676 m
1 .12676 L
s
0 .2 m
1 .2 L
s
0 .27324 m
1 .27324 L
s
0 .34649 m
1 .34649 L
s
0 g
.08333 0 m
.08333 .00625 L
s
gsave
.08333 -0.0125 -71.0938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.23214 0 m
.23214 .00625 L
s
gsave
.23214 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.52976 0 m
.52976 .00625 L
s
gsave
.52976 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.67857 0 m
.67857 .00625 L
s
gsave
.67857 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.82738 0 m
.82738 .00625 L
s
gsave
.82738 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.17262 0 m
.17262 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.35119 0 m
.35119 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.47024 0 m
.47024 .00375 L
s
.5 0 m
.5 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.64881 0 m
.64881 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76786 0 m
.76786 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94643 0 m
.94643 .00375 L
s
.05357 0 m
.05357 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -104.156 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.438 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.875 16.625 moveto
(@) show
130.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
141.000 16.625 moveto
(D) show
145.313 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05351 m
.00625 .05351 L
s
gsave
-0.0125 .05351 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .12676 m
.00625 .12676 L
s
gsave
-0.0125 .12676 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
gsave
-0.0125 .2 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .27324 m
.00625 .27324 L
s
gsave
-0.0125 .27324 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .34649 m
.00625 .34649 L
s
gsave
-0.0125 .34649 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06816 m
.00375 .06816 L
s
0 .08281 m
.00375 .08281 L
s
0 .09746 m
.00375 .09746 L
s
0 .11211 m
.00375 .11211 L
s
0 .1414 m
.00375 .1414 L
s
0 .15605 m
.00375 .15605 L
s
0 .1707 m
.00375 .1707 L
s
0 .18535 m
.00375 .18535 L
s
0 .21465 m
.00375 .21465 L
s
0 .2293 m
.00375 .2293 L
s
0 .24395 m
.00375 .24395 L
s
0 .2586 m
.00375 .2586 L
s
0 .28789 m
.00375 .28789 L
s
0 .30254 m
.00375 .30254 L
s
0 .31719 m
.00375 .31719 L
s
0 .33184 m
.00375 .33184 L
s
0 .03886 m
.00375 .03886 L
s
0 .02421 m
.00375 .02421 L
s
0 .00956 m
.00375 .00956 L
s
0 .36114 m
.00375 .36114 L
s
0 .37579 m
.00375 .37579 L
s
0 .39044 m
.00375 .39044 L
s
.25 Mabswid
0 0 m
0 .4 L
s
gsave
-0.01875 .2 -133.719 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
105.344 12.1875 translate
90 rotate
-105.344 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(spot) show
90.938 16.625 moveto
(size) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.438 16.625 moveto
(@) show
121.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
143.375 16.625 moveto
(D) show
147.688 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .39375 m
.08333 .4 L
s
.23214 .39375 m
.23214 .4 L
s
.38095 .39375 m
.38095 .4 L
s
.52976 .39375 m
.52976 .4 L
s
.67857 .39375 m
.67857 .4 L
s
.82738 .39375 m
.82738 .4 L
s
.97619 .39375 m
.97619 .4 L
s
.125 Mabswid
.1131 .39625 m
.1131 .4 L
s
.14286 .39625 m
.14286 .4 L
s
.17262 .39625 m
.17262 .4 L
s
.20238 .39625 m
.20238 .4 L
s
.2619 .39625 m
.2619 .4 L
s
.29167 .39625 m
.29167 .4 L
s
.32143 .39625 m
.32143 .4 L
s
.35119 .39625 m
.35119 .4 L
s
.41071 .39625 m
.41071 .4 L
s
.44048 .39625 m
.44048 .4 L
s
.47024 .39625 m
.47024 .4 L
s
.5 .39625 m
.5 .4 L
s
.55952 .39625 m
.55952 .4 L
s
.58929 .39625 m
.58929 .4 L
s
.61905 .39625 m
.61905 .4 L
s
.64881 .39625 m
.64881 .4 L
s
.70833 .39625 m
.70833 .4 L
s
.7381 .39625 m
.7381 .4 L
s
.76786 .39625 m
.76786 .4 L
s
.79762 .39625 m
.79762 .4 L
s
.85714 .39625 m
.85714 .4 L
s
.8869 .39625 m
.8869 .4 L
s
.91667 .39625 m
.91667 .4 L
s
.94643 .39625 m
.94643 .4 L
s
.05357 .39625 m
.05357 .4 L
s
.02381 .39625 m
.02381 .4 L
s
.25 Mabswid
0 .4 m
1 .4 L
s
gsave
.5 .4125 -100 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
100.375 16.625 moveto
(Profile) show
137.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .05351 m
1 .05351 L
s
.99375 .12676 m
1 .12676 L
s
.99375 .2 m
1 .2 L
s
.99375 .27324 m
1 .27324 L
s
.99375 .34649 m
1 .34649 L
s
.125 Mabswid
.99625 .06816 m
1 .06816 L
s
.99625 .08281 m
1 .08281 L
s
.99625 .09746 m
1 .09746 L
s
.99625 .11211 m
1 .11211 L
s
.99625 .1414 m
1 .1414 L
s
.99625 .15605 m
1 .15605 L
s
.99625 .1707 m
1 .1707 L
s
.99625 .18535 m
1 .18535 L
s
.99625 .21465 m
1 .21465 L
s
.99625 .2293 m
1 .2293 L
s
.99625 .24395 m
1 .24395 L
s
.99625 .2586 m
1 .2586 L
s
.99625 .28789 m
1 .28789 L
s
.99625 .30254 m
1 .30254 L
s
.99625 .31719 m
1 .31719 L
s
.99625 .33184 m
1 .33184 L
s
.99625 .03886 m
1 .03886 L
s
.99625 .02421 m
1 .02421 L
s
.99625 .00956 m
1 .00956 L
s
.99625 .36114 m
1 .36114 L
s
.99625 .37579 m
1 .37579 L
s
.99625 .39044 m
1 .39044 L
s
.25 Mabswid
1 0 m
1 .4 L
s
.977 .121 .023 r
.0075 w
.17262 .13127 m
.17262 .26873 L
s
.19836 .09802 m
.19836 .30198 L
s
.26935 .07728 m
.26935 .32272 L
s
0 .133 .859 r
.02381 .13127 m
.02381 .26873 L
s
.97619 .00952 m
.97619 .39048 L
s
0 g
.5 Mabswid
.02381 .26873 m
.04262 .25213 L
.06244 .23509 L
.07216 .22718 L
.0775 .2231 L
.08255 .21957 L
.08542 .21778 L
.08693 .21692 L
.08852 .21609 L
.08987 .21545 L
.09135 .21484 L
.092 .21461 L
.0927 .21438 L
.09396 .21402 L
.09466 .21386 L
.09532 .21373 L
.09603 .21362 L
.0968 .21354 L
.09753 .21349 L
.09822 .21348 L
.0995 .21353 L
.10077 .21368 L
.10194 .2139 L
.10322 .21422 L
.10387 .21442 L
.10458 .21466 L
.10588 .21516 L
.10709 .21569 L
.10982 .21709 L
.11223 .21852 L
.11478 .22017 L
.12409 .22704 L
.145 .24447 L
.18275 .2818 L
.19218 .29398 L
.19447 .29695 L
.19692 .30011 L
.19764 .30105 L
.19832 .30193 L
.1996 .30234 L
.2021 .30306 L
.21298 .30621 L
.22296 .30911 L
.24128 .31446 L
.25168 .31751 L
.25677 .31901 L
.26142 .32038 L
.26378 .32107 L
.26634 .32183 L
.26751 .32218 L
Mistroke
.26876 .32255 L
.26994 .32247 L
.27101 .32201 L
.2813 .31765 L
.30234 .30878 L
.34246 .292 L
.38106 .27616 L
.42212 .2599 L
.44258 .25219 L
.46166 .2454 L
.4812 .23906 L
.49081 .23627 L
.49968 .23395 L
.50946 .23174 L
.51461 .23075 L
.51724 .2303 L
.52008 .22985 L
.52246 .22951 L
.52463 .22923 L
.52685 .22897 L
.52891 .22876 L
.53118 .22855 L
.53238 .22846 L
.53365 .22837 L
.535 .22828 L
.53627 .22822 L
.53741 .22816 L
.53864 .22812 L
.53988 .22808 L
.54101 .22806 L
.54231 .22804 L
.54355 .22803 L
.54469 .22804 L
.54574 .22805 L
.5469 .22807 L
.54813 .2281 L
.54936 .22814 L
.55005 .22817 L
.55069 .2282 L
.55186 .22826 L
.55309 .22833 L
.55444 .22842 L
.5557 .22852 L
.55707 .22864 L
.55856 .22878 L
.5613 .22907 L
.56389 .22939 L
.56874 .23009 L
.57148 .23054 L
.57439 .23107 L
Mistroke
.57962 .23211 L
.58904 .2343 L
.59917 .23702 L
.61747 .24266 L
.65871 .25743 L
.69844 .27302 L
.73666 .28862 L
.77732 .30557 L
.81647 .3221 L
.85807 .33979 L
.89816 .35694 L
.93673 .37349 L
.97619 .39048 L
Mfstroke
.02381 .13127 m
.04262 .14787 L
.06244 .16491 L
.07216 .17282 L
.0775 .1769 L
.08255 .18043 L
.08542 .18222 L
.08693 .18308 L
.08852 .18391 L
.08987 .18455 L
.09135 .18516 L
.092 .18539 L
.0927 .18562 L
.09396 .18598 L
.09466 .18614 L
.09532 .18627 L
.09603 .18638 L
.0968 .18646 L
.09753 .18651 L
.09822 .18652 L
.0995 .18647 L
.10077 .18632 L
.10194 .1861 L
.10322 .18578 L
.10387 .18558 L
.10458 .18534 L
.10588 .18484 L
.10709 .18431 L
.10982 .18291 L
.11223 .18148 L
.11478 .17983 L
.12409 .17296 L
.145 .15553 L
.18275 .1182 L
.19218 .10602 L
.19447 .10305 L
.19692 .09989 L
.19764 .09895 L
.19832 .09807 L
.1996 .09766 L
.2021 .09694 L
.21298 .09379 L
.22296 .09089 L
.24128 .08554 L
.25168 .08249 L
.25677 .08099 L
.26142 .07962 L
.26378 .07893 L
.26634 .07817 L
.26751 .07782 L
Mistroke
.26876 .07745 L
.26994 .07753 L
.27101 .07799 L
.2813 .08235 L
.30234 .09122 L
.34246 .108 L
.38106 .12384 L
.42212 .1401 L
.44258 .14781 L
.46166 .1546 L
.4812 .16094 L
.49081 .16373 L
.49968 .16605 L
.50946 .16826 L
.51461 .16925 L
.51724 .1697 L
.52008 .17015 L
.52246 .17049 L
.52463 .17077 L
.52685 .17103 L
.52891 .17124 L
.53118 .17145 L
.53238 .17154 L
.53365 .17163 L
.535 .17172 L
.53627 .17178 L
.53741 .17184 L
.53864 .17188 L
.53988 .17192 L
.54101 .17194 L
.54231 .17196 L
.54355 .17197 L
.54469 .17196 L
.54574 .17195 L
.5469 .17193 L
.54813 .1719 L
.54936 .17186 L
.55005 .17183 L
.55069 .1718 L
.55186 .17174 L
.55309 .17167 L
.55444 .17158 L
.5557 .17148 L
.55707 .17136 L
.55856 .17122 L
.5613 .17093 L
.56389 .17061 L
.56874 .16991 L
.57148 .16946 L
.57439 .16893 L
Mistroke
.57962 .16789 L
.58904 .1657 L
.59917 .16298 L
.61747 .15734 L
.65871 .14257 L
.69844 .12698 L
.73666 .11138 L
.77732 .09443 L
.81647 .0779 L
.85807 .06021 L
.89816 .04306 L
.93673 .02651 L
.97619 .00952 L
Mfstroke
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{612.625, 245},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009T0000mB000`400?l00000o`00003oo`3ooooo
0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo;`3oool00`000000oooo0?ooo`0]0?ooo`<0
00003@3oool300000?<0oooo003o0?ooobl0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0?40oooo003o0?ooobl0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?40oooo003o0?ooob40oooo1@000009
0?ooo`040000003oool00000000000@0oooo0`0000040?ooo`<000000`3oool00`000000oooo0?oo
o`0200000080oooo00@000000?ooo`3oool0oooo0`0000030?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob80oooo00<000000?ooo`3o
ool02P3oool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000003
0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3a0?ooo`00o`3ooolR0?ooo`030000003oool0oooo00X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo0?oo
o`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0l@3o
ool00?l0oooo8`3oool010000000oooo0?ooo`3oool7000000030?ooo`000000oooo0080oooo00@0
00000?ooo`3oool000000`3oool010000000oooo0?ooo`3oool3000000<0oooo00@000000?ooo`3o
ool000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob@0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob@0oooo00<000000?ooo`3oool0203o
ool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3a0?ooo`00o`3ooolQ0?ooo`D000002@3oool010000000oooo0000000000040?ooo`<00000103o
ool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`040000003oool0oooo0?ooo`<00000
0`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0080oooo00@000000?ooo`00
000000000P3oool2000000D0oooo00<000000?ooo`3oool0l@3oool00?l0ooooA`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0l@3oool00?l0oooo
A`3oool00`000000oooo0?ooo`0E0?ooo`<000003@3oool300000?<0oooo003o0?oood@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooaP0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3o
oomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool008d0oooo00<000000?ooo`3o
ool0>P3oool4000004<0oooo00<000000?ooo`3oool0?P3oool6000003l0oooo100000130?ooo`03
0000003oool0oooo03l0oooo100000100?ooo`00S@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0m0?ooo`00S@3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0?03o
ool6000004@0oooo00<000000?ooo`3oool0?@3oool00880oooo1`0000040?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0m0?ooo`040000003oool0
oooo000004D0oooo00<000000?ooo`3oool0?@3oool008d0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo03d0oooo00@000000?ooo`3oool00000@03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo002=0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0?P3oool300000440oooo00<000000?ooo`000000@03oool5
00000400oooo002=0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool000000400oooo00<000000?ooo`3oool0@P3oool008/0
oooo00<000000?ooo`000000>`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`000000A@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03l0
oooo0P0000110?ooo`030000003oool0oooo0440oooo002<0?ooo`800000>`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03l0oooo0P0000100?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03l0oooo
0P0000110?ooo`030000003oool0oooo0440oooo002=0?ooo`030000003oool0oooo03X0oooo1000
00130?ooo`030000003oool0oooo03l0oooo100000100?ooo`@00000@`3oool00`000000oooo0?oo
o`0o0?ooo`D00000?`3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0
ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00H`3ooooo00000<`00000=P3oool006<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0400oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001S0?ooo`800000903oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@03oool200000003000Rf`3oool0oooo00D0oooo0`00000f0?oo
o`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`0n0?ooo`8000000`008]/90?ooo`030000003oool0oooo03@0
oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo03`0oooo0P0000020?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0j0?ooo`800000103oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0=`3oool3000000H0oooo0`008]/9
0?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03D0oooo0P0000090?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0c0?ooo`80
00002`3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo0P00000T0?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0a0?ooo`800000
3@3oool3000Rf`L0oooo0`00000f0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0^0?ooo`<000003`3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0;03oool2
00000180oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo
02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
02X0oooo0P00000D0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000
oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`0X0?ooo`8000005P3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo
00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool09@3oool3000001P0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo02<0oooo0P00000K0?ooo`<002;K2@3oool00`000000oooo0?oo
o`0d0?ooo`00H`3oool2000002@0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0240oooo0P00000M0?ooo`<002;K1`3oool3000003H0oooo001S0?oo
o`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo01l0oooo0P00000O0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`0L0?ooo`<000008@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool005@0oooo1P0000090?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo01X0oooo0P00000T0?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00E@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo01P0oooo0P00000V0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00EP3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo01H0oooo0P00000X0?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0d0?ooo`00C03oool7000000@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`0C0?ooo`<00000:P3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005P0
oooo00<000000?ooo`3oool0203oool300000?l0001oS@0007l2000002d0001o0`008]/60000O`@0
0000=P3oool005T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0?0?ooo`800000
;`3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`0=0?ooo`800000<@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool005T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0:0?ooo`<00000<`3oool3
000Rf`T0oooo00<000000?ooo`3oool0=03oool005@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo00P0oooo0P00000f0?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00E@3oool4000000X0oooo00<000000?ooo`3oool08`3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3oool2000003P0
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`800000903oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool00`3oool3000003X0oooo
0`008]/70?ooo`<00000=P3oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0440oooo00@0001o0?ooo`3oool0oooo0P00000m0?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool0100007l0000000000000000o0?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0400oooo0P0000120?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool03@3oool00`3j7PD000000?XN1@0a0?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0n0?ooo`80000000<0oooo
0000O`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?oo
o`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00X0oooo1`00000`0?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0k0?oo
o`<000000`3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0203oool2000000<0oooo0`3j7PD00`3oool000000000000^0?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0i0?ooo`8000001P3oool00`0007l0
oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000002@0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`040?ooo`@000001@3oool30?XN1@<0oooo
0`00000[0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`0f0?ooo`<00000203oool00`0007l0oooo0?ooo`100?ooo`<002;K1`3oool3000003H0oooo
001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`04000000T0oooo0`3j7PD60?ooo`800000:@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0=03oool2000000/0oooo00<0001o0?ooo`3oool0@03o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`000000000000d0oooo0`3j7PD80?ooo`8000009`3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0<@3oool3
000000d0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
06<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0o0?ooo`<000003`3oool30?XN
1@X0oooo0P00000U0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`0^0?ooo`<00000403oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo03/0
oooo100000020?ooo`030000O`3oool0oooo00d0oooo0`3j7PD<0?ooo`<000008P3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0;03oool2000001<0
oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo
00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0f0?ooo`D000001P3oool00`0007l0oooo
0?ooo`0=0?ooo`<0nQh53`3oool200000200oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo02T0oooo0`00000E0?ooo`030000O`3oool0oooo0400oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0
001o0?ooo`3oool0<@3oool20?XN1@<000002`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh54@3o
ool2000001h0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo02L0oooo0P00000H0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo001S0?ooo`800000903oool00`0007l0oooo0?ooo`0a0?ooo`80000000<0nQh5
0?ooo`3oool02`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh54`3oool3000001/0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo02D0oooo0P00000J
0?ooo`030000O`3oool0oooo0400oooo0`008]/70?ooo`<00000=P3oool006<0oooo00<000000?oo
o`3oool08`3oool00`0007l0oooo0?ooo`0a0?ooo`030000003j7PD0nQh500d0oooo00<0001o0?oo
o`3oool03@3oool30?XN1AH0oooo0P00000I0?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`0R0?ooo`<00000703oool00`0007l0oooo0?ooo`100?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`03
0000O`3oool0oooo0300oooo00@000000?XN1@3j7PD0nQh53@3oool00`0007l0oooo0?ooo`0=0?oo
o`<0nQh5603oool3000001H0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0200oooo0P00000O0?ooo`030000O`3oool0oooo0400oooo0`008]/90?oo
o`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3o
ool0;`3oool00`000000oooo0?XN1@020?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1A/0
oooo0P00000D0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`0M0?ooo`<000008@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo02l0oooo
00<000000?ooo`3j7PD00P3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDM0?ooo`800000
4P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
6`3oool2000002@0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0^0?ooo`030000003o
ool0oooo00<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh57`3oool3000000l0oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo01T0oooo0P00
000V0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l
0?ooo`8000000P3oool00`000000oooo0?ooo`0P0?ooo`800000903oool00`0007l0oooo0?ooo`0]
0?ooo`040000003oool0oooo0?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh58P3o
ool2000000d0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo01H0oooo0`00000X0?ooo`030000O`3oool0oooo0400oooo0`008]/70?ooo`<00000=P3o
ool003/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo02<0oooo00<0001o0?ooo`3oool0;03oool00`000000oooo0?ooo`020?ooo`<0nQh53@3o
ool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5903oool3000000X0oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo01@0oooo0P00000[0?ooo`030000O`3o
ool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3o
ool0oooo02/0oooo00<000000?ooo`3oool00`3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3o
ool30?XN1BL0oooo0P0000080?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`0A0?ooo`<00000;@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00@0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDY0?ooo`8000001P3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool03`3o
ool200000300oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool003`0oooo00<000000?ooo`3oool00P00000F0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool08`3oool00`0007l0oooo0?ooo`0Y0?ooo`030000003oool0oooo00D0oooo0`3j7PD=
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PD[0?ooo`<000000`3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool03@3oool200000380oooo00<0001o
0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005L0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo02P0oooo00<000000?oo
o`3oool01P3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1Bh0oooo0P0000000`3o
ool0001o0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool02P3oool30000
03@0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005L0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo02L0
oooo00<000000?ooo`3oool01`3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C00
oooo0`0000120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0203oool2000003L0
oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo
2P0000070?ooo`L00000103oool00`000000oooo0?ooo`090?ooo`<00000C00007l00`000000001o
0000O`080000O`<0nQh57@0007l30?XN1C<0001o0`00002<0000O`<00000O00007l3000Rf`H0001o
1000000f0?ooo`00?03oool01@000000oooo0?ooo`3oool0000001H0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`060?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0U0?ooo`030000
003j7PD0nQh500T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000
O`3oool0oooo0080oooo0P00000m0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
0`3oool2000003`0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool003/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`008]/00000000Rf`0J0?ooo`030000O`3o
ool0oooo02@0oooo00@000000?XN1@3j7PD0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C40oooo00<0001o0?ooo`3oool0103oool3000003X0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`03000003h0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool2000Rf`030000003o
ool0oooo01P0oooo00<0001o0?ooo`3oool08`3oool00`000000oooo0?XN1@020?XN1@T0oooo0`3j
7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo00L0oooo0`00
000g0?ooo`030000O`3oool0oooo0480oooo00<0001o000000000000@@3oool00`0007l0oooo0?oo
o`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool5000001@0oooo00<00000
0?ooo`0000002`3oool00`000000oooo0?ooo`060?ooo`<002;K00<000000?ooo`3oool05`3oool0
0`0007l0oooo0?ooo`0R0?ooo`030000003oool0oooo00<0nQh52@3oool30?XN1@d0oooo00<0001o
0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool02P3oool2000003D0oooo00<0001o
0?ooo`3oool0@03oool3000004<0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<00000
0?ooo`3oool0=03oool005H0oooo0P00000;0?ooo`030000003oool0oooo00H0oooo0`008]/00`3o
ool000000?ooo`0G0?ooo`030000O`3oool0oooo0240oooo00@000000?ooo`3oool0oooo0`3j7PD9
0?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool00`0007l0oooo0?ooo`0<
0?ooo`<00000<P3oool00`0007l0oooo0?ooo`0m0?ooo`<000000P3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001G0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool3000Rf`80oooo0P00000F0?oo
o`030000O`3oool0oooo0200oooo00<000000?ooo`3oool00P3oool30?XN1@T0oooo0`3j7PD=0?oo
o`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo00l0oooo0`00000_0?oo
o`030000O`3oool0oooo03/0oooo0P0000050?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003`0oooo1@00000R0?ooo`80
00001`3oool3000Rf`@0oooo00<000000?ooo`3oool04`3oool00`0007l0oooo0?ooo`0O0?ooo`03
0000003oool0oooo00<0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0
nQh5<@3oool00`0007l0oooo0?ooo`0B0?ooo`800000;@3oool00`0007l0oooo0?ooo`0h0?ooo`<0
00001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/70?ooo`<0
0000=P3oool003/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00H0oooo0`008]/50?ooo`030000003oool0oooo0180oooo00<0001o0?ooo`3oool0
7P3oool00`000000oooo0?ooo`040?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C40oooo00<0001o0?ooo`3oool0503oool3000002X0oooo00<0001o0?ooo`3oool0
=@3oool3000000X0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool01P3oool3000Rf`H0oooo00<000000?ooo`3oool04@3o
ool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo00D0oooo0`3j7PD90?ooo`<0nQh53@3o
ool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool00`0007l0oooo0?ooo`0G0?ooo`800000:03o
ool00`0007l0oooo0?ooo`0c0?ooo`8000003@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`<002;K1`3oool0
0`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo01`0oooo00<000000?ooo`3oool01P3oool3
0?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0
oooo01T0oooo0`00000U0?ooo`030000O`3oool0oooo0300oooo0`00000?0?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
03`0oooo1@00000R0?ooo`030000003oool0oooo00H0oooo0`008]/80?ooo`030000003oool0oooo
00l0oooo00<0001o0?ooo`3oool06`3oool00`000000oooo0?ooo`070?ooo`<0nQh52@3oool30?XN
1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0703oool20000
02<0oooo00<0001o0?ooo`3oool0;@3oool300000180oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000
oooo0?ooo`060?ooo`<002;K2@3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo01X0
oooo00<000000?ooo`3oool0203oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0
oooo0`3j7PDa0?ooo`030000O`3oool0oooo01h0oooo0`00000P0?ooo`030000O`3oool0oooo02/0
oooo0P00000E0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`060?ooo`<002;K2P3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo01T0oooo
00<000000?ooo`3oool02@3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo
0`3j7PDa0?ooo`030000O`3oool0oooo0240oooo0`00000M0?ooo`030000O`3oool0oooo02P0oooo
0`00000G0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool003T0oooo2@00000Q0?ooo`8000001`3oool3000Rf`/0oooo0P00
000=0?ooo`030000O`3oool0oooo01P0oooo00<000000?ooo`3oool02P3oool30?XN1@T0oooo0`3j
7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo02@0oooo0`00
000J0?ooo`030000O`3oool0oooo02D0oooo0`00000J0?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@03oool3000Rf`L0oooo0`00000f0?ooo`00>`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool3000Rf`d0oooo00<00000
0?ooo`3oool02P3oool00`0007l0oooo0?ooo`0F0?ooo`8000003@3oool30?XN1@T0oooo0`3j7PD=
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo02L0oooo0`00000G
0?ooo`030000O`3oool0oooo0280oooo0`00000M0?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?oo
o`3oool01P3oool3000Rf`h0oooo00<000000?ooo`3oool02@3oool00`0007l0oooo0?ooo`0E0?oo
o`030000003oool0oooo00d0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?oo
o`<0nQh5<@3oool00`0007l0oooo0?ooo`0Z0?ooo`@000004`3oool00`0007l0oooo0?ooo`0O0?oo
o`<00000803oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?oo
o`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo00H0oooo0`008]/?0?ooo`03
0000003oool0oooo00P0oooo00<0001o0?ooo`3oool0503oool00`000000oooo0?ooo`0>0?ooo`<0
nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3o
ool0;P3oool4000000l0oooo00<0001o0?ooo`3oool0703oool3000002<0oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
H`3oool00`000000oooo0?ooo`060?ooo`<002;K403oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo01<0oooo00<000000?ooo`3oool03`3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000
O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo0380oooo1000000;0?ooo`030000
O`3oool0oooo01L0oooo1@00000V0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool01P3o
ool3000Rfa40oooo0P0000070?ooo`030000O`3oool0oooo0140oooo0P00000B0?ooo`<0nQh52@3o
ool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0=P3o
ool4000000L0oooo00<0001o0?ooo`3oool04P3oool5000002/0oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2
000000L0oooo0`008]/C0?ooo`8000001@3oool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0
oooo0180oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool0
0`0007l0oooo0?ooo`0j0?ooo`P000003@3oool700000300oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`100?ooo`<002;K1`3oool3000003H0oooo000l0?ooo`8000000P3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00H0oooo0`008]/E0?ooo`030000003oool0oooo
0080oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`<0nQh52@3oool30?XN
1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`00
07l000000000000;000003L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool3000RfaH0oooo00D000000?oo
o`3oool0oooo0000O`0@0?ooo`030000003oool0oooo01@0oooo0`3j7PD90?ooo`<0nQh53@3oool0
0`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool01P3oool3000RfaL0oooo00@000000?ooo`3oool0001o3P3o
ool2000001L0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3o
ool3000RfaP0oooo00<000000?ooo`0007l03@3oool00`000000oooo0?ooo`0G0?ooo`<0nQh52@3o
ool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003`0oooo00<000000?ooo`3oool00P00000R
0?ooo`030000003oool0oooo00H0oooo0`008]/I0?ooo`030000000007l0oooo00/0oooo00<00000
0?ooo`3oool0603oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?oo
o`030000003oool0oooo00H0oooo0`008]/J0?ooo`<00000203oool2000001/0oooo0`3j7PD90?oo
o`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000000L0oooo0`008]/J0?ooo`03
0000O`3oool0oooo00P000007@3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0
oooo0`3j7PDa0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/70?ooo`<00000=P3oool003P0oooo
00<000000?ooo`3oool01`00000Q0?ooo`030000003oool0oooo00H0oooo0`008]/J0?ooo`030000
O`3oool0oooo00<0oooo0P00000P0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool006<0oooo00<000000?ooo`3oool01P3oool3000RfaX0oooo00<0001o0?ooo`3oool09@3o
ool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001E0?ooo`@000002P3oool0
0`000000oooo0?ooo`060?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0U0?ooo`<0nQh52@3oool3
0?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3
000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0U0?ooo`<0nQh52@3oool30?XN
1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00@000000?ooo`3oool0oooo0`00000B0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`<002;K6P3oool00`0007l0oooo0?ooo`0U0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?oo
o`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool003/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`<002;K6P3oool00`0007l0oooo0?ooo`0U0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?oo
o`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool003/0oooo0`0000030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`<000001P0007l3000Rfd80001o0`3j7PD90000O`<0
nQh57@0007l30?XN1Ol0001o@P0007l3000Rf`H0001o1000000f0?ooo`00>`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo0`008]/J0?ooo`030000O`3oool0oooo02D0oooo
0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool3000RfaX0oooo00<0
001o0?ooo`3oool09@3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j
7PDa0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001D
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0U0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o
0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<00000
0?ooo`3oool0=03oool003`0oooo1@00000C0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0U0?oo
o`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0A0?ooo`@000002P3oool00`000000oooo0?ooo`060?oo
o`<002;K6P3oool00`0007l0oooo0?ooo`0U0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?oo
o`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool003/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0O0?oo
o`8000001`3oool3000RfaX0oooo00<0001o0?ooo`3oool02000000M0?ooo`<0nQh52@3oool30?XN
1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000R
f`L0oooo0`00000f0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool01P3oool3000RfaX0oooo00@0001o00000000000000001P3oool2
000001`0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool30000
00030?ooo`000000oooo0240oooo00<000000?ooo`3oool01P3oool3000RfaX0oooo00<0001o0000
003oool02@3oool2000001X0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?oo
o`<0nQh5<@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00H`3oool00`000000oooo0?ooo`060?ooo`<002;K6@3oool2000000d0oooo00<000000?ooo`3o
ool05`3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000
003oool0oooo00H0oooo0`008]/G0?ooo`80000000<0oooo0000O`3oool03@3oool00`000000oooo
0?ooo`0F0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<0
00000?ooo`3oool01P3oool3000RfaH0oooo00D000000?ooo`3oool0oooo0000O`0?0?ooo`800000
5P3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003o
ool0oooo00H0oooo0`008]/E0?ooo`030000003oool0oooo0080oooo00<0001o0?ooo`3oool03`3o
ool00`000000oooo0?ooo`0C0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3o
ool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool003T0oooo3000000N0?ooo`8000001`3oool3000Rfa@0oooo00<000000?ooo`3oool00`3oool0
0`0007l0oooo0?ooo`0@0?ooo`030000003oool0oooo0180oooo0`3j7PD90?ooo`<0nQh53@3oool0
0`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool00`0007l0oooo0?ooo`0m0?oooaL00000<P3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/70?ooo`<00000=P3oool0
03T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00H0oooo0`008]/B0?ooo`8000001P3oool00`0007l0oooo0?ooo`0A0?ooo`8000004P3oool30?XN
1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo
03L0oooo1P0000040?ooo`030000O`3oool0oooo0100oooo1`00000[0?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003T0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0
oooo0`008]/A0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3oool04`3oool00`000000
oooo0?ooo`0?0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40
oooo00<0001o0?ooo`3oool0<`3oool4000000X0oooo00<0001o0?ooo`3oool05`3oool3000002P0
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`060?ooo`<002;K403oool00`000000oooo
0?ooo`070?ooo`030000O`3oool0oooo01@0oooo00<000000?ooo`3oool03P3oool30?XN1@T0oooo
0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo02l0oooo
1000000>0?ooo`030000O`3oool0oooo01X0oooo0P00000V0?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<0
00000?ooo`3oool01P3oool3000Rf`l0oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?oo
o`0E0?ooo`030000003oool0oooo00d0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?oo
o`0=0?ooo`<0nQh5<@3oool00`0007l0oooo0?ooo`0]0?ooo`8000004P3oool00`0007l0oooo0?oo
o`0L0?ooo`@000008P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`00
8]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`L000008@3oool00`000000oooo0?ooo`06
0?ooo`<002;K3P3oool00`000000oooo0?ooo`090?ooo`030000O`3oool0oooo01H0oooo0P00000=
0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o
0?ooo`3oool0:P3oool3000001@0oooo00<0001o0?ooo`3oool0803oool4000001h0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00?03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00H0oooo0`008]/=0?oo
o`030000003oool0oooo00X0oooo00<0001o0?ooo`3oool0603oool00`000000oooo0?ooo`0:0?oo
o`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?oo
o`3oool09`3oool3000001L0oooo00<0001o0?ooo`3oool0903oool4000001X0oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00>`3oool00`000000oooo0?ooo`0U0?ooo`8000001`3oool3000Rf`/0oooo0P00000=0?ooo`03
0000O`3oool0oooo01T0oooo00<000000?ooo`3oool02@3oool30?XN1@T0oooo0`3j7PD=0?ooo`03
0000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo02@0oooo0`00000J0?ooo`03
0000O`3oool0oooo02P0oooo0`00000G0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@03oool3000Rf`L0oooo0`00000f0?ooo`00>`3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00H0oooo0`008]/:0?ooo`030000003oool0oooo00d0oooo00<0001o0?ooo`3oool0
6P3oool00`000000oooo0?ooo`080?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C40oooo00<0001o0?ooo`3oool08@3oool3000001d0oooo00<0001o0?ooo`3oool0
:`3oool2000001D0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool600000240oooo00<000000?ooo`3oool01P3o
ool3000Rf`T0oooo00<000000?ooo`3oool03P3oool00`0007l0oooo0?ooo`0K0?ooo`030000003o
ool0oooo00L0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3o
ool00`0007l0oooo0?ooo`0O0?ooo`800000803oool00`0007l0oooo0?ooo`0]0?ooo`<000004P3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo000k0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01P3oool3
000Rf`P0oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`0L0?ooo`030000003oool0
oooo00H0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool0
0`0007l0oooo0?ooo`0L0?ooo`<000008P3oool00`0007l0oooo0?ooo`0`0?ooo`<000003`3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo000k0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01P3oool3000R
f`L0oooo00<000000?ooo`3oool0403oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo
00D0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool00`00
07l0oooo0?ooo`0I0?ooo`<000009@3oool00`0007l0oooo0?ooo`0c0?ooo`8000003@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo000k0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01P3oool3000Rf`H0
oooo00<000000?ooo`3oool04@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00@0
oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool00`0007l0
oooo0?ooo`0F0?ooo`<00000:03oool00`0007l0oooo0?ooo`0e0?ooo`<000002P3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0
oooo000l0?ooo`H000008@3oool00`000000oooo0?ooo`060?ooo`<002;K103oool2000001@0oooo
00<0001o0?ooo`3oool07`3oool00`000000oooo0?ooo`030?ooo`<0nQh52@3oool30?XN1@d0oooo
00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool04P3oool4000002/0oooo
00<0001o0?ooo`3oool0>03oool3000000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000000L0oooo0`00
8]/30?ooo`030000003oool0oooo01@0oooo00<0001o0?ooo`3oool0803oool00`000000oooo0?oo
o`020?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0
001o0?ooo`3oool03`3oool3000002l0oooo00<0001o0?ooo`3oool0>`3oool2000000D0oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K1`3oool3000003H0oooo001S
0?ooo`030000003oool0oooo00H0oooo0`008]/20?ooo`030000003oool0oooo01D0oooo00<0001o
0?ooo`3oool08@3oool010000000oooo0?ooo`3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3o
ool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo00d0oooo0P00000b0?ooo`030000O`3o
ool0oooo03d0oooo0`0000020?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo1`00000Q0?ooo`030000003oool0
oooo00H0oooo0`008]/2000001P0oooo00<0001o0?ooo`3oool08P3oool00`000000oooo0?ooo`03
0?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0
oooo00/0oooo0P00000d0?ooo`030000O`3oool0oooo0400oooo0P0000000`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?oo
o`8002;K00<000000?ooo`3oool0603oool00`0007l0oooo0?ooo`0S0?ooo`030000003oool0nQh5
0080nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?oo
o`3oool0203oool3000003H0oooo00<0001o0?ooo`3oool0@P3oool300000440oooo00<0001o0?oo
o`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<002;K00000000
8]/06P3oool00`0007l0oooo0?ooo`0T0?ooo`040000003j7PD0nQh50?XN1@T0oooo0`3j7PD=0?oo
o`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo00H0oooo0P00000i0?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool00`00000n0?ooo`030000O`3oool0oooo
0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`<002;K6P3oool00`0007l0
oooo0?ooo`0U0?ooo`030000003j7PD0nQh500T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0
oooo0`3j7PDa0?ooo`030000O`3oool0oooo00<0oooo0`00000k0?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool00`3oool2000003`0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool003`0oooo1P00000E0?ooo`030000003oool0oooo00T0oooo
0`00001<0000O`030000000007l0001o00P0001o0`3j7PDM0000O`<0nQh5=@0007l2000008/0001o
0`00001l0000O`<002;K1P0007l4000003H0oooo000k0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo02L0oooo00<0
00000?ooo`3oool01`3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00@0
001o0?ooo`0000000000@03oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo00P0oooo
0P00000g0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
000k0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0S0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool01P3oool30?XN1@d0oooo00<0
001o0?ooo`3oool03@3oool30?XN1C00oooo0`0000120?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool02P3oool3000003@0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0:@3oool00`000000oooo0?ooo`05
0?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5;P3oool2000000030?ooo`0007l0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0=0?ooo`800000<P3oool0
0`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool60000
01<0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo
02X0oooo00<000000?ooo`3oool0103oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN
1B/0oooo0`0000030?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`0?0?ooo`800000<03oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00EP3oool2000000/0oooo00<000000?ooo`3oool08`3oool00`0007l0
oooo0?ooo`0[0?ooo`030000003oool0oooo00<0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0
oooo0`3j7PDY0?ooo`8000001P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool04@3oool3000002d0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool005L0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0S0?ooo`030000O`3oool0oooo02`0oooo00<000000?ooo`3oool00P3oool30?XN1@d0oooo
00<0001o0?ooo`3oool03@3oool30?XN1BL0oooo0P0000080?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0D0?ooo`800000:`3oool00`0007l0oooo
0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo01`0oooo0P00000T0?ooo`030000O`3oool0oooo02`0oooo00<0
00000?ooo`3oool00P3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1B@0oooo0`00
000:0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`0F0?ooo`<00000:03oool00`0007l0oooo0?ooo`100?ooo`<002;K1`3oool3000003H0oooo000i
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0S
0?ooo`030000O`3oool0oooo02d0oooo00@000000?ooo`3oool0oooo0`3j7PD=0?ooo`030000O`3o
ool0oooo00d0oooo0`3j7PDR0?ooo`8000003@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool06@3oool2000002H0oooo00<0001o0?ooo`3oool0@03o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003T0oooo3000000N0?ooo`030000003oool0
oooo02<0oooo00<0001o0?ooo`3oool0;P3oool00`000000oooo0?ooo`030?XN1@d0oooo00<0001o
0?ooo`3oool03@3oool30?XN1Al0oooo0`00000?0?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0K0?ooo`800000903oool00`0007l0oooo0?ooo`10
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?oo
o`030000O`3oool0oooo02l0oooo00<000000?ooo`3j7PD00P3j7PD=0?ooo`030000O`3oool0oooo
00d0oooo0`3j7PDM0?ooo`8000004P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool07@3oool300000240oooo00<0001o0?ooo`3oool0@03oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0
oooo0?ooo`0`0?ooo`040000003j7PD0nQh50?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN
1A/0oooo0P00000D0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`0P0?ooo`8000007`3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0300
oooo00@000000?XN1@3j7PD0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5603oool30000
01H0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0280oooo0`00000L0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0<@3oool200000003
0?XN1@3oool0oooo00/0oooo00<0001o0?ooo`3oool03@3oool30?XN1AH0oooo0P00000I0?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0U0?ooo`80
00006P3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
H`3oool2000002@0oooo00<0001o0?ooo`3oool0<@3oool00`3j7PD0000000000002000000/0oooo
00<0001o0?ooo`3oool03@3oool30?XN1A<0oooo0`00000K0?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0W0?ooo`800000603oool00`0007l0oooo
0?ooo`100?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0
001o0?ooo`3oool0=P3oool4000000L0oooo00<0001o0?ooo`3oool03@3oool30?XN1A40oooo0P00
000N0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`0Y0?ooo`<000005@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?oo
o`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo03X0oooo0P000005
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PD?0?ooo`800000803oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0;03oool2000001<0oooo00<0001o
0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?oo
o`3oool08`3oool00`0007l0oooo0?ooo`0l0?ooo`<000000P3oool00`0007l0oooo0?ooo`0=0?oo
o`<0nQh5303oool300000280oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo02h0oooo0P00000A0?ooo`030000O`3oool0oooo0400oooo0`008]/90?oo
o`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3o
ool0?`3oool4000000h0oooo0`3j7PD:0?ooo`8000009@3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0<03oool2000000l0oooo00<0001o0?ooo`3o
ool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0
8`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0000000<000002P3oool30?XN1@P0oooo
0P00000W0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`0b0?ooo`<00000303oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00H`3oool2000002@0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`030?ooo`800000203oool30?XN1@H0oooo0P00000Y0?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0e0?ooo`8000002P3oool00`0007l0oooo0?oo
o`100?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`050?ooo`@00000103oool30?XN1@<0oooo0`00000[
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0g
0?ooo`800000203oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool02@3oool4000000<0nQh500<0oooo000000000000;P3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0>@3oool2000000H0oooo00<0001o0?oo
o`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3o
ool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00d0oooo1000000`0?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0k0?ooo`<0
00000`3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo03h0oooo0P0000000`3oool0001o0?ooo`110?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@03oool200000480oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S
0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`040000O`0000000000000003l0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S
0?ooo`800000903oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00@0001o
0?ooo`3oool0oooo0P00000m0?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000003oool0
oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo00<0oooo0`00000j0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`00
0000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`060?ooo`800000>03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005@0
oooo1P0000090?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo00P0oooo0P00000f0?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00E@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02<0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00X0oooo
0`00000c0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00EP3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo00d0oooo0P00000a0?ooo`<002;K2@3oool00`000000oooo0?oo
o`0d0?ooo`00E`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02<0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00l0oooo0P00000_
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00F03oool00`000000oooo0?ooo`080?oo
o`<00000o`0007n=0000O`800000;@0007l3000Rf`H0001o1000000f0?ooo`00F@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo01<0oooo0`00000Z0?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00F@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo01H0oooo
0P00000X0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00F@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo01P0oooo0P00000V0?ooo`<002;K2@3oool00`000000oooo0?oo
o`0d0?ooo`00E03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool06P3oool2000002@0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001E0?oo
o`@000002P3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`0L0?ooo`<000008@3oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool07`3oool2000001l0oooo0`008]/90?ooo`03
0000003oool0oooo03@0oooo001S0?ooo`800000903oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool08@3oool3000001`0oooo0`008]/70?ooo`<00000
=P3oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0903oool2000001X0oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo02H0oooo0`00000G0?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0Y0?ooo`<00000503oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0;03oool200000180
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo02h0oooo
0`00000?0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000002@0oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0340oooo0P00
000=0?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03<0oooo0P00000;
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0e0?oo
o`8000002@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3o
ool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0=`3oool3000000H0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000
003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo03X0oooo0P0000040?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3o
ool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`0l0?ooo`8000000P3oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0?P3oool2000000<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00H`3oool2000002@0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0400oooo0P0000000`008]/0oooo0?ooo`050?ooo`<00000=P3oool006<0
oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03@0oooo
001S0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=03oool006<0ooooo`00003<
000003H0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo
003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0
ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool0
0?l0oooo9@3oool6000000@0oooo0`0000040?ooo`80000000D0oooo0000003oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo0`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
oooo0`00003j0?ooo`00o`3ooolU0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00000`3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`050000003oool0
oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00D000000?ooo`3oool0oooo0000003i0?ooo`00o`3ooolU0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0?/0oooo003o0?ooobD0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`05000000<0oooo100000020?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool500000?T0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01@000000
oooo0?ooo`3oool0000000D0oooo1P0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0
oooo0000003i0?ooo`00o`3ooolU0?ooo`H000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000P3oool200000080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo008000000P3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0?L0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`3oool3000000@0oooo0`0000030?ooo`040000003oool0000000000080
oooo0P0000060?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`000002
0?ooo`<000000P3oool3000000050?ooo`000000oooo0?ooo`0000000`3oool300000?X0oooo003o
0?ooobD0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?h0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0?h0oooo003o0?ooobD0oooo1P00000O0?ooo`H000003`3oool300000080
oooo00<000000?ooo`3oool0oP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo0000
\
\>"],
  ImageRangeCache->{{{57.1875, 546.25}, {676.188, 481.188}} -> {-4.06481, \
14.0549, 0.0146745, 0.0298139}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

AS Port Beam\
\>", "Subtitle"],

Cell["\<\
The lens L2 is at the antisymmetric port just after the first turning mirror.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(zL2 = 0.25;\)\), "\[IndentingNewLine]", 
    \(\(fL2 = 1.146;\)\), "\[IndentingNewLine]", 
    \({WaistL2, 
        zWaistL2} = \[IndentingNewLine]Lensing[{WaistLXY, zWaistLXY}, {fL2, 
          zL2}, kk]\), "\[IndentingNewLine]", 
    \({WaistL2X, 
        zWaistL2X} = \[IndentingNewLine]Lensing[{WaistLX, zWaistLX}, {fL2, 
          zL2 - MichelsonAsymmetry/2}, kk]\), "\[IndentingNewLine]", 
    \({WaistL2Y, 
        zWaistL2Y} = \[IndentingNewLine]Lensing[{WaistLY, zWaistLY}, {fL2, 
          zL2 + MichelsonAsymmetry/2}, kk]\)}], "Input"],

Cell[BoxData[
    \({0.0003912413140230727`, 2.09677110503253`}\)], "Output"],

Cell[BoxData[
    \({0.00041081840501665045`, 2.059703757920612`}\)], "Output"],

Cell[BoxData[
    \({0.00037277920478146387`, 2.131825621456737`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Print["\<Focal Length of L2 Lens = \>", 
        fL2, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Position of L2 Lens (for optical path length) = \>", 
        zL2, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<True Position of L2 Lens = \>", 
        zL2 - BSAddedPathLength, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Size after L2 = \>", \ 
        1000\ WaistL2, \ "\< mm\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Position after L2 = \>", \ 
        zWaistL2, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Rayleigh Range after L2 = \>", 
        RayleighLength[WaistL2, 
          kk], \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Size after L2 (X arm Michelson) = \>", \ 
        1000\ WaistL2X, \ "\< mm\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Position after L2 (X arm Michelson) = \>", \ 
        zWaistL2X, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Rayleigh Range after L2 (X arm Michelson) = \>", 
        RayleighLength[WaistL2X, 
          kk], \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Size after L2 (Y arm Michelson) = \>", \ 
        1000\ WaistL2Y, \ "\< mm\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Position after L2 (Y arm Michelson) = \>", \ 
        zWaistL2Y, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Rayleigh Range after L2 (Y arm Michelson) = \>", 
        RayleighLength[WaistL2Y, kk], \ "\< m\>"];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Focal Length of L2 Lens = "\[InvisibleSpace]1.146`\
\[InvisibleSpace]" m"\),
      SequenceForm[ "Focal Length of L2 Lens = ", 1.1459999999999999, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Position of L2 Lens (for optical path length) = "\
\[InvisibleSpace]0.25`\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Position of L2 Lens (for optical path length) = ", .25, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("True Position of L2 Lens = \
"\[InvisibleSpace]0.23410141113180166`\[InvisibleSpace]" m"\),
      SequenceForm[ "True Position of L2 Lens = ", .23410141113180166, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Size after L2 = \
"\[InvisibleSpace]0.3912413140230727`\[InvisibleSpace]" mm"\),
      SequenceForm[ "Waist Size after L2 = ", .39124131402307272, " mm"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Position after L2 = \
"\[InvisibleSpace]2.09677110503253`\[InvisibleSpace]" m"\),
      SequenceForm[ "Waist Position after L2 = ", 2.0967711050325302, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Rayleigh Range after L2 = \
"\[InvisibleSpace]0.451957567405338`\[InvisibleSpace]" m"\),
      SequenceForm[ "Rayleigh Range after L2 = ", .45195756740533799, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Size after L2 (X arm Michelson) = "\
\[InvisibleSpace]0.41081840501665046`\[InvisibleSpace]" mm"\),
      SequenceForm[ 
      "Waist Size after L2 (X arm Michelson) = ", .41081840501665046, " mm"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Position after L2 (X arm Michelson) = "\
\[InvisibleSpace]2.059703757920612`\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Waist Position after L2 (X arm Michelson) = ", 2.0597037579206119, 
        " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Rayleigh Range after L2 (X arm Michelson) = "\
\[InvisibleSpace]0.49831966853362764`\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Rayleigh Range after L2 (X arm Michelson) = ", .49831966853362764, 
        " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Size after L2 (Y arm Michelson) = "\
\[InvisibleSpace]0.37277920478146387`\[InvisibleSpace]" mm"\),
      SequenceForm[ 
      "Waist Size after L2 (Y arm Michelson) = ", .37277920478146387, " mm"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Position after L2 (Y arm Michelson) = "\
\[InvisibleSpace]2.131825621456737`\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Waist Position after L2 (Y arm Michelson) = ", 2.1318256214567368, 
        " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Rayleigh Range after L2 (Y arm Michelson) = "\
\[InvisibleSpace]0.4103095259142547`\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Rayleigh Range after L2 (Y arm Michelson) = ", .41030952591425468, 
        " m"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AS Port Beam Profile (Average Michelson)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TelescopePlot[{zETM, 5.0}, {CavityWaist, 
          zCavityWaist}, {{ITMFocalLength, zITM}, {fLXY, zLXY}, {fL2, zL2}}, 
        kk];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.226284 0.149981 0.2 0.0748881 [
[.0763 -0.0125 -10.0938 -16.375 ]
[.0763 -0.0125 10.0938 0 ]
[.22628 -0.0125 -5.59375 -16.375 ]
[.22628 -0.0125 5.59375 0 ]
[.37627 -0.0125 -5.59375 -16.375 ]
[.37627 -0.0125 5.59375 0 ]
[.52625 -0.0125 -5.59375 -16.375 ]
[.52625 -0.0125 5.59375 0 ]
[.67623 -0.0125 -5.59375 -16.375 ]
[.67623 -0.0125 5.59375 0 ]
[.82621 -0.0125 -5.59375 -16.375 ]
[.82621 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -16.375 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -43.1563 -32.75 ]
[.5 -0.0125 43.1563 -16.375 ]
[-0.0125 .05022 -20.1875 -8.1875 ]
[-0.0125 .05022 0 8.1875 ]
[-0.0125 .12511 -20.1875 -8.1875 ]
[-0.0125 .12511 0 8.1875 ]
[-0.0125 .2 -11.1875 -8.1875 ]
[-0.0125 .2 0 8.1875 ]
[-0.0125 .27489 -11.1875 -8.1875 ]
[-0.0125 .27489 0 8.1875 ]
[-0.0125 .34978 -11.1875 -8.1875 ]
[-0.0125 .34978 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .2 -36.5625 -44.3438 ]
[-0.01875 .2 -20.1875 44.3438 ]
[ 0 .4 .125 0 ]
[.5 .4125 -39 0 ]
[.5 .4125 39 16.375 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.0763 0 m
.0763 .4 L
s
.22628 0 m
.22628 .4 L
s
.37627 0 m
.37627 .4 L
s
.52625 0 m
.52625 .4 L
s
.67623 0 m
.67623 .4 L
s
.82621 0 m
.82621 .4 L
s
0 .05022 m
1 .05022 L
s
0 .12511 m
1 .12511 L
s
0 .2 m
1 .2 L
s
0 .27489 m
1 .27489 L
s
0 .34978 m
1 .34978 L
s
0 g
.0763 0 m
.0763 .00625 L
s
gsave
.0763 -0.0125 -71.0938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22628 0 m
.22628 .00625 L
s
gsave
.22628 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.37627 0 m
.37627 .00625 L
s
gsave
.37627 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.52625 0 m
.52625 .00625 L
s
gsave
.52625 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.67623 0 m
.67623 .00625 L
s
gsave
.67623 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.82621 0 m
.82621 .00625 L
s
gsave
.82621 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.1063 0 m
.1063 .00375 L
s
.1363 0 m
.1363 .00375 L
s
.16629 0 m
.16629 .00375 L
s
.19629 0 m
.19629 .00375 L
s
.25628 0 m
.25628 .00375 L
s
.28628 0 m
.28628 .00375 L
s
.31627 0 m
.31627 .00375 L
s
.34627 0 m
.34627 .00375 L
s
.40626 0 m
.40626 .00375 L
s
.43626 0 m
.43626 .00375 L
s
.46625 0 m
.46625 .00375 L
s
.49625 0 m
.49625 .00375 L
s
.55624 0 m
.55624 .00375 L
s
.58624 0 m
.58624 .00375 L
s
.61624 0 m
.61624 .00375 L
s
.64623 0 m
.64623 .00375 L
s
.70622 0 m
.70622 .00375 L
s
.73622 0 m
.73622 .00375 L
s
.76622 0 m
.76622 .00375 L
s
.79621 0 m
.79621 .00375 L
s
.85621 0 m
.85621 .00375 L
s
.8862 0 m
.8862 .00375 L
s
.9162 0 m
.9162 .00375 L
s
.94619 0 m
.94619 .00375 L
s
.04631 0 m
.04631 .00375 L
s
.01631 0 m
.01631 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -104.156 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.438 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.875 16.625 moveto
(@) show
130.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
141.000 16.625 moveto
(D) show
145.313 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05022 m
.00625 .05022 L
s
gsave
-0.0125 .05022 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .12511 m
.00625 .12511 L
s
gsave
-0.0125 .12511 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
gsave
-0.0125 .2 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .27489 m
.00625 .27489 L
s
gsave
-0.0125 .27489 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .34978 m
.00625 .34978 L
s
gsave
-0.0125 .34978 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0652 m
.00375 .0652 L
s
0 .08018 m
.00375 .08018 L
s
0 .09516 m
.00375 .09516 L
s
0 .11013 m
.00375 .11013 L
s
0 .14009 m
.00375 .14009 L
s
0 .15507 m
.00375 .15507 L
s
0 .17004 m
.00375 .17004 L
s
0 .18502 m
.00375 .18502 L
s
0 .21498 m
.00375 .21498 L
s
0 .22996 m
.00375 .22996 L
s
0 .24493 m
.00375 .24493 L
s
0 .25991 m
.00375 .25991 L
s
0 .28987 m
.00375 .28987 L
s
0 .30484 m
.00375 .30484 L
s
0 .31982 m
.00375 .31982 L
s
0 .3348 m
.00375 .3348 L
s
0 .03525 m
.00375 .03525 L
s
0 .02027 m
.00375 .02027 L
s
0 .00529 m
.00375 .00529 L
s
0 .36475 m
.00375 .36475 L
s
0 .37973 m
.00375 .37973 L
s
0 .39471 m
.00375 .39471 L
s
.25 Mabswid
0 0 m
0 .4 L
s
gsave
-0.01875 .2 -133.719 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
105.344 12.1875 translate
90 rotate
-105.344 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(spot) show
90.938 16.625 moveto
(size) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.438 16.625 moveto
(@) show
121.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
143.375 16.625 moveto
(D) show
147.688 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.0763 .39375 m
.0763 .4 L
s
.22628 .39375 m
.22628 .4 L
s
.37627 .39375 m
.37627 .4 L
s
.52625 .39375 m
.52625 .4 L
s
.67623 .39375 m
.67623 .4 L
s
.82621 .39375 m
.82621 .4 L
s
.97619 .39375 m
.97619 .4 L
s
.125 Mabswid
.1063 .39625 m
.1063 .4 L
s
.1363 .39625 m
.1363 .4 L
s
.16629 .39625 m
.16629 .4 L
s
.19629 .39625 m
.19629 .4 L
s
.25628 .39625 m
.25628 .4 L
s
.28628 .39625 m
.28628 .4 L
s
.31627 .39625 m
.31627 .4 L
s
.34627 .39625 m
.34627 .4 L
s
.40626 .39625 m
.40626 .4 L
s
.43626 .39625 m
.43626 .4 L
s
.46625 .39625 m
.46625 .4 L
s
.49625 .39625 m
.49625 .4 L
s
.55624 .39625 m
.55624 .4 L
s
.58624 .39625 m
.58624 .4 L
s
.61624 .39625 m
.61624 .4 L
s
.64623 .39625 m
.64623 .4 L
s
.70622 .39625 m
.70622 .4 L
s
.73622 .39625 m
.73622 .4 L
s
.76622 .39625 m
.76622 .4 L
s
.79621 .39625 m
.79621 .4 L
s
.85621 .39625 m
.85621 .4 L
s
.8862 .39625 m
.8862 .4 L
s
.9162 .39625 m
.9162 .4 L
s
.94619 .39625 m
.94619 .4 L
s
.04631 .39625 m
.04631 .4 L
s
.01631 .39625 m
.01631 .4 L
s
.25 Mabswid
0 .4 m
1 .4 L
s
gsave
.5 .4125 -100 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
100.375 16.625 moveto
(Profile) show
137.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .05022 m
1 .05022 L
s
.99375 .12511 m
1 .12511 L
s
.99375 .2 m
1 .2 L
s
.99375 .27489 m
1 .27489 L
s
.99375 .34978 m
1 .34978 L
s
.125 Mabswid
.99625 .0652 m
1 .0652 L
s
.99625 .08018 m
1 .08018 L
s
.99625 .09516 m
1 .09516 L
s
.99625 .11013 m
1 .11013 L
s
.99625 .14009 m
1 .14009 L
s
.99625 .15507 m
1 .15507 L
s
.99625 .17004 m
1 .17004 L
s
.99625 .18502 m
1 .18502 L
s
.99625 .21498 m
1 .21498 L
s
.99625 .22996 m
1 .22996 L
s
.99625 .24493 m
1 .24493 L
s
.99625 .25991 m
1 .25991 L
s
.99625 .28987 m
1 .28987 L
s
.99625 .30484 m
1 .30484 L
s
.99625 .31982 m
1 .31982 L
s
.99625 .3348 m
1 .3348 L
s
.99625 .03525 m
1 .03525 L
s
.99625 .02027 m
1 .02027 L
s
.99625 .00529 m
1 .00529 L
s
.99625 .36475 m
1 .36475 L
s
.99625 .37973 m
1 .37973 L
s
.99625 .39471 m
1 .39471 L
s
.25 Mabswid
1 0 m
1 .4 L
s
.977 .121 .023 r
.0075 w
.17379 .12973 m
.17379 .27027 L
s
.19989 .09553 m
.19989 .30447 L
s
.26378 .07675 m
.26378 .32325 L
s
0 .133 .859 r
.02381 .12973 m
.02381 .27027 L
s
.97619 .00952 m
.97619 .39048 L
s
0 g
.5 Mabswid
.02381 .27027 m
.04262 .25343 L
.06244 .23614 L
.07216 .22809 L
.0775 .22394 L
.08255 .22032 L
.08542 .21847 L
.08693 .21758 L
.08852 .21671 L
.08987 .21604 L
.09135 .21539 L
.092 .21513 L
.0927 .21488 L
.09396 .21448 L
.09466 .2143 L
.09532 .21415 L
.09603 .21401 L
.0968 .2139 L
.09753 .21383 L
.09822 .21379 L
.0995 .2138 L
.10077 .2139 L
.10194 .21408 L
.10322 .21437 L
.10387 .21455 L
.10458 .21477 L
.10588 .21524 L
.10709 .21575 L
.10982 .2171 L
.11223 .2185 L
.11478 .22014 L
.12409 .22702 L
.145 .24464 L
.1546 .25309 L
.1647 .2621 L
.16887 .26584 L
.17116 .2679 L
.17228 .26892 L
.17332 .26985 L
.17455 .27127 L
.17588 .27301 L
.17821 .27605 L
.18275 .282 L
.19197 .29407 L
.19449 .29739 L
.1972 .30094 L
.19852 .30267 L
.19976 .30431 L
.20088 .30476 L
.2021 .30511 L
Mistroke
.21223 .30806 L
.22296 .3112 L
.24432 .31749 L
.25439 .32047 L
.25881 .32178 L
.26132 .32252 L
.26254 .32289 L
.26366 .32322 L
.26483 .32281 L
.26594 .32235 L
.26838 .32133 L
.27336 .31924 L
.28384 .31485 L
.30284 .30693 L
.34122 .29109 L
.38205 .27459 L
.42137 .25934 L
.45917 .24585 L
.47856 .23977 L
.48945 .23675 L
.49428 .23553 L
.49943 .23432 L
.50458 .23321 L
.50926 .23231 L
.51396 .23151 L
.51839 .23085 L
.52091 .23053 L
.52357 .23023 L
.52584 .23 L
.52834 .22979 L
.52974 .22968 L
.53102 .2296 L
.5325 .22952 L
.53318 .22948 L
.53391 .22945 L
.5352 .2294 L
.5364 .22936 L
.53768 .22933 L
.53842 .22932 L
.53911 .22931 L
.54028 .2293 L
.54153 .2293 L
.54272 .22931 L
.54379 .22933 L
.54506 .22936 L
.54577 .22938 L
.54643 .2294 L
.54764 .22945 L
.54892 .22951 L
.55015 .22958 L
Mistroke
.55146 .22966 L
.55384 .22984 L
.5553 .22997 L
.55668 .2301 L
.55926 .23037 L
.56149 .23064 L
.56385 .23095 L
.56811 .23159 L
.57317 .23248 L
.57776 .23338 L
.5878 .23566 L
.59702 .23808 L
.61785 .24437 L
.65736 .25829 L
.69535 .27296 L
.73579 .28925 L
.77472 .30528 L
.8161 .32257 L
.85597 .33936 L
.89432 .3556 L
.93512 .37296 L
.9744 .38971 L
.97619 .39048 L
Mfstroke
.02381 .12973 m
.04262 .14657 L
.06244 .16386 L
.07216 .17191 L
.0775 .17606 L
.08255 .17968 L
.08542 .18153 L
.08693 .18242 L
.08852 .18329 L
.08987 .18396 L
.09135 .18461 L
.092 .18487 L
.0927 .18512 L
.09396 .18552 L
.09466 .1857 L
.09532 .18585 L
.09603 .18599 L
.0968 .1861 L
.09753 .18617 L
.09822 .18621 L
.0995 .1862 L
.10077 .1861 L
.10194 .18592 L
.10322 .18563 L
.10387 .18545 L
.10458 .18523 L
.10588 .18476 L
.10709 .18425 L
.10982 .1829 L
.11223 .1815 L
.11478 .17986 L
.12409 .17298 L
.145 .15536 L
.1546 .14691 L
.1647 .1379 L
.16887 .13416 L
.17116 .1321 L
.17228 .13108 L
.17332 .13015 L
.17455 .12873 L
.17588 .12699 L
.17821 .12395 L
.18275 .118 L
.19197 .10593 L
.19449 .10261 L
.1972 .09906 L
.19852 .09733 L
.19976 .09569 L
.20088 .09524 L
.2021 .09489 L
Mistroke
.21223 .09194 L
.22296 .0888 L
.24432 .08251 L
.25439 .07953 L
.25881 .07822 L
.26132 .07748 L
.26254 .07711 L
.26366 .07678 L
.26483 .07719 L
.26594 .07765 L
.26838 .07867 L
.27336 .08076 L
.28384 .08515 L
.30284 .09307 L
.34122 .10891 L
.38205 .12541 L
.42137 .14066 L
.45917 .15415 L
.47856 .16023 L
.48945 .16325 L
.49428 .16447 L
.49943 .16568 L
.50458 .16679 L
.50926 .16769 L
.51396 .16849 L
.51839 .16915 L
.52091 .16947 L
.52357 .16977 L
.52584 .17 L
.52834 .17021 L
.52974 .17032 L
.53102 .1704 L
.5325 .17048 L
.53318 .17052 L
.53391 .17055 L
.5352 .1706 L
.5364 .17064 L
.53768 .17067 L
.53842 .17068 L
.53911 .17069 L
.54028 .1707 L
.54153 .1707 L
.54272 .17069 L
.54379 .17067 L
.54506 .17064 L
.54577 .17062 L
.54643 .1706 L
.54764 .17055 L
.54892 .17049 L
.55015 .17042 L
Mistroke
.55146 .17034 L
.55384 .17016 L
.5553 .17003 L
.55668 .1699 L
.55926 .16963 L
.56149 .16936 L
.56385 .16905 L
.56811 .16841 L
.57317 .16752 L
.57776 .16662 L
.5878 .16434 L
.59702 .16192 L
.61785 .15563 L
.65736 .14171 L
.69535 .12704 L
.73579 .11075 L
.77472 .09472 L
.8161 .07743 L
.85597 .06064 L
.89432 .0444 L
.93512 .02704 L
.9744 .01029 L
.97619 .00952 L
Mfstroke
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{614, 245.563},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009V0000mB000`400?l00000o`00003oo`3ooooo
0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0oooo<03oool00`000000oooo0?ooo`0/0?ooo`<0
00003@3oool300000?D0oooo003o0?oooc00oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0?<0oooo003o0?oooc00oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?<0oooo003o0?ooob40oooo1@00000:
0?ooo`040000003oool00000000000@0oooo0`0000040?ooo`<000000`3oool00`000000oooo0?oo
o`0200000080oooo00@000000?ooo`3oool0oooo0`0000030?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000?D0oooo003o0?ooob80oooo00<000000?ooo`3oool02`3oool20000
0080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`040000003o
ool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000003e0?ooo`00o`3o
oolR0?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000001P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`000000m@3oool00?l0oooo8`3oool00`000000oooo0?ooo`020?ooo`L0
000000<0oooo0000003oool00P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo
0?ooo`<000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000m@3oool0
0?l0oooo903oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000030?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`000000m@3oool00?l0oooo903oool00`000000oooo0?ooo`09
0?ooo`8000000P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo
00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo0P0000020?ooo`8000000P3oool01@000000oooo0?ooo`3oool000000?D0oooo003o
0?ooob40oooo1@00000:0?ooo`040000003oool00000000000@0oooo0`0000040?ooo`<000000`3o
ool00`000000oooo0000000200000080oooo00@000000?ooo`3oool0oooo0`0000030?ooo`040000
003oool00000000000D0oooo00<000000?ooo`3oool00`3oool010000000oooo0000000000020?oo
o`800000103oool00`000000oooo0?ooo`3c0?ooo`00o`3ooom80?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3c0?ooo`00o`3ooom80?ooo`030000
003oool0oooo01@0oooo0`00000=0?ooo`<00000m@3oool00?l0ooooA@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0?l0oooo6@3oool00?l0ooooo`3ooomX0?ooo`00o`3ooooo0?oo
ofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00o`3ooooo0?ooofP0oooo003o
0?ooool0ooooJ03oool008X0oooo00<000000?ooo`3oool0>`3oool4000004<0oooo00<000000?oo
o`3oool0?`3oool600000400oooo100000140?ooo`030000003oool0oooo03l0oooo100000110?oo
o`00RP3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0n0?ooo`00RP3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool0?@3oool6000004@0oooo00<000000?ooo`3oool0
?P3oool007l0oooo1`0000040?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0n0?ooo`040000003oool0oooo000004D0oooo00<000000?ooo`3oool0
?P3oool008X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo03h0oooo00@000000?ooo`3oool00000@03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo03h0oooo002:0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0?`3o
ool300000480oooo00<000000?ooo`000000@03oool500000440oooo002:0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
00000400oooo00<000000?ooo`3oool0@`3oool008P0oooo00<000000?ooo`000000?03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo03h0oooo00<000000?ooo`000000AP3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo0400oooo0P0000110?ooo`030000003oool0oooo
0480oooo00290?ooo`800000?03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03l0
oooo0P0000110?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0400oooo0P0000110?ooo`030000003oool0oooo0480
oooo002:0?ooo`030000003oool0oooo03/0oooo100000130?ooo`030000003oool0oooo0400oooo
100000110?ooo`@00000A03oool00`000000oooo0?ooo`0o0?ooo`D00000@03oool00?l0ooooo`3o
oomX0?ooo`00o`3ooooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00
o`3ooooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00H`3ooooo0000
0<d00000=`3oool006<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0e0?ooo`00
H`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03D0oooo001S0?ooo`8000008@3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`060?ooo`800000=`3oool006<0oooo00<000000?ooo`3oool0803oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3
000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@03oool30000
0003000Rf`3oool0oooo00H0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<000000?ooo`3o
ool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0?P3oool2000000040?ooo`008]/002;K000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0
oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0?03oool2000000<0oooo0`008]/80?ooo`030000003oool0oooo03D0
oooo001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo03X0oooo0P0000050?ooo`<002;K203oool00`000000oooo
0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0g0?ooo`<000001`3oool3000Rf`P0oooo00<0
00000?ooo`3oool0=@3oool006<0oooo0P00000Q0?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0e0?ooo`8000002P3oool3000Rf`L0oooo0P00000g
0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`0c0?ooo`800000303oool3000Rf`P0oooo00<000000?oo
o`3oool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0<@3oool2000000h0oooo0`008]/80?ooo`03
0000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo02h0oooo0`00000@0?ooo`<002;K
203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0/0?ooo`8000004`3o
ool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<000000?ooo`3oool0803oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0:P3oool2
000001D0oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo
0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
02L0oooo0`00000G0?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool200000240
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo02D0
oooo0P00000J0?ooo`<002;K1`3oool2000003L0oooo001S0?ooo`030000003oool0oooo0200oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0280oooo
0`00000L0?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?oo
o`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`0P0?ooo`8000007`3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool005@0oooo1P000009
0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo01h0oooo0P00000Q0?ooo`<002;K203oool00`000000oooo0?ooo`0e
0?ooo`00E@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0200oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo01/0oooo0`00000S0?oo
o`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00EP3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo01T0oooo0P00000V0?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00
C03oool7000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0P0?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0F0?ooo`<00000
:03oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool005P0oooo00<000000?ooo`3oool0203o
ool300000?l0001oT@0007l2000002/0001o0`008]/60000O`<00000=`3oool005T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0A0?ooo`<00000;@3oool3000Rf`P0oooo00<00000
0?ooo`3oool0=@3oool005T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0>0?oo
o`<00000<03oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool005T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`0<0?ooo`800000<`3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool005@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo00T0oooo0`00000e0?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00E@3o
ool4000000X0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool01`3oool2000003P0oooo0`008]/80?ooo`030000003o
ool0oooo03D0oooo001S0?ooo`8000008@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool01@3oool2000003X0oooo0`008]/70?ooo`800000=`3oool0
06<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool00`3oool2000003`0oooo0`008]/80?ooo`030000003oool0oooo
03D0oooo001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo00<00000?P3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o000000000000@@3oool3000Rf`P0oooo00<000000?ooo`3oool0
=@3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo0P0000130?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool0
0`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool03@3oool3
0?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo03l0oooo0P0000000`3oool0001o0?ooo`120?ooo`<002;K203oool00`000000oooo0?ooo`0e
0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0303oool400000380oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo03`0oooo0`0000030?ooo`030000O`3oool0oooo0440oooo0`008]/80?oo
o`030000003oool0oooo03D0oooo001S0?ooo`8000008@3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo00P0oooo100000001@3oool0nQh50?XN1@3j7PD000000340oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo03X0oooo0P0000060?oo
o`030000O`3oool0oooo0440oooo0`008]/70?ooo`800000=`3oool006<0oooo00<000000?ooo`3o
ool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo00@0oooo100000050?ooo`<0
nQh500@0oooo0000000000000000;P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0>03oool2000000P0oooo00<0001o0?ooo`3oool0@@3oool3000R
f`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0
oooo0?ooo`120?ooo`040000O`3oool0oooo0?ooo`<000002@3oool30?XN1@@0oooo0P00000/0?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0e0?oo
o`<000002P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?oo
o`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo1000000<0?ooo`<0
nQh51P3oool3000002T0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo03<0oooo0P00000=0?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`03
0000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0
?`3oool3000000030000O`3oool0oooo00d0oooo0`3j7PD90?ooo`<000009P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0<03oool3000000l0oooo
00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<0
00000?ooo`3oool0803oool00`0007l0oooo0?ooo`0m0?ooo`8000000`3oool00`0007l0oooo0?oo
o`0=0?ooo`<0nQh5303oool3000002<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo02h0oooo0P00000B0?ooo`030000O`3oool0oooo0440oooo0`00
8]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo0200oooo00<0001o
0?ooo`3oool0=@3oool30?XN1@80oooo0`0000050?ooo`030000O`3oool0oooo00d0oooo0`3j7PD?
0?ooo`<00000803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0;03oool2000001@0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<00000
0?ooo`3oool0=@3oool006<0oooo0P00000Q0?ooo`030000O`3oool0oooo03D0oooo1@0000080?oo
o`030000O`3oool0oooo00d0oooo0`3j7PDB0?ooo`8000007P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0:@3oool3000001H0oooo00<0001o0?oo
o`3oool0@@3oool3000Rf`L0oooo0P00000g0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`03
0000O`3oool0oooo03D0oooo00<000000?XN1@3j7PD02P3oool00`0007l0oooo0?ooo`0=0?ooo`<0
nQh5503oool2000001`0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo02L0oooo0P00000I0?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`03
0000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0
=03oool010000000nQh50?XN1@3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDF0?ooo`80
00006P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0903oool3000001/0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`0c0?ooo`030000
003oool0nQh50080nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5603oool3000001L0oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0280oooo
0P00000N0?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo
001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0<`3oool00`000000oooo0?XN
1@020?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1A/0oooo0P00000E0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0O0?ooo`<00000803o
ool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool0
0`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0380oooo00<000000?ooo`3oool00`3j7PD:
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDM0?ooo`8000004`3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0703oool3000002<0oooo00<0001o
0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<000000?oo
o`3oool0803oool00`0007l0oooo0?ooo`0a0?ooo`040000003oool0oooo0?ooo`<0nQh52P3oool0
0`0007l0oooo0?ooo`0=0?ooo`<0nQh57`3oool200000140oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo01X0oooo0P00000V0?ooo`030000O`3oool0
oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`8000008@3oool00`00
07l0oooo0?ooo`0a0?ooo`040000003oool0oooo0?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=
0?ooo`<0nQh58@3oool3000000h0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo01L0oooo0`00000X0?ooo`030000O`3oool0oooo0440oooo0`008]/7
0?ooo`800000=`3oool003`0oooo0P0000020?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0803oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo0080oooo0`3j7PD:0?oo
o`030000O`3oool0oooo00d0oooo0`3j7PDT0?ooo`800000303oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool05@3oool2000002/0oooo00<0001o0?oo
o`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool003/0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0200oooo00<0001o0?oo
o`3oool0;`3oool00`000000oooo0?ooo`030?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?oo
o`<0nQh59P3oool3000000T0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo01<0oooo0P00000]0?ooo`030000O`3oool0oooo0440oooo0`008]/80?oo
o`030000003oool0oooo03D0oooo000k0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo02l0oooo00<000000?oo
o`3oool00`3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1BT0oooo0P0000070?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0@0?oo
o`<00000;`3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?oo
o`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo02h0oooo00<000000?oo
o`3oool0103oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1B/0oooo0`0000040?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0>0?oo
o`800000<P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?oo
o`00?03oool00`000000oooo0?ooo`02000001H0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0P0?ooo`030000O`3oool0oooo02d0oooo00<000000?ooo`3oool01@3oool30?XN1@X0
oooo00<0001o0?ooo`3oool03@3oool30?XN1Bh0oooo0`0000000`3oool0001o0?ooo`130?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool02`3oool3000003@0oooo00<0001o0?ooo`3o
ool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool005L0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo02`0oooo00<000000?ooo`3oool0
1P3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo0P0000140?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool02@3oool2000003L0oooo00<0001o0?ooo`3oool0
@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool004`0oooo1`0000040?ooo`030000003o
ool0oooo00T0oooo0`00001>0000O`030000000007l0001o00L0001o0`3j7PDJ0000O`<0nQh5<`00
07l300000900001o0P00001m0000O`<002;K1P0007l3000003L0oooo000k0?ooo`X000004P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`030000O`3oool0
oooo02T0oooo00<0nQh50000003j7PD02@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool3
0?XN1C80oooo00@0001o0?ooo`3oool0oooo0P00000o0?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0103oool3000003/0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<0
00000?ooo`3oool0=@3oool003`0oooo00D000000?ooo`3oool0oooo0000000F0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01`3oool00`008]/00000000Rf`0F0?ooo`030000O`3o
ool0oooo02T0oooo0P0000000`3j7PD0oooo0?ooo`070?ooo`<0nQh52P3oool00`0007l0oooo0?oo
o`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`030?ooo`<00000?03oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0080oooo0P00000n0?ooo`030000O`3oool0oooo0440oooo0`00
8]/80?ooo`030000003oool0oooo03D0oooo000k0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo0P008]/0
0`000000oooo0?ooo`0D0?ooo`030000O`3oool0oooo02P0oooo0P0000020?XN1@T0oooo0`3j7PD:
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo00H0oooo0P00000j
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`0000000P0000100?ooo`030000O`3oool0
oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo000k0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo
00L0oooo0`008]/00`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo02L0oooo00<000000?oo
o`3j7PD00P3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`00
07l0oooo0?ooo`080?ooo`<00000=`3oool00`0007l0oooo0?ooo`120?ooo`800000@`3oool00`00
07l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00?03oool5000001D0
oooo0P00000;0?ooo`030000003oool0oooo00L0oooo0`008]/00`3oool000000?ooo`0C0?ooo`03
0000O`3oool0oooo02H0oooo00<000000?ooo`3oool00`3j7PD90?ooo`<0nQh52P3oool00`0007l0
oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`0;0?ooo`<00000=03oool00`0007l0
oooo0?ooo`100?ooo`80000000<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<0
02;K203oool00`000000oooo0?ooo`0e0?ooo`00E`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00L0oooo0`008]/20?ooo`030000003oool0oooo0140oooo00<0001o0?ooo`3oool0
9@3oool010000000oooo0?ooo`3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0
oooo0`3j7PDb0?ooo`030000O`3oool0oooo00h0oooo0P00000b0?ooo`030000O`3oool0oooo03d0
oooo0`0000020?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0
oooo00<000000?ooo`3oool0=@3oool006<0oooo0P0000080?ooo`<002;K0`3oool00`000000oooo
0?ooo`0@0?ooo`030000O`3oool0oooo02@0oooo00<000000?ooo`3oool00P3oool30?XN1@T0oooo
0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0100oooo
0`00000_0?ooo`030000O`3oool0oooo03/0oooo0P0000050?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@@3oool3000Rf`L0oooo0P00000g0?ooo`00?03oool500000280oooo00<0
00000?ooo`3oool01`3oool3000Rf`@0oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?oo
o`0S0?ooo`030000003oool0oooo00<0oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?oo
o`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`0C0?ooo`<00000;03oool00`0007l0oooo0?oo
o`0h0?ooo`<000001`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`00
8]/80?ooo`030000003oool0oooo03D0oooo000k0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`<002;K1@3oool00`000000oooo0?ooo`0>
0?ooo`030000O`3oool0oooo0280oooo00<000000?ooo`3oool0103oool30?XN1@T0oooo0`3j7PD:
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo01H0oooo0`00000Y
0?ooo`030000O`3oool0oooo03D0oooo0`00000:0?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool003/0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo0`008]/60?oo
o`030000003oool0oooo00d0oooo00<0001o0?ooo`3oool08@3oool00`000000oooo0?ooo`050?oo
o`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?oo
o`3oool06@3oool3000002H0oooo00<0001o0?ooo`3oool0<P3oool3000000d0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?oo
o`00>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool01`3oool3000Rf`L0oooo00<000000?ooo`3oool0303oool00`0007l0oooo0?ooo`0P0?ooo`03
0000003oool0oooo00H0oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0
nQh5<P3oool00`0007l0oooo0?ooo`0L0?ooo`<000008`3oool00`0007l0oooo0?ooo`0_0?ooo`<0
0000403oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`03
0000003oool0oooo03D0oooo000l0?ooo`D000008P3oool00`000000oooo0?ooo`070?ooo`<002;K
203oool00`000000oooo0?ooo`0;0?ooo`030000O`3oool0oooo01h0oooo0P0000090?ooo`<0nQh5
2@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0
7`3oool300000200oooo00<0001o0?ooo`3oool0;03oool3000001<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3o
ool00`000000oooo0?ooo`070?ooo`<002;K2@3oool00`000000oooo0?ooo`0:0?ooo`030000O`3o
ool0oooo01d0oooo00<000000?ooo`3oool02@3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3o
ool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0280oooo0`00000M0?ooo`030000O`3o
ool0oooo02T0oooo0`00000F0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool003/0oooo00<000000?ooo`3oool09@3oool2
000000P0oooo0`008]/:0?ooo`8000002P3oool00`0007l0oooo0?ooo`0L0?ooo`030000003oool0
oooo00X0oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool0
0`0007l0oooo0?ooo`0U0?ooo`<000006P3oool00`0007l0oooo0?ooo`0V0?ooo`<000006@3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/70?ooo`800000=`3oool0
03T0oooo2@00000Q0?ooo`030000003oool0oooo00L0oooo0`008]/<0?ooo`030000003oool0oooo
00L0oooo00<0001o0?ooo`3oool06`3oool00`000000oooo0?ooo`0;0?ooo`<0nQh52@3oool30?XN
1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0:03oool30000
01L0oooo00<0001o0?ooo`3oool08`3oool3000001`0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00>`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool3000Rf`d0
oooo00<000000?ooo`3oool01P3oool00`0007l0oooo0?ooo`0J0?ooo`030000003oool0oooo00`0
oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0
oooo0?ooo`0[0?ooo`<00000503oool00`0007l0oooo0?ooo`0O0?ooo`@000007`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0
oooo001S0?ooo`030000003oool0oooo00L0oooo0`008]/>0?ooo`030000003oool0oooo00D0oooo
00<0001o0?ooo`3oool06@3oool00`000000oooo0?ooo`0=0?ooo`<0nQh52@3oool30?XN1@X0oooo
00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0;P3oool200000180oooo
00<0001o0?ooo`3oool0703oool3000002<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?oo
o`070?ooo`<002;K3`3oool00`000000oooo0?ooo`040?ooo`030000O`3oool0oooo01L0oooo0P00
000@0?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0
001o0?ooo`3oool0<03oool4000000h0oooo00<0001o0?ooo`3oool05`3oool5000002H0oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?oo
o`0e0?ooo`00H`3oool00`000000oooo0?ooo`070?ooo`<002;K403oool2000000@0oooo00<0001o
0?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o
0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0=03oool5000000T0oooo00<0001o
0?ooo`3oool04P3oool5000002/0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`070?oo
o`<002;K4P3oool200000080oooo00<0001o0?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?oo
o`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?oo
o`3oool0>@3oool700000080oooo00<0001o0?ooo`3oool0303oool600000300oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?oo
o`00H`3oool2000000P0oooo0`008]/D0?ooo`030000003oool0001o01H0oooo00<000000?ooo`3o
ool04P3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`03
0000O`3oool0oooo0400oooo4@00000f0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool3000Rf`L0oooo0P00000g0?ooo`00?03oool200000080oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`070?ooo`<002;K5@3oool00`000000001o0?ooo`0D0?ooo`030000
003oool0oooo01<0oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5
<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00>`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
1`3oool3000RfaH0oooo00<000000?ooo`3oool04@3oool2000001H0oooo0`3j7PD90?ooo`<0nQh5
2P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K
203oool00`000000oooo0?ooo`0e0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool3000RfaH0oooo00<0001o000000000000
3`3oool2000001P0oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5
<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00>`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
1`3oool3000RfaH0oooo00@0001o0?ooo`3oool000003@3oool00`000000oooo0?ooo`0H0?ooo`<0
nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool003`0oooo00<000000?ooo`3oool0
0P00000R0?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`040000O`3oool0oooo0?ooo`80
00002P3oool00`000000oooo0?ooo`0I0?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3o
ool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool006<0oooo00<000000?ooo`3oool01`3oool3000RfaH0oooo00<0001o0?ooo`3oool0
0P3oool3000000D0oooo0`00000L0?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0
=@3oool006<0oooo0P0000080?ooo`<002;K5P3oool00`0007l0oooo0?ooo`040?ooo`L000007P3o
ool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo0`008]/70?ooo`800000=`3oool003P0oooo00<000000?ooo`3oool01`00000Q
0?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`030000O`3oool0oooo02T0oooo0`3j7PD9
0?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`070?oo
o`<002;K5P3oool00`0007l0oooo0?ooo`0Y0?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o0?oo
o`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?oo
o`3oool0=@3oool005D0oooo1000000:0?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`03
0000O`3oool0oooo02T0oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0
nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00
>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`030000
O`3oool0oooo02T0oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5
<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00>`3o
ool010000000oooo0?ooo`3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`030000O`3oool0oooo02T0oooo
0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00>`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`<000001`0007l3000Rfd80001o0`3j7PD90000O`<0nQh56P0007l30?XN1Ol0001o
AP0007l3000Rf`H0001o0`00000g0?ooo`00>`3oool3000000<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool3000RfaH0oooo00<0001o0?ooo`3oool0:@3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3o
ool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003o
ool0oooo03D0oooo000k0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool3
000RfaH0oooo00<0001o0?ooo`3oool0:@3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0
oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003oool0
oooo03D0oooo001D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`<002;K5P3oool00`0007l0oooo0?ooo`0Y0?ooo`<0nQh52@3oool30?XN
1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000R
f`P0oooo00<000000?ooo`3oool0=@3oool005@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`030000O`3oool0oooo02T0
oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00?03oool5000001<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
0`008]/F0?ooo`030000O`3oool0oooo02T0oooo0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo
0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo
0?ooo`0e0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0140oooo
1000000:0?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`030000O`3oool0oooo02T0oooo
0`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00>`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo01l0oooo0P0000080?ooo`<002;K5P3oool00`0007l0oooo
0?ooo`040?ooo`L000007P3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo
0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/70?ooo`800000=`3oool003/0oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo
0`008]/F0?ooo`030000O`3oool0oooo0080oooo0P0000070?ooo`800000703oool30?XN1@T0oooo
0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo
0`008]/80?ooo`030000003oool0oooo03D0oooo000l0?ooo`<0000000<0oooo0000003oool08@3o
ool00`000000oooo0?ooo`070?ooo`<002;K5P3oool01@0007l0oooo0?ooo`3oool0000000/0oooo
00<000000?ooo`3oool06@3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo
0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo
001S0?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`040000O`3oool00000000000d0oooo
00<000000?ooo`3oool0603oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo
0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo
001S0?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`800000403oool2000001P0oooo0`3j
7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`07
0?ooo`<002;K5@3oool00`000000001o0?ooo`0B0?ooo`8000005P3oool30?XN1@T0oooo0`3j7PD:
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/8
0?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo00L0oooo0`008]/D0?oo
o`030000003oool0001o01D0oooo00<000000?ooo`3oool04`3oool30?XN1@T0oooo0`3j7PD:0?oo
o`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/80?oo
o`030000003oool0oooo03D0oooo000i0?ooo``000007P3oool2000000P0oooo0`008]/C0?ooo`04
0000003oool0oooo0000OaH0oooo00<000000?ooo`3oool04P3oool30?XN1@T0oooo0`3j7PD:0?oo
o`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo03l0oooo5000000d0?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`L0oooo0P00000g0?oo
o`00>@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool01`3oool3000Rfa40oooo0P0000030?ooo`030000O`3oool0oooo01D0oooo00<000000?ooo`3o
ool04@3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`03
0000O`3oool0oooo03X0oooo1@0000030?ooo`030000O`3oool0oooo00h0oooo1@00000_0?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool003T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00L0oooo0`008]/@0?ooo`030000003oool0oooo00<0oooo00<0001o0?ooo`3oool0
5P3oool00`000000oooo0?ooo`0@0?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C80oooo00<0001o0?ooo`3oool0=@3oool5000000P0oooo00<0001o0?ooo`3oool0
4`3oool4000002/0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K
203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`070?ooo`<002;K3`3o
ool00`000000oooo0?ooo`040?ooo`030000O`3oool0oooo01L0oooo0P00000@0?ooo`<0nQh52@3o
ool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0<03o
ool5000000d0oooo00<0001o0?ooo`3oool05`3oool4000002L0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool0
0`000000oooo0?ooo`070?ooo`<002;K3P3oool00`000000oooo0?ooo`050?ooo`030000O`3oool0
oooo01T0oooo00<000000?ooo`3oool03@3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0
oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo02h0oooo0P00000B0?ooo`030000O`3oool0
oooo01/0oooo1000000S0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3
000Rf`P0oooo00<000000?ooo`3oool0=@3oool003/0oooo1`00000Q0?ooo`030000003oool0oooo
00L0oooo0`008]/=0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3oool06P3oool00`00
0000oooo0?ooo`0<0?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN
1C80oooo00<0001o0?ooo`3oool0:P3oool4000001@0oooo00<0001o0?ooo`3oool07`3oool30000
0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`00
0000oooo0?ooo`0e0?ooo`00?03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00L0
oooo0`008]/<0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool06`3oool00`000000
oooo0?ooo`0;0?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80
oooo00<0001o0?ooo`3oool09P3oool4000001P0oooo00<0001o0?ooo`3oool08P3oool4000001`0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000
oooo0?ooo`0e0?ooo`00>`3oool00`000000oooo0?ooo`0U0?ooo`800000203oool3000Rf`X0oooo
0P00000:0?ooo`030000O`3oool0oooo01`0oooo00<000000?ooo`3oool02P3oool30?XN1@T0oooo
0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0280oooo
1000000L0?ooo`030000O`3oool0oooo02H0oooo0`00000I0?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@@3oool3000Rf`L0oooo0P00000g0?ooo`00>`3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00L0oooo0`008]/90?ooo`030000003oool0oooo00X0oooo00<0
001o0?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`<0nQh52@3oool30?XN1@X0oooo00<0
001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0803oool200000200oooo00<0
001o0?ooo`3oool0:@3oool3000001H0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00?03oool600000240oooo00<00000
0?ooo`3oool01`3oool3000Rf`P0oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0N
0?ooo`8000002@3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb
0?ooo`030000O`3oool0oooo01d0oooo0`00000R0?ooo`030000O`3oool0oooo02`0oooo0`00000C
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<00000
0?ooo`3oool0=@3oool003/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`070?oo
o`<002;K1`3oool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo0200oooo00<000000?oo
o`3oool01P3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?oo
o`030000O`3oool0oooo01/0oooo0P00000U0?ooo`030000O`3oool0oooo02l0oooo0`00000@0?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?oo
o`3oool0=@3oool003/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`070?ooo`<0
02;K1P3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo0240oooo00<000000?ooo`3o
ool01@3oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`03
0000O`3oool0oooo01P0oooo0`00000W0?ooo`030000O`3oool0oooo0380oooo0`00000=0?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool003/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`070?ooo`<002;K
1@3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo0280oooo00<000000?ooo`3oool0
103oool30?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000
O`3oool0oooo01D0oooo0`00000Z0?ooo`030000O`3oool0oooo03D0oooo0`00000:0?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0
=@3oool003`0oooo1P00000Q0?ooo`030000003oool0oooo00L0oooo0`008]/40?ooo`030000003o
ool0oooo00l0oooo00<0001o0?ooo`3oool08`3oool00`000000oooo0?ooo`030?ooo`<0nQh52@3o
ool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool04`3o
ool2000002d0oooo00<0001o0?ooo`3oool0>03oool3000000L0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool2
000000P0oooo0`008]/30?ooo`030000003oool0oooo0100oooo00<0001o0?ooo`3oool0903oool0
0`000000oooo0?ooo`020?ooo`<0nQh52@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool3
0?XN1C80oooo00<0001o0?ooo`3oool0403oool3000002l0oooo00<0001o0?ooo`3oool0>`3oool2
000000D0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K1`3oool2
000003L0oooo001S0?ooo`030000003oool0oooo00L0oooo0`008]/20?ooo`030000003oool0oooo
0140oooo00<0001o0?ooo`3oool09@3oool010000000oooo0?ooo`3oool30?XN1@T0oooo0`3j7PD:
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo00h0oooo0P00000b
0?ooo`030000O`3oool0oooo03d0oooo0`0000020?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool003/0oooo1`00000Q0?oo
o`030000003oool0oooo00L0oooo0`008]/00`3oool000000?ooo`0C0?ooo`030000O`3oool0oooo
02H0oooo00<000000?ooo`3oool00`3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?oo
o`<0nQh5<P3oool00`0007l0oooo0?ooo`0;0?ooo`<00000=03oool00`0007l0oooo0?ooo`100?oo
o`80000000<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`00
0000oooo0?ooo`0e0?ooo`00?03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01`3oool3000Rf`030000003oool0oooo01<0oooo00<0001o0?ooo`3o
ool09`3oool00`000000oooo0?XN1@020?XN1@T0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0
oooo0`3j7PDb0?ooo`030000O`3oool0oooo00T0oooo0P00000g0?ooo`030000O`3oool0oooo0480
oooo0P0000130?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0
oooo000k0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`070?ooo`8002;K00<000000?ooo`3oool0503oool00`0007l0oooo0?ooo`0X0?ooo`800000
0P3j7PD90?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo
0?ooo`060?ooo`<00000>@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0000000800000
@03oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00>`3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`008]/00000000Rf`0F0?ooo`030000O`3oool0oooo02T0oooo0P0000000`3j7PD0oooo0?oo
o`070?ooo`<0nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?oo
o`030?ooo`<00000?03oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0080oooo0P00
000n0?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo000l
0?ooo`H000005@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo0`008]/F
0?ooo`030000O`3oool0oooo02T0oooo00<0nQh50000003j7PD02@3oool30?XN1@X0oooo00<0001o
0?ooo`3oool03@3oool30?XN1C80oooo00@0001o0?ooo`3oool0oooo0P00000o0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0103oool3000003/0oooo00<0001o0?ooo`3oool0@@3o
ool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool003/0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`090?ooo`<00000CP0007l2000000P0001o0`3j7PDJ0000O`<0nQh5<`0007l3
00000900001o0`00001l0000O`<002;K1P0007l3000003L0oooo000k0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo
02d0oooo00<000000?ooo`3oool01@3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN
1C40oooo0P0000140?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool02P3oool20000
03H0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool003/0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0200
oooo00<0001o0?ooo`3oool0;@3oool00`000000oooo0?ooo`050?ooo`<0nQh52P3oool00`0007l0
oooo0?ooo`0=0?ooo`<0nQh5;P3oool3000000030?ooo`0007l0oooo04<0oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`0<0?ooo`<00000<`3oool00`0007l0oooo0?ooo`110?ooo`<0
02;K203oool00`000000oooo0?ooo`0e0?ooo`00?03oool6000001<0oooo00<000000?ooo`000000
2`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo02h0oooo00<000000?ooo`3oool0
103oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1B`0oooo0P0000040?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0?0?ooo`<00000
<03oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00EP3o
ool2000000/0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`0_0?ooo`030000003o
ool0oooo00<0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDY0?ooo`<000001P3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool04P3o
ool2000002h0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3o
ool003T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`0_0?ooo`030000003oool0
oooo00<0oooo0`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDV0?ooo`<000002@3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0503oool3
000002/0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool0
03T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0200oooo00<0001o0?ooo`3oool0<03oool00`000000oooo0?ooo`020?ooo`<0nQh52P3oool00`00
07l0oooo0?ooo`0=0?ooo`<0nQh5903oool2000000`0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo01L0oooo0`00000X0?ooo`030000O`3oool0oooo
0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo000i0?ooo``000007P3oool200000240
oooo00<0001o0?ooo`3oool0<@3oool010000000oooo0?ooo`3oool30?XN1@X0oooo00<0001o0?oo
o`3oool03@3oool30?XN1B40oooo0`00000>0?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`0J0?ooo`8000009P3oool00`0007l0oooo0?ooo`110?oo
o`<002;K1`3oool2000003L0oooo001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3o
ool0<@3oool010000000oooo0?ooo`3oool30?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN
1Al0oooo0P00000A0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`0L0?ooo`800000903oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`00
0000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0380
oooo00<000000?ooo`3oool00`3j7PD:0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDM0?ooo`80
00004`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool07P3oool200000280oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`0c0?ooo`030000
003oool0nQh50080nQh52P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh56`3oool2000001D0oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0200oooo
0`00000O0?ooo`030000O`3oool0oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo
001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0<`3oool00`000000oooo0?XN
1@020?XN1@X0oooo00<0001o0?ooo`3oool03@3oool30?XN1AP0oooo0`00000G0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0S0?ooo`8000007@3o
ool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool0
0`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo03@0oooo00@000000?XN1@3j7PD0nQh52P3o
ool00`0007l0oooo0?ooo`0=0?ooo`<0nQh55P3oool2000001X0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo02D0oooo0P00000K0?ooo`030000O`3o
ool0oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0
oooo0200oooo00<0001o0?ooo`3oool0=@3oool00`000000nQh50?XN1@0:0?ooo`030000O`3oool0
oooo00d0oooo0`3j7PDD0?ooo`800000703oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool09`3oool2000001T0oooo00<0001o0?ooo`3oool0@@3oool3
000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo0P00000Q0?ooo`030000O`3oool0oooo
03D0oooo00@0nQh500000000000000002@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh54P3oool2
000001h0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo02T0oooo0`00000F0?ooo`030000O`3oool0oooo0440oooo0`008]/70?ooo`800000=`3oool0
06<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`0i0?ooo`@000001@3oool00`00
07l0oooo0?ooo`0=0?ooo`<0nQh53`3oool300000200oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo02`0oooo0P00000D0?ooo`030000O`3oool0oooo
0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo0200
oooo00<0001o0?ooo`3oool0?@3oool2000000<0oooo00<0001o0?ooo`3oool03@3oool30?XN1@`0
oooo0`00000S0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`0^0?ooo`8000004P3oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`000000
oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo03l0oooo
1000000?0?ooo`<0nQh52@3oool3000002H0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0300oooo0`00000?0?ooo`030000O`3oool0oooo0440oooo
0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo0200oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0000000000003000000X0oooo0`3j7PD60?ooo`<00000:@3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0<`3o
ool2000000d0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3o
ool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo00<0oooo100000060?ooo`<0nQh5103oool2000002`0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo03D0oooo0`00000:0?ooo`030000O`3oool0
oooo0440oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo
0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`070?ooo`800000103oool30?XN
1@80oooo0P00000^0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`0h0?ooo`800000203oool00`0007l0oooo0?ooo`110?ooo`<002;K203oool00`00
0000oooo0?ooo`0e0?ooo`00H`3oool200000240oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`090?ooo`@000000`3j7PD200000300oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo03X0oooo0P0000060?ooo`030000O`3oool0oooo0440
oooo0`008]/70?ooo`800000=`3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo00d0oooo0`00000b0?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0l0?ooo`<000000`3oool00`0007l0oooo
0?ooo`110?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?oo
o`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo03l0oooo0P00
00000`3oool0001o0?ooo`120?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool0
0`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3
00000480oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo
0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`040000O`3oool00000
00000400oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo
0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`040000O`3oool0oooo
0?ooo`<00000?@3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo0P00000Q0?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`040?oo
o`<00000>P3oool3000Rf`L0oooo0P00000g0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`070?ooo`80
0000>03oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<000000?ooo`3oool0
803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
2@3oool3000003D0oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003o
ool0oooo0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo00`0oooo0P00000c0?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00E03oool6
000000T0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool03P3oool200000340oooo0`008]/80?ooo`030000003oool0
oooo03D0oooo001E0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0803oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0403oool20000
02l0oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001F0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool04P3oool3000002`0oooo0`008]/80?ooo`030000003oool0oooo03D0
oooo001G0?ooo`030000003oool0oooo00T0oooo0`00003o0000Oi80001o0P00000Z0000O`<002;K
1P0007l3000003L0oooo001H0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0803o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool05`3o
ool2000002P0oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001I0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool06@3oool2000002H0oooo0`008]/80?ooo`030000003oool0
oooo03D0oooo001I0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0803oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool06`3oool30000
02<0oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001I0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool07P3oool200000240oooo0`008]/80?ooo`030000003oool0oooo03D0
oooo001D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`0P0?ooo`8000007`3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool005D0oooo1000
000:0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0280oooo0`00000L0?ooo`<002;K203oool00`000000oooo0?oo
o`0e0?ooo`00H`3oool200000240oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo02D0oooo0P00000J0?ooo`<002;K1`3oool2000003L0oooo001S0?oo
o`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo02L0oooo0`00000G0?ooo`<002;K203oool00`000000oooo0?ooo`0e0?oo
o`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`0Z0?ooo`8000005@3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0;03oool2000001<0oooo0`008]/80?ooo`030000
003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo02h0oooo0`00000@0?ooo`<002;K203o
ool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0a0?ooo`8000003P3oool3
000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0<`3oool20000
00`0oooo0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`8000008@3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0=@3oool2000000X0
oooo0`008]/70?ooo`800000=`3oool006<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0=`3oool3000000L0oooo
0`008]/80?ooo`030000003oool0oooo03D0oooo001S0?ooo`030000003oool0oooo0200oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo03X0oooo0P00
00050?ooo`<002;K203oool00`000000oooo0?ooo`0e0?ooo`00H`3oool00`000000oooo0?ooo`0P
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0l
0?ooo`8000000`3oool3000Rf`P0oooo00<000000?ooo`3oool0=@3oool006<0oooo00<000000?oo
o`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0?P3oool2000000040?ooo`008]/002;K000Rf`P0oooo00<000000?ooo`3oool0=@3oool0
06<0oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@03oool300000003000Rf`3oool0oooo00H0oooo00<000000?oo
o`3oool0=@3oool006<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0@@3oool3000Rf`P0oooo00<000000?ooo`3o
ool0=@3oool006<0oooo0P00000Q0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00H0oooo0P00000g0?ooo`00H`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03D0oooo001S0?ooool00000c@00000g
0?ooo`00o`3ooooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00o`3o
oooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00o`3ooooo0?ooofP0
oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00o`3ooooo0?ooofP0oooo003o0?oo
obH0oooo1P0000040?ooo`<00000103oool2000000050?ooo`000000oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`<000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0?ooo`<0
0000n`3oool00?l0oooo9P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0
oooo00@000000?ooo`3oool000000P3oool200000080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`05
0000003oool0oooo0?ooo`000000nP3oool00?l0oooo9P3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`3l0?ooo`00o`3ooolV0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@0000030?ooo`@000000P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
1@00003j0?ooo`00o`3ooolV0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`H000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`00
0000nP3oool00?l0oooo9P3oool6000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool200000080oooo0P0000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0200000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`3h0?ooo`00o`3ooolV0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool0oooo0`0000040?ooo`<000000`3oool010000000oooo0000000000020?ooo`80
00001P3oool00`000000oooo0?ooo`030?ooo`060000003oool0oooo0000003oool000000P3oool3
00000080oooo0`0000001@3oool000000?ooo`3oool0000000<0oooo0`00003k0?ooo`00o`3ooolV
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o
0?ooo`00o`3ooolV0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`3o0?ooo`00o`3ooolV0?ooo`H000007`3oool6000000l0oooo0`0000020?ooo`03
0000003oool0oooo0?l0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00\
\>"],
  ImageRangeCache->{{{57.1875, 547.375}, {359.75, 164.313}} -> {-3.98809, \
2.18243, 0.0145191, 0.0290779}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AS Port Beam Profile (X-Arm of Michelson)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TelescopePlot[{zETM + MichelsonAsymmetry/2, 5.0}, {CavityWaist, 
          zCavityWaist + MichelsonAsymmetry/2}, {{ITMFocalLength, 
            zITM + MichelsonAsymmetry/2}, {fLX, zLX}, {fL2, zL2}}, 
        kk];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.220333 0.151172 0.2 0.0765308 [
[.06916 -0.0125 -10.0938 -16.375 ]
[.06916 -0.0125 10.0938 0 ]
[.22033 -0.0125 -5.59375 -16.375 ]
[.22033 -0.0125 5.59375 0 ]
[.3715 -0.0125 -5.59375 -16.375 ]
[.3715 -0.0125 5.59375 0 ]
[.52268 -0.0125 -5.59375 -16.375 ]
[.52268 -0.0125 5.59375 0 ]
[.67385 -0.0125 -5.59375 -16.375 ]
[.67385 -0.0125 5.59375 0 ]
[.82502 -0.0125 -5.59375 -16.375 ]
[.82502 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -16.375 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -43.1563 -32.75 ]
[.5 -0.0125 43.1563 -16.375 ]
[-0.0125 .04694 -20.1875 -8.1875 ]
[-0.0125 .04694 0 8.1875 ]
[-0.0125 .12347 -20.1875 -8.1875 ]
[-0.0125 .12347 0 8.1875 ]
[-0.0125 .2 -11.1875 -8.1875 ]
[-0.0125 .2 0 8.1875 ]
[-0.0125 .27653 -11.1875 -8.1875 ]
[-0.0125 .27653 0 8.1875 ]
[-0.0125 .35306 -11.1875 -8.1875 ]
[-0.0125 .35306 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .2 -36.5625 -44.3438 ]
[-0.01875 .2 -20.1875 44.3438 ]
[ 0 .4 .125 0 ]
[.5 .4125 -39 0 ]
[.5 .4125 39 16.375 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.06916 0 m
.06916 .4 L
s
.22033 0 m
.22033 .4 L
s
.3715 0 m
.3715 .4 L
s
.52268 0 m
.52268 .4 L
s
.67385 0 m
.67385 .4 L
s
.82502 0 m
.82502 .4 L
s
0 .04694 m
1 .04694 L
s
0 .12347 m
1 .12347 L
s
0 .2 m
1 .2 L
s
0 .27653 m
1 .27653 L
s
0 .35306 m
1 .35306 L
s
0 g
.06916 0 m
.06916 .00625 L
s
gsave
.06916 -0.0125 -71.0938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.22033 0 m
.22033 .00625 L
s
gsave
.22033 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.3715 0 m
.3715 .00625 L
s
gsave
.3715 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.52268 0 m
.52268 .00625 L
s
gsave
.52268 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.67385 0 m
.67385 .00625 L
s
gsave
.67385 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.82502 0 m
.82502 .00625 L
s
gsave
.82502 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.0994 0 m
.0994 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.15986 0 m
.15986 .00375 L
s
.1901 0 m
.1901 .00375 L
s
.25057 0 m
.25057 .00375 L
s
.2808 0 m
.2808 .00375 L
s
.31104 0 m
.31104 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.43197 0 m
.43197 .00375 L
s
.46221 0 m
.46221 .00375 L
s
.49244 0 m
.49244 .00375 L
s
.55291 0 m
.55291 .00375 L
s
.58314 0 m
.58314 .00375 L
s
.61338 0 m
.61338 .00375 L
s
.64361 0 m
.64361 .00375 L
s
.70408 0 m
.70408 .00375 L
s
.73432 0 m
.73432 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79478 0 m
.79478 .00375 L
s
.85525 0 m
.85525 .00375 L
s
.88549 0 m
.88549 .00375 L
s
.91572 0 m
.91572 .00375 L
s
.94596 0 m
.94596 .00375 L
s
.03893 0 m
.03893 .00375 L
s
.00869 0 m
.00869 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -104.156 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.438 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.875 16.625 moveto
(@) show
130.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
141.000 16.625 moveto
(D) show
145.313 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .04694 m
.00625 .04694 L
s
gsave
-0.0125 .04694 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .12347 m
.00625 .12347 L
s
gsave
-0.0125 .12347 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
gsave
-0.0125 .2 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .27653 m
.00625 .27653 L
s
gsave
-0.0125 .27653 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .35306 m
.00625 .35306 L
s
gsave
-0.0125 .35306 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06224 m
.00375 .06224 L
s
0 .07755 m
.00375 .07755 L
s
0 .09286 m
.00375 .09286 L
s
0 .10816 m
.00375 .10816 L
s
0 .13878 m
.00375 .13878 L
s
0 .15408 m
.00375 .15408 L
s
0 .16939 m
.00375 .16939 L
s
0 .18469 m
.00375 .18469 L
s
0 .21531 m
.00375 .21531 L
s
0 .23061 m
.00375 .23061 L
s
0 .24592 m
.00375 .24592 L
s
0 .26122 m
.00375 .26122 L
s
0 .29184 m
.00375 .29184 L
s
0 .30714 m
.00375 .30714 L
s
0 .32245 m
.00375 .32245 L
s
0 .33776 m
.00375 .33776 L
s
0 .03163 m
.00375 .03163 L
s
0 .01633 m
.00375 .01633 L
s
0 .00102 m
.00375 .00102 L
s
0 .36837 m
.00375 .36837 L
s
0 .38367 m
.00375 .38367 L
s
0 .39898 m
.00375 .39898 L
s
.25 Mabswid
0 0 m
0 .4 L
s
gsave
-0.01875 .2 -133.719 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
105.344 12.1875 translate
90 rotate
-105.344 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(spot) show
90.938 16.625 moveto
(size) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.438 16.625 moveto
(@) show
121.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
143.375 16.625 moveto
(D) show
147.688 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.06916 .39375 m
.06916 .4 L
s
.22033 .39375 m
.22033 .4 L
s
.3715 .39375 m
.3715 .4 L
s
.52268 .39375 m
.52268 .4 L
s
.67385 .39375 m
.67385 .4 L
s
.82502 .39375 m
.82502 .4 L
s
.97619 .39375 m
.97619 .4 L
s
.125 Mabswid
.0994 .39625 m
.0994 .4 L
s
.12963 .39625 m
.12963 .4 L
s
.15986 .39625 m
.15986 .4 L
s
.1901 .39625 m
.1901 .4 L
s
.25057 .39625 m
.25057 .4 L
s
.2808 .39625 m
.2808 .4 L
s
.31104 .39625 m
.31104 .4 L
s
.34127 .39625 m
.34127 .4 L
s
.40174 .39625 m
.40174 .4 L
s
.43197 .39625 m
.43197 .4 L
s
.46221 .39625 m
.46221 .4 L
s
.49244 .39625 m
.49244 .4 L
s
.55291 .39625 m
.55291 .4 L
s
.58314 .39625 m
.58314 .4 L
s
.61338 .39625 m
.61338 .4 L
s
.64361 .39625 m
.64361 .4 L
s
.70408 .39625 m
.70408 .4 L
s
.73432 .39625 m
.73432 .4 L
s
.76455 .39625 m
.76455 .4 L
s
.79478 .39625 m
.79478 .4 L
s
.85525 .39625 m
.85525 .4 L
s
.88549 .39625 m
.88549 .4 L
s
.91572 .39625 m
.91572 .4 L
s
.94596 .39625 m
.94596 .4 L
s
.03893 .39625 m
.03893 .4 L
s
.00869 .39625 m
.00869 .4 L
s
.25 Mabswid
0 .4 m
1 .4 L
s
gsave
.5 .4125 -100 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
100.375 16.625 moveto
(Profile) show
137.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .04694 m
1 .04694 L
s
.99375 .12347 m
1 .12347 L
s
.99375 .2 m
1 .2 L
s
.99375 .27653 m
1 .27653 L
s
.99375 .35306 m
1 .35306 L
s
.125 Mabswid
.99625 .06224 m
1 .06224 L
s
.99625 .07755 m
1 .07755 L
s
.99625 .09286 m
1 .09286 L
s
.99625 .10816 m
1 .10816 L
s
.99625 .13878 m
1 .13878 L
s
.99625 .15408 m
1 .15408 L
s
.99625 .16939 m
1 .16939 L
s
.99625 .18469 m
1 .18469 L
s
.99625 .21531 m
1 .21531 L
s
.99625 .23061 m
1 .23061 L
s
.99625 .24592 m
1 .24592 L
s
.99625 .26122 m
1 .26122 L
s
.99625 .29184 m
1 .29184 L
s
.99625 .30714 m
1 .30714 L
s
.99625 .32245 m
1 .32245 L
s
.99625 .33776 m
1 .33776 L
s
.99625 .03163 m
1 .03163 L
s
.99625 .01633 m
1 .01633 L
s
.99625 .00102 m
1 .00102 L
s
.99625 .36837 m
1 .36837 L
s
.99625 .38367 m
1 .38367 L
s
.99625 .39898 m
1 .39898 L
s
.25 Mabswid
1 0 m
1 .4 L
s
.977 .121 .023 r
.0075 w
.17498 .12818 m
.17498 .27182 L
s
.20144 .09304 m
.20144 .30696 L
s
.25813 .07627 m
.25813 .32373 L
s
0 .133 .859 r
.02381 .12818 m
.02381 .27182 L
s
.97619 .00952 m
.97619 .39048 L
s
0 g
.5 Mabswid
.02381 .27182 m
.04262 .25474 L
.06244 .2372 L
.07216 .22902 L
.0775 .22479 L
.08255 .22108 L
.08542 .21918 L
.08693 .21826 L
.08852 .21735 L
.08987 .21665 L
.09135 .21595 L
.0927 .21541 L
.09396 .21497 L
.09461 .21477 L
.09533 .21459 L
.09663 .21432 L
.0979 .21415 L
.09907 .21409 L
.09979 .21409 L
.10047 .21412 L
.10174 .21425 L
.10245 .21437 L
.1031 .2145 L
.10382 .21468 L
.10458 .21489 L
.1058 .2153 L
.10713 .21582 L
.10838 .21638 L
.10954 .21696 L
.11406 .21962 L
.11898 .22305 L
.12422 .22708 L
.14255 .2426 L
.1803 .27887 L
.19052 .29244 L
.19609 .29985 L
.19881 .30346 L
.19999 .30504 L
.20128 .30675 L
.20246 .30726 L
.20356 .30758 L
.20572 .30821 L
.21046 .3096 L
.22051 .31256 L
.24049 .31848 L
.24551 .31997 L
.25026 .32138 L
.25454 .32266 L
.25571 .32301 L
.25695 .32338 L
Mistroke
.25813 .32373 L
.25919 .32328 L
.26824 .31953 L
.27796 .31551 L
.2986 .307 L
.33871 .29065 L
.37732 .27528 L
.41837 .25963 L
.43883 .25229 L
.45791 .24591 L
.47628 .24038 L
.48657 .23765 L
.49594 .23546 L
.50076 .23446 L
.50588 .23351 L
.51024 .23279 L
.51506 .23211 L
.51775 .23178 L
.52022 .23151 L
.52293 .23125 L
.52429 .23114 L
.52578 .23103 L
.52708 .23094 L
.5283 .23087 L
.52971 .2308 L
.53099 .23074 L
.5322 .23069 L
.53332 .23066 L
.53454 .23063 L
.53583 .23061 L
.53705 .2306 L
.53774 .2306 L
.53837 .2306 L
.53954 .23061 L
.54078 .23063 L
.54189 .23066 L
.54293 .23068 L
.54407 .23072 L
.5453 .23078 L
.54653 .23084 L
.54787 .23091 L
.54928 .231 L
.55059 .2311 L
.55294 .23129 L
.55545 .23153 L
.55781 .23179 L
.56038 .23211 L
.56505 .23277 L
.56958 .23351 L
.57377 .23429 L
Mistroke
.58345 .23635 L
.59251 .23858 L
.61314 .24452 L
.65194 .25775 L
.69318 .27334 L
.73291 .28911 L
.77112 .30465 L
.81179 .32143 L
.85094 .33774 L
.89254 .35518 L
.93263 .37207 L
.9712 .38836 L
.97619 .39048 L
Mfstroke
.02381 .12818 m
.04262 .14526 L
.06244 .1628 L
.07216 .17098 L
.0775 .17521 L
.08255 .17892 L
.08542 .18082 L
.08693 .18174 L
.08852 .18265 L
.08987 .18335 L
.09135 .18405 L
.0927 .18459 L
.09396 .18503 L
.09461 .18523 L
.09533 .18541 L
.09663 .18568 L
.0979 .18585 L
.09907 .18591 L
.09979 .18591 L
.10047 .18588 L
.10174 .18575 L
.10245 .18563 L
.1031 .1855 L
.10382 .18532 L
.10458 .18511 L
.1058 .1847 L
.10713 .18418 L
.10838 .18362 L
.10954 .18304 L
.11406 .18038 L
.11898 .17695 L
.12422 .17292 L
.14255 .1574 L
.1803 .12113 L
.19052 .10756 L
.19609 .10015 L
.19881 .09654 L
.19999 .09496 L
.20128 .09325 L
.20246 .09274 L
.20356 .09242 L
.20572 .09179 L
.21046 .0904 L
.22051 .08744 L
.24049 .08152 L
.24551 .08003 L
.25026 .07862 L
.25454 .07734 L
.25571 .07699 L
.25695 .07662 L
Mistroke
.25813 .07627 L
.25919 .07672 L
.26824 .08047 L
.27796 .08449 L
.2986 .093 L
.33871 .10935 L
.37732 .12472 L
.41837 .14037 L
.43883 .14771 L
.45791 .15409 L
.47628 .15962 L
.48657 .16235 L
.49594 .16454 L
.50076 .16554 L
.50588 .16649 L
.51024 .16721 L
.51506 .16789 L
.51775 .16822 L
.52022 .16849 L
.52293 .16875 L
.52429 .16886 L
.52578 .16897 L
.52708 .16906 L
.5283 .16913 L
.52971 .1692 L
.53099 .16926 L
.5322 .16931 L
.53332 .16934 L
.53454 .16937 L
.53583 .16939 L
.53705 .1694 L
.53774 .1694 L
.53837 .1694 L
.53954 .16939 L
.54078 .16937 L
.54189 .16934 L
.54293 .16932 L
.54407 .16928 L
.5453 .16922 L
.54653 .16916 L
.54787 .16909 L
.54928 .169 L
.55059 .1689 L
.55294 .16871 L
.55545 .16847 L
.55781 .16821 L
.56038 .16789 L
.56505 .16723 L
.56958 .16649 L
.57377 .16571 L
Mistroke
.58345 .16365 L
.59251 .16142 L
.61314 .15548 L
.65194 .14225 L
.69318 .12666 L
.73291 .11089 L
.77112 .09535 L
.81179 .07857 L
.85094 .06226 L
.89254 .04482 L
.93263 .02793 L
.9712 .01164 L
.97619 .00952 L
Mfstroke
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{612.625, 245},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009T0000mB000`400?l00000o`00003oo`3ooooo
0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo;`3oool00`000000oooo0?ooo`0]0?ooo`<0
00003@3oool300000?<0oooo003o0?ooobl0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0?40oooo003o0?ooobl0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?40oooo003o0?ooob40oooo1@000009
0?ooo`040000003oool00000000000@0oooo0`0000040?ooo`<000000`3oool00`000000oooo0?oo
o`0200000080oooo00@000000?ooo`3oool0oooo0`0000030?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob80oooo00<000000?ooo`3o
ool02P3oool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000003
0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3a0?ooo`00o`3ooolR0?ooo`030000003oool0oooo00X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo0?oo
o`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0l@3o
ool00?l0oooo8`3oool010000000oooo0?ooo`3oool7000000030?ooo`000000oooo0080oooo00@0
00000?ooo`3oool000000`3oool010000000oooo0?ooo`3oool3000000<0oooo00@000000?ooo`3o
ool000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob@0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob@0oooo00<000000?ooo`3oool0203o
ool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3a0?ooo`00o`3ooolQ0?ooo`D000002@3oool010000000oooo0000000000040?ooo`<00000103o
ool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`040000003oool0oooo0?ooo`<00000
0`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0080oooo00@000000?ooo`00
000000000P3oool2000000D0oooo00<000000?ooo`3oool0l@3oool00?l0ooooA`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0l@3oool00?l0oooo
A`3oool00`000000oooo0?ooo`0E0?ooo`<000003@3oool300000?<0oooo003o0?oood@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooaP0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3o
oomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool008H0oooo00<000000?ooo`3o
ool0?03oool4000004<0oooo00<000000?ooo`3oool0@03oool600000400oooo100000140?ooo`03
0000003oool0oooo0400oooo100000100?ooo`00QP3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0m0?ooo`00QP3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0?@3o
ool6000004D0oooo00<000000?ooo`3oool0?@3oool007/0oooo1`0000040?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0n0?ooo`040000003oool0
oooo000004H0oooo00<000000?ooo`3oool0?@3oool008H0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo03h0oooo00@000000?ooo`3oool00000@@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo00260?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool0?`3oool300000480oooo00<000000?ooo`000000@@3oool5
00000400oooo00260?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool000000440oooo00<000000?ooo`3oool0@P3oool008@0
oooo00<000000?ooo`000000?@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`000000A`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0400
oooo0P0000120?ooo`030000003oool0oooo0440oooo00250?ooo`800000?@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03l0oooo0P0000120?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo
0P0000120?ooo`030000003oool0oooo0440oooo00260?ooo`030000003oool0oooo03`0oooo1000
00130?ooo`030000003oool0oooo0440oooo100000110?ooo`@00000A03oool00`000000oooo0?oo
o`100?ooo`D00000?`3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0
ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00H`3ooooo00000<`00000=P3oool006<0oooo00D000000?ooo`3oool0
oooo0000000<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0d0?ooo`00H`3oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003o
ool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo00<002;K000000008]/02@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool0
0`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`0o0?ooo`<000000P008]/90?ooo`030000003oool0oooo03@0oooo001S0?oo
o`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo03d0oooo0P0000020?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00H`3oool2000001d0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo03/0oooo0P0000040?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000
003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo03T0oooo0P0000060?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3o
ool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`0f0?ooo`<00000203oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0=03oool2000000/0oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0380oooo0P00000=0?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0`0?ooo`8000003`3oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo
0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0;@3oool300000140oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`8000007@3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0:`3oool2000001@0oooo0`00
8]/70?ooo`<00000=P3oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0:@3oool2000001H0oooo0`008]/9
0?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo02L0oooo0P00000H0?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0T0?ooo`<0
00006P3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005@0oooo1P0000090?ooo`030000
003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0280oooo0P00000M0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0200oooo0P00000O0?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00EP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo01h0oooo0P00000Q0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00C03oool70000
00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0K0?ooo`<000008`3oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool005P0oooo00<000000?ooo`3oool0203oool300000?l0
001oU00007l2000002H0001o0`008]/60000O`@00000=P3oool005T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`0G0?ooo`800000:03oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool005T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0D0?ooo`<00000:P3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`0B0?ooo`800000;@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
05@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
00l0oooo0`00000_0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E@3oool4000000X0
oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool03@3oool200000380oooo0`008]/90?ooo`030000003oool0oooo03@0
oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo00/0oooo0P00000d0?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00H`3oool2000001d0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo00P0oooo0`00000f0?ooo`<002;K1`3oool3000003H0oooo001S
0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo00H0oooo0P00000i0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`030?ooo`<00000>`3oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`03
0000O`3oool0oooo0480oooo00@0001o0?ooo`3oool0oooo0P00000n0?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool0@P3oool0100007l000000000000000100?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`130?ooo`030000O`3oool0oooo0400oooo0`0000130?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo
00<0001o0?ooo`3oool0303oool400000380oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`130?ooo`030000O`3oool0oooo03h0oooo0P0000020?ooo`030000O`3oool0oooo0440oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`8000007@3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo00X0oooo0P000000103oool0nQh50?XN1@3j7PD200000300oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo03/0oooo
0`0000040?ooo`030000O`3oool0oooo0440oooo0`008]/70?ooo`<00000=P3oool006<0oooo00<0
00000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo00D0oooo1@00
00030?ooo`<0nQh50P3oool2000002h0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo03T0oooo0P0000070?ooo`030000O`3oool0oooo0440oooo0`00
8]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`020?ooo`<00000203oool30?XN1@@0oooo0P00000/
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0g
0?ooo`8000002@3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`0000000P00000;0?ooo`<0nQh51P3oool3000002T0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`130?ooo`030000O`3oool0oooo03@0oooo0`00000;0?ooo`030000O`3oool0oooo
0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0
oooo00<0001o0?ooo`3oool0@@3oool4000000h0oooo0`3j7PD90?ooo`8000009`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0<P3oool2000000h0
oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo
00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`0n0?ooo`<000000P3oool00`0007l0oooo
0?ooo`0=0?ooo`<0nQh52`3oool2000002D0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`130?ooo`030000O`3oool0oooo02l0oooo0`00000@0?ooo`030000O`3oool0oooo0440oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0
001o0?ooo`3oool0>@3oool20?XN1@<000001@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh53@3o
ool2000002<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3o
ool0oooo02d0oooo0P00000C0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo001S0?ooo`8000007@3oool00`0007l0oooo0?ooo`0i0?ooo`030?XN1@000000
nQh500L0oooo00<0001o0?ooo`3oool03@3oool30?XN1@l0oooo0`00000P0?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0[0?ooo`8000005@3oool0
0`0007l0oooo0?ooo`110?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000003oool0oooo
01`0oooo00<0001o0?ooo`3oool0>@3oool00`000000nQh50?XN1@070?ooo`030000O`3oool0oooo
00d0oooo0`3j7PDB0?ooo`<000007@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0:03oool3000001L0oooo00<0001o0?ooo`3oool0@@3oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0
oooo0?ooo`0h0?ooo`040000003j7PD0nQh50?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN
1AD0oooo0P00000K0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`0V0?ooo`8000006P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo03L0
oooo00<000000?ooo`3j7PD00P3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDG0?ooo`<0
0000603oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3o
ool08`3oool3000001`0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`0f0?ooo`030000
003oool0oooo00<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh56P3oool3000001D0oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0240oooo
0P00000O0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0=P3oool00`000000oooo0?oo
o`030?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1Ad0oooo0P00000C0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0O0?ooo`8000008@3o
ool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool0
0`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo03D0oooo00@000000?ooo`3oool0oooo0`3j
7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDO0?ooo`<00000403oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0703oool3000002<0oooo00<0
001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo0P00000M
0?ooo`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool00P3oool30?XN1@L0oooo00<0001o
0?ooo`3oool03@3oool30?XN1B80oooo0`00000=0?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0J0?ooo`8000009P3oool00`0007l0oooo0?ooo`11
0?ooo`<002;K1`3oool3000003H0oooo000l0?ooo`8000000P3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`020?oo
o`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh59@3oool2000000/0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo01L0oooo0`00000X0?oo
o`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0L0?oo
o`030000O`3oool0oooo03<0oooo00<000000?ooo`3oool00`3oool30?XN1@L0oooo00<0001o0?oo
o`3oool03@3oool30?XN1BL0oooo0`0000080?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`0D0?ooo`<00000:`3oool00`0007l0oooo0?ooo`110?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?oo
o`030000O`3oool0oooo0380oooo00<000000?ooo`3oool0103oool30?XN1@L0oooo00<0001o0?oo
o`3oool03@3oool30?XN1BX0oooo0P0000060?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`0B0?ooo`800000;P3oool00`0007l0oooo0?ooo`110?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?oo
o`030000O`3oool0oooo0340oooo00<000000?ooo`3oool01@3oool30?XN1@L0oooo00<0001o0?oo
o`3oool03@3oool30?XN1B`0oooo0`0000030?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`0?0?ooo`<00000<03oool00`0007l0oooo0?ooo`110?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool00`000000oooo0?ooo`02000001H0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo0340
oooo00<000000?ooo`3oool01@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1Bl0
oooo0`0000000`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3o
ool0303oool3000003<0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool004`0oooo1`0000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
703oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo00H0oooo0`3j7PD70?ooo`030000
O`3oool0oooo00d0oooo0`3j7PDb0?ooo`800000@`3oool00`0007l0oooo0?ooo`130?ooo`030000
O`3oool0oooo00X0oooo0P00000f0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000
003oool0oooo03@0oooo001G0?ooo`030000003oool0oooo00T0oooo0`00001>0000O`0300000000
07l0001o00L0001o0`3j7PDG0000O`<0nQh5=00007l300000900001o0`00001l0000O`<002;K1P00
07l4000003H0oooo000k0?ooo`X000004P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00H0oooo0`008]/C0?ooo`030000O`3oool0oooo02d0oooo00<0nQh50000003j7PD02@3oool3
0?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool00P3oool2
000003h0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`040?ooo`<00000>`3oool0
0`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool01@00
0000oooo0?ooo`3oool0000001H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`06
0?ooo`03000Rf`00000002;K01<0oooo00<0001o0?ooo`3oool0;@3oool00`000000nQh50?XN1@09
0?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`04
0?ooo`<00000>`3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0080oooo0P00000n
0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0000000;0?oo
o`030000003oool0oooo00H0oooo0P008]/00`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo
02`0oooo00@000000?XN1@3j7PD0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool3
0?XN1C80oooo00<0001o0?ooo`3oool01`3oool2000003T0oooo00<0001o0?ooo`3oool0@`3oool0
0`0007l0oooo0000000200000400oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<00000
0?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?oo
o`8000002`3oool00`000000oooo0?ooo`060?ooo`<002;K00<000000?ooo`3oool0403oool00`00
07l0oooo0?ooo`0[0?ooo`030000003oool0nQh50080nQh52@3oool30?XN1@L0oooo00<0001o0?oo
o`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool02@3oool3000003H0oooo00<0001o0?oo
o`3oool0@`3oool2000004<0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool003`0oooo1@00000F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01P3oool3000Rf`030?ooo`000000oooo0100oooo00<0001o0?ooo`3oool0:P3oool00`000000
oooo0?ooo`030?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`03
0000O`3oool0oooo00`0oooo0`00000c0?ooo`030000O`3oool0oooo0400oooo0`0000000`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0
oooo001S0?ooo`030000003oool0oooo00H0oooo0`008]/20?ooo`8000003`3oool00`0007l0oooo
0?ooo`0Y0?ooo`040000003oool0oooo0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3o
ool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool03`3oool200000340oooo00<0001o0?ooo`3o
ool0?@3oool3000000<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000000L0oooo0`008]/40?ooo`030000
003oool0oooo00`0oooo00<0001o0?ooo`3oool09`3oool2000000@0oooo0`3j7PD90?ooo`<0nQh5
1`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`0A0?ooo`<00000
;P3oool00`0007l0oooo0?ooo`0k0?ooo`8000001P3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo0`008]/70?ooo`<00000=P3oool003`0oooo1@00000R0?ooo`030000003o
ool0oooo00H0oooo0`008]/50?ooo`030000003oool0oooo00/0oooo00<0001o0?ooo`3oool09P3o
ool00`000000oooo0?ooo`040?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3o
ool30?XN1C80oooo00<0001o0?ooo`3oool0503oool2000002`0oooo00<0001o0?ooo`3oool0>03o
ool3000000P0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool01P3oool3000Rf`H0oooo00<000000?ooo`3oool02P3oool0
0`0007l0oooo0?ooo`0U0?ooo`030000003oool0oooo00D0oooo0`3j7PD90?ooo`<0nQh51`3oool0
0`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`0F0?ooo`<00000:@3oool0
0`0007l0oooo0?ooo`0e0?ooo`<000002`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`<002;K1`3oool00`00
0000oooo0?ooo`090?ooo`030000O`3oool0oooo02@0oooo00<000000?ooo`3oool01P3oool30?XN
1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo
01T0oooo0P00000W0?ooo`030000O`3oool0oooo0380oooo0`00000>0?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00H0
oooo0`008]/80?ooo`030000003oool0oooo00P0oooo00<0001o0?ooo`3oool08`3oool00`000000
oooo0?ooo`070?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80
oooo00<0001o0?ooo`3oool06`3oool3000002@0oooo00<0001o0?ooo`3oool0;`3oool300000140
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00?03oool500000280oooo00<000000?ooo`3oool01P3oool3000Rf`T0oooo
00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo
0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo
0?ooo`0N0?ooo`<000008@3oool00`0007l0oooo0?ooo`0/0?ooo`<00000503oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
001S0?ooo`030000003oool0oooo00H0oooo0`008]/:0?ooo`030000003oool0oooo00H0oooo00<0
001o0?ooo`3oool08@3oool00`000000oooo0?ooo`090?ooo`<0nQh52@3oool30?XN1@L0oooo00<0
001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool08@3oool3000001h0oooo00<0
001o0?ooo`3oool0:@3oool3000001L0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`0U
0?ooo`8000001`3oool3000Rf`/0oooo0P0000060?ooo`030000O`3oool0oooo0200oooo00<00000
0?ooo`3oool02P3oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb
0?ooo`030000O`3oool0oooo02@0oooo0`00000K0?ooo`030000O`3oool0oooo02H0oooo0`00000J
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`L0oooo0`00000f
0?ooo`00>@3oool900000240oooo00<000000?ooo`3oool01P3oool3000Rf`d0oooo00<000000?oo
o`3oool00`3oool00`0007l0oooo0?ooo`0O0?ooo`030000003oool0oooo00/0oooo0`3j7PD90?oo
o`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`0W0?oo
o`@000005`3oool00`0007l0oooo0?ooo`0S0?ooo`<000007@3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`<0
02;K3P3oool00`000000oooo0?ooo`020?ooo`030000O`3oool0oooo01h0oooo00<000000?ooo`3o
ool0303oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`03
0000O`3oool0oooo02/0oooo1@00000B0?ooo`030000O`3oool0oooo01l0oooo1000000P0?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool006<0oooo00<000000?ooo`3oool01P3oool3000Rf`l0oooo00D000000?ooo`3oool0
oooo0000O`0O0?ooo`030000003oool0oooo00d0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0
oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`0`0?ooo`@000003P3oool00`0007l0
oooo0?ooo`0L0?ooo`<00000903oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo00H0oooo
0`008]/@0?ooo`040000003oool0oooo0000Oah0oooo00<000000?ooo`3oool03P3oool30?XN1@T0
oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo03@0
oooo0`00000;0?ooo`030000O`3oool0oooo01P0oooo1000000W0?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo
00<000000?ooo`3oool01P3oool3000Rfa40oooo0P0000000`0007l0oooo0?ooo`0J0?ooo`800000
4@3oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000
O`3oool0oooo03L0oooo1@0000060?ooo`030000O`3oool0oooo01<0oooo1@00000[0?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool006<0oooo00<000000?ooo`3oool01P3oool3000Rfa<0oooo0P00000J0?ooo`030000003o
ool0oooo0140oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3o
ool00`0007l0oooo0?ooo`0l0?ooo`T000002@3oool:00000300oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2
000000L0oooo0`008]/C0?ooo`030000O`3oool0000001P0oooo00<000000?ooo`3oool04P3oool3
0?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool02P00000i0?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@@3oool3000Rf`L0oooo0`00000f0?ooo`00?03oool200000080oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`060?ooo`<002;K4`3oool0100007l0oooo0?ooo`00000F
0?ooo`030000003oool0oooo01<0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=
0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool01P3oool3000Rfa<0oooo00D0001o0?ooo`3oool0oooo0000000C0?ooo`8000005P3o
ool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`<002;K4`3o
ool00`0007l0oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05P3o
ool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`<002;K4`3o
ool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05`3o
ool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`030000003oool0
oooo008000008P3oool00`000000oooo0?ooo`060?ooo`<002;K4`3oool00`0007l0oooo0?ooo`04
0?ooo`800000303oool00`000000oooo0?ooo`0H0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o
0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<00000
0?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool01P3oool3000Rfa<0oooo00<0001o0?oo
o`3oool01P3oool2000000L0oooo0`00000K0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?oo
o`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool006<0oooo0P0000070?ooo`<002;K4`3oool00`0007l0oooo0?ooo`080?ooo`L0
00007P3oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0440oooo0`008]/70?ooo`<00000=P3oool003P0oooo00<000000?ooo`3oool0
1`00000Q0?ooo`030000003oool0oooo00H0oooo0`008]/C0?ooo`030000O`3oool0oooo02d0oooo
0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?oo
o`060?ooo`<002;K4`3oool00`0007l0oooo0?ooo`0]0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0
001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool005D0oooo1000000:0?ooo`030000003oool0oooo00H0oooo0`008]/C
0?ooo`030000O`3oool0oooo02d0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=
0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00>`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo0`008]/C0?oo
o`030000O`3oool0oooo02d0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?oo
o`<0nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00>`3oool010000000oooo0?ooo`3oool300000180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo0`008]/C0?ooo`030000O`3oool0oooo
02d0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo0`008]/C0?ooo`030000O`3oool0oooo
02d0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool3000000<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0
oooo0`0000060000O`<002;K@`0007l30?XN1@T0001o0`3j7PDG0000O`<0nQh5o`0007m70000O`<0
02;K1P0007l4000003H0oooo000k0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool3000Rfa<0oooo00<0001o0?ooo`3oool0;@3oool30?XN1@T0oooo0`3j7PD70?ooo`030000
O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000
003oool0oooo03@0oooo001D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`<002;K4`3oool00`0007l0oooo0?ooo`0]0?ooo`<0nQh52@3o
ool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo0`008]/C0?ooo`030000O`3oool0
oooo02d0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool50000
01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00H0oooo0`008]/C0?ooo`030000O`3oool0oooo02d0oooo0`3j7PD90?ooo`<0nQh51`3oool00`00
07l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0140oooo1000000:0?ooo`030000003oool0oooo00H0oooo0`008]/C0?ooo`030000O`3oool0oooo
02d0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool3000R
fa<0oooo00<0001o0?ooo`3oool02@3oool5000001l0oooo0`3j7PD90?ooo`<0nQh51`3oool00`00
07l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
01l0oooo0P0000070?ooo`<002;K4`3oool00`0007l0oooo0?ooo`070?ooo`<00000103oool30000
01`0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`<002;K1`3oool3000003H0oooo000l0?ooo`<0000000<0oooo0000003o
ool08@3oool00`000000oooo0?ooo`060?ooo`<002;K4`3oool00`0007l0oooo0?ooo`050?ooo`80
00002P3oool00`000000oooo0?ooo`0I0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3o
ool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool006<0oooo00<000000?ooo`3oool01P3oool3000Rfa<0oooo00<0001o0?ooo`3oool0
0`3oool2000000d0oooo00<000000?ooo`3oool0603oool30?XN1@T0oooo0`3j7PD70?ooo`030000
O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000
003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo00H0oooo0`008]/C0?ooo`030000O`3o
ool0oooo0080oooo00<000000?ooo`3oool03P3oool2000001P0oooo0`3j7PD90?ooo`<0nQh51`3o
ool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`060?ooo`<002;K4`3oool0
1@0007l0oooo0?ooo`3oool0000001<0oooo0P00000F0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0
001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool01P3oool3000Rfa<0oooo00@0001o
0?ooo`3oool000005P3oool00`000000oooo0?ooo`0C0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0
001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool003T0oooo3000000N0?ooo`030000003oool0oooo00H0oooo0`008]/C
0?ooo`030000O`3oool0000001P0oooo00<000000?ooo`3oool04P3oool30?XN1@T0oooo0`3j7PD7
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/9
0?ooo`030000003oool0oooo03@0oooo000i0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0703oool2000000L0oooo0`008]/C0?ooo`030000O`000000oooo01T0oooo00<000000?oo
o`3oool04@3oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb0?oo
o`030000O`3oool0oooo03l0oooo5P00000c0?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool3000Rf`L0oooo0`00000f0?ooo`00>@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool3000Rfa80oooo0P00000L0?ooo`03
0000003oool0oooo0100oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0
nQh5<P3oool00`0007l0oooo0?ooo`0h0?ooo`L000000`3oool00`0007l0oooo0?ooo`0@0?ooo`L0
0000;03oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`03
0000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo00H0oooo0`008]/A0?ooo`030000
003oool0001o01d0oooo0P00000@0?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C80oooo00<0001o0?ooo`3oool0=@3oool3000000X0oooo00<0001o0?ooo`3oool0
5`3oool4000002P0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`060?ooo`<002;K403o
ool010000000oooo0?ooo`0007lO0?ooo`030000003oool0oooo00d0oooo0`3j7PD90?ooo`<0nQh5
1`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`0`0?ooo`D00000
3@3oool00`0007l0oooo0?ooo`0K0?ooo`@00000903oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`L000008@3o
ool00`000000oooo0?ooo`060?ooo`<002;K3`3oool01@000000oooo0?ooo`3oool0001o0200oooo
00<000000?ooo`3oool0303oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo
0`3j7PDb0?ooo`030000O`3oool0oooo02`0oooo1000000B0?ooo`030000O`3oool0oooo01l0oooo
0`00000Q0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool003`0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`060?ooo`<002;K3P3oool00`000000oooo0?ooo`020?ooo`030000O`3oool0oooo01l0oooo00<0
00000?ooo`3oool02`3oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j
7PDb0?ooo`030000O`3oool0oooo02X0oooo0P00000F0?ooo`030000O`3oool0oooo0280oooo1000
000M0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`06
0?ooo`<002;K3@3oool00`000000oooo0?ooo`030?ooo`030000O`3oool0oooo0200oooo00<00000
0?ooo`3oool02P3oool30?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDb
0?ooo`030000O`3oool0oooo02L0oooo0`00000H0?ooo`030000O`3oool0oooo02H0oooo0`00000J
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<00000
0?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool09@3oool2000000L0oooo0`008]/;0?oo
o`8000001P3oool00`0007l0oooo0?ooo`0Q0?ooo`030000003oool0oooo00T0oooo0`3j7PD90?oo
o`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`0T0?oo
o`<000006`3oool00`0007l0oooo0?ooo`0Y0?ooo`<000005`3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0440oooo0`008]/70?ooo`<00000=P3oool003`0oooo1P00000Q0?ooo`03
0000003oool0oooo00H0oooo0`008]/:0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3o
ool08P3oool00`000000oooo0?ooo`080?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3o
ool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool08@3oool3000001h0oooo00<0001o0?ooo`3o
ool0;03oool3000001@0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00H0oooo0`008]/90?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0
8`3oool00`000000oooo0?ooo`070?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C80oooo00<0001o0?ooo`3oool07P3oool300000240oooo00<0001o0?ooo`3oool0
;`3oool300000140oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00H0oooo0`008]/80?ooo`030000003oool0oooo00P0oooo00<0001o0?ooo`3oool0903o
ool00`000000oooo0?ooo`060?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3o
ool30?XN1C80oooo00<0001o0?ooo`3oool06`3oool3000002@0oooo00<0001o0?ooo`3oool0<P3o
ool3000000h0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00H0oooo0`008]/70?ooo`030000003oool0oooo00T0oooo00<0001o0?ooo`3oool09@3oool0
0`000000oooo0?ooo`050?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool3
0?XN1C80oooo00<0001o0?ooo`3oool0603oool3000002L0oooo00<0001o0?ooo`3oool0=@3oool3
000000/0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0d0?ooo`00?03oool600000240oooo00<000000?ooo`3oool01P3oool3000R
f`H0oooo00<000000?ooo`3oool02P3oool00`0007l0oooo0?ooo`0V0?ooo`030000003oool0oooo
00@0oooo0`3j7PD90?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`00
07l0oooo0?ooo`0D0?ooo`@00000:P3oool00`0007l0oooo0?ooo`0h0?ooo`<00000203oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo001S0?ooo`030000003oool0oooo00H0oooo0`008]/50?ooo`030000003oool0oooo00/0
oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`030?ooo`<0nQh52@3oool30?XN1@L0
oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3oool04@3oool3000002h0
oooo00<0001o0?ooo`3oool0>`3oool2000000H0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000000L0oooo
0`008]/40?ooo`030000003oool0oooo00`0oooo00<0001o0?ooo`3oool0:03oool00`000000oooo
0?ooo`020?ooo`<0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo
00<0001o0?ooo`3oool03`3oool200000340oooo00<0001o0?ooo`3oool0?@3oool3000000<0oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`<002;K1`3oool3000003H0oooo
000k0?ooo`L000008@3oool00`000000oooo0?ooo`060?ooo`<002;K0P3oool2000000l0oooo00<0
001o0?ooo`3oool0:@3oool010000000oooo0?ooo`3oool30?XN1@T0oooo0`3j7PD70?ooo`030000
O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0oooo00`0oooo0`00000c0?ooo`030000
O`3oool0oooo0400oooo0P0000000`3oool0001o0?ooo`130?ooo`030000O`3oool0oooo0440oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool01P3oool3000Rf`030?ooo`000000oooo0100oooo00<0001o0?ooo`3oool0:P3o
ool00`000000oooo0?ooo`030?XN1@T0oooo0`3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j
7PDb0?ooo`030000O`3oool0oooo00X0oooo0P00000f0?ooo`030000O`3oool0oooo0480oooo0`00
00130?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`06
0?ooo`<002;K00<000000?ooo`3oool0403oool00`0007l0oooo0?ooo`0[0?ooo`030000003oool0
nQh50080nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o
0?ooo`3oool01`3oool3000003P0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo00000002
00000400oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
03/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00H0oooo0P008]/00`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo02`0oooo00@000000?XN
1@3j7PD0nQh52@3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o
0?ooo`3oool0103oool3000003/0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`02
0?ooo`800000?P3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00?03oool6000001D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?oo
o`03000Rf`00000002;K01<0oooo00<0001o0?ooo`3oool0;@3oool00`000000nQh50?XN1@090?oo
o`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<P3oool00`0007l0oooo0?ooo`020?oo
o`800000?P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo00@0oooo0`00000k0?oo
o`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`<0
02;K4`3oool00`0007l0oooo0?ooo`0]0?ooo`030?XN1@000000nQh500T0oooo0`3j7PD70?ooo`03
0000O`3oool0oooo00d0oooo0`3j7PDb0?ooo`030000O`3oool0000000800000@03oool00`0007l0
oooo0?ooo`130?ooo`030000O`3oool0oooo00L0oooo0P00000i0?ooo`030000O`3oool0oooo0440
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool02@3oool3000004h0001o00<000000000O`0007l01`0007l30?XN1AL0001o
0`3j7PDb0000O`800000U@0007l2000007/0001o0`008]/60000O`@00000=P3oool003/0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01`0oooo00<0
001o0?ooo`3oool0<03oool00`000000oooo0?ooo`060?ooo`<0nQh51`3oool00`0007l0oooo0?oo
o`0=0?ooo`<0nQh5;`3oool3000000030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3o
ool00`0007l0oooo0?ooo`0;0?ooo`<00000=03oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00?03oool6000001D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo0340oooo00<000000?ooo`3oool01@3oool3
0?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1Bd0oooo0P0000030?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0>0?ooo`800000<P3oool0
0`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E@3oool00`00
0000oooo0000000;0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0<P3oool00`00
0000oooo0?ooo`040?ooo`<0nQh51`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5:P3oool30000
00D0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo
0100oooo0`00000_0?ooo`030000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo001F0?ooo`8000002`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo0380
oooo00<000000?ooo`3oool0103oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1BL0
oooo0`0000080?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`0C0?ooo`800000;@3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00>@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo03<0oooo
00<000000?ooo`3oool00`3oool30?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1BD0oooo
0P00000;0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`0E0?ooo`800000:`3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00>@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0703oool00`0007l0oooo0?ooo`0d0?ooo`030000003oool0oooo0080oooo0`3j
7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDR0?ooo`<000003@3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool05`3oool3000002P0oooo00<0
001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003T0oooo3000000N
0?ooo`8000007@3oool00`0007l0oooo0?ooo`0e0?ooo`040000003oool0oooo0?ooo`<0nQh51`3o
ool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5803oool200000100oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo01X0oooo0P00000V0?ooo`030000O`3o
ool0oooo0440oooo0`008]/70?ooo`<00000=P3oool006<0oooo00<000000?ooo`3oool0703oool0
0`0007l0oooo0?ooo`0f0?ooo`030000003oool0oooo00<0nQh51`3oool00`0007l0oooo0?ooo`0=
0?ooo`<0nQh57P3oool200000180oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo01`0oooo0`00000S0?ooo`030000O`3oool0oooo0440oooo0`008]/9
0?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?oo
o`3oool0=P3oool00`000000oooo0?ooo`030?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN
1A/0oooo0`00000D0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`0O0?ooo`8000008@3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo03L0
oooo00<000000?ooo`3j7PD00P3j7PD70?ooo`030000O`3oool0oooo00d0oooo0`3j7PDI0?ooo`80
00005`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3o
ool08@3oool2000001l0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`0h0?ooo`040000
003j7PD0nQh50?XN1@L0oooo00<0001o0?ooo`3oool03@3oool30?XN1AH0oooo0`00000I0?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0S0?ooo`<0
0000703oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo03T0oooo00<000000?XN1@3j7PD0
1`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5503oool2000001`0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo02H0oooo0P00000J0?ooo`030000
O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003o
ool0oooo01`0oooo00<0001o0?ooo`3oool0>@3oool00`000000nQh50?XN1@070?ooo`030000O`3o
ool0oooo00d0oooo0`3j7PDB0?ooo`8000007P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0:03oool3000001L0oooo00<0001o0?ooo`3oool0@@3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo0P00000M0?ooo`030000O`3oool0
oooo03T0oooo00@0nQh500000000000000001P3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh53`3o
ool300000200oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3o
ool0oooo02/0oooo0`00000D0?ooo`030000O`3oool0oooo0440oooo0`008]/70?ooo`<00000=P3o
ool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`0i0?ooo`<0nQh500<0oooo
0000000000000P0000020?ooo`030000O`3oool0oooo00d0oooo0`3j7PD=0?ooo`8000008`3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0;P3oool2
00000180oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
06<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`110?ooo`@000003P3oool30?XN
1@/0oooo0P00000U0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`0`0?ooo`<000003`3oool00`0007l0oooo0?ooo`110?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0
oooo00<0001o0?ooo`0000000P00000;0?ooo`<0nQh52@3oool2000002L0oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo03<0oooo0`00000<0?ooo`03
0000O`3oool0oooo0440oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000
003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`020?ooo`<00000
203oool30?XN1@H0oooo0`00000Y0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@`3oool00`0007l0oooo0?ooo`0f0?ooo`8000002P3oool00`0007l0oooo0?ooo`110?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool01@3oool2000000H0oooo0`3j7PD20?ooo`@00000;03o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0>03o
ool3000000L0oooo00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo00L0oooo100000020?ooo`<0nQh50P00000`0?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`0k0?ooo`<00000103oool00`0007l0oooo0?ooo`11
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000001d0oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`0;0?ooo`D00000<P3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0?P3oool200000080oooo00<0001o0?oo
o`3oool0@@3oool3000Rf`L0oooo0`00000f0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool03@3oool30?XN1C80oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0400oooo0P0000000`0007l0
oooo0?ooo`110?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo
0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool200000480oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0
001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0000000800000?`3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool00P3oool2
000003d0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo
01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
00@0oooo0P00000k0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000
oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`060?ooo`800000>@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo
0P00000M0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`080?ooo`<00000=P3oool3000Rf`L0oooo0`00000f0?ooo`00H`3oool00`000000oooo0?oo
o`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`0;0?ooo`800000=03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<00000
0?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o
0?ooo`3oool03@3oool200000380oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001D0?oo
o`H000002@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`0?0?ooo`<00000;`3oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool005D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0B0?ooo`80
0000;@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005H0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`0D0?ooo`<00000:P3oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool005L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0G0?ooo`800000:03o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005P0oooo00<000000?ooo`3oool0203oool3
00000?l0001oU00007l2000002H0001o0`008]/60000O`@00000=P3oool005T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`0K0?ooo`<000008`3oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool005T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0N0?ooo`80
00008@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`0P0?ooo`8000007`3oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool005@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0280oooo0P00000M0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E@3oool4
000000X0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0903oool3000001X0oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo02L0oooo0P00000H0?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool2000001d0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo02T0oooo0P00000F0?ooo`<002;K1`3oool3000003H0
oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo02/0oooo0P00000D0?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04<0oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo04<0oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0]0?ooo`<000004@3oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`13
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0<03oool2000000l0oooo0`008]/9
0?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo01`0oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0380oooo0`00000<0?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0L0?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo04<0oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0e0?ooo`80
00002P3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0
703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
=`3oool3000000L0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`8000007@3o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0>P3o
ool3000000@0oooo0`008]/70?ooo`<00000=P3oool006<0oooo00<000000?ooo`3oool0703oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0?@3oool2
00000080oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo
01`0oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@`3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
03l0oooo0P000003000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3o
ool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool200000003000Rf`3oool0oooo00L0oooo00<000000?ooo`3oool0=03oool006<0oooo
00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`130?ooo`030000O`3oool0oooo0480oooo
00<0001o0?ooo`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03@0oooo001S
0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0=03oool006<0ooooo`00003<000003H0oooo003o0?oo
ool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3o
ool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo
o`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo9@3oool60000
00@0oooo0`0000040?ooo`80000000D0oooo0000003oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0`00
00030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0oooo0`00003j0?ooo`00
o`3ooolU0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool010000000
oooo0?ooo`0000020?ooo`8000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3o
ool0oooo0000003i0?ooo`00o`3ooolU0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0?/0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`05000000<0oooo100000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool500000?T0oooo
003o0?ooobD0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool00000
00D0oooo1P0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo0000003i0?ooo`00
o`3ooolU0?ooo`H000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3o
ool0oooo000000020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo008000000P3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo0?L0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`3oool3000000@0oooo0`0000030?ooo`040000003oool0000000000080oooo0P0000060?ooo`03
0000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`0000020?ooo`<000000P3oool3
000000050?ooo`000000oooo0?ooo`0000000`3oool300000?X0oooo003o0?ooobD0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?h0oooo003o0?oo
obD0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0?h0oooo003o0?ooobD0oooo1P00000O0?ooo`H000003`3oool300000080oooo00<000000?ooo`3o
ool0oP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo0000\
\>"],
  ImageRangeCache->{{{57.1875, 546.25}, {663.938, 468.938}} -> {-3.92318, \
13.0145, 0.0144452, 0.0285337}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AS Port Beam Profile (Y-Arm of Michelson)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TelescopePlot[{zETM - MichelsonAsymmetry/2, 5.0}, {CavityWaist, 
          zCavityWaist - MichelsonAsymmetry/2}, {{ITMFocalLength, 
            zITM - MichelsonAsymmetry/2}, {fLY, zLY}, {fL2, zL2}}, 
        kk];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.232143 0.14881 0.2 0.0732447 [
[.08333 -0.0125 -10.0938 -16.375 ]
[.08333 -0.0125 10.0938 0 ]
[.23214 -0.0125 -5.59375 -16.375 ]
[.23214 -0.0125 5.59375 0 ]
[.38095 -0.0125 -5.59375 -16.375 ]
[.38095 -0.0125 5.59375 0 ]
[.52976 -0.0125 -5.59375 -16.375 ]
[.52976 -0.0125 5.59375 0 ]
[.67857 -0.0125 -5.59375 -16.375 ]
[.67857 -0.0125 5.59375 0 ]
[.82738 -0.0125 -5.59375 -16.375 ]
[.82738 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -16.375 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -43.1563 -32.75 ]
[.5 -0.0125 43.1563 -16.375 ]
[-0.0125 .05351 -20.1875 -8.1875 ]
[-0.0125 .05351 0 8.1875 ]
[-0.0125 .12676 -20.1875 -8.1875 ]
[-0.0125 .12676 0 8.1875 ]
[-0.0125 .2 -11.1875 -8.1875 ]
[-0.0125 .2 0 8.1875 ]
[-0.0125 .27324 -11.1875 -8.1875 ]
[-0.0125 .27324 0 8.1875 ]
[-0.0125 .34649 -11.1875 -8.1875 ]
[-0.0125 .34649 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .2 -36.5625 -44.3438 ]
[-0.01875 .2 -20.1875 44.3438 ]
[ 0 .4 .125 0 ]
[.5 .4125 -39 0 ]
[.5 .4125 39 16.375 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .4 L
s
.23214 0 m
.23214 .4 L
s
.38095 0 m
.38095 .4 L
s
.52976 0 m
.52976 .4 L
s
.67857 0 m
.67857 .4 L
s
.82738 0 m
.82738 .4 L
s
0 .05351 m
1 .05351 L
s
0 .12676 m
1 .12676 L
s
0 .2 m
1 .2 L
s
0 .27324 m
1 .27324 L
s
0 .34649 m
1 .34649 L
s
0 g
.08333 0 m
.08333 .00625 L
s
gsave
.08333 -0.0125 -71.0938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.23214 0 m
.23214 .00625 L
s
gsave
.23214 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.52976 0 m
.52976 .00625 L
s
gsave
.52976 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.67857 0 m
.67857 .00625 L
s
gsave
.67857 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.82738 0 m
.82738 .00625 L
s
gsave
.82738 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.17262 0 m
.17262 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.35119 0 m
.35119 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.47024 0 m
.47024 .00375 L
s
.5 0 m
.5 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.64881 0 m
.64881 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76786 0 m
.76786 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94643 0 m
.94643 .00375 L
s
.05357 0 m
.05357 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -104.156 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.438 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.875 16.625 moveto
(@) show
130.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
141.000 16.625 moveto
(D) show
145.313 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05351 m
.00625 .05351 L
s
gsave
-0.0125 .05351 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .12676 m
.00625 .12676 L
s
gsave
-0.0125 .12676 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
gsave
-0.0125 .2 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .27324 m
.00625 .27324 L
s
gsave
-0.0125 .27324 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .34649 m
.00625 .34649 L
s
gsave
-0.0125 .34649 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06816 m
.00375 .06816 L
s
0 .08281 m
.00375 .08281 L
s
0 .09746 m
.00375 .09746 L
s
0 .11211 m
.00375 .11211 L
s
0 .1414 m
.00375 .1414 L
s
0 .15605 m
.00375 .15605 L
s
0 .1707 m
.00375 .1707 L
s
0 .18535 m
.00375 .18535 L
s
0 .21465 m
.00375 .21465 L
s
0 .2293 m
.00375 .2293 L
s
0 .24395 m
.00375 .24395 L
s
0 .2586 m
.00375 .2586 L
s
0 .28789 m
.00375 .28789 L
s
0 .30254 m
.00375 .30254 L
s
0 .31719 m
.00375 .31719 L
s
0 .33184 m
.00375 .33184 L
s
0 .03886 m
.00375 .03886 L
s
0 .02421 m
.00375 .02421 L
s
0 .00956 m
.00375 .00956 L
s
0 .36114 m
.00375 .36114 L
s
0 .37579 m
.00375 .37579 L
s
0 .39044 m
.00375 .39044 L
s
.25 Mabswid
0 0 m
0 .4 L
s
gsave
-0.01875 .2 -133.719 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
105.344 12.1875 translate
90 rotate
-105.344 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(spot) show
90.938 16.625 moveto
(size) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.438 16.625 moveto
(@) show
121.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
143.375 16.625 moveto
(D) show
147.688 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .39375 m
.08333 .4 L
s
.23214 .39375 m
.23214 .4 L
s
.38095 .39375 m
.38095 .4 L
s
.52976 .39375 m
.52976 .4 L
s
.67857 .39375 m
.67857 .4 L
s
.82738 .39375 m
.82738 .4 L
s
.97619 .39375 m
.97619 .4 L
s
.125 Mabswid
.1131 .39625 m
.1131 .4 L
s
.14286 .39625 m
.14286 .4 L
s
.17262 .39625 m
.17262 .4 L
s
.20238 .39625 m
.20238 .4 L
s
.2619 .39625 m
.2619 .4 L
s
.29167 .39625 m
.29167 .4 L
s
.32143 .39625 m
.32143 .4 L
s
.35119 .39625 m
.35119 .4 L
s
.41071 .39625 m
.41071 .4 L
s
.44048 .39625 m
.44048 .4 L
s
.47024 .39625 m
.47024 .4 L
s
.5 .39625 m
.5 .4 L
s
.55952 .39625 m
.55952 .4 L
s
.58929 .39625 m
.58929 .4 L
s
.61905 .39625 m
.61905 .4 L
s
.64881 .39625 m
.64881 .4 L
s
.70833 .39625 m
.70833 .4 L
s
.7381 .39625 m
.7381 .4 L
s
.76786 .39625 m
.76786 .4 L
s
.79762 .39625 m
.79762 .4 L
s
.85714 .39625 m
.85714 .4 L
s
.8869 .39625 m
.8869 .4 L
s
.91667 .39625 m
.91667 .4 L
s
.94643 .39625 m
.94643 .4 L
s
.05357 .39625 m
.05357 .4 L
s
.02381 .39625 m
.02381 .4 L
s
.25 Mabswid
0 .4 m
1 .4 L
s
gsave
.5 .4125 -100 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
100.375 16.625 moveto
(Profile) show
137.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .05351 m
1 .05351 L
s
.99375 .12676 m
1 .12676 L
s
.99375 .2 m
1 .2 L
s
.99375 .27324 m
1 .27324 L
s
.99375 .34649 m
1 .34649 L
s
.125 Mabswid
.99625 .06816 m
1 .06816 L
s
.99625 .08281 m
1 .08281 L
s
.99625 .09746 m
1 .09746 L
s
.99625 .11211 m
1 .11211 L
s
.99625 .1414 m
1 .1414 L
s
.99625 .15605 m
1 .15605 L
s
.99625 .1707 m
1 .1707 L
s
.99625 .18535 m
1 .18535 L
s
.99625 .21465 m
1 .21465 L
s
.99625 .2293 m
1 .2293 L
s
.99625 .24395 m
1 .24395 L
s
.99625 .2586 m
1 .2586 L
s
.99625 .28789 m
1 .28789 L
s
.99625 .30254 m
1 .30254 L
s
.99625 .31719 m
1 .31719 L
s
.99625 .33184 m
1 .33184 L
s
.99625 .03886 m
1 .03886 L
s
.99625 .02421 m
1 .02421 L
s
.99625 .00956 m
1 .00956 L
s
.99625 .36114 m
1 .36114 L
s
.99625 .37579 m
1 .37579 L
s
.99625 .39044 m
1 .39044 L
s
.25 Mabswid
1 0 m
1 .4 L
s
.977 .121 .023 r
.0075 w
.17262 .13127 m
.17262 .26873 L
s
.19836 .09802 m
.19836 .30198 L
s
.26935 .07728 m
.26935 .32272 L
s
0 .133 .859 r
.02381 .13127 m
.02381 .26873 L
s
.97619 .00952 m
.97619 .39048 L
s
0 g
.5 Mabswid
.02381 .26873 m
.04262 .25213 L
.06244 .23509 L
.07216 .22718 L
.0775 .2231 L
.08255 .21957 L
.08542 .21778 L
.08693 .21692 L
.08852 .21609 L
.08987 .21545 L
.09135 .21484 L
.092 .21461 L
.0927 .21438 L
.09396 .21402 L
.09466 .21386 L
.09532 .21373 L
.09603 .21362 L
.0968 .21354 L
.09753 .21349 L
.09822 .21348 L
.0995 .21353 L
.10077 .21368 L
.10194 .2139 L
.10322 .21422 L
.10387 .21442 L
.10458 .21466 L
.10588 .21516 L
.10709 .21569 L
.10982 .21709 L
.11223 .21852 L
.11478 .22017 L
.12409 .22704 L
.145 .24447 L
.18275 .2818 L
.19218 .29398 L
.19447 .29695 L
.19692 .30011 L
.19764 .30105 L
.19832 .30193 L
.1996 .30234 L
.2021 .30306 L
.21298 .30621 L
.22296 .30911 L
.24128 .31446 L
.25168 .31751 L
.25677 .31901 L
.26142 .32038 L
.26378 .32107 L
.26634 .32183 L
.26751 .32218 L
Mistroke
.26876 .32255 L
.26994 .32247 L
.27101 .32201 L
.2813 .31765 L
.30234 .30878 L
.34246 .292 L
.38106 .27616 L
.42212 .2599 L
.44258 .25219 L
.46166 .2454 L
.4812 .23906 L
.49081 .23627 L
.49968 .23395 L
.50946 .23174 L
.51461 .23075 L
.51724 .2303 L
.52008 .22985 L
.52246 .22951 L
.52463 .22923 L
.52685 .22897 L
.52891 .22876 L
.53118 .22855 L
.53238 .22846 L
.53365 .22837 L
.535 .22828 L
.53627 .22822 L
.53741 .22816 L
.53864 .22812 L
.53988 .22808 L
.54101 .22806 L
.54231 .22804 L
.54355 .22803 L
.54469 .22804 L
.54574 .22805 L
.5469 .22807 L
.54813 .2281 L
.54936 .22814 L
.55005 .22817 L
.55069 .2282 L
.55186 .22826 L
.55309 .22833 L
.55444 .22842 L
.5557 .22852 L
.55707 .22864 L
.55856 .22878 L
.5613 .22907 L
.56389 .22939 L
.56874 .23009 L
.57148 .23054 L
.57439 .23107 L
Mistroke
.57962 .23211 L
.58904 .2343 L
.59917 .23702 L
.61747 .24266 L
.65871 .25743 L
.69844 .27302 L
.73666 .28862 L
.77732 .30557 L
.81647 .3221 L
.85807 .33979 L
.89816 .35694 L
.93673 .37349 L
.97619 .39048 L
Mfstroke
.02381 .13127 m
.04262 .14787 L
.06244 .16491 L
.07216 .17282 L
.0775 .1769 L
.08255 .18043 L
.08542 .18222 L
.08693 .18308 L
.08852 .18391 L
.08987 .18455 L
.09135 .18516 L
.092 .18539 L
.0927 .18562 L
.09396 .18598 L
.09466 .18614 L
.09532 .18627 L
.09603 .18638 L
.0968 .18646 L
.09753 .18651 L
.09822 .18652 L
.0995 .18647 L
.10077 .18632 L
.10194 .1861 L
.10322 .18578 L
.10387 .18558 L
.10458 .18534 L
.10588 .18484 L
.10709 .18431 L
.10982 .18291 L
.11223 .18148 L
.11478 .17983 L
.12409 .17296 L
.145 .15553 L
.18275 .1182 L
.19218 .10602 L
.19447 .10305 L
.19692 .09989 L
.19764 .09895 L
.19832 .09807 L
.1996 .09766 L
.2021 .09694 L
.21298 .09379 L
.22296 .09089 L
.24128 .08554 L
.25168 .08249 L
.25677 .08099 L
.26142 .07962 L
.26378 .07893 L
.26634 .07817 L
.26751 .07782 L
Mistroke
.26876 .07745 L
.26994 .07753 L
.27101 .07799 L
.2813 .08235 L
.30234 .09122 L
.34246 .108 L
.38106 .12384 L
.42212 .1401 L
.44258 .14781 L
.46166 .1546 L
.4812 .16094 L
.49081 .16373 L
.49968 .16605 L
.50946 .16826 L
.51461 .16925 L
.51724 .1697 L
.52008 .17015 L
.52246 .17049 L
.52463 .17077 L
.52685 .17103 L
.52891 .17124 L
.53118 .17145 L
.53238 .17154 L
.53365 .17163 L
.535 .17172 L
.53627 .17178 L
.53741 .17184 L
.53864 .17188 L
.53988 .17192 L
.54101 .17194 L
.54231 .17196 L
.54355 .17197 L
.54469 .17196 L
.54574 .17195 L
.5469 .17193 L
.54813 .1719 L
.54936 .17186 L
.55005 .17183 L
.55069 .1718 L
.55186 .17174 L
.55309 .17167 L
.55444 .17158 L
.5557 .17148 L
.55707 .17136 L
.55856 .17122 L
.5613 .17093 L
.56389 .17061 L
.56874 .16991 L
.57148 .16946 L
.57439 .16893 L
Mistroke
.57962 .16789 L
.58904 .1657 L
.59917 .16298 L
.61747 .15734 L
.65871 .14257 L
.69844 .12698 L
.73666 .11138 L
.77732 .09443 L
.81647 .0779 L
.85807 .06021 L
.89816 .04306 L
.93673 .02651 L
.97619 .00952 L
Mfstroke
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{612.625, 245},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009T0000mB000`400?l00000o`00003oo`3ooooo
0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo;`3oool00`000000oooo0?ooo`0]0?ooo`<0
00003@3oool300000?<0oooo003o0?ooobl0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0?40oooo003o0?ooobl0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?40oooo003o0?ooob40oooo1@000009
0?ooo`040000003oool00000000000@0oooo0`0000040?ooo`<000000`3oool00`000000oooo0?oo
o`0200000080oooo00@000000?ooo`3oool0oooo0`0000030?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob80oooo00<000000?ooo`3o
ool02P3oool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000003
0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3a0?ooo`00o`3ooolR0?ooo`030000003oool0oooo00X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo0?oo
o`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0l@3o
ool00?l0oooo8`3oool010000000oooo0?ooo`3oool7000000030?ooo`000000oooo0080oooo00@0
00000?ooo`3oool000000`3oool010000000oooo0?ooo`3oool3000000<0oooo00@000000?ooo`3o
ool000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob@0oooo00<0
00000?ooo`3oool0203oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0?40oooo003o0?ooob@0oooo00<000000?ooo`3oool0203o
ool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3a0?ooo`00o`3ooolQ0?ooo`D000002@3oool010000000oooo0000000000040?ooo`<00000103o
ool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`040000003oool0oooo0?ooo`<00000
0`3oool010000000oooo0000000000060?ooo`030000003oool0oooo0080oooo00@000000?ooo`00
000000000P3oool2000000D0oooo00<000000?ooo`3oool0l@3oool00?l0ooooA`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0l@3oool00?l0oooo
A`3oool00`000000oooo0?ooo`0E0?ooo`<000003@3oool300000?<0oooo003o0?oood@0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooaP0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3o
oomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool008d0oooo00<000000?ooo`3o
ool0>P3oool4000004<0oooo00<000000?ooo`3oool0?P3oool6000003l0oooo100000130?ooo`03
0000003oool0oooo03l0oooo100000100?ooo`00S@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0m0?ooo`00S@3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0?03o
ool6000004@0oooo00<000000?ooo`3oool0?@3oool00880oooo1`0000040?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0m0?ooo`040000003oool0
oooo000004D0oooo00<000000?ooo`3oool0?@3oool008d0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo03d0oooo00@000000?ooo`3oool00000@03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03d0oooo002=0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool0?P3oool300000440oooo00<000000?ooo`000000@03oool5
00000400oooo002=0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool000000400oooo00<000000?ooo`3oool0@P3oool008/0
oooo00<000000?ooo`000000>`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`000000A@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03l0
oooo0P0000110?ooo`030000003oool0oooo0440oooo002<0?ooo`800000>`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03l0oooo0P0000100?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03l0oooo
0P0000110?ooo`030000003oool0oooo0440oooo002=0?ooo`030000003oool0oooo03X0oooo1000
00130?ooo`030000003oool0oooo03l0oooo100000100?ooo`@00000@`3oool00`000000oooo0?oo
o`0o0?ooo`D00000?`3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0
ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00H`3ooooo00000<`00000=P3oool006<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0400oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo001S0?ooo`800000903oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@03oool200000003000Rf`3oool0oooo00D0oooo0`00000f0?oo
o`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`0n0?ooo`8000000`008]/90?ooo`030000003oool0oooo03@0
oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo03`0oooo0P0000020?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0j0?ooo`800000103oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0=`3oool3000000H0oooo0`008]/9
0?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03D0oooo0P0000090?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0c0?ooo`80
00002`3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo0P00000T0?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0a0?ooo`800000
3@3oool3000Rf`L0oooo0`00000f0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0^0?ooo`<000003`3o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0;03oool2
00000180oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo
02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
02X0oooo0P00000D0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000
oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`0X0?ooo`8000005P3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo
00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool09@3oool3000001P0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo02<0oooo0P00000K0?ooo`<002;K2@3oool00`000000oooo0?oo
o`0d0?ooo`00H`3oool2000002@0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0240oooo0P00000M0?ooo`<002;K1`3oool3000003H0oooo001S0?oo
o`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo01l0oooo0P00000O0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`0L0?ooo`<000008@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0=03oool005@0oooo1P0000090?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0
@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo01X0oooo0P00000T0?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00E@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo01P0oooo0P00000V0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00EP3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo01H0oooo0P00000X0?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0d0?ooo`00C03oool7000000@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`0C0?ooo`<00000:P3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005P0
oooo00<000000?ooo`3oool0203oool300000?l0001oS@0007l2000002d0001o0`008]/60000O`@0
0000=P3oool005T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0?0?ooo`800000
;`3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`0=0?ooo`800000<@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool005T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0:0?ooo`<00000<`3oool3
000Rf`T0oooo00<000000?ooo`3oool0=03oool005@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo00P0oooo0P00000f0?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00E@3oool4000000X0oooo00<000000?ooo`3oool08`3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool01P3oool2000003P0
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`800000903oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool00`3oool3000003X0oooo
0`008]/70?ooo`<00000=P3oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`120?ooo`030000O`3oool0oooo0440oooo00@0001o0?ooo`3oool0oooo0P00000m0?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool0100007l0000000000000000o0?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0400oooo0P0000120?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool03@3oool00`3j7PD000000?XN1@0a0?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0n0?ooo`80000000<0oooo
0000O`3oool0@@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?oo
o`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00X0oooo1`00000`0?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0k0?oo
o`<000000`3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0203oool2000000<0oooo0`3j7PD00`3oool000000000000^0?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0i0?ooo`8000001P3oool00`0007l0
oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000002@0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`040?ooo`@000001@3oool30?XN1@<0oooo
0`00000[0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`0f0?ooo`<00000203oool00`0007l0oooo0?ooo`100?ooo`<002;K1`3oool3000003H0oooo
001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`04000000T0oooo0`3j7PD60?ooo`800000:@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool0=03oool2000000/0oooo00<0001o0?ooo`3oool0@03o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`000000000000d0oooo0`3j7PD80?ooo`8000009`3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0<@3oool3
000000d0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
06<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0o0?ooo`<000003`3oool30?XN
1@X0oooo0P00000U0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`0^0?ooo`<00000403oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo03/0
oooo100000020?ooo`030000O`3oool0oooo00d0oooo0`3j7PD<0?ooo`<000008P3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0;03oool2000001<0
oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo
00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0f0?ooo`D000001P3oool00`0007l0oooo
0?ooo`0=0?ooo`<0nQh53`3oool200000200oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`120?ooo`030000O`3oool0oooo02T0oooo0`00000E0?ooo`030000O`3oool0oooo0400oooo
0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0
001o0?ooo`3oool0<@3oool20?XN1@<000002`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh54@3o
ool2000001h0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo02L0oooo0P00000H0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo001S0?ooo`800000903oool00`0007l0oooo0?ooo`0a0?ooo`80000000<0nQh5
0?ooo`3oool02`3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh54`3oool3000001/0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo02D0oooo0P00000J
0?ooo`030000O`3oool0oooo0400oooo0`008]/70?ooo`<00000=P3oool006<0oooo00<000000?oo
o`3oool08`3oool00`0007l0oooo0?ooo`0a0?ooo`030000003j7PD0nQh500d0oooo00<0001o0?oo
o`3oool03@3oool30?XN1AH0oooo0P00000I0?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@P3oool00`0007l0oooo0?ooo`0R0?ooo`<00000703oool00`0007l0oooo0?ooo`100?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`03
0000O`3oool0oooo0300oooo00@000000?XN1@3j7PD0nQh53@3oool00`0007l0oooo0?ooo`0=0?oo
o`<0nQh5603oool3000001H0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0200oooo0P00000O0?ooo`030000O`3oool0oooo0400oooo0`008]/90?oo
o`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3o
ool0;`3oool00`000000oooo0?XN1@020?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1A/0
oooo0P00000D0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`0M0?ooo`<000008@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo02l0oooo
00<000000?ooo`3j7PD00P3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDM0?ooo`800000
4P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
6`3oool2000002@0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0^0?ooo`030000003o
ool0oooo00<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh57`3oool3000000l0oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo01T0oooo0P00
000V0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l
0?ooo`8000000P3oool00`000000oooo0?ooo`0P0?ooo`800000903oool00`0007l0oooo0?ooo`0]
0?ooo`040000003oool0oooo0?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh58P3o
ool2000000d0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo01H0oooo0`00000X0?ooo`030000O`3oool0oooo0400oooo0`008]/70?ooo`<00000=P3o
ool003/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo02<0oooo00<0001o0?ooo`3oool0;03oool00`000000oooo0?ooo`020?ooo`<0nQh53@3o
ool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5903oool3000000X0oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo01@0oooo0P00000[0?ooo`030000O`3o
ool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3o
ool0oooo02/0oooo00<000000?ooo`3oool00`3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3o
ool30?XN1BL0oooo0P0000080?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3o
ool00`0007l0oooo0?ooo`0A0?ooo`<00000;@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00@0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDY0?ooo`8000001P3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool03`3o
ool200000300oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool003`0oooo00<000000?ooo`3oool00P00000F0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool08`3oool00`0007l0oooo0?ooo`0Y0?ooo`030000003oool0oooo00D0oooo0`3j7PD=
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PD[0?ooo`<000000`3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool03@3oool200000380oooo00<0001o
0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005L0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo02P0oooo00<000000?oo
o`3oool01P3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1Bh0oooo0P0000000`3o
ool0001o0?ooo`120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool02P3oool30000
03@0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005L0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo02L0
oooo00<000000?ooo`3oool01`3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C00
oooo0`0000120?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0203oool2000003L0
oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo
2P0000070?ooo`L00000103oool00`000000oooo0?ooo`090?ooo`<00000C00007l00`000000001o
0000O`080000O`<0nQh57@0007l30?XN1C<0001o0`00002<0000O`<00000O00007l3000Rf`H0001o
1000000f0?ooo`00?03oool01@000000oooo0?ooo`3oool0000001H0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`060?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0U0?ooo`030000
003j7PD0nQh500T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000
O`3oool0oooo0080oooo0P00000m0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0
0`3oool2000003`0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool003/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`008]/00000000Rf`0J0?ooo`030000O`3o
ool0oooo02@0oooo00@000000?XN1@3j7PD0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C40oooo00<0001o0?ooo`3oool0103oool3000003X0oooo00<0001o0?ooo`3oool0
@P3oool00`0007l0oooo0?ooo`03000003h0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool2000Rf`030000003o
ool0oooo01P0oooo00<0001o0?ooo`3oool08`3oool00`000000oooo0?XN1@020?XN1@T0oooo0`3j
7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo00L0oooo0`00
000g0?ooo`030000O`3oool0oooo0480oooo00<0001o000000000000@@3oool00`0007l0oooo0?oo
o`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool5000001@0oooo00<00000
0?ooo`0000002`3oool00`000000oooo0?ooo`060?ooo`<002;K00<000000?ooo`3oool05`3oool0
0`0007l0oooo0?ooo`0R0?ooo`030000003oool0oooo00<0nQh52@3oool30?XN1@d0oooo00<0001o
0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool02P3oool2000003D0oooo00<0001o
0?ooo`3oool0@03oool3000004<0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<00000
0?ooo`3oool0=03oool005H0oooo0P00000;0?ooo`030000003oool0oooo00H0oooo0`008]/00`3o
ool000000?ooo`0G0?ooo`030000O`3oool0oooo0240oooo00@000000?ooo`3oool0oooo0`3j7PD9
0?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool00`0007l0oooo0?ooo`0<
0?ooo`<00000<P3oool00`0007l0oooo0?ooo`0m0?ooo`<000000P3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001G0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool3000Rf`80oooo0P00000F0?oo
o`030000O`3oool0oooo0200oooo00<000000?ooo`3oool00P3oool30?XN1@T0oooo0`3j7PD=0?oo
o`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo00l0oooo0`00000_0?oo
o`030000O`3oool0oooo03/0oooo0P0000050?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003`0oooo1@00000R0?ooo`80
00001`3oool3000Rf`@0oooo00<000000?ooo`3oool04`3oool00`0007l0oooo0?ooo`0O0?ooo`03
0000003oool0oooo00<0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0
nQh5<@3oool00`0007l0oooo0?ooo`0B0?ooo`800000;@3oool00`0007l0oooo0?ooo`0h0?ooo`<0
00001`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/70?ooo`<0
0000=P3oool003/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00H0oooo0`008]/50?ooo`030000003oool0oooo0180oooo00<0001o0?ooo`3oool0
7P3oool00`000000oooo0?ooo`040?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C40oooo00<0001o0?ooo`3oool0503oool3000002X0oooo00<0001o0?ooo`3oool0
=@3oool3000000X0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool01P3oool3000Rf`H0oooo00<000000?ooo`3oool04@3o
ool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo00D0oooo0`3j7PD90?ooo`<0nQh53@3o
ool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool00`0007l0oooo0?ooo`0G0?ooo`800000:03o
ool00`0007l0oooo0?ooo`0c0?ooo`8000003@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`<002;K1`3oool0
0`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo01`0oooo00<000000?ooo`3oool01P3oool3
0?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0
oooo01T0oooo0`00000U0?ooo`030000O`3oool0oooo0300oooo0`00000?0?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool0
03`0oooo1@00000R0?ooo`030000003oool0oooo00H0oooo0`008]/80?ooo`030000003oool0oooo
00l0oooo00<0001o0?ooo`3oool06`3oool00`000000oooo0?ooo`070?ooo`<0nQh52@3oool30?XN
1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0703oool20000
02<0oooo00<0001o0?ooo`3oool0;@3oool300000180oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000
oooo0?ooo`060?ooo`<002;K2@3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo01X0
oooo00<000000?ooo`3oool0203oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0
oooo0`3j7PDa0?ooo`030000O`3oool0oooo01h0oooo0`00000P0?ooo`030000O`3oool0oooo02/0
oooo0P00000E0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`060?ooo`<002;K2P3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo01T0oooo
00<000000?ooo`3oool02@3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo
0`3j7PDa0?ooo`030000O`3oool0oooo0240oooo0`00000M0?ooo`030000O`3oool0oooo02P0oooo
0`00000G0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo
00<000000?ooo`3oool0=03oool003T0oooo2@00000Q0?ooo`8000001`3oool3000Rf`/0oooo0P00
000=0?ooo`030000O`3oool0oooo01P0oooo00<000000?ooo`3oool02P3oool30?XN1@T0oooo0`3j
7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo02@0oooo0`00
000J0?ooo`030000O`3oool0oooo02D0oooo0`00000J0?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@03oool3000Rf`L0oooo0`00000f0?ooo`00>`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool3000Rf`d0oooo00<00000
0?ooo`3oool02P3oool00`0007l0oooo0?ooo`0F0?ooo`8000003@3oool30?XN1@T0oooo0`3j7PD=
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo02L0oooo0`00000G
0?ooo`030000O`3oool0oooo0280oooo0`00000M0?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?oo
o`3oool01P3oool3000Rf`h0oooo00<000000?ooo`3oool02@3oool00`0007l0oooo0?ooo`0E0?oo
o`030000003oool0oooo00d0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?oo
o`<0nQh5<@3oool00`0007l0oooo0?ooo`0Z0?ooo`@000004`3oool00`0007l0oooo0?ooo`0O0?oo
o`<00000803oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?oo
o`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo00H0oooo0`008]/?0?ooo`03
0000003oool0oooo00P0oooo00<0001o0?ooo`3oool0503oool00`000000oooo0?ooo`0>0?ooo`<0
nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3o
ool0;P3oool4000000l0oooo00<0001o0?ooo`3oool0703oool3000002<0oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
H`3oool00`000000oooo0?ooo`060?ooo`<002;K403oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo01<0oooo00<000000?ooo`3oool03`3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000
O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo0380oooo1000000;0?ooo`030000
O`3oool0oooo01L0oooo1@00000V0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool01P3o
ool3000Rfa40oooo0P0000070?ooo`030000O`3oool0oooo0140oooo0P00000B0?ooo`<0nQh52@3o
ool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0=P3o
ool4000000L0oooo00<0001o0?ooo`3oool04P3oool5000002/0oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2
000000L0oooo0`008]/C0?ooo`8000001@3oool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0
oooo0180oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool0
0`0007l0oooo0?ooo`0j0?ooo`P000003@3oool700000300oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`100?ooo`<002;K1`3oool3000003H0oooo000l0?ooo`8000000P3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00H0oooo0`008]/E0?ooo`030000003oool0oooo
0080oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`<0nQh52@3oool30?XN
1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`00
07l000000000000;000003L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool3000RfaH0oooo00D000000?oo
o`3oool0oooo0000O`0@0?ooo`030000003oool0oooo01@0oooo0`3j7PD90?ooo`<0nQh53@3oool0
0`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0d0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool01P3oool3000RfaL0oooo00@000000?ooo`3oool0001o3P3o
ool2000001L0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3o
ool3000RfaP0oooo00<000000?ooo`0007l03@3oool00`000000oooo0?ooo`0G0?ooo`<0nQh52@3o
ool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003`0oooo00<000000?ooo`3oool00P00000R
0?ooo`030000003oool0oooo00H0oooo0`008]/I0?ooo`030000000007l0oooo00/0oooo00<00000
0?ooo`3oool0603oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?oo
o`030000003oool0oooo00H0oooo0`008]/J0?ooo`<00000203oool2000001/0oooo0`3j7PD90?oo
o`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?oo
o`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000000L0oooo0`008]/J0?ooo`03
0000O`3oool0oooo00P000007@3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0
oooo0`3j7PDa0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/70?ooo`<00000=P3oool003P0oooo
00<000000?ooo`3oool01`00000Q0?ooo`030000003oool0oooo00H0oooo0`008]/J0?ooo`030000
O`3oool0oooo00<0oooo0P00000P0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0
=03oool006<0oooo00<000000?ooo`3oool01P3oool3000RfaX0oooo00<0001o0?ooo`3oool09@3o
ool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001E0?ooo`@000002P3oool0
0`000000oooo0?ooo`060?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0U0?ooo`<0nQh52@3oool3
0?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3
000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0U0?ooo`<0nQh52@3oool30?XN
1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00@000000?ooo`3oool0oooo0`00000B0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`<002;K6P3oool00`0007l0oooo0?ooo`0U0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?oo
o`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool003/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`<002;K6P3oool00`0007l0oooo0?ooo`0U0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?oo
o`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool003/0oooo0`0000030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`<000001P0007l3000Rfd80001o0`3j7PD90000O`<0
nQh57@0007l30?XN1Ol0001o@P0007l3000Rf`H0001o1000000f0?ooo`00>`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo0`008]/J0?ooo`030000O`3oool0oooo02D0oooo
0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool00`0007l0oooo
0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00E03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool3000RfaX0oooo00<0
001o0?ooo`3oool09@3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j
7PDa0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001D
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`06
0?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0U0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o
0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`12
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<00000
0?ooo`3oool0=03oool003`0oooo1@00000C0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0U0?oo
o`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0A0?ooo`@000002P3oool00`000000oooo0?ooo`060?oo
o`<002;K6P3oool00`0007l0oooo0?ooo`0U0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?oo
o`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool003/0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0O0?oo
o`8000001`3oool3000RfaX0oooo00<0001o0?ooo`3oool02000000M0?ooo`<0nQh52@3oool30?XN
1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000R
f`L0oooo0`00000f0?ooo`00>`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool01P3oool3000RfaX0oooo00@0001o00000000000000001P3oool2
000001`0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool30000
00030?ooo`000000oooo0240oooo00<000000?ooo`3oool01P3oool3000RfaX0oooo00<0001o0000
003oool02@3oool2000001X0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?oo
o`<0nQh5<@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00H`3oool00`000000oooo0?ooo`060?ooo`<002;K6@3oool2000000d0oooo00<000000?ooo`3o
ool05`3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000
003oool0oooo00H0oooo0`008]/G0?ooo`80000000<0oooo0000O`3oool03@3oool00`000000oooo
0?ooo`0F0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<0
00000?ooo`3oool01P3oool3000RfaH0oooo00D000000?ooo`3oool0oooo0000O`0?0?ooo`800000
5P3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003o
ool0oooo00H0oooo0`008]/E0?ooo`030000003oool0oooo0080oooo00<0001o0?ooo`3oool03`3o
ool00`000000oooo0?ooo`0C0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3o
ool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool003T0oooo3000000N0?ooo`8000001`3oool3000Rfa@0oooo00<000000?ooo`3oool00`3oool0
0`0007l0oooo0?ooo`0@0?ooo`030000003oool0oooo0180oooo0`3j7PD90?ooo`<0nQh53@3oool0
0`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool00`0007l0oooo0?ooo`0m0?oooaL00000<P3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/70?ooo`<00000=P3oool0
03T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00H0oooo0`008]/B0?ooo`8000001P3oool00`0007l0oooo0?ooo`0A0?ooo`8000004P3oool30?XN
1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo
03L0oooo1P0000040?ooo`030000O`3oool0oooo0100oooo1`00000[0?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003T0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0
oooo0`008]/A0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3oool04`3oool00`000000
oooo0?ooo`0?0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40
oooo00<0001o0?ooo`3oool0<`3oool4000000X0oooo00<0001o0?ooo`3oool05`3oool3000002P0
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`060?ooo`<002;K403oool00`000000oooo
0?ooo`070?ooo`030000O`3oool0oooo01@0oooo00<000000?ooo`3oool03P3oool30?XN1@T0oooo
0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo02l0oooo
1000000>0?ooo`030000O`3oool0oooo01X0oooo0P00000V0?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<0
00000?ooo`3oool01P3oool3000Rf`l0oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?oo
o`0E0?ooo`030000003oool0oooo00d0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?oo
o`0=0?ooo`<0nQh5<@3oool00`0007l0oooo0?ooo`0]0?ooo`8000004P3oool00`0007l0oooo0?oo
o`0L0?ooo`@000008P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`00
8]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`L000008@3oool00`000000oooo0?ooo`06
0?ooo`<002;K3P3oool00`000000oooo0?ooo`090?ooo`030000O`3oool0oooo01H0oooo0P00000=
0?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o
0?ooo`3oool0:P3oool3000001@0oooo00<0001o0?ooo`3oool0803oool4000001h0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00?03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00H0oooo0`008]/=0?oo
o`030000003oool0oooo00X0oooo00<0001o0?ooo`3oool0603oool00`000000oooo0?ooo`0:0?oo
o`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?oo
o`3oool09`3oool3000001L0oooo00<0001o0?ooo`3oool0903oool4000001X0oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?oo
o`00>`3oool00`000000oooo0?ooo`0U0?ooo`8000001`3oool3000Rf`/0oooo0P00000=0?ooo`03
0000O`3oool0oooo01T0oooo00<000000?ooo`3oool02@3oool30?XN1@T0oooo0`3j7PD=0?ooo`03
0000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo02@0oooo0`00000J0?ooo`03
0000O`3oool0oooo02P0oooo0`00000G0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@03oool3000Rf`L0oooo0`00000f0?ooo`00>`3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00H0oooo0`008]/:0?ooo`030000003oool0oooo00d0oooo00<0001o0?ooo`3oool0
6P3oool00`000000oooo0?ooo`080?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C40oooo00<0001o0?ooo`3oool08@3oool3000001d0oooo00<0001o0?ooo`3oool0
:`3oool2000001D0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K
2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool600000240oooo00<000000?ooo`3oool01P3o
ool3000Rf`T0oooo00<000000?ooo`3oool03P3oool00`0007l0oooo0?ooo`0K0?ooo`030000003o
ool0oooo00L0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3o
ool00`0007l0oooo0?ooo`0O0?ooo`800000803oool00`0007l0oooo0?ooo`0]0?ooo`<000004P3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo000k0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01P3oool3
000Rf`P0oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`0L0?ooo`030000003oool0
oooo00H0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool0
0`0007l0oooo0?ooo`0L0?ooo`<000008P3oool00`0007l0oooo0?ooo`0`0?ooo`<000003`3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0
oooo03@0oooo000k0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01P3oool3000R
f`L0oooo00<000000?ooo`3oool0403oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo
00D0oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool00`00
07l0oooo0?ooo`0I0?ooo`<000009@3oool00`0007l0oooo0?ooo`0c0?ooo`8000003@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo000k0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01P3oool3000Rf`H0
oooo00<000000?ooo`3oool04@3oool00`0007l0oooo0?ooo`0N0?ooo`030000003oool0oooo00@0
oooo0`3j7PD90?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5<@3oool00`0007l0
oooo0?ooo`0F0?ooo`<00000:03oool00`0007l0oooo0?ooo`0e0?ooo`<000002P3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0
oooo000l0?ooo`H000008@3oool00`000000oooo0?ooo`060?ooo`<002;K103oool2000001@0oooo
00<0001o0?ooo`3oool07`3oool00`000000oooo0?ooo`030?ooo`<0nQh52@3oool30?XN1@d0oooo
00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?ooo`3oool04P3oool4000002/0oooo
00<0001o0?ooo`3oool0>03oool3000000L0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo
0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000000L0oooo0`00
8]/30?ooo`030000003oool0oooo01@0oooo00<0001o0?ooo`3oool0803oool00`000000oooo0?oo
o`020?ooo`<0nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0
001o0?ooo`3oool03`3oool3000002l0oooo00<0001o0?ooo`3oool0>`3oool2000000D0oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`100?ooo`<002;K1`3oool3000003H0oooo001S
0?ooo`030000003oool0oooo00H0oooo0`008]/20?ooo`030000003oool0oooo01D0oooo00<0001o
0?ooo`3oool08@3oool010000000oooo0?ooo`3oool30?XN1@T0oooo0`3j7PD=0?ooo`030000O`3o
ool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo00d0oooo0P00000b0?ooo`030000O`3o
ool0oooo03d0oooo0`0000020?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@03o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo1`00000Q0?ooo`030000003oool0
oooo00H0oooo0`008]/2000001P0oooo00<0001o0?ooo`3oool08P3oool00`000000oooo0?ooo`03
0?XN1@T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0
oooo00/0oooo0P00000d0?ooo`030000O`3oool0oooo0400oooo0P0000000`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000l0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?oo
o`8002;K00<000000?ooo`3oool0603oool00`0007l0oooo0?ooo`0S0?ooo`030000003oool0nQh5
0080nQh52@3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00<0001o0?oo
o`3oool0203oool3000003H0oooo00<0001o0?ooo`3oool0@P3oool300000440oooo00<0001o0?oo
o`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<002;K00000000
8]/06P3oool00`0007l0oooo0?ooo`0T0?ooo`040000003j7PD0nQh50?XN1@T0oooo0`3j7PD=0?oo
o`030000O`3oool0oooo00d0oooo0`3j7PDa0?ooo`030000O`3oool0oooo00H0oooo0P00000i0?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool00`00000n0?ooo`030000O`3oool0oooo
0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo000k0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`<002;K6P3oool00`0007l0
oooo0?ooo`0U0?ooo`030000003j7PD0nQh500T0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0
oooo0`3j7PDa0?ooo`030000O`3oool0oooo00<0oooo0`00000k0?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool00`3oool2000003`0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool003`0oooo1P00000E0?ooo`030000003oool0oooo00T0oooo
0`00001<0000O`030000000007l0001o00P0001o0`3j7PDM0000O`<0nQh5=@0007l2000008/0001o
0`00001l0000O`<002;K1P0007l4000003H0oooo000k0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo02L0oooo00<0
00000?ooo`3oool01`3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1C40oooo00@0
001o0?ooo`0000000000@03oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo00P0oooo
0P00000g0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo03@0oooo
000k0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0S0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool01P3oool30?XN1@d0oooo00<0
001o0?ooo`3oool03@3oool30?XN1C00oooo0`0000120?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool02P3oool3000003@0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<0
00000?ooo`3oool0=03oool003/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0:@3oool00`000000oooo0?ooo`05
0?ooo`<0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5;P3oool2000000030?ooo`0007l0
oooo0480oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0=0?ooo`800000<P3oool0
0`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00?03oool60000
01<0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo
02X0oooo00<000000?ooo`3oool0103oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN
1B/0oooo0`0000030?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`0?0?ooo`800000<03oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00EP3oool2000000/0oooo00<000000?ooo`3oool08`3oool00`0007l0
oooo0?ooo`0[0?ooo`030000003oool0oooo00<0oooo0`3j7PD=0?ooo`030000O`3oool0oooo00d0
oooo0`3j7PDY0?ooo`8000001P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480
oooo00<0001o0?ooo`3oool04@3oool3000002d0oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0
oooo00<000000?ooo`3oool0=03oool005L0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0S0?ooo`030000O`3oool0oooo02`0oooo00<000000?ooo`3oool00P3oool30?XN1@d0oooo
00<0001o0?ooo`3oool03@3oool30?XN1BL0oooo0P0000080?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0D0?ooo`800000:`3oool00`0007l0oooo
0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00>@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo01`0oooo0P00000T0?ooo`030000O`3oool0oooo02`0oooo00<0
00000?ooo`3oool00P3oool30?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN1B@0oooo0`00
000:0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`0F0?ooo`<00000:03oool00`0007l0oooo0?ooo`100?ooo`<002;K1`3oool3000003H0oooo000i
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0S
0?ooo`030000O`3oool0oooo02d0oooo00@000000?ooo`3oool0oooo0`3j7PD=0?ooo`030000O`3o
ool0oooo00d0oooo0`3j7PDR0?ooo`8000003@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0480oooo00<0001o0?ooo`3oool06@3oool2000002H0oooo00<0001o0?ooo`3oool0@03o
ool3000Rf`T0oooo00<000000?ooo`3oool0=03oool003T0oooo3000000N0?ooo`030000003oool0
oooo02<0oooo00<0001o0?ooo`3oool0;P3oool00`000000oooo0?ooo`030?XN1@d0oooo00<0001o
0?ooo`3oool03@3oool30?XN1Al0oooo0`00000?0?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0K0?ooo`800000903oool00`0007l0oooo0?ooo`10
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?oo
o`030000O`3oool0oooo02l0oooo00<000000?ooo`3j7PD00P3j7PD=0?ooo`030000O`3oool0oooo
00d0oooo0`3j7PDM0?ooo`8000004P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool07@3oool300000240oooo00<0001o0?ooo`3oool0@03oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0
oooo0?ooo`0`0?ooo`040000003j7PD0nQh50?XN1@d0oooo00<0001o0?ooo`3oool03@3oool30?XN
1A/0oooo0P00000D0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`00
07l0oooo0?ooo`0P0?ooo`8000007`3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0300
oooo00@000000?XN1@3j7PD0nQh53@3oool00`0007l0oooo0?ooo`0=0?ooo`<0nQh5603oool30000
01H0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo
0280oooo0`00000L0?ooo`030000O`3oool0oooo0400oooo0`008]/90?ooo`030000003oool0oooo
03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0<@3oool200000003
0?XN1@3oool0oooo00/0oooo00<0001o0?ooo`3oool03@3oool30?XN1AH0oooo0P00000I0?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0U0?ooo`80
00006P3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
H`3oool2000002@0oooo00<0001o0?ooo`3oool0<@3oool00`3j7PD0000000000002000000/0oooo
00<0001o0?ooo`3oool03@3oool30?XN1A<0oooo0`00000K0?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0W0?ooo`800000603oool00`0007l0oooo
0?ooo`100?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0
001o0?ooo`3oool0=P3oool4000000L0oooo00<0001o0?ooo`3oool03@3oool30?XN1A40oooo0P00
000N0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`0Y0?ooo`<000005@3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?oo
o`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo03X0oooo0P000005
0?ooo`030000O`3oool0oooo00d0oooo0`3j7PD?0?ooo`800000803oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0;03oool2000001<0oooo00<0001o
0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?oo
o`3oool08`3oool00`0007l0oooo0?ooo`0l0?ooo`<000000P3oool00`0007l0oooo0?ooo`0=0?oo
o`<0nQh5303oool300000280oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?oo
o`030000O`3oool0oooo02h0oooo0P00000A0?ooo`030000O`3oool0oooo0400oooo0`008]/90?oo
o`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3o
ool0?`3oool4000000h0oooo0`3j7PD:0?ooo`8000009@3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0<03oool2000000l0oooo00<0001o0?ooo`3o
ool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool0
8`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0000000<000002P3oool30?XN1@P0oooo
0P00000W0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo
0?ooo`0b0?ooo`<00000303oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00H`3oool2000002@0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`030?ooo`800000203oool30?XN1@H0oooo0P00000Y0?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0e0?ooo`8000002P3oool00`0007l0oooo0?oo
o`100?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`050?ooo`@00000103oool30?XN1@<0oooo0`00000[
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0g
0?ooo`800000203oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool02@3oool4000000<0nQh500<0oooo000000000000;P3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0>@3oool2000000H0oooo00<0001o0?oo
o`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3o
ool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00d0oooo1000000`0?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`0k0?ooo`<0
00000`3oool00`0007l0oooo0?ooo`100?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00
H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0
3@3oool30?XN1C40oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo03h0oooo0P0000000`3oool0001o0?ooo`110?ooo`<002;K2@3oool00`000000oooo
0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0
001o0?ooo`3oool0@03oool200000480oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S
0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`11
0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`11
0?ooo`040000O`0000000000000003l0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S
0?ooo`800000903oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00@0001o
0?ooo`3oool0oooo0P00000m0?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000003oool0
oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo00<0oooo0`00000j0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`00
0000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`00
07l0oooo0?ooo`060?ooo`800000>03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool005@0
oooo1P0000090?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo00P0oooo0P00000f0?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00E@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02<0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00X0oooo
0`00000c0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00EP3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo00d0oooo0P00000a0?ooo`<002;K2@3oool00`000000oooo0?oo
o`0d0?ooo`00E`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02<0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo00l0oooo0P00000_
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00F03oool00`000000oooo0?ooo`080?oo
o`<00000o`0007n=0000O`800000;@0007l3000Rf`H0001o1000000f0?ooo`00F@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo01<0oooo0`00000Z0?ooo`<002;K2@3oool00`000000
oooo0?ooo`0d0?ooo`00F@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo01H0oooo
0P00000X0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00F@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?oo
o`110?ooo`030000O`3oool0oooo01P0oooo0P00000V0?ooo`<002;K2@3oool00`000000oooo0?oo
o`0d0?ooo`00E03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool06P3oool2000002@0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001E0?oo
o`@000002P3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?oo
o`3oool0@@3oool00`0007l0oooo0?ooo`0L0?ooo`<000008@3oool3000Rf`T0oooo00<000000?oo
o`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`03
0000O`3oool0oooo0440oooo00<0001o0?ooo`3oool07`3oool2000001l0oooo0`008]/90?ooo`03
0000003oool0oooo03@0oooo001S0?ooo`800000903oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool08@3oool3000001`0oooo0`008]/70?ooo`<00000
=P3oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3o
ool0oooo0440oooo00<0001o0?ooo`3oool0903oool2000001X0oooo0`008]/90?ooo`030000003o
ool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool0
0`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo02H0oooo0`00000G0?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo
0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo
0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0Y0?ooo`<00000503oool3000R
f`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0
oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0
oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0;03oool200000180
oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000003oool0oooo02<0oooo
00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo
00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo02h0oooo
0`00000?0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool2000002@0oooo00<0
001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0
001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0340oooo0P00
000=0?ooo`<002;K1`3oool3000003H0oooo001S0?ooo`030000003oool0oooo02<0oooo00<0001o
0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o
0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo03<0oooo0P00000;
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3oool00`000000oooo0?ooo`0S0?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`0e0?oo
o`8000002@3oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo00<000000?ooo`3o
ool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3o
ool0=`3oool3000000H0oooo0`008]/90?ooo`030000003oool0oooo03@0oooo001S0?ooo`030000
003oool0oooo02<0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?ooo`030000
O`3oool0oooo03X0oooo0P0000040?ooo`<002;K2@3oool00`000000oooo0?ooo`0d0?ooo`00H`3o
ool00`000000oooo0?ooo`0S0?ooo`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0480oooo00<0001o0?ooo`3oool0@@3o
ool00`0007l0oooo0?ooo`0l0?ooo`8000000P3oool3000Rf`T0oooo00<000000?ooo`3oool0=03o
ool006<0oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0
oooo0440oooo00<0001o0?ooo`3oool0?P3oool2000000<002;K2@3oool00`000000oooo0?ooo`0d
0?ooo`00H`3oool2000002@0oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0440oooo00<0001o0?ooo`3oool0@P3oool00`0007l0oooo0?ooo`110?oo
o`030000O`3oool0oooo0400oooo0P0000000`008]/0oooo0?ooo`050?ooo`<00000=P3oool006<0
oooo00<000000?ooo`3oool08`3oool00`0007l0oooo0?ooo`110?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@@3oool00`0007l0oooo0?ooo`120?ooo`030000O`3oool0oooo0440
oooo00<0001o0?ooo`3oool0@03oool3000Rf`T0oooo00<000000?ooo`3oool0=03oool006<0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03@0oooo
001S0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0=03oool006<0ooooo`00003<
000003H0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo
003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0
ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool0
0?l0oooo9@3oool6000000@0oooo0`0000040?ooo`80000000D0oooo0000003oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo0`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
oooo0`00003j0?ooo`00o`3ooolU0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00000`3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`050000003oool0
oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00D000000?ooo`3oool0oooo0000003i0?ooo`00o`3ooolU0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000001P3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0?/0oooo003o0?ooobD0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`05000000<0oooo100000020?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool500000?T0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01@000000
oooo0?ooo`3oool0000000D0oooo1P0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0
oooo0000003i0?ooo`00o`3ooolU0?ooo`H000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000P3oool200000080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo008000000P3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo0?L0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`3oool3000000@0oooo0`0000030?ooo`040000003oool0000000000080
oooo0P0000060?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool000000?ooo`000002
0?ooo`<000000P3oool3000000050?ooo`000000oooo0?ooo`0000000`3oool300000?X0oooo003o
0?ooobD0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0?h0oooo003o0?ooobD0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0?h0oooo003o0?ooobD0oooo1P00000O0?ooo`H000003`3oool300000080
oooo00<000000?ooo`3oool0oP3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo0000
\
\>"],
  ImageRangeCache->{{{57.1875, 546.25}, {372, 177}} -> {-4.06481, 2.71865, \
0.0146745, 0.0298139}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

Probe Beam\
\>", "Subtitle"],

Cell["\<\
The lens L3 is there to \"mirror\" the beam on the beam sampler, since we are \
propating the wrong way.
The lenses L4 and L5 are for mode matching to the AS port beam.\
\>", "Text"],

Cell[BoxData[{
    \(zL3 = 0.15; \  (*\ 
      beam\ splitter\ for\ probe\ beam\ *) \[IndentingNewLine]fL3 = 
      ff /. \(Solve[\(Lensing[{WaistLXY, zWaistLXY}, {ff, zL3}, 
                  kk]\)\[LeftDoubleBracket]1\[RightDoubleBracket] \[Equal] 
              WaistLXY, 
            ff]\)\[LeftDoubleBracket]1\[RightDoubleBracket];\
\[IndentingNewLine] (*\ Beam\ propagate\ from\ other\ direction, \ 
      so\ just\ "\<mirror\>"\ it\ *) \), "\[IndentingNewLine]", 
    \(\({WaistL3, zWaistL3} = 
        Lensing[{WaistLXY, zWaistLXY}, {fL3, zL3}, 
          kk];\)\), "\[IndentingNewLine]", 
    \(\(zL4 = 1.291;\)\), "\[IndentingNewLine]", 
    \(\(fL4 = 0.6806;\)\), "\[IndentingNewLine]", 
    \(\({WaistL4, 
          zWaistL4} = \[IndentingNewLine]Lensing[{WaistL3, zWaistL3}, {fL4, 
            zL4}, kk];\)\), "\[IndentingNewLine]", 
    \(\(zL5 = 1.414;\)\), "\[IndentingNewLine]", 
    \(\(fL5 = \(-0.614\);\)\), "\[IndentingNewLine]", 
    \(\({WaistL5, 
          zWaistL5} = \[IndentingNewLine]Lensing[{WaistL4, zWaistL4}, {fL5, 
            zL5}, kk];\)\)}], "Input"],

Cell[CellGroupData[{

Cell["Find Mode Matching Solutuion", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ProbeBeamWaist[zzL4_, zzL5_] := 
      Lensing[Lensing[{WaistL3, zWaistL3}, {fL4, zzL4}, kk], {fL5, zzL5}, 
        kk]; FindRoot[{\(ProbeBeamWaist[zzL4, 
              zzL5]\)\[LeftDoubleBracket]1\[RightDoubleBracket] == 
          WaistL2, \(ProbeBeamWaist[zzL4, 
              zzL5]\)\[LeftDoubleBracket]2\[RightDoubleBracket] == 
          zWaistL2}, {{zzL4, zL4}, {zzL5, zL5}}, 
      MaxIterations \[Rule] 400]\)], "Input"],

Cell[BoxData[
    \({zzL4 \[Rule] 1.290461957762042`, 
      zzL5 \[Rule] 1.4141494183289187`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Print["\<Focal Length of L3 'Lens' = \>", 
        fL3, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Position of L3 Beam Sampler = \>", 
        zL3, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Size after L3 = \>", \ 
        1000\ WaistL3, \ "\< mm\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Position after L3 = \>", \ 
        zWaistL3, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Rayleigh Range after L3 = \>", 
        RayleighLength[WaistL3, 
          kk], \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Focal Length of L4 Lens = \>", 
        fL4, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Position of L4 Lens = \>", 
        zL4, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Size after L4 = \>", \ 
        1000\ WaistL4, \ "\< mm\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Position after L4 = \>", \ 
        zWaistL4, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Rayleigh Range after L4 = \>", 
        RayleighLength[WaistL4, 
          kk], \ "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Focal Length of L5 Lens = \>", 
        fL5, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Position of L5 Lens = \>", 
        zL5, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Size after L5 = \>", \ 
        1000\ WaistL5, \ "\< mm\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Waist Position after L5= \>", \ 
        zWaistL5, "\< m\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Rayleigh Range after L5 = \>", 
        RayleighLength[WaistL5, kk], \ "\< m\>"];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Focal Length of L3 'Lens' = \
"\[InvisibleSpace]1.3385381128702036`\[InvisibleSpace]" m"\),
      SequenceForm[ "Focal Length of L3 'Lens' = ", 1.3385381128702036, " m"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Position of L3 Beam Sampler = \
"\[InvisibleSpace]0.15`\[InvisibleSpace]" m"\),
      SequenceForm[ 
      "Position of L3 Beam Sampler = ", .14999999999999999, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Size after L3 = \
"\[InvisibleSpace]0.5376862287834825`\[InvisibleSpace]" mm"\),
      SequenceForm[ "Waist Size after L3 = ", .53768622878348249, " mm"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Position after L3 = \
"\[InvisibleSpace]2.5195629312010936`\[InvisibleSpace]" m"\),
      SequenceForm[ "Waist Position after L3 = ", 2.5195629312010936, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Rayleigh Range after L3 = \
"\[InvisibleSpace]0.8536229282252673`\[InvisibleSpace]" m"\),
      SequenceForm[ "Rayleigh Range after L3 = ", .85362292822526731, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Focal Length of L4 Lens = "\[InvisibleSpace]0.6806`\
\[InvisibleSpace]" m"\),
      SequenceForm[ "Focal Length of L4 Lens = ", .68059999999999998, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Position of L4 Lens = "\[InvisibleSpace]1.291`\
\[InvisibleSpace]" m"\),
      SequenceForm[ "Position of L4 Lens = ", 1.2909999999999999, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Size after L4 = \
"\[InvisibleSpace]0.17498569994216248`\[InvisibleSpace]" mm"\),
      SequenceForm[ "Waist Size after L4 = ", .17498569994216248, " mm"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Position after L4 = \
"\[InvisibleSpace]1.7693957476661595`\[InvisibleSpace]" m"\),
      SequenceForm[ "Waist Position after L4 = ", 1.7693957476661595, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Rayleigh Range after L4 = \
"\[InvisibleSpace]0.09040935331183271`\[InvisibleSpace]" m"\),
      SequenceForm[ "Rayleigh Range after L4 = ", .09040935331183271, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Focal Length of L5 Lens = \
"\[InvisibleSpace]\(-0.614`\)\[InvisibleSpace]" m"\),
      SequenceForm[ "Focal Length of L5 Lens = ", -.61399999999999999, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Position of L5 Lens = "\[InvisibleSpace]1.414`\
\[InvisibleSpace]" m"\),
      SequenceForm[ "Position of L5 Lens = ", 1.4139999999999999, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Size after L5 = \
"\[InvisibleSpace]0.3921891291222145`\[InvisibleSpace]" mm"\),
      SequenceForm[ "Waist Size after L5 = ", .39218912912221449, " mm"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Waist Position after L5= \
"\[InvisibleSpace]2.0990373762040884`\[InvisibleSpace]" m"\),
      SequenceForm[ "Waist Position after L5= ", 2.0990373762040884, " m"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Rayleigh Range after L5 = \
"\[InvisibleSpace]0.45415003059925685`\[InvisibleSpace]" m"\),
      SequenceForm[ "Rayleigh Range after L5 = ", .45415003059925685, " m"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Probe Beam Port Beam Profile (No Mode Matching)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TelescopePlot[{zETM, 4.0}, {CavityWaist, 
          zCavityWaist}, {{ITMFocalLength, zITM}, {fLXY, zLXY}, {fL3, zL3}}, 
        kk];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.26413 0.178015 0.2 0.120064 [
[.08611 -0.0125 -10.0938 -16.375 ]
[.08611 -0.0125 10.0938 0 ]
[.26413 -0.0125 -5.59375 -16.375 ]
[.26413 -0.0125 5.59375 0 ]
[.44215 -0.0125 -5.59375 -16.375 ]
[.44215 -0.0125 5.59375 0 ]
[.62016 -0.0125 -5.59375 -16.375 ]
[.62016 -0.0125 5.59375 0 ]
[.79818 -0.0125 -5.59375 -16.375 ]
[.79818 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -16.375 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -43.1563 -32.75 ]
[.5 -0.0125 43.1563 -16.375 ]
[-0.0125 .0199 -30.9375 -8.1875 ]
[-0.0125 .0199 0 8.1875 ]
[-0.0125 .07994 -20.1875 -8.1875 ]
[-0.0125 .07994 0 8.1875 ]
[-0.0125 .13997 -30.9375 -8.1875 ]
[-0.0125 .13997 0 8.1875 ]
[-0.0125 .2 -11.1875 -8.1875 ]
[-0.0125 .2 0 8.1875 ]
[-0.0125 .26003 -21.9375 -8.1875 ]
[-0.0125 .26003 0 8.1875 ]
[-0.0125 .32006 -11.1875 -8.1875 ]
[-0.0125 .32006 0 8.1875 ]
[-0.0125 .3801 -21.9375 -8.1875 ]
[-0.0125 .3801 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .2 -47.3125 -44.3438 ]
[-0.01875 .2 -30.9375 44.3438 ]
[ 0 .4 .125 0 ]
[.5 .4125 -39 0 ]
[.5 .4125 39 16.375 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.08611 0 m
.08611 .4 L
s
.26413 0 m
.26413 .4 L
s
.44215 0 m
.44215 .4 L
s
.62016 0 m
.62016 .4 L
s
.79818 0 m
.79818 .4 L
s
0 .0199 m
1 .0199 L
s
0 .07994 m
1 .07994 L
s
0 .13997 m
1 .13997 L
s
0 .2 m
1 .2 L
s
0 .26003 m
1 .26003 L
s
0 .32006 m
1 .32006 L
s
0 .3801 m
1 .3801 L
s
0 g
.08611 0 m
.08611 .00625 L
s
gsave
.08611 -0.0125 -71.0938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.26413 0 m
.26413 .00625 L
s
gsave
.26413 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.44215 0 m
.44215 .00625 L
s
gsave
.44215 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.62016 0 m
.62016 .00625 L
s
gsave
.62016 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.79818 0 m
.79818 .00625 L
s
gsave
.79818 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.12172 0 m
.12172 .00375 L
s
.15732 0 m
.15732 .00375 L
s
.19292 0 m
.19292 .00375 L
s
.22853 0 m
.22853 .00375 L
s
.29973 0 m
.29973 .00375 L
s
.33534 0 m
.33534 .00375 L
s
.37094 0 m
.37094 .00375 L
s
.40654 0 m
.40654 .00375 L
s
.47775 0 m
.47775 .00375 L
s
.51335 0 m
.51335 .00375 L
s
.54895 0 m
.54895 .00375 L
s
.58456 0 m
.58456 .00375 L
s
.65576 0 m
.65576 .00375 L
s
.69137 0 m
.69137 .00375 L
s
.72697 0 m
.72697 .00375 L
s
.76257 0 m
.76257 .00375 L
s
.83378 0 m
.83378 .00375 L
s
.86938 0 m
.86938 .00375 L
s
.90498 0 m
.90498 .00375 L
s
.94059 0 m
.94059 .00375 L
s
.05051 0 m
.05051 .00375 L
s
.01491 0 m
.01491 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -104.156 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.438 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.875 16.625 moveto
(@) show
130.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
141.000 16.625 moveto
(D) show
145.313 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0199 m
.00625 .0199 L
s
gsave
-0.0125 .0199 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .07994 m
.00625 .07994 L
s
gsave
-0.0125 .07994 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .13997 m
.00625 .13997 L
s
gsave
-0.0125 .13997 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
gsave
-0.0125 .2 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .26003 m
.00625 .26003 L
s
gsave
-0.0125 .26003 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .32006 m
.00625 .32006 L
s
gsave
-0.0125 .32006 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .3801 m
.00625 .3801 L
s
gsave
-0.0125 .3801 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03191 m
.00375 .03191 L
s
0 .04392 m
.00375 .04392 L
s
0 .05592 m
.00375 .05592 L
s
0 .06793 m
.00375 .06793 L
s
0 .09194 m
.00375 .09194 L
s
0 .10395 m
.00375 .10395 L
s
0 .11596 m
.00375 .11596 L
s
0 .12796 m
.00375 .12796 L
s
0 .15197 m
.00375 .15197 L
s
0 .16398 m
.00375 .16398 L
s
0 .17599 m
.00375 .17599 L
s
0 .18799 m
.00375 .18799 L
s
0 .21201 m
.00375 .21201 L
s
0 .22401 m
.00375 .22401 L
s
0 .23602 m
.00375 .23602 L
s
0 .24803 m
.00375 .24803 L
s
0 .27204 m
.00375 .27204 L
s
0 .28404 m
.00375 .28404 L
s
0 .29605 m
.00375 .29605 L
s
0 .30806 m
.00375 .30806 L
s
0 .33207 m
.00375 .33207 L
s
0 .34408 m
.00375 .34408 L
s
0 .35608 m
.00375 .35608 L
s
0 .36809 m
.00375 .36809 L
s
0 .0079 m
.00375 .0079 L
s
0 .3921 m
.00375 .3921 L
s
.25 Mabswid
0 0 m
0 .4 L
s
gsave
-0.01875 .2 -144.469 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
105.344 12.1875 translate
90 rotate
-105.344 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(spot) show
90.938 16.625 moveto
(size) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.438 16.625 moveto
(@) show
121.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
143.375 16.625 moveto
(D) show
147.688 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08611 .39375 m
.08611 .4 L
s
.26413 .39375 m
.26413 .4 L
s
.44215 .39375 m
.44215 .4 L
s
.62016 .39375 m
.62016 .4 L
s
.79818 .39375 m
.79818 .4 L
s
.97619 .39375 m
.97619 .4 L
s
.125 Mabswid
.12172 .39625 m
.12172 .4 L
s
.15732 .39625 m
.15732 .4 L
s
.19292 .39625 m
.19292 .4 L
s
.22853 .39625 m
.22853 .4 L
s
.29973 .39625 m
.29973 .4 L
s
.33534 .39625 m
.33534 .4 L
s
.37094 .39625 m
.37094 .4 L
s
.40654 .39625 m
.40654 .4 L
s
.47775 .39625 m
.47775 .4 L
s
.51335 .39625 m
.51335 .4 L
s
.54895 .39625 m
.54895 .4 L
s
.58456 .39625 m
.58456 .4 L
s
.65576 .39625 m
.65576 .4 L
s
.69137 .39625 m
.69137 .4 L
s
.72697 .39625 m
.72697 .4 L
s
.76257 .39625 m
.76257 .4 L
s
.83378 .39625 m
.83378 .4 L
s
.86938 .39625 m
.86938 .4 L
s
.90498 .39625 m
.90498 .4 L
s
.94059 .39625 m
.94059 .4 L
s
.05051 .39625 m
.05051 .4 L
s
.01491 .39625 m
.01491 .4 L
s
.25 Mabswid
0 .4 m
1 .4 L
s
gsave
.5 .4125 -100 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
100.375 16.625 moveto
(Profile) show
137.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .0199 m
1 .0199 L
s
.99375 .07994 m
1 .07994 L
s
.99375 .13997 m
1 .13997 L
s
.99375 .2 m
1 .2 L
s
.99375 .26003 m
1 .26003 L
s
.99375 .32006 m
1 .32006 L
s
.99375 .3801 m
1 .3801 L
s
.125 Mabswid
.99625 .03191 m
1 .03191 L
s
.99625 .04392 m
1 .04392 L
s
.99625 .05592 m
1 .05592 L
s
.99625 .06793 m
1 .06793 L
s
.99625 .09194 m
1 .09194 L
s
.99625 .10395 m
1 .10395 L
s
.99625 .11596 m
1 .11596 L
s
.99625 .12796 m
1 .12796 L
s
.99625 .15197 m
1 .15197 L
s
.99625 .16398 m
1 .16398 L
s
.99625 .17599 m
1 .17599 L
s
.99625 .18799 m
1 .18799 L
s
.99625 .21201 m
1 .21201 L
s
.99625 .22401 m
1 .22401 L
s
.99625 .23602 m
1 .23602 L
s
.99625 .24803 m
1 .24803 L
s
.99625 .27204 m
1 .27204 L
s
.99625 .28404 m
1 .28404 L
s
.99625 .29605 m
1 .29605 L
s
.99625 .30806 m
1 .30806 L
s
.99625 .33207 m
1 .33207 L
s
.99625 .34408 m
1 .34408 L
s
.99625 .35608 m
1 .35608 L
s
.99625 .36809 m
1 .36809 L
s
.99625 .0079 m
1 .0079 L
s
.99625 .3921 m
1 .3921 L
s
.25 Mabswid
1 0 m
1 .4 L
s
.977 .121 .023 r
.0075 w
.20182 .08733 m
.20182 .31267 L
s
.2328 .03251 m
.2328 .36749 L
s
.29083 .00952 m
.29083 .39048 L
s
0 .133 .859 r
.02381 .08733 m
.02381 .31267 L
s
.97619 .07076 m
.97619 .32924 L
s
0 g
.5 Mabswid
.02381 .31267 m
.02474 .31154 L
.02575 .31031 L
.0267 .30915 L
.02761 .30804 L
.02859 .30686 L
.02952 .30572 L
.03052 .30451 L
.03148 .30335 L
.0324 .30223 L
.03338 .30104 L
.03433 .2999 L
.03524 .2988 L
.03621 .29762 L
.03714 .2965 L
.03813 .2953 L
.03908 .29415 L
.04 .29304 L
.04098 .29187 L
.04192 .29074 L
.04292 .28953 L
.04388 .28838 L
.0448 .28726 L
.04579 .28608 L
.04674 .28494 L
.04765 .28385 L
.04862 .28269 L
.04956 .28157 L
.05055 .28038 L
.05151 .27924 L
.05243 .27815 L
.05341 .27698 L
.05435 .27586 L
.05526 .27478 L
.05622 .27364 L
.05715 .27254 L
.05814 .27137 L
.05909 .27025 L
.06001 .26917 L
.06098 .26803 L
.06192 .26693 L
.06292 .26576 L
.06388 .26464 L
.0648 .26356 L
.06579 .26242 L
.06673 .26132 L
.06764 .26027 L
.06861 .25915 L
.06954 .25808 L
.07054 .25694 L
Mistroke
.07149 .25585 L
.07241 .25481 L
.07339 .2537 L
.07433 .25263 L
.07533 .25151 L
.07629 .25043 L
.07722 .2494 L
.07821 .24831 L
.07916 .24726 L
.08007 .24626 L
.08104 .24521 L
.08198 .2442 L
.08297 .24313 L
.08393 .24211 L
.08485 .24114 L
.08584 .24012 L
.08678 .23915 L
.08769 .23822 L
.08866 .23725 L
.08959 .23633 L
.09058 .23536 L
.09153 .23444 L
.09245 .23358 L
.09342 .23268 L
.09436 .23183 L
.09536 .23095 L
.09632 .23012 L
.09725 .22936 L
.09823 .22857 L
.09918 .22784 L
.10009 .22716 L
.10106 .22648 L
.10199 .22586 L
.10247 .22556 L
.10299 .22524 L
.10394 .22469 L
.10442 .22443 L
.10492 .22417 L
.10539 .22394 L
.10583 .22374 L
.10631 .22352 L
.10676 .22334 L
.10721 .22317 L
.10747 .22307 L
.10771 .22299 L
.10796 .2229 L
.1082 .22283 L
.10841 .22276 L
.10865 .22269 L
.10887 .22263 L
Mistroke
.10912 .22257 L
.10925 .22254 L
.10938 .2225 L
.10951 .22247 L
.10963 .22245 L
.10987 .2224 L
.11 .22237 L
.11014 .22235 L
.11027 .22232 L
.11039 .2223 L
.1105 .22228 L
.11062 .22226 L
.11074 .22225 L
.11085 .22223 L
.11097 .22221 L
.1111 .2222 L
.11116 .22219 L
.11123 .22218 L
.1113 .22218 L
.11136 .22217 L
.11142 .22216 L
.11149 .22216 L
.11155 .22215 L
.1116 .22215 L
.11166 .22214 L
.11172 .22214 L
.11178 .22213 L
.11185 .22213 L
.11191 .22212 L
.11196 .22212 L
.11201 .22212 L
.11207 .22212 L
.1121 .22211 L
.11213 .22211 L
.11216 .22211 L
.1122 .22211 L
.11223 .22211 L
.11227 .22211 L
.1123 .22211 L
.11233 .2221 L
.11236 .2221 L
.11239 .2221 L
.11241 .2221 L
.11242 .2221 L
.11245 .2221 L
.11248 .2221 L
.11251 .2221 L
.11254 .2221 L
.11257 .2221 L
.1126 .2221 L
Mistroke
.11263 .2221 L
.11265 .2221 L
.11266 .2221 L
.11268 .2221 L
.1127 .2221 L
.11273 .2221 L
.11275 .2221 L
.11279 .2221 L
.11282 .2221 L
.11284 .2221 L
.11287 .2221 L
.1129 .2221 L
.11292 .2221 L
.11295 .2221 L
.11298 .2221 L
.11301 .2221 L
.11304 .2221 L
.11307 .2221 L
.1131 .2221 L
.11313 .2221 L
.11316 .2221 L
.11319 .2221 L
.11321 .2221 L
.11322 .2221 L
.11325 .2221 L
.11327 .2221 L
.11328 .2221 L
.11332 .2221 L
.11335 .22211 L
.11338 .22211 L
.11342 .22211 L
.11345 .22211 L
.11348 .22211 L
.11351 .22211 L
.11354 .22211 L
.11361 .22212 L
.11364 .22212 L
.11367 .22212 L
.11373 .22212 L
.11379 .22213 L
.11386 .22213 L
.11392 .22214 L
.11399 .22214 L
.11406 .22215 L
.11411 .22215 L
.11418 .22216 L
.11429 .22217 L
.11436 .22218 L
.11442 .22219 L
.11454 .2222 L
Mistroke
.11465 .22221 L
.11477 .22223 L
.1149 .22225 L
.11502 .22226 L
.11513 .22228 L
.11524 .2223 L
.11547 .22234 L
.11558 .22236 L
.11571 .22238 L
.11593 .22243 L
.11605 .22246 L
.11616 .22248 L
.11642 .22255 L
.11666 .22261 L
.11691 .22267 L
.11712 .22273 L
.11736 .2228 L
.1176 .22288 L
.11783 .22295 L
.11809 .22304 L
.11833 .22313 L
.11879 .22331 L
.11904 .22341 L
.11929 .22351 L
.11976 .22372 L
.1202 .22392 L
.12069 .22416 L
.12114 .22439 L
.12163 .22466 L
.12209 .22492 L
.12301 .22546 L
.12396 .22606 L
.12486 .22668 L
.12583 .22737 L
.12675 .22806 L
.12774 .22883 L
.12869 .22961 L
.12961 .23037 L
.13058 .23121 L
.13152 .23205 L
.13251 .23295 L
.13347 .23385 L
.1344 .23472 L
.13538 .23567 L
.13632 .2366 L
.13723 .2375 L
.1382 .23848 L
.13913 .23943 L
.14012 .24046 L
.14108 .24146 L
Mistroke
.14199 .24242 L
.14297 .24346 L
.14391 .24447 L
.14491 .24555 L
.14587 .2466 L
.1468 .24762 L
.14778 .2487 L
.14873 .24976 L
.14965 .25077 L
.15062 .25186 L
.15155 .25291 L
.15255 .25404 L
.1535 .25512 L
.15442 .25617 L
.1554 .25729 L
.15635 .25838 L
.15726 .25942 L
.15822 .26053 L
.15915 .26161 L
.16014 .26276 L
.16109 .26386 L
.16201 .26493 L
.16298 .26607 L
.16392 .26717 L
.16492 .26834 L
.16588 .26947 L
.1668 .27056 L
.16779 .27172 L
.16873 .27284 L
.16964 .27391 L
.17061 .27506 L
.17154 .27617 L
.17254 .27735 L
.17349 .27849 L
.17441 .27958 L
.17539 .28075 L
.17633 .28187 L
.17733 .28307 L
.17829 .28422 L
.17922 .28533 L
.18021 .28652 L
.18116 .28766 L
.18207 .28876 L
.18304 .28993 L
.18398 .29105 L
.18498 .29225 L
.18593 .29341 L
.18686 .29452 L
.18784 .2957 L
.18878 .29685 L
Mistroke
.18969 .29794 L
.19066 .29911 L
.19159 .30024 L
.19258 .30144 L
.19353 .30259 L
.19445 .30371 L
.19543 .30489 L
.19637 .30603 L
.19736 .30724 L
.19833 .30841 L
.19925 .30954 L
.20024 .31073 L
.20073 .31133 L
.20118 .31189 L
.20141 .31216 L
.20162 .31242 L
.20174 .31257 L
.20177 .3126 L
.20179 .31263 L
.20181 .31265 L
.20184 .31269 L
.20185 .31272 L
.20187 .31275 L
.2021 .31314 L
.20308 .31489 L
.20403 .31657 L
.20495 .31818 L
.20592 .3199 L
.20686 .32156 L
.20786 .32332 L
.20882 .32502 L
.20974 .32665 L
.21072 .32839 L
.21167 .33006 L
.21258 .33167 L
.21355 .33338 L
.21448 .33503 L
.21547 .33678 L
.21642 .33847 L
.21734 .3401 L
.21832 .34183 L
.21926 .34349 L
.22026 .34526 L
.22122 .34697 L
.22215 .34861 L
.22314 .35036 L
.22409 .35204 L
.225 .35366 L
.22597 .35538 L
.22691 .35704 L
Mistroke
.2279 .3588 L
.22886 .3605 L
.22978 .36213 L
.23076 .36387 L
.2317 .36555 L
.23218 .36639 L
.23238 .36675 L
.23261 .36716 L
.23267 .36726 L
.23273 .36736 L
.23276 .36742 L
.23279 .36747 L
.23281 .36749 L
.23284 .3675 L
.23308 .3676 L
.23358 .36779 L
.23456 .36818 L
.23551 .36855 L
.23642 .36891 L
.23739 .36929 L
.23832 .36966 L
.23932 .37005 L
.24027 .37042 L
.24119 .37078 L
.24217 .37117 L
.24311 .37154 L
.24411 .37193 L
.24508 .37231 L
.246 .37268 L
.24699 .37307 L
.24794 .37344 L
.24886 .3738 L
.24983 .37419 L
.25077 .37456 L
.25176 .37495 L
.25272 .37533 L
.25364 .37569 L
.25462 .37608 L
.25557 .37646 L
.25648 .37681 L
.25745 .3772 L
.25838 .37757 L
.25937 .37796 L
.26032 .37834 L
.26124 .3787 L
.26222 .37909 L
.26316 .37946 L
.26415 .37985 L
.26512 .38024 L
.26604 .3806 L
Mistroke
.26703 .38099 L
.26798 .38137 L
.26889 .38173 L
.26986 .38212 L
.27079 .38249 L
.27179 .38288 L
.27275 .38327 L
.27367 .38363 L
.27465 .38402 L
.27559 .3844 L
.2765 .38476 L
.27746 .38514 L
.27839 .38551 L
.27938 .38591 L
.28033 .38628 L
.28125 .38665 L
.28222 .38704 L
.28316 .38741 L
.28415 .38781 L
.28512 .38819 L
.28604 .38856 L
.28702 .38895 L
.28797 .38933 L
.28888 .3897 L
.28985 .39008 L
.29029 .39026 L
.29053 .39036 L
.29066 .39041 L
.29072 .39043 L
.29078 .39046 L
.29081 .39047 L
.29083 .39047 L
.29085 .39047 L
.29087 .39046 L
.29088 .39046 L
.29092 .39044 L
.29104 .39039 L
.29129 .39029 L
.29177 .3901 L
.29277 .3897 L
.29373 .38932 L
.29465 .38895 L
.29563 .38856 L
.29657 .38818 L
.29748 .38782 L
.29845 .38744 L
.29938 .38706 L
.30037 .38667 L
.30132 .38629 L
.30224 .38592 L
Mistroke
.30321 .38554 L
.30415 .38516 L
.30515 .38476 L
.30611 .38438 L
.30704 .38401 L
.30802 .38362 L
.30897 .38325 L
.30988 .38288 L
.31085 .3825 L
.31178 .38213 L
.31278 .38173 L
.31373 .38135 L
.31465 .38099 L
.31563 .3806 L
.31657 .38023 L
.31748 .37987 L
.31845 .37948 L
.31937 .37912 L
.32036 .37872 L
.32131 .37835 L
.32223 .37799 L
.3232 .3776 L
.32414 .37723 L
.32513 .37683 L
.32609 .37646 L
.32702 .37609 L
.328 .3757 L
.32895 .37533 L
.32985 .37497 L
.33082 .37459 L
.33175 .37422 L
.33275 .37383 L
.3337 .37345 L
.33462 .37309 L
.33559 .37271 L
.33653 .37234 L
.33753 .37194 L
.3385 .37156 L
.33942 .3712 L
.34041 .37081 L
.34136 .37044 L
.34227 .37008 L
.34324 .3697 L
.34418 .36933 L
.34517 .36894 L
.34613 .36856 L
.34705 .3682 L
.34803 .36782 L
.34897 .36745 L
.34988 .36709 L
Mistroke
.35085 .36671 L
.35178 .36635 L
.35277 .36596 L
.35372 .36559 L
.35463 .36523 L
.35561 .36485 L
.35655 .36448 L
.35754 .36409 L
.35851 .36372 L
.35943 .36336 L
.36041 .36297 L
.36136 .3626 L
.36227 .36225 L
.36324 .36187 L
.36417 .36151 L
.36517 .36112 L
.36612 .36075 L
.36704 .36039 L
.36802 .36001 L
.36896 .35965 L
.36996 .35926 L
.37092 .35888 L
.37185 .35852 L
.37284 .35814 L
.37379 .35777 L
.3747 .35742 L
.37568 .35704 L
.37661 .35668 L
.37761 .35629 L
.37857 .35592 L
.37949 .35557 L
.38047 .35519 L
.38142 .35482 L
.38232 .35447 L
.38329 .3541 L
.38422 .35374 L
.38521 .35336 L
.38617 .35299 L
.38708 .35264 L
.38806 .35226 L
.389 .3519 L
.39 .35152 L
.39096 .35115 L
.39189 .35079 L
.39287 .35041 L
.39382 .35005 L
.39473 .3497 L
.3957 .34933 L
.39663 .34897 L
.39763 .34859 L
Mistroke
.39858 .34822 L
.39951 .34787 L
.40048 .3475 L
.40143 .34714 L
.40233 .34679 L
.4033 .34642 L
.40423 .34607 L
.40522 .34569 L
.40617 .34533 L
.40708 .34498 L
.40806 .34461 L
.40899 .34425 L
.40999 .34388 L
.41095 .34351 L
.41188 .34316 L
.41286 .34279 L
.4138 .34243 L
.41471 .34209 L
.41568 .34172 L
.41661 .34137 L
.41761 .34099 L
.41856 .34063 L
.41948 .34029 L
.42046 .33992 L
.4214 .33956 L
.4224 .33919 L
.42336 .33882 L
.42429 .33848 L
.42527 .3381 L
.42622 .33775 L
.42714 .33741 L
.42811 .33704 L
.42904 .33669 L
.43004 .33632 L
.431 .33596 L
.43192 .33562 L
.4329 .33525 L
.43384 .3349 L
.43475 .33456 L
.43572 .3342 L
.43665 .33385 L
.43764 .33348 L
.43859 .33313 L
.43951 .33279 L
.44048 .33243 L
.44142 .33208 L
.44242 .33171 L
.44338 .33135 L
.4443 .33101 L
.44529 .33065 L
Mistroke
.44624 .3303 L
.44715 .32996 L
.44812 .32961 L
.44905 .32926 L
.45004 .3289 L
.451 .32854 L
.45192 .32821 L
.4529 .32785 L
.45384 .3275 L
.45474 .32717 L
.45571 .32682 L
.45664 .32648 L
.45762 .32612 L
.45858 .32577 L
.45949 .32544 L
.46046 .32508 L
.4614 .32474 L
.4624 .32438 L
.46336 .32403 L
.46428 .3237 L
.46526 .32334 L
.46621 .323 L
.46711 .32267 L
.46808 .32232 L
.46901 .32199 L
.47 .32163 L
.47096 .32129 L
.47188 .32096 L
.47285 .32061 L
.47379 .32027 L
.47479 .31991 L
.47575 .31957 L
.47668 .31924 L
.47767 .31888 L
.47861 .31855 L
.47953 .31822 L
.4805 .31788 L
.48143 .31754 L
.48243 .31719 L
.48338 .31685 L
.4843 .31653 L
.48528 .31618 L
.48623 .31585 L
.48713 .31553 L
.4881 .31519 L
.48903 .31486 L
.49002 .31451 L
.49097 .31418 L
.49189 .31386 L
.49286 .31352 L
Mistroke
.4938 .31319 L
.4948 .31284 L
.49576 .31251 L
.49668 .31219 L
.49766 .31185 L
.49861 .31152 L
.49952 .3112 L
.50049 .31087 L
.50142 .31055 L
.50241 .3102 L
.50337 .30987 L
.50429 .30956 L
.50527 .30922 L
.50621 .3089 L
.50721 .30856 L
.50817 .30823 L
.5091 .30791 L
.51009 .30758 L
.51104 .30726 L
.51195 .30695 L
.51292 .30662 L
.51386 .3063 L
.51485 .30597 L
.51581 .30564 L
.51673 .30533 L
.51771 .305 L
.51866 .30469 L
.51957 .30438 L
.52053 .30406 L
.52147 .30375 L
.52245 .30342 L
.52341 .30311 L
.52433 .3028 L
.5253 .30248 L
.52624 .30217 L
.52724 .30184 L
.5282 .30153 L
.52913 .30123 L
.53011 .3009 L
.53106 .30059 L
.53197 .3003 L
.53294 .29998 L
.53387 .29968 L
.53487 .29936 L
.53582 .29905 L
.53674 .29875 L
.53772 .29844 L
.53867 .29814 L
.53957 .29785 L
.54054 .29754 L
Mistroke
.54147 .29724 L
.54245 .29693 L
.5434 .29663 L
.54432 .29634 L
.54529 .29603 L
.54623 .29574 L
.54723 .29543 L
.54819 .29513 L
.54911 .29484 L
.55009 .29454 L
.55104 .29424 L
.55195 .29396 L
.55292 .29366 L
.55385 .29338 L
.55484 .29307 L
.55579 .29278 L
.55671 .2925 L
.55769 .2922 L
.55863 .29192 L
.55963 .29162 L
.56059 .29133 L
.56152 .29105 L
.5625 .29075 L
.56345 .29047 L
.56437 .2902 L
.56534 .28991 L
.56627 .28964 L
.56727 .28934 L
.56822 .28906 L
.56915 .28879 L
.57013 .28851 L
.57107 .28823 L
.57198 .28797 L
.57294 .28769 L
.57387 .28743 L
.57486 .28714 L
.57582 .28687 L
.57673 .28661 L
.57771 .28634 L
.57865 .28607 L
.57964 .28579 L
.5806 .28553 L
.58153 .28527 L
.58251 .285 L
.58346 .28473 L
.58437 .28448 L
.58534 .28422 L
.58627 .28397 L
.58727 .2837 L
.58822 .28344 L
Mistroke
.58914 .28319 L
.59012 .28293 L
.59106 .28268 L
.59206 .28241 L
.59303 .28216 L
.59395 .28192 L
.59494 .28166 L
.59589 .28141 L
.5968 .28118 L
.59778 .28093 L
.59871 .28069 L
.59971 .28043 L
.60067 .28019 L
.60159 .27996 L
.60257 .27972 L
.60352 .27948 L
.60443 .27926 L
.60539 .27902 L
.60633 .27879 L
.60732 .27855 L
.60827 .27832 L
.60919 .2781 L
.61016 .27787 L
.6111 .27764 L
.6121 .27741 L
.61306 .27718 L
.61399 .27697 L
.61497 .27674 L
.61592 .27653 L
.61684 .27632 L
.61781 .2761 L
.61874 .27589 L
.61973 .27567 L
.62069 .27546 L
.62161 .27526 L
.62259 .27504 L
.62353 .27484 L
.62444 .27465 L
.62541 .27444 L
.62634 .27424 L
.62732 .27404 L
.62828 .27384 L
.62919 .27365 L
.63017 .27345 L
.6311 .27327 L
.6321 .27307 L
.63306 .27288 L
.63398 .27269 L
.63497 .2725 L
.63591 .27232 L
Mistroke
.63682 .27215 L
.63779 .27197 L
.63872 .27179 L
.63972 .27161 L
.64067 .27143 L
.64159 .27127 L
.64257 .27109 L
.64351 .27093 L
.64451 .27075 L
.64547 .27058 L
.6464 .27043 L
.64738 .27026 L
.64833 .2701 L
.64925 .26995 L
.65022 .26979 L
.65116 .26964 L
.65215 .26949 L
.65311 .26934 L
.65403 .26919 L
.65501 .26904 L
.65596 .2689 L
.65686 .26877 L
.65783 .26863 L
.65876 .2685 L
.65975 .26836 L
.6607 .26822 L
.66162 .2681 L
.6626 .26797 L
.66353 .26785 L
.66453 .26772 L
.66549 .26759 L
.66642 .26748 L
.6674 .26736 L
.66835 .26724 L
.66926 .26714 L
.67023 .26702 L
.67117 .26692 L
.67216 .26681 L
.67311 .26671 L
.67403 .26661 L
.67501 .26651 L
.67596 .26641 L
.67686 .26632 L
.67783 .26623 L
.67875 .26614 L
.67974 .26605 L
.68069 .26597 L
.68161 .26589 L
.68258 .26581 L
.68352 .26573 L
Mistroke
.68451 .26565 L
.68547 .26558 L
.6864 .26551 L
.68738 .26544 L
.68832 .26538 L
.68923 .26532 L
.6902 .26526 L
.69113 .2652 L
.69212 .26514 L
.69308 .26509 L
.694 .26504 L
.69497 .26499 L
.69591 .26495 L
.69691 .2649 L
.69788 .26486 L
.6988 .26482 L
.69927 .26481 L
.69979 .26479 L
.70074 .26475 L
.7012 .26474 L
.70171 .26472 L
.70218 .26471 L
.7027 .2647 L
.7032 .26468 L
.70366 .26467 L
.70411 .26466 L
.7046 .26465 L
.70507 .26464 L
.70557 .26463 L
.70605 .26462 L
.70629 .26461 L
.70656 .26461 L
.70703 .2646 L
.70729 .2646 L
.70753 .26459 L
.70776 .26459 L
.70799 .26459 L
.70825 .26458 L
.70849 .26458 L
.70872 .26458 L
.70896 .26458 L
.70919 .26457 L
.7094 .26457 L
.70952 .26457 L
.70964 .26457 L
.70986 .26457 L
.70999 .26457 L
.71012 .26457 L
.71024 .26456 L
.71036 .26456 L
Mistroke
.71048 .26456 L
.71059 .26456 L
.71071 .26456 L
.71084 .26456 L
.7109 .26456 L
.71097 .26456 L
.71104 .26456 L
.7111 .26456 L
.71116 .26456 L
.71123 .26456 L
.71134 .26456 L
.7114 .26456 L
.71147 .26456 L
.71153 .26456 L
.71159 .26456 L
.71164 .26456 L
.7117 .26456 L
.71175 .26456 L
.71181 .26456 L
.71187 .26456 L
.7119 .26456 L
.71194 .26456 L
.71196 .26456 L
.712 .26456 L
.71202 .26456 L
.71205 .26456 L
.71208 .26456 L
.71212 .26456 L
.71215 .26456 L
.71219 .26456 L
.71222 .26456 L
.71225 .26456 L
.71228 .26456 L
.7123 .26456 L
.71231 .26456 L
.71234 .26456 L
.71237 .26456 L
.7124 .26456 L
.71243 .26456 L
.71246 .26456 L
.71247 .26456 L
.71249 .26456 L
.71252 .26456 L
.71255 .26456 L
.71258 .26456 L
.7126 .26456 L
.71263 .26456 L
.71265 .26456 L
.71268 .26456 L
.71271 .26456 L
Mistroke
.71274 .26456 L
.71277 .26456 L
.7128 .26456 L
.71281 .26456 L
.71283 .26456 L
.71286 .26456 L
.71289 .26456 L
.71291 .26456 L
.71292 .26456 L
.71295 .26456 L
.71297 .26456 L
.71299 .26456 L
.713 .26456 L
.71302 .26456 L
.71305 .26456 L
.71308 .26456 L
.71311 .26456 L
.71314 .26456 L
.71317 .26456 L
.7132 .26456 L
.71323 .26456 L
.71326 .26456 L
.71329 .26456 L
.71333 .26456 L
.71339 .26456 L
.71342 .26456 L
.71345 .26456 L
.71348 .26456 L
.71352 .26456 L
.71358 .26456 L
.71363 .26456 L
.71369 .26456 L
.71376 .26456 L
.71381 .26456 L
.71387 .26456 L
.71393 .26456 L
.71399 .26456 L
.71409 .26456 L
.71415 .26456 L
.7142 .26456 L
.71432 .26456 L
.71438 .26456 L
.71444 .26456 L
.71455 .26456 L
.71466 .26456 L
.71478 .26456 L
.71489 .26456 L
.71502 .26456 L
.71515 .26457 L
.71527 .26457 L
Mistroke
.71538 .26457 L
.7155 .26457 L
.71562 .26457 L
.71585 .26457 L
.71606 .26457 L
.71631 .26458 L
.71653 .26458 L
.71679 .26458 L
.71704 .26458 L
.71727 .26459 L
.71752 .26459 L
.71773 .26459 L
.71796 .2646 L
.71843 .2646 L
.7187 .26461 L
.71894 .26461 L
.71939 .26462 L
.71965 .26463 L
.71989 .26463 L
.72034 .26464 L
.72084 .26465 L
.7213 .26466 L
.7218 .26467 L
.72228 .26469 L
.72279 .2647 L
.72371 .26473 L
.72418 .26474 L
.72468 .26476 L
.72516 .26478 L
.72568 .26479 L
.72664 .26483 L
.72762 .26487 L
.72857 .26491 L
.72948 .26495 L
.73045 .265 L
.73138 .26505 L
.73237 .2651 L
.73333 .26515 L
.73424 .26521 L
.73522 .26527 L
.73616 .26533 L
.73716 .26539 L
.73813 .26546 L
.73905 .26552 L
.74004 .2656 L
.74099 .26567 L
.7419 .26574 L
.74288 .26582 L
.74381 .2659 L
.74481 .26599 L
Mistroke
.74577 .26607 L
.74669 .26616 L
.74767 .26625 L
.74861 .26634 L
.74952 .26643 L
.75049 .26653 L
.75142 .26662 L
.75241 .26673 L
.75336 .26683 L
.75428 .26694 L
.75525 .26705 L
.75619 .26715 L
.75719 .26727 L
.75815 .26739 L
.75908 .2675 L
.76006 .26763 L
.76101 .26775 L
.76192 .26787 L
.76289 .26799 L
.76383 .26812 L
.76482 .26826 L
.76578 .26839 L
.7667 .26852 L
.76767 .26866 L
.76862 .2688 L
.76952 .26893 L
.77049 .26907 L
.77142 .26922 L
.7724 .26937 L
.77336 .26952 L
.77427 .26966 L
.77524 .26982 L
.77618 .26997 L
.77718 .27014 L
.77814 .2703 L
.77906 .27045 L
.78004 .27062 L
.78099 .27078 L
.7819 .27094 L
.78287 .27112 L
.7838 .27128 L
.78479 .27146 L
.78574 .27164 L
.78666 .27181 L
.78764 .27199 L
.78858 .27217 L
.78958 .27236 L
.79054 .27254 L
.79147 .27272 L
.79245 .27292 L
Mistroke
.7934 .27311 L
.79431 .27329 L
.79529 .27349 L
.79622 .27368 L
.79722 .27388 L
.79817 .27408 L
.79909 .27427 L
.80007 .27448 L
.80102 .27468 L
.80193 .27487 L
.80289 .27508 L
.80382 .27528 L
.80481 .2755 L
.80576 .27571 L
.80668 .27592 L
.80765 .27614 L
.80859 .27635 L
.80959 .27657 L
.81055 .27679 L
.81148 .27701 L
.81246 .27724 L
.81341 .27746 L
.81432 .27767 L
.81529 .2779 L
.81622 .27813 L
.81721 .27836 L
.81817 .27859 L
.81909 .27882 L
.82006 .27906 L
.82101 .27929 L
.82201 .27954 L
.82297 .27978 L
.8239 .28001 L
.82489 .28026 L
.82584 .2805 L
.82675 .28073 L
.82772 .28098 L
.82866 .28122 L
.82965 .28148 L
.83061 .28173 L
.83154 .28197 L
.83252 .28222 L
.83346 .28247 L
.83437 .28271 L
.83534 .28297 L
.83627 .28322 L
.83726 .28349 L
.83821 .28374 L
.83913 .28399 L
.84011 .28426 L
Mistroke
.84105 .28452 L
.84204 .28479 L
.84301 .28506 L
.84393 .28531 L
.84492 .28559 L
.84587 .28585 L
.84678 .28611 L
.84775 .28638 L
.84868 .28665 L
.84968 .28693 L
.85063 .2872 L
.85155 .28746 L
.85253 .28774 L
.85348 .28802 L
.85438 .28828 L
.85535 .28856 L
.85628 .28883 L
.85727 .28912 L
.85822 .2894 L
.85913 .28967 L
.86011 .28995 L
.86104 .29023 L
.86204 .29053 L
.863 .29082 L
.86392 .29109 L
.86491 .29139 L
.86585 .29167 L
.86676 .29195 L
.86773 .29224 L
.86866 .29252 L
.86966 .29283 L
.87061 .29312 L
.87153 .2934 L
.87251 .2937 L
.87345 .29399 L
.87445 .2943 L
.87541 .2946 L
.87634 .29489 L
.87732 .29519 L
.87827 .29549 L
.87919 .29578 L
.88016 .29608 L
.88109 .29638 L
.88209 .29669 L
.88305 .29699 L
.88397 .29729 L
.88495 .2976 L
.88589 .2979 L
.8868 .29819 L
.88777 .2985 L
Mistroke
.8887 .2988 L
.88969 .29912 L
.89064 .29943 L
.89156 .29972 L
.89253 .30004 L
.89347 .30034 L
.89447 .30067 L
.89543 .30098 L
.89636 .30128 L
.89734 .30161 L
.89829 .30192 L
.8992 .30222 L
.90017 .30254 L
.9011 .30285 L
.90209 .30317 L
.90305 .30349 L
.90397 .3038 L
.90495 .30412 L
.90589 .30444 L
.9068 .30474 L
.90776 .30506 L
.90869 .30537 L
.90968 .30571 L
.91063 .30603 L
.91154 .30634 L
.91252 .30666 L
.91345 .30698 L
.91445 .30732 L
.91541 .30764 L
.91633 .30796 L
.91731 .30829 L
.91826 .30862 L
.91917 .30893 L
.92014 .30926 L
.92107 .30958 L
.92206 .30992 L
.92301 .31025 L
.92393 .31056 L
.92491 .3109 L
.92585 .31123 L
.92685 .31157 L
.92781 .3119 L
.92873 .31223 L
.92972 .31257 L
.93067 .3129 L
.93158 .31322 L
.93255 .31356 L
.93349 .31388 L
.93448 .31423 L
.93544 .31457 L
Mistroke
.93636 .31489 L
.93734 .31524 L
.93828 .31557 L
.93919 .31589 L
.94016 .31623 L
.94108 .31656 L
.94207 .31691 L
.94303 .31724 L
.94394 .31757 L
.94492 .31792 L
.94585 .31825 L
.94685 .3186 L
.94781 .31895 L
.94874 .31928 L
.94972 .31963 L
.95067 .31997 L
.95158 .32029 L
.95255 .32064 L
.95348 .32098 L
.95447 .32133 L
.95543 .32168 L
.95634 .32201 L
.95732 .32236 L
.95826 .3227 L
.95926 .32306 L
.96023 .32341 L
.96116 .32375 L
.96214 .3241 L
.96309 .32445 L
.96401 .32478 L
.96498 .32514 L
.96591 .32548 L
.96691 .32584 L
.96787 .32619 L
.96879 .32653 L
.96977 .32688 L
.97072 .32723 L
.97162 .32756 L
.97259 .32792 L
.97352 .32826 L
.97451 .32862 L
.97547 .32897 L
.97619 .32924 L
Mfstroke
.02381 .08733 m
.02474 .08846 L
.02575 .08969 L
.0267 .09085 L
.02761 .09196 L
.02859 .09314 L
.02952 .09428 L
.03052 .09549 L
.03148 .09665 L
.0324 .09777 L
.03338 .09896 L
.03433 .1001 L
.03524 .1012 L
.03621 .10238 L
.03714 .1035 L
.03813 .1047 L
.03908 .10585 L
.04 .10696 L
.04098 .10813 L
.04192 .10926 L
.04292 .11047 L
.04388 .11162 L
.0448 .11274 L
.04579 .11392 L
.04674 .11506 L
.04765 .11615 L
.04862 .11731 L
.04956 .11843 L
.05055 .11962 L
.05151 .12076 L
.05243 .12185 L
.05341 .12302 L
.05435 .12414 L
.05526 .12522 L
.05622 .12636 L
.05715 .12746 L
.05814 .12863 L
.05909 .12975 L
.06001 .13083 L
.06098 .13197 L
.06192 .13307 L
.06292 .13424 L
.06388 .13536 L
.0648 .13644 L
.06579 .13758 L
.06673 .13868 L
.06764 .13973 L
.06861 .14085 L
.06954 .14192 L
.07054 .14306 L
Mistroke
.07149 .14415 L
.07241 .14519 L
.07339 .1463 L
.07433 .14737 L
.07533 .14849 L
.07629 .14957 L
.07722 .1506 L
.07821 .15169 L
.07916 .15274 L
.08007 .15374 L
.08104 .15479 L
.08198 .1558 L
.08297 .15687 L
.08393 .15789 L
.08485 .15886 L
.08584 .15988 L
.08678 .16085 L
.08769 .16178 L
.08866 .16275 L
.08959 .16367 L
.09058 .16464 L
.09153 .16556 L
.09245 .16642 L
.09342 .16732 L
.09436 .16817 L
.09536 .16905 L
.09632 .16988 L
.09725 .17064 L
.09823 .17143 L
.09918 .17216 L
.10009 .17284 L
.10106 .17352 L
.10199 .17414 L
.10247 .17444 L
.10299 .17476 L
.10394 .17531 L
.10442 .17557 L
.10492 .17583 L
.10539 .17606 L
.10583 .17626 L
.10631 .17648 L
.10676 .17666 L
.10721 .17683 L
.10747 .17693 L
.10771 .17701 L
.10796 .1771 L
.1082 .17717 L
.10841 .17724 L
.10865 .17731 L
.10887 .17737 L
Mistroke
.10912 .17743 L
.10925 .17746 L
.10938 .1775 L
.10951 .17753 L
.10963 .17755 L
.10987 .1776 L
.11 .17763 L
.11014 .17765 L
.11027 .17768 L
.11039 .1777 L
.1105 .17772 L
.11062 .17774 L
.11074 .17775 L
.11085 .17777 L
.11097 .17779 L
.1111 .1778 L
.11116 .17781 L
.11123 .17782 L
.1113 .17782 L
.11136 .17783 L
.11142 .17784 L
.11149 .17784 L
.11155 .17785 L
.1116 .17785 L
.11166 .17786 L
.11172 .17786 L
.11178 .17787 L
.11185 .17787 L
.11191 .17788 L
.11196 .17788 L
.11201 .17788 L
.11207 .17788 L
.1121 .17789 L
.11213 .17789 L
.11216 .17789 L
.1122 .17789 L
.11223 .17789 L
.11227 .17789 L
.1123 .17789 L
.11233 .1779 L
.11236 .1779 L
.11239 .1779 L
.11241 .1779 L
.11242 .1779 L
.11245 .1779 L
.11248 .1779 L
.11251 .1779 L
.11254 .1779 L
.11257 .1779 L
.1126 .1779 L
Mistroke
.11263 .1779 L
.11265 .1779 L
.11266 .1779 L
.11268 .1779 L
.1127 .1779 L
.11273 .1779 L
.11275 .1779 L
.11279 .1779 L
.11282 .1779 L
.11284 .1779 L
.11287 .1779 L
.1129 .1779 L
.11292 .1779 L
.11295 .1779 L
.11298 .1779 L
.11301 .1779 L
.11304 .1779 L
.11307 .1779 L
.1131 .1779 L
.11313 .1779 L
.11316 .1779 L
.11319 .1779 L
.11321 .1779 L
.11322 .1779 L
.11325 .1779 L
.11327 .1779 L
.11328 .1779 L
.11332 .1779 L
.11335 .17789 L
.11338 .17789 L
.11342 .17789 L
.11345 .17789 L
.11348 .17789 L
.11351 .17789 L
.11354 .17789 L
.11361 .17788 L
.11364 .17788 L
.11367 .17788 L
.11373 .17788 L
.11379 .17787 L
.11386 .17787 L
.11392 .17786 L
.11399 .17786 L
.11406 .17785 L
.11411 .17785 L
.11418 .17784 L
.11429 .17783 L
.11436 .17782 L
.11442 .17781 L
.11454 .1778 L
Mistroke
.11465 .17779 L
.11477 .17777 L
.1149 .17775 L
.11502 .17774 L
.11513 .17772 L
.11524 .1777 L
.11547 .17766 L
.11558 .17764 L
.11571 .17762 L
.11593 .17757 L
.11605 .17754 L
.11616 .17752 L
.11642 .17745 L
.11666 .17739 L
.11691 .17733 L
.11712 .17727 L
.11736 .1772 L
.1176 .17712 L
.11783 .17705 L
.11809 .17696 L
.11833 .17687 L
.11879 .17669 L
.11904 .17659 L
.11929 .17649 L
.11976 .17628 L
.1202 .17608 L
.12069 .17584 L
.12114 .17561 L
.12163 .17534 L
.12209 .17508 L
.12301 .17454 L
.12396 .17394 L
.12486 .17332 L
.12583 .17263 L
.12675 .17194 L
.12774 .17117 L
.12869 .17039 L
.12961 .16963 L
.13058 .16879 L
.13152 .16795 L
.13251 .16705 L
.13347 .16615 L
.1344 .16528 L
.13538 .16433 L
.13632 .1634 L
.13723 .1625 L
.1382 .16152 L
.13913 .16057 L
.14012 .15954 L
.14108 .15854 L
Mistroke
.14199 .15758 L
.14297 .15654 L
.14391 .15553 L
.14491 .15445 L
.14587 .1534 L
.1468 .15238 L
.14778 .1513 L
.14873 .15024 L
.14965 .14923 L
.15062 .14814 L
.15155 .14709 L
.15255 .14596 L
.1535 .14488 L
.15442 .14383 L
.1554 .14271 L
.15635 .14162 L
.15726 .14058 L
.15822 .13947 L
.15915 .13839 L
.16014 .13724 L
.16109 .13614 L
.16201 .13507 L
.16298 .13393 L
.16392 .13283 L
.16492 .13166 L
.16588 .13053 L
.1668 .12944 L
.16779 .12828 L
.16873 .12716 L
.16964 .12609 L
.17061 .12494 L
.17154 .12383 L
.17254 .12265 L
.17349 .12151 L
.17441 .12042 L
.17539 .11925 L
.17633 .11813 L
.17733 .11693 L
.17829 .11578 L
.17922 .11467 L
.18021 .11348 L
.18116 .11234 L
.18207 .11124 L
.18304 .11007 L
.18398 .10895 L
.18498 .10775 L
.18593 .10659 L
.18686 .10548 L
.18784 .1043 L
.18878 .10315 L
Mistroke
.18969 .10206 L
.19066 .10089 L
.19159 .09976 L
.19258 .09856 L
.19353 .09741 L
.19445 .09629 L
.19543 .09511 L
.19637 .09397 L
.19736 .09276 L
.19833 .09159 L
.19925 .09046 L
.20024 .08927 L
.20073 .08867 L
.20118 .08811 L
.20141 .08784 L
.20162 .08758 L
.20174 .08743 L
.20177 .0874 L
.20179 .08737 L
.20181 .08735 L
.20184 .08731 L
.20185 .08728 L
.20187 .08725 L
.2021 .08686 L
.20308 .08511 L
.20403 .08343 L
.20495 .08182 L
.20592 .0801 L
.20686 .07844 L
.20786 .07668 L
.20882 .07498 L
.20974 .07335 L
.21072 .07161 L
.21167 .06994 L
.21258 .06833 L
.21355 .06662 L
.21448 .06497 L
.21547 .06322 L
.21642 .06153 L
.21734 .0599 L
.21832 .05817 L
.21926 .05651 L
.22026 .05474 L
.22122 .05303 L
.22215 .05139 L
.22314 .04964 L
.22409 .04796 L
.225 .04634 L
.22597 .04462 L
.22691 .04296 L
Mistroke
.2279 .0412 L
.22886 .0395 L
.22978 .03787 L
.23076 .03613 L
.2317 .03445 L
.23218 .03361 L
.23238 .03325 L
.23261 .03284 L
.23267 .03274 L
.23273 .03264 L
.23276 .03258 L
.23279 .03253 L
.23281 .03251 L
.23284 .0325 L
.23308 .0324 L
.23358 .03221 L
.23456 .03182 L
.23551 .03145 L
.23642 .03109 L
.23739 .03071 L
.23832 .03034 L
.23932 .02995 L
.24027 .02958 L
.24119 .02922 L
.24217 .02883 L
.24311 .02846 L
.24411 .02807 L
.24508 .02769 L
.246 .02732 L
.24699 .02693 L
.24794 .02656 L
.24886 .0262 L
.24983 .02581 L
.25077 .02544 L
.25176 .02505 L
.25272 .02467 L
.25364 .02431 L
.25462 .02392 L
.25557 .02354 L
.25648 .02319 L
.25745 .0228 L
.25838 .02243 L
.25937 .02204 L
.26032 .02166 L
.26124 .0213 L
.26222 .02091 L
.26316 .02054 L
.26415 .02015 L
.26512 .01976 L
.26604 .0194 L
Mistroke
.26703 .01901 L
.26798 .01863 L
.26889 .01827 L
.26986 .01788 L
.27079 .01751 L
.27179 .01712 L
.27275 .01673 L
.27367 .01637 L
.27465 .01598 L
.27559 .0156 L
.2765 .01524 L
.27746 .01486 L
.27839 .01449 L
.27938 .01409 L
.28033 .01372 L
.28125 .01335 L
.28222 .01296 L
.28316 .01259 L
.28415 .01219 L
.28512 .01181 L
.28604 .01144 L
.28702 .01105 L
.28797 .01067 L
.28888 .0103 L
.28985 .00992 L
.29029 .00974 L
.29053 .00964 L
.29066 .00959 L
.29072 .00957 L
.29078 .00954 L
.29081 .00953 L
.29083 .00953 L
.29085 .00953 L
.29087 .00954 L
.29088 .00954 L
.29092 .00956 L
.29104 .00961 L
.29129 .00971 L
.29177 .0099 L
.29277 .0103 L
.29373 .01068 L
.29465 .01105 L
.29563 .01144 L
.29657 .01182 L
.29748 .01218 L
.29845 .01256 L
.29938 .01294 L
.30037 .01333 L
.30132 .01371 L
.30224 .01408 L
Mistroke
.30321 .01446 L
.30415 .01484 L
.30515 .01524 L
.30611 .01562 L
.30704 .01599 L
.30802 .01638 L
.30897 .01675 L
.30988 .01712 L
.31085 .0175 L
.31178 .01787 L
.31278 .01827 L
.31373 .01865 L
.31465 .01901 L
.31563 .0194 L
.31657 .01977 L
.31748 .02013 L
.31845 .02052 L
.31937 .02088 L
.32036 .02128 L
.32131 .02165 L
.32223 .02201 L
.3232 .0224 L
.32414 .02277 L
.32513 .02317 L
.32609 .02354 L
.32702 .02391 L
.328 .0243 L
.32895 .02467 L
.32985 .02503 L
.33082 .02541 L
.33175 .02578 L
.33275 .02617 L
.3337 .02655 L
.33462 .02691 L
.33559 .02729 L
.33653 .02766 L
.33753 .02806 L
.3385 .02844 L
.33942 .0288 L
.34041 .02919 L
.34136 .02956 L
.34227 .02992 L
.34324 .0303 L
.34418 .03067 L
.34517 .03106 L
.34613 .03144 L
.34705 .0318 L
.34803 .03218 L
.34897 .03255 L
.34988 .03291 L
Mistroke
.35085 .03329 L
.35178 .03365 L
.35277 .03404 L
.35372 .03441 L
.35463 .03477 L
.35561 .03515 L
.35655 .03552 L
.35754 .03591 L
.35851 .03628 L
.35943 .03664 L
.36041 .03703 L
.36136 .0374 L
.36227 .03775 L
.36324 .03813 L
.36417 .03849 L
.36517 .03888 L
.36612 .03925 L
.36704 .03961 L
.36802 .03999 L
.36896 .04035 L
.36996 .04074 L
.37092 .04112 L
.37185 .04148 L
.37284 .04186 L
.37379 .04223 L
.3747 .04258 L
.37568 .04296 L
.37661 .04332 L
.37761 .04371 L
.37857 .04408 L
.37949 .04443 L
.38047 .04481 L
.38142 .04518 L
.38232 .04553 L
.38329 .0459 L
.38422 .04626 L
.38521 .04664 L
.38617 .04701 L
.38708 .04736 L
.38806 .04774 L
.389 .0481 L
.39 .04848 L
.39096 .04885 L
.39189 .04921 L
.39287 .04959 L
.39382 .04995 L
.39473 .0503 L
.3957 .05067 L
.39663 .05103 L
.39763 .05141 L
Mistroke
.39858 .05178 L
.39951 .05213 L
.40048 .0525 L
.40143 .05286 L
.40233 .05321 L
.4033 .05358 L
.40423 .05393 L
.40522 .05431 L
.40617 .05467 L
.40708 .05502 L
.40806 .05539 L
.40899 .05575 L
.40999 .05612 L
.41095 .05649 L
.41188 .05684 L
.41286 .05721 L
.4138 .05757 L
.41471 .05791 L
.41568 .05828 L
.41661 .05863 L
.41761 .05901 L
.41856 .05937 L
.41948 .05971 L
.42046 .06008 L
.4214 .06044 L
.4224 .06081 L
.42336 .06118 L
.42429 .06152 L
.42527 .0619 L
.42622 .06225 L
.42714 .06259 L
.42811 .06296 L
.42904 .06331 L
.43004 .06368 L
.431 .06404 L
.43192 .06438 L
.4329 .06475 L
.43384 .0651 L
.43475 .06544 L
.43572 .0658 L
.43665 .06615 L
.43764 .06652 L
.43859 .06687 L
.43951 .06721 L
.44048 .06757 L
.44142 .06792 L
.44242 .06829 L
.44338 .06865 L
.4443 .06899 L
.44529 .06935 L
Mistroke
.44624 .0697 L
.44715 .07004 L
.44812 .07039 L
.44905 .07074 L
.45004 .0711 L
.451 .07146 L
.45192 .07179 L
.4529 .07215 L
.45384 .0725 L
.45474 .07283 L
.45571 .07318 L
.45664 .07352 L
.45762 .07388 L
.45858 .07423 L
.45949 .07456 L
.46046 .07492 L
.4614 .07526 L
.4624 .07562 L
.46336 .07597 L
.46428 .0763 L
.46526 .07666 L
.46621 .077 L
.46711 .07733 L
.46808 .07768 L
.46901 .07801 L
.47 .07837 L
.47096 .07871 L
.47188 .07904 L
.47285 .07939 L
.47379 .07973 L
.47479 .08009 L
.47575 .08043 L
.47668 .08076 L
.47767 .08112 L
.47861 .08145 L
.47953 .08178 L
.4805 .08212 L
.48143 .08246 L
.48243 .08281 L
.48338 .08315 L
.4843 .08347 L
.48528 .08382 L
.48623 .08415 L
.48713 .08447 L
.4881 .08481 L
.48903 .08514 L
.49002 .08549 L
.49097 .08582 L
.49189 .08614 L
.49286 .08648 L
Mistroke
.4938 .08681 L
.4948 .08716 L
.49576 .08749 L
.49668 .08781 L
.49766 .08815 L
.49861 .08848 L
.49952 .0888 L
.50049 .08913 L
.50142 .08945 L
.50241 .0898 L
.50337 .09013 L
.50429 .09044 L
.50527 .09078 L
.50621 .0911 L
.50721 .09144 L
.50817 .09177 L
.5091 .09209 L
.51009 .09242 L
.51104 .09274 L
.51195 .09305 L
.51292 .09338 L
.51386 .0937 L
.51485 .09403 L
.51581 .09436 L
.51673 .09467 L
.51771 .095 L
.51866 .09531 L
.51957 .09562 L
.52053 .09594 L
.52147 .09625 L
.52245 .09658 L
.52341 .09689 L
.52433 .0972 L
.5253 .09752 L
.52624 .09783 L
.52724 .09816 L
.5282 .09847 L
.52913 .09877 L
.53011 .0991 L
.53106 .09941 L
.53197 .0997 L
.53294 .10002 L
.53387 .10032 L
.53487 .10064 L
.53582 .10095 L
.53674 .10125 L
.53772 .10156 L
.53867 .10186 L
.53957 .10215 L
.54054 .10246 L
Mistroke
.54147 .10276 L
.54245 .10307 L
.5434 .10337 L
.54432 .10366 L
.54529 .10397 L
.54623 .10426 L
.54723 .10457 L
.54819 .10487 L
.54911 .10516 L
.55009 .10546 L
.55104 .10576 L
.55195 .10604 L
.55292 .10634 L
.55385 .10662 L
.55484 .10693 L
.55579 .10722 L
.55671 .1075 L
.55769 .1078 L
.55863 .10808 L
.55963 .10838 L
.56059 .10867 L
.56152 .10895 L
.5625 .10925 L
.56345 .10953 L
.56437 .1098 L
.56534 .11009 L
.56627 .11036 L
.56727 .11066 L
.56822 .11094 L
.56915 .11121 L
.57013 .11149 L
.57107 .11177 L
.57198 .11203 L
.57294 .11231 L
.57387 .11257 L
.57486 .11286 L
.57582 .11313 L
.57673 .11339 L
.57771 .11366 L
.57865 .11393 L
.57964 .11421 L
.5806 .11447 L
.58153 .11473 L
.58251 .115 L
.58346 .11527 L
.58437 .11552 L
.58534 .11578 L
.58627 .11603 L
.58727 .1163 L
.58822 .11656 L
Mistroke
.58914 .11681 L
.59012 .11707 L
.59106 .11732 L
.59206 .11759 L
.59303 .11784 L
.59395 .11808 L
.59494 .11834 L
.59589 .11859 L
.5968 .11882 L
.59778 .11907 L
.59871 .11931 L
.59971 .11957 L
.60067 .11981 L
.60159 .12004 L
.60257 .12028 L
.60352 .12052 L
.60443 .12074 L
.60539 .12098 L
.60633 .12121 L
.60732 .12145 L
.60827 .12168 L
.60919 .1219 L
.61016 .12213 L
.6111 .12236 L
.6121 .12259 L
.61306 .12282 L
.61399 .12303 L
.61497 .12326 L
.61592 .12347 L
.61684 .12368 L
.61781 .1239 L
.61874 .12411 L
.61973 .12433 L
.62069 .12454 L
.62161 .12474 L
.62259 .12496 L
.62353 .12516 L
.62444 .12535 L
.62541 .12556 L
.62634 .12576 L
.62732 .12596 L
.62828 .12616 L
.62919 .12635 L
.63017 .12655 L
.6311 .12673 L
.6321 .12693 L
.63306 .12712 L
.63398 .12731 L
.63497 .1275 L
.63591 .12768 L
Mistroke
.63682 .12785 L
.63779 .12803 L
.63872 .12821 L
.63972 .12839 L
.64067 .12857 L
.64159 .12873 L
.64257 .12891 L
.64351 .12907 L
.64451 .12925 L
.64547 .12942 L
.6464 .12957 L
.64738 .12974 L
.64833 .1299 L
.64925 .13005 L
.65022 .13021 L
.65116 .13036 L
.65215 .13051 L
.65311 .13066 L
.65403 .13081 L
.65501 .13096 L
.65596 .1311 L
.65686 .13123 L
.65783 .13137 L
.65876 .1315 L
.65975 .13164 L
.6607 .13178 L
.66162 .1319 L
.6626 .13203 L
.66353 .13215 L
.66453 .13228 L
.66549 .13241 L
.66642 .13252 L
.6674 .13264 L
.66835 .13276 L
.66926 .13286 L
.67023 .13298 L
.67117 .13308 L
.67216 .13319 L
.67311 .13329 L
.67403 .13339 L
.67501 .13349 L
.67596 .13359 L
.67686 .13368 L
.67783 .13377 L
.67875 .13386 L
.67974 .13395 L
.68069 .13403 L
.68161 .13411 L
.68258 .13419 L
.68352 .13427 L
Mistroke
.68451 .13435 L
.68547 .13442 L
.6864 .13449 L
.68738 .13456 L
.68832 .13462 L
.68923 .13468 L
.6902 .13474 L
.69113 .1348 L
.69212 .13486 L
.69308 .13491 L
.694 .13496 L
.69497 .13501 L
.69591 .13505 L
.69691 .1351 L
.69788 .13514 L
.6988 .13518 L
.69927 .13519 L
.69979 .13521 L
.70074 .13525 L
.7012 .13526 L
.70171 .13528 L
.70218 .13529 L
.7027 .1353 L
.7032 .13532 L
.70366 .13533 L
.70411 .13534 L
.7046 .13535 L
.70507 .13536 L
.70557 .13537 L
.70605 .13538 L
.70629 .13539 L
.70656 .13539 L
.70703 .1354 L
.70729 .1354 L
.70753 .13541 L
.70776 .13541 L
.70799 .13541 L
.70825 .13542 L
.70849 .13542 L
.70872 .13542 L
.70896 .13542 L
.70919 .13543 L
.7094 .13543 L
.70952 .13543 L
.70964 .13543 L
.70986 .13543 L
.70999 .13543 L
.71012 .13543 L
.71024 .13544 L
.71036 .13544 L
Mistroke
.71048 .13544 L
.71059 .13544 L
.71071 .13544 L
.71084 .13544 L
.7109 .13544 L
.71097 .13544 L
.71104 .13544 L
.7111 .13544 L
.71116 .13544 L
.71123 .13544 L
.71134 .13544 L
.7114 .13544 L
.71147 .13544 L
.71153 .13544 L
.71159 .13544 L
.71164 .13544 L
.7117 .13544 L
.71175 .13544 L
.71181 .13544 L
.71187 .13544 L
.7119 .13544 L
.71194 .13544 L
.71196 .13544 L
.712 .13544 L
.71202 .13544 L
.71205 .13544 L
.71208 .13544 L
.71212 .13544 L
.71215 .13544 L
.71219 .13544 L
.71222 .13544 L
.71225 .13544 L
.71228 .13544 L
.7123 .13544 L
.71231 .13544 L
.71234 .13544 L
.71237 .13544 L
.7124 .13544 L
.71243 .13544 L
.71246 .13544 L
.71247 .13544 L
.71249 .13544 L
.71252 .13544 L
.71255 .13544 L
.71258 .13544 L
.7126 .13544 L
.71263 .13544 L
.71265 .13544 L
.71268 .13544 L
.71271 .13544 L
Mistroke
.71274 .13544 L
.71277 .13544 L
.7128 .13544 L
.71281 .13544 L
.71283 .13544 L
.71286 .13544 L
.71289 .13544 L
.71291 .13544 L
.71292 .13544 L
.71295 .13544 L
.71297 .13544 L
.71299 .13544 L
.713 .13544 L
.71302 .13544 L
.71305 .13544 L
.71308 .13544 L
.71311 .13544 L
.71314 .13544 L
.71317 .13544 L
.7132 .13544 L
.71323 .13544 L
.71326 .13544 L
.71329 .13544 L
.71333 .13544 L
.71339 .13544 L
.71342 .13544 L
.71345 .13544 L
.71348 .13544 L
.71352 .13544 L
.71358 .13544 L
.71363 .13544 L
.71369 .13544 L
.71376 .13544 L
.71381 .13544 L
.71387 .13544 L
.71393 .13544 L
.71399 .13544 L
.71409 .13544 L
.71415 .13544 L
.7142 .13544 L
.71432 .13544 L
.71438 .13544 L
.71444 .13544 L
.71455 .13544 L
.71466 .13544 L
.71478 .13544 L
.71489 .13544 L
.71502 .13544 L
.71515 .13543 L
.71527 .13543 L
Mistroke
.71538 .13543 L
.7155 .13543 L
.71562 .13543 L
.71585 .13543 L
.71606 .13543 L
.71631 .13542 L
.71653 .13542 L
.71679 .13542 L
.71704 .13542 L
.71727 .13541 L
.71752 .13541 L
.71773 .13541 L
.71796 .1354 L
.71843 .1354 L
.7187 .13539 L
.71894 .13539 L
.71939 .13538 L
.71965 .13537 L
.71989 .13537 L
.72034 .13536 L
.72084 .13535 L
.7213 .13534 L
.7218 .13533 L
.72228 .13531 L
.72279 .1353 L
.72371 .13527 L
.72418 .13526 L
.72468 .13524 L
.72516 .13522 L
.72568 .13521 L
.72664 .13517 L
.72762 .13513 L
.72857 .13509 L
.72948 .13505 L
.73045 .135 L
.73138 .13495 L
.73237 .1349 L
.73333 .13485 L
.73424 .13479 L
.73522 .13473 L
.73616 .13467 L
.73716 .13461 L
.73813 .13454 L
.73905 .13448 L
.74004 .1344 L
.74099 .13433 L
.7419 .13426 L
.74288 .13418 L
.74381 .1341 L
.74481 .13401 L
Mistroke
.74577 .13393 L
.74669 .13384 L
.74767 .13375 L
.74861 .13366 L
.74952 .13357 L
.75049 .13347 L
.75142 .13338 L
.75241 .13327 L
.75336 .13317 L
.75428 .13306 L
.75525 .13295 L
.75619 .13285 L
.75719 .13273 L
.75815 .13261 L
.75908 .1325 L
.76006 .13237 L
.76101 .13225 L
.76192 .13213 L
.76289 .13201 L
.76383 .13188 L
.76482 .13174 L
.76578 .13161 L
.7667 .13148 L
.76767 .13134 L
.76862 .1312 L
.76952 .13107 L
.77049 .13093 L
.77142 .13078 L
.7724 .13063 L
.77336 .13048 L
.77427 .13034 L
.77524 .13018 L
.77618 .13003 L
.77718 .12986 L
.77814 .1297 L
.77906 .12955 L
.78004 .12938 L
.78099 .12922 L
.7819 .12906 L
.78287 .12888 L
.7838 .12872 L
.78479 .12854 L
.78574 .12836 L
.78666 .12819 L
.78764 .12801 L
.78858 .12783 L
.78958 .12764 L
.79054 .12746 L
.79147 .12728 L
.79245 .12708 L
Mistroke
.7934 .12689 L
.79431 .12671 L
.79529 .12651 L
.79622 .12632 L
.79722 .12612 L
.79817 .12592 L
.79909 .12573 L
.80007 .12552 L
.80102 .12532 L
.80193 .12513 L
.80289 .12492 L
.80382 .12472 L
.80481 .1245 L
.80576 .12429 L
.80668 .12408 L
.80765 .12386 L
.80859 .12365 L
.80959 .12343 L
.81055 .12321 L
.81148 .12299 L
.81246 .12276 L
.81341 .12254 L
.81432 .12233 L
.81529 .1221 L
.81622 .12187 L
.81721 .12164 L
.81817 .12141 L
.81909 .12118 L
.82006 .12094 L
.82101 .12071 L
.82201 .12046 L
.82297 .12022 L
.8239 .11999 L
.82489 .11974 L
.82584 .1195 L
.82675 .11927 L
.82772 .11902 L
.82866 .11878 L
.82965 .11852 L
.83061 .11827 L
.83154 .11803 L
.83252 .11778 L
.83346 .11753 L
.83437 .11729 L
.83534 .11703 L
.83627 .11678 L
.83726 .11651 L
.83821 .11626 L
.83913 .11601 L
.84011 .11574 L
Mistroke
.84105 .11548 L
.84204 .11521 L
.84301 .11494 L
.84393 .11469 L
.84492 .11441 L
.84587 .11415 L
.84678 .11389 L
.84775 .11362 L
.84868 .11335 L
.84968 .11307 L
.85063 .1128 L
.85155 .11254 L
.85253 .11226 L
.85348 .11198 L
.85438 .11172 L
.85535 .11144 L
.85628 .11117 L
.85727 .11088 L
.85822 .1106 L
.85913 .11033 L
.86011 .11005 L
.86104 .10977 L
.86204 .10947 L
.863 .10918 L
.86392 .10891 L
.86491 .10861 L
.86585 .10833 L
.86676 .10805 L
.86773 .10776 L
.86866 .10748 L
.86966 .10717 L
.87061 .10688 L
.87153 .1066 L
.87251 .1063 L
.87345 .10601 L
.87445 .1057 L
.87541 .1054 L
.87634 .10511 L
.87732 .10481 L
.87827 .10451 L
.87919 .10422 L
.88016 .10392 L
.88109 .10362 L
.88209 .10331 L
.88305 .10301 L
.88397 .10271 L
.88495 .1024 L
.88589 .1021 L
.8868 .10181 L
.88777 .1015 L
Mistroke
.8887 .1012 L
.88969 .10088 L
.89064 .10057 L
.89156 .10028 L
.89253 .09996 L
.89347 .09966 L
.89447 .09933 L
.89543 .09902 L
.89636 .09872 L
.89734 .09839 L
.89829 .09808 L
.8992 .09778 L
.90017 .09746 L
.9011 .09715 L
.90209 .09683 L
.90305 .09651 L
.90397 .0962 L
.90495 .09588 L
.90589 .09556 L
.9068 .09526 L
.90776 .09494 L
.90869 .09463 L
.90968 .09429 L
.91063 .09397 L
.91154 .09366 L
.91252 .09334 L
.91345 .09302 L
.91445 .09268 L
.91541 .09236 L
.91633 .09204 L
.91731 .09171 L
.91826 .09138 L
.91917 .09107 L
.92014 .09074 L
.92107 .09042 L
.92206 .09008 L
.92301 .08975 L
.92393 .08944 L
.92491 .0891 L
.92585 .08877 L
.92685 .08843 L
.92781 .0881 L
.92873 .08777 L
.92972 .08743 L
.93067 .0871 L
.93158 .08678 L
.93255 .08644 L
.93349 .08612 L
.93448 .08577 L
.93544 .08543 L
Mistroke
.93636 .08511 L
.93734 .08476 L
.93828 .08443 L
.93919 .08411 L
.94016 .08377 L
.94108 .08344 L
.94207 .08309 L
.94303 .08276 L
.94394 .08243 L
.94492 .08208 L
.94585 .08175 L
.94685 .0814 L
.94781 .08105 L
.94874 .08072 L
.94972 .08037 L
.95067 .08003 L
.95158 .07971 L
.95255 .07936 L
.95348 .07902 L
.95447 .07867 L
.95543 .07832 L
.95634 .07799 L
.95732 .07764 L
.95826 .0773 L
.95926 .07694 L
.96023 .07659 L
.96116 .07625 L
.96214 .0759 L
.96309 .07555 L
.96401 .07522 L
.96498 .07486 L
.96591 .07452 L
.96691 .07416 L
.96787 .07381 L
.96879 .07347 L
.96977 .07312 L
.97072 .07277 L
.97162 .07244 L
.97259 .07208 L
.97352 .07174 L
.97451 .07138 L
.97547 .07103 L
.97619 .07076 L
Mfstroke
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{614, 245.563},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009V0000mB000`400?l00000o`00003oo`3ooooo
0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0oooo=P3oool00`000000oooo0?ooo`0/0?ooo`<0
00003@3oool300000>l0oooo003o0?ooocH0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0>d0oooo003o0?ooocH0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0>d0oooo003o0?ooobL0oooo1@00000:
0?ooo`040000003oool00000000000@0oooo0`0000040?ooo`<000000`3oool00`000000oooo0?oo
o`0200000080oooo00@000000?ooo`3oool0oooo0`0000030?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0>d0oooo003o0?ooobP0oooo00<000000?ooo`3o
ool02`3oool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000003
0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3]0?ooo`00o`3ooolX0?ooo`030000003oool0oooo00/0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo0?oo
o`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0k@3o
ool00?l0oooo:@3oool010000000oooo0?ooo`3oool700000080oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool3000000<0oooo00@000000?ooo`3o
ool000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0>d0oooo003o0?ooobX0oooo00<0
00000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0>d0oooo003o0?ooobX0oooo00<000000?ooo`3oool02@3o
ool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3]0?ooo`00o`3ooolW0?ooo`D000002P3oool010000000oooo0000000000040?ooo`<00000103o
ool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`040000003oool0oooo0?ooo`<00000
0`3oool010000000oooo0000000000050?ooo`030000003oool0oooo0080oooo00@000000?ooo`00
000000000P3oool2000000D0oooo00<000000?ooo`3oool0k@3oool00?l0ooooCP3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0k@3oool00?l0oooo
CP3oool00`000000oooo0?ooo`0D0?ooo`<000003@3oool300000>l0oooo003o0?oood/0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooa<0oooo003o0?ooool0ooooJ03oool0
0?l0ooooo`3ooomX0?ooo`00o`3ooooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3o
oomX0?ooo`00o`3ooooo0?ooofP0oooo002C0?ooo`030000003oool0oooo04T0oooo1000001@0?oo
o`030000003oool0oooo04`0oooo1P00001<0?ooo`@00000D@3oool00`000000oooo0?ooo`0j0?oo
o`00T`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo03X0oooo002C0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo04h0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1:0?ooo`H00000
>`3oool008P0oooo1`0000040?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`1;0?ooo`040000003oool0oooo000003`0oooo002C0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo0500oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1;0?ooo`040000003o
ool0oooo000003`0oooo002C0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0B`3o
ool3000004l0oooo00<000000?ooo`000000?03oool009<0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`000000?03oool0
0940oooo00<000000?ooo`000000BP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`000000D`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
04d0oooo0P00000l0?ooo`00TP3oool2000004X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1<0?ooo`800000CP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`800000?03oool009<0oooo
00<000000?ooo`3oool0B@3oool400000500oooo00<000000?ooo`3oool0C@3oool4000004d0oooo
1000001A0?ooo`030000003oool0oooo03X0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX
0?ooo`00o`3ooooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00o`3o
oooo0?ooofP0oooo003o0?ooool0ooooJ03oool006P0ooooo`00003>00000340oooo001X0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0_0?ooo`00
J03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
;`3oool006P0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0_0?ooo`00J03oool3
000002D0oooo00<0001o0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool0
0`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0F03oool3
00000340oooo001X0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0CP3oool00`00
07l0oooo0?ooo`080?ooo`@00000@`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo
04l0oooo00<0001o0?ooo`3oool0FP3oool00`000000oooo0?ooo`0_0?ooo`00D@3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`@000002P3oool00`000000oooo0?ooo`0U0?oo
o`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool01P3oool300000080nQh5100000100?oo
o`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1J0?oo
o`030000003oool0oooo02l0oooo001A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3o
ool0CP3oool00`0007l0oooo0?ooo`030?ooo`<000000`3oool30?XN1@80oooo0`00000n0?ooo`03
0000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1J0?ooo`03
0000003oool0oooo02l0oooo001A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo04h0oooo00@0001o0?ooo`3oool0
oooo0`0000050?ooo`<0nQh51@3oool3000003/0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0
oooo0?ooo`1?0?ooo`030000O`3oool0oooo05X0oooo00<000000?ooo`3oool0;`3oool004H0oooo
1`0000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0U0?ooo`030000O`3oool0oooo04h0oooo00@0001o0000000000000000203oool30?XN1@L0
oooo0`00000i0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0
oooo0?ooo`1J0?ooo`030000003oool0oooo02l0oooo001A0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`@00000M00007l3000000X0001o
0`3j7PD:0000O`<00000o`0007le0000O`@00000<@3oool00540oooo00<000000?ooo`3oool01@3o
ool5000000X0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`1:0?ooo`<0000000<0
oooo0000O`3oool02P3oool30?XN1@`0oooo0`00000d0?ooo`030000O`3oool0oooo04l0oooo00<0
001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1J0?ooo`030000003oool0oooo02l0oooo001A
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0U
0?ooo`030000O`3oool0oooo04L0oooo100000030?ooo`030000O`3oool0oooo00T0oooo0`3j7PD?
0?ooo`<00000<@3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o
0?ooo`3oool0FP3oool00`000000oooo0?ooo`0_0?ooo`00C`3oool00`000000oooo000000080?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`150?oo
o`<000001P3oool00`0007l0oooo0?ooo`090?ooo`<0nQh54@3oool3000002l0oooo00<0001o0?oo
o`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo05X0oooo00<000000?oo
o`3oool0;`3oool00500oooo0P0000080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool09@3oool00`0007l0oooo0?ooo`0o0?ooo`<0nQh500@0oooo0000000000000000203oool00`00
07l0oooo0?ooo`090?ooo`<0nQh5503oool3000002`0oooo00<0001o0?ooo`3oool0C`3oool00`00
07l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo05X0oooo00<000000?ooo`3oool0;`3oool00540
oooo00<000000?ooo`3oool01P3oool5000000T0oooo0`00000U0?ooo`030000O`3oool0oooo03l0
oooo00@0nQh500000000000000002`3oool00`0007l0oooo0?ooo`090?ooo`<0nQh55P3oool30000
02X0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo
05P0oooo0`00000a0?ooo`00J03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo03l0
oooo00<0nQh50000003j7PD0303oool00`0007l0oooo0?ooo`090?ooo`<0nQh56@3oool3000002L0
oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo05X0
oooo00<000000?ooo`3oool0;`3oool006P0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo
0?ooo`0o0?ooo`030000003j7PD0nQh500`0oooo00<0001o0?ooo`3oool02@3oool30?XN1A`0oooo
0`00000T0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo
0?ooo`1J0?ooo`030000003oool0oooo02l0oooo001X0?ooo`030000003oool0oooo02D0oooo00<0
001o0?ooo`3oool0?`3oool00`000000nQh50?XN1@0<0?ooo`030000O`3oool0oooo00T0oooo0`3j
7PDN0?ooo`<000008P3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0
001o0?ooo`3oool0FP3oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`0U
0?ooo`030000O`3oool0oooo03h0oooo00@000000?XN1@3j7PD0nQh5303oool00`0007l0oooo0?oo
o`090?ooo`<0nQh58@3oool3000001l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?oo
o`1?0?ooo`030000O`3oool0oooo05X0oooo00<000000?ooo`3oool0;`3oool006P0oooo00<00000
0?ooo`3oool09@3oool00`0007l0oooo0?ooo`0m0?ooo`030000003oool0nQh50080nQh5303oool0
0`0007l0oooo0?ooo`090?ooo`<0nQh58`3oool3000001d0oooo00<0001o0?ooo`3oool0C`3oool0
0`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo05X0oooo00<000000?ooo`3oool0;`3oool0
06P0oooo0`00000U0?ooo`030000O`3oool0oooo03d0oooo00<000000?ooo`3j7PD00P3j7PD<0?oo
o`030000O`3oool0oooo00T0oooo0`3j7PDV0?ooo`<000006P3oool00`0007l0oooo0?ooo`1?0?oo
o`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0F03oool300000340oooo001X0?ooo`03
0000003oool0oooo02D0oooo00<0001o0?ooo`3oool0?03oool00`000000oooo0?ooo`030?XN1@`0
oooo00<0001o0?ooo`3oool02@3oool30?XN1BP0oooo0`00000H0?ooo`030000O`3oool0oooo04l0
oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1J0?ooo`030000003oool0oooo02l0
oooo001X0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0?03oool00`000000oooo
0?ooo`030?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1B/0oooo0`00000E0?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1J0?ooo`030000
003oool0oooo02l0oooo001X0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0>`3o
ool010000000oooo0?ooo`3oool30?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1Bd0oooo
1000000B0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo
0?ooo`1J0?ooo`030000003oool0oooo02l0oooo001X0?ooo`030000003oool0oooo02D0oooo00<0
001o0?ooo`3oool0>`3oool010000000oooo0?ooo`3oool30?XN1@`0oooo00<0001o0?ooo`3oool0
2@3oool30?XN1C00oooo0`00000@0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0
C`3oool00`0007l0oooo0?ooo`1J0?ooo`030000003oool0oooo02l0oooo001X0?ooo`<000009@3o
ool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo0`3j7PD<0?ooo`030000O`3o
ool0oooo00T0oooo0`3j7PDc0?ooo`<000003@3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3o
ool0oooo04l0oooo00<0001o0?ooo`3oool0F03oool300000340oooo001X0?ooo`030000003oool0
oooo02D0oooo00<0001o0?ooo`3oool0>@3oool00`000000oooo0?ooo`030?ooo`<0nQh5303oool0
0`0007l0oooo0?ooo`090?ooo`<0nQh5=@3oool4000000X0oooo00<0001o0?ooo`3oool0C`3oool0
0`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo05X0oooo00<000000?ooo`3oool0;`3oool0
06P0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0i0?ooo`030000003oool0oooo
00<0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PDh0?ooo`<00000203oool00`00
07l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0FP3oool00`00
0000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo03T0
oooo00<000000?ooo`3oool00`3oool30?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1C/0
oooo0`0000050?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0
oooo0?ooo`1J0?ooo`030000003oool0oooo02l0oooo001X0?ooo`030000003oool0oooo02D0oooo
00<0001o0?ooo`3oool0>03oool00`000000oooo0?ooo`040?ooo`<0nQh5303oool00`0007l0oooo
0?ooo`090?ooo`<0nQh5?@3oool3000000<0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo
0?ooo`1?0?ooo`030000O`3oool0oooo05X0oooo00<000000?ooo`3oool0;`3oool006P0oooo00<0
00000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0g0?ooo`030000003oool0oooo00D0oooo0`3j
7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE00?ooo`<0000000<0001o0?ooo`3oool0C`3o
ool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo05X0oooo00<000000?ooo`3oool0;`3o
ool006P0oooo0`00000U0?ooo`030000O`3oool0oooo03L0oooo00<000000?ooo`3oool01@3oool3
0?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo0`00001?0?ooo`030000O`3oool0
oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`L0oooo0`00000a0?ooo`00J03oool00`00
0000oooo0?ooo`0U0?ooo`030000O`3oool0oooo03H0oooo00<000000?ooo`3oool01P3oool30?XN
1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool00`00001<0?oo
o`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool200000003000Rf`3oool0oooo
00L0oooo00<000000?ooo`3oool0;`3oool005`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0U0?ooo`030000O`3oool0oooo03D0oooo00<000000?ooo`3oool01`3oool30?XN1@`0
oooo00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool00P3oool3000004X0
oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1;0?ooo`<000000`008]/90?ooo`03
0000003oool0oooo02l0oooo001L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
9@3oool00`0007l0oooo0?ooo`0e0?ooo`030000003oool0oooo00L0oooo0`3j7PD<0?ooo`030000
O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo00D0oooo0`0000170?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0B03oool400000080oooo0`008]/90?ooo`030000
003oool0oooo02l0oooo001L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09@3o
ool00`0007l0oooo0?ooo`0e0?ooo`030000003oool0oooo00L0oooo0`3j7PD<0?ooo`030000O`3o
ool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo00L0oooo100000140?ooo`030000O`3o
ool0oooo04l0oooo00<0001o0?ooo`3oool0A@3oool4000000D0oooo0`008]/90?ooo`030000003o
ool0oooo02l0oooo001A0?ooo`L00000103oool00`000000oooo0?ooo`090?ooo`@00000F`0007l0
0`000000001o0000O`080000O`<0nQh5600007l30?XN1E40001o0`00003I0000O`<00000200007l3
000Rf`H0001o1000000a0?ooo`00G03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
02D0oooo00<0001o0?ooo`3oool0<`3oool00`000000oooo0?ooo`090?ooo`<0nQh5303oool00`00
07l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`0=0?ooo`<00000?`3oool00`00
07l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo0400oooo0`00000;0?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0_0?ooo`00G03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02D0
oooo00<0001o0?ooo`3oool0<`3oool00`000000oooo0?ooo`090?ooo`<0nQh5303oool00`0007l0
oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`0@0?ooo`<00000?03oool00`0007l0
oooo0?ooo`1?0?ooo`030000O`3oool0oooo03d0oooo0`00000>0?ooo`<002;K2@3oool00`000000
oooo0?ooo`0_0?ooo`00G03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo
0`008]/K0?ooo`030000O`3oool0oooo0340oooo00<0nQh50000003j7PD02`3oool30?XN1@`0oooo
00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool04`3oool3000003T0oooo
00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0j0?ooo`@00000403oool3000Rf`T0oooo
00<000000?ooo`3oool0;`3oool005X0oooo00<000000?ooo`0000002`3oool00`000000oooo0?oo
o`070?ooo`03000Rf`00000002;K01/0oooo00<0001o0?ooo`3oool0<@3oool2000000030?XN1@3o
ool0oooo00T0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3o
ool0oooo01H0oooo0`00000f0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0=`3o
ool4000001<0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo001K0?ooo`8000002`3oool0
0`000000oooo0?ooo`070?ooo`8002;K00<000000?ooo`3oool06@3oool00`0007l0oooo0?ooo`0a
0?ooo`030000003j7PD0nQh500/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE3
0?ooo`030000O`3oool0oooo01T0oooo0`00000c0?ooo`030000O`3oool0oooo04l0oooo00<0001o
0?ooo`3oool0=03oool4000001H0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo001L0?oo
o`030000003oool0oooo00T0oooo0`0000070?ooo`<002;K00<000000?ooo`3oool0603oool00`00
07l0oooo0?ooo`0`0?ooo`040000003j7PD0nQh50?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0
oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo01`0oooo0`00000`0?ooo`030000O`3oool0
oooo04l0oooo00<0001o0?ooo`3oool0<P3oool3000001T0oooo0`008]/70?ooo`<00000<@3oool0
06P0oooo00<000000?ooo`3oool01`3oool3000Rf`030?ooo`000000oooo01P0oooo00<0001o0?oo
o`3oool0;`3oool00`000000oooo0?XN1@020?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo
00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo01h0oooo1000000]0?ooo`030000O`3oool0oooo
04l0oooo00<0001o0?ooo`3oool0;`3oool3000001`0oooo0`008]/90?ooo`030000003oool0oooo
02l0oooo001X0?ooo`030000003oool0oooo00L0oooo0`008]/00`3oool000000000000H0?ooo`03
0000O`3oool0oooo02h0oooo00<000000?ooo`3oool00`3j7PD;0?ooo`<0nQh5303oool00`0007l0
oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`0Q0?ooo`@00000:P3oool00`0007l0
oooo0?ooo`1?0?ooo`030000O`3oool0oooo02/0oooo1000000O0?ooo`<002;K2@3oool00`000000
oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<002;K0P3oool2000001L0oooo
00<0001o0?ooo`3oool0;@3oool200000080oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo
0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`0T0?ooo`@000009`3oool00`0007l0oooo
0?ooo`1?0?ooo`030000O`3oool0oooo02P0oooo1000000R0?ooo`<002;K2@3oool00`000000oooo
0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<002;K0`3oool00`000000oooo0?oo
o`0E0?ooo`030000O`3oool0oooo02`0oooo0P0000030?ooo`<0nQh52`3oool30?XN1@`0oooo00<0
001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool09`3oool4000002@0oooo00<0
001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0U0?ooo`@000009@3oool3000Rf`T0oooo00<0
00000?ooo`3oool0;`3oool006P0oooo0`0000070?ooo`<002;K103oool00`000000oooo0?ooo`0D
0?ooo`030000O`3oool0oooo02/0oooo0P0000040?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o
0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool0:`3oool300000240oooo00<0001o
0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0R0?ooo`@00000:03oool3000Rf`L0oooo0`00000a
0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<002;K1@3oool00`000000oooo0?ooo`0C0?oo
o`030000O`3oool0oooo02X0oooo0P0000050?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?oo
o`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool0;P3oool4000001d0oooo00<0001o0?oo
o`3oool0C`3oool00`0007l0oooo0?ooo`0O0?ooo`<00000;03oool3000Rf`T0oooo00<000000?oo
o`3oool0;`3oool006P0oooo00<000000?ooo`3oool01`3oool3000Rf`D0oooo0P00000D0?ooo`03
0000O`3oool0oooo02X0oooo00<000000?ooo`3oool0103oool30?XN1@/0oooo0`3j7PD<0?ooo`03
0000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo0340oooo1000000J0?ooo`03
0000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0703oool3000002l0oooo0`008]/90?ooo`03
0000003oool0oooo02l0oooo001X0?ooo`030000003oool0oooo00L0oooo0`008]/60?ooo`800000
4`3oool00`0007l0oooo0?ooo`0Y0?ooo`8000001P3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000
O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo03@0oooo1000000G0?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0603oool400000380oooo0`008]/90?ooo`030000
003oool0oooo02l0oooo000g0?ooo`8000000P3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00L0oooo0`008]/70?ooo`8000004P3oool00`0007l0oooo0?ooo`0X0?ooo`8000001`3o
ool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3o
ool0oooo03P0oooo1000000C0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool05@3o
ool4000003D0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo000f0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`070?ooo`<002;K203o
ool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo02L0oooo0P0000080?ooo`<0nQh52`3o
ool30?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool0>`3o
ool400000100oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0A0?ooo`@00000>@3o
ool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool003H0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0Y0?ooo`<000001`3oool3000Rf`T0oooo00<000000?ooo`3oool03`3o
ool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00L0oooo0`3j7PD;0?ooo`<0nQh5303o
ool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`0o0?ooo`@00000303o
ool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo00d0oooo1@00000l0?ooo`<002;K1`3o
ool300000340oooo000f0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`070?ooo`<002;K2P3oool00`000000oooo0?ooo`0>0?ooo`030000O`3o
ool0oooo02H0oooo00<000000?ooo`3oool0203oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3o
ool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo0480oooo1@0000080?ooo`030000O`3o
ool0oooo04l0oooo00<0001o0?ooo`3oool02@3oool500000400oooo0`008]/90?ooo`030000003o
ool0oooo02l0oooo000g0?ooo`030000003oool0oooo00800000;03oool00`000000oooo0?ooo`07
0?ooo`<002;K2`3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo02D0oooo00<00000
0?ooo`3oool02@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE3
0?ooo`030000O`3oool0oooo04H0oooo1@0000040?ooo`030000O`3oool0oooo04l0oooo00<0001o
0?ooo`3oool01@3oool5000004@0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo001X0?oo
o`030000003oool0oooo00L0oooo0`008]/<0?ooo`030000003oool0oooo00`0oooo00<0001o0?oo
o`3oool0903oool00`000000oooo0?ooo`0:0?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?oo
o`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool0B`3oool4000000030000O`3oool0oooo
04l0oooo00@0001o0?ooo`3oool0oooo1@0000180?ooo`<002;K2@3oool00`000000oooo0?ooo`0_
0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<002;K303oool00`000000oooo0?ooo`0<0?oo
o`030000O`3oool0oooo02<0oooo00<000000?ooo`3oool02`3oool30?XN1@/0oooo0`3j7PD<0?oo
o`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo1@00001=0?oo
o`D00000C03oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool003H0oooo2P00000X0?ooo`<0
00001`3oool3000Rf`d0oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0R0?ooo`80
00003@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`03
0000O`3oool0oooo04l0oooo00@0001o0?ooo`3oool0oooo1P0000120?ooo`H0000000<0001o0?oo
o`3oool0CP3oool3000Rf`L0oooo0`00000a0?ooo`00=`3oool01@000000oooo0?ooo`3oool00000
02`0oooo00<000000?ooo`3oool01`3oool3000Rf`h0oooo00<000000?ooo`3oool02P3oool00`00
07l0oooo0?ooo`0Q0?ooo`8000003P3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo
00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool01`3oool60000
03L0oooo1P0000050?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0oooo
02l0oooo000f0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool4000000<0
oooo00@000000?ooo`3oool0oooo1000000:0?ooo`030000003oool0oooo00L0oooo0`008]/?0?oo
o`030000003oool0oooo00T0oooo00<0001o0?ooo`3oool08@3oool00`000000oooo0?ooo`0=0?oo
o`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?oo
o`3oool0C`3oool00`0007l0oooo0?ooo`0<0?ooo`P00000:03oool8000000/0oooo00<0001o0?oo
o`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool003H0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool3000Rf`l0oooo0P00000:0?ooo`030000O`3oool0oooo0200oooo00<000000?ooo`3o
ool03P3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`03
0000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0503oool<000000L0oooo0`0000060?ooo`d0
00004P3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00
=`3oool500000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool3000Rfa00oooo0P0000090?ooo`030000
O`3oool0oooo01l0oooo00<000000?ooo`3oool03`3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000
O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0
803ooolA000001h0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0
;`3oool004H0oooo1`0000000`3oool000000?ooo`030?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`<002;K4@3oool2000000P0oooo00<0
001o0?ooo`3oool07P3oool200000140oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?oo
o`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0
001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool004h0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`3oool4000000H0001o0`008]/B0000O`8000009`0007l200000180001o0`3j7PD;
0000O`<0nQh5600007l30?XN1Ol0001o>@0007l3000Rf`H0001o1000000a0?ooo`00=`3oool50000
0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`D000002P3oool00`00
0000oooo0?ooo`070?ooo`<002;K4`3oool00`000000oooo0?ooo`050?ooo`030000O`3oool0oooo
01`0oooo0P00000C0?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN
1D<0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo
04h0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo000f0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`<002;K503oool00`000000
oooo0?ooo`040?ooo`030000O`3oool0oooo01`0oooo00<000000?ooo`3oool04P3oool30?XN1@/0
oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0
oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000
oooo0?ooo`0_0?ooo`00=P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01`3oool3000RfaD0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo
0?ooo`0K0?ooo`030000003oool0oooo01<0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo
0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo
00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool003H0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo0`00
8]/F0?ooo`030000003oool0oooo0080oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?oo
o`0D0?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0
001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`00
8]/90?ooo`030000003oool0oooo02l0oooo000g0?ooo`D000004`3oool4000000L0oooo1@000009
0?ooo`<000001`3oool3000RfaH0oooo0P0000030?ooo`030000O`3oool0oooo01T0oooo00<00000
0?ooo`3oool05@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE3
0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>
0?ooo`<002;K1`3oool300000340oooo001X0?ooo`030000003oool0oooo00L0oooo0`008]/G0?oo
o`8000000P3oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0oooo01H0oooo0`3j7PD;0?oo
o`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`1?0?oo
o`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?oo
o`3oool0;`3oool003H0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`070?ooo`<0
02;K603oool2000000030?ooo`0007l0oooo01P0oooo00<000000?ooo`3oool05`3oool30?XN1@/0
oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0
oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool9000002/0oooo00<000000?ooo`3oool01`3oool3000RfaT0oooo
0P0000000`0007l0oooo0?ooo`0F0?ooo`030000003oool0oooo01P0oooo0`3j7PD;0?ooo`<0nQh5
303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`1?0?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0
;`3oool003H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00L0oooo0`008]/J0?ooo`8000005`3oool00`000000oooo0?ooo`0I0?ooo`<0nQh52`3o
ool30?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool0C`3o
ool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003o
ool0oooo02l0oooo001X0?ooo`030000003oool0oooo00L0oooo0`008]/K0?ooo`8000005@3oool2
000001/0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool0
0`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3
000Rf`T0oooo00<000000?ooo`3oool0;`3oool006P0oooo0`0000070?ooo`<002;K6`3oool00`00
07l000000000000C0?ooo`800000703oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo
00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`00
07l0oooo0?ooo`1>0?ooo`<002;K1`3oool300000340oooo001X0?ooo`030000003oool0oooo00L0
oooo0`008]/K0?ooo`040000O`3oool0000000000140oooo00<000000?ooo`3oool0703oool30?XN
1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo
04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`00
0000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<002;K6`3oool00`0007l0
oooo0?ooo`02000000l0oooo00<000000?ooo`3oool07@3oool30?XN1@/0oooo0`3j7PD<0?ooo`03
0000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3o
ool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00
J03oool00`000000oooo0?ooo`070?ooo`<002;K6`3oool0100007l0oooo0?ooo`3oool2000000d0
oooo00<000000?ooo`3oool07P3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0
oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0
oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00=`3oool200000080oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`070?ooo`<002;K6`3oool00`0007l0oooo
0?ooo`030?ooo`030000003oool0oooo00P0oooo0P00000Q0?ooo`<0nQh52`3oool30?XN1@`0oooo
00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo
0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo
000f0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0:@3oool3000000L0oooo
0`008]/K0?ooo`030000O`3oool0oooo00@0oooo0`0000050?ooo`<000008P3oool30?XN1@/0oooo
0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo
00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K1`3oool300000340oooo
000f0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`070?ooo`<002;K6`3oool00`0007l0oooo0?ooo`060?ooo`L00000903oool30?XN1@/0oooo
0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo
00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo
0?ooo`0_0?ooo`00=P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool01`3oool3000Rfa/0oooo00<0001o0?ooo`3oool0<@3oool30?XN1@/0oooo
0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo
00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo
0?ooo`0_0?ooo`00=`3oool00`000000oooo0?ooo`02000002`0oooo00<000000?ooo`3oool01`3o
ool3000Rfa/0oooo00<0001o0?ooo`3oool0<@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3o
ool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3o
ool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00J03oool0
0`000000oooo0?ooo`070?ooo`<002;K6`3oool00`0007l0oooo0?ooo`0a0?ooo`<0nQh52`3oool3
0?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool0C`3oool0
0`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0
oooo02l0oooo001X0?ooo`030000003oool0oooo00L0oooo0`008]/K0?ooo`030000O`3oool0oooo
0340oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`00
07l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000R
f`T0oooo00<000000?ooo`3oool0;`3oool003<0oooo00<000000?ooo`3oool01`00000[0?ooo`<0
00001`3oool3000Rfa/0oooo00<0001o0?ooo`3oool0<@3oool30?XN1@/0oooo0`3j7PD<0?ooo`03
0000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3o
ool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K1`3oool300000340oooo001X0?ooo`030000
003oool0oooo00L0oooo0`008]/K0?ooo`030000O`3oool0oooo0340oooo0`3j7PD;0?ooo`<0nQh5
303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`1?0?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0
;`3oool005X0oooo1000000:0?ooo`030000003oool0oooo00L0oooo0`008]/K0?ooo`030000O`3o
ool0oooo0340oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3o
ool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3o
ool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool003H0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`<002;K6`3oool00`0007l0oooo0?ooo`0a0?ooo`<0nQh52`3oool3
0?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool0C`3oool0
0`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0
oooo02l0oooo000f0?ooo`040000003oool0oooo0?ooo`<00000703oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool3000Rfa/0oooo00<0001o
0?ooo`3oool0<@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE3
0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00=P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`07
0?ooo`@000001P0007l3000Rfdl0001o0`3j7PD;0000O`<0nQh5600007l30?XN1Ol0001o>@0007l3
000Rf`H0001o1000000a0?ooo`00=P3oool3000000<0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool3000R
fa/0oooo00<0001o0?ooo`3oool0<@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo
00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`00
07l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00=P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0`008]/K0?ooo`030000O`3oool0oooo0340
oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0
oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0
oooo00<000000?ooo`3oool0;`3oool005T0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo0`008]/K0?ooo`030000O`3oool0oooo0340oooo
0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo
0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo
00<000000?ooo`3oool0;`3oool005T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo0`008]/K0?ooo`030000O`3oool0oooo0340oooo0`3j
7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?oo
o`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<0
00000?ooo`3oool0;`3oool003L0oooo1@00000M0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`<002;K6`3oool00`0007l0oooo0?ooo`0a
0?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o
0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/9
0?ooo`030000003oool0oooo02l0oooo000f0?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool06`3oool4000000X0oooo0`0000070?ooo`<002;K6`3oool00`0007l0oooo0?ooo`0a
0?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o
0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/7
0?ooo`<00000<@3oool003H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00L0oooo0`008]/K0?ooo`030000O`3oool0oooo0340oooo0`3j7PD;
0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`1?
0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<00000
0?ooo`3oool0;`3oool003H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00L0oooo0`008]/K0?ooo`030000O`3oool0oooo0340oooo0`3j7PD;
0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`1?
0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<00000
0?ooo`3oool0;`3oool003L0oooo0`0000000`3oool000000?ooo`0[0?ooo`030000003oool0oooo
00L0oooo0`008]/K0?ooo`030000O`3oool0oooo0340oooo0`3j7PD;0?ooo`<0nQh5303oool00`00
07l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo
04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool006P0
oooo00<000000?ooo`3oool01`3oool3000Rfa/0oooo00<0001o0?ooo`3oool0203oool3000002H0
oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0
oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0
oooo00<000000?ooo`3oool0;`3oool006P0oooo0`0000070?ooo`<002;K6`3oool00`0007l0oooo
0?ooo`050?ooo`P00000903oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo
0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo
0?ooo`1>0?ooo`<002;K1`3oool300000340oooo001X0?ooo`030000003oool0oooo00L0oooo0`00
8]/K0?ooo`030000O`3oool0oooo00@0oooo0P0000060?ooo`<000008P3oool30?XN1@/0oooo0`3j
7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo00<0
001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?oo
o`0_0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<002;K6`3oool00`0007l0oooo0?ooo`03
0?ooo`030000003oool0oooo00P0oooo0P00000Q0?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o
0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?
0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo000d0?oo
o``00000:03oool00`000000oooo0?ooo`070?ooo`<002;K6`3oool0100007l0oooo0?ooo`3oool2
000000d0oooo0P00000O0?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool02@3oool3
0?XN1D<0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0
oooo04h0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo000d0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`070?ooo`<002;K6`3oool00`00
07l0oooo0?ooo`02000000l0oooo00<000000?ooo`3oool07@3oool30?XN1@/0oooo0`3j7PD<0?oo
o`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo00<0001o0?oo
o`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?oo
o`00=03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool01`3oool3000Rfa/0oooo00<0001o0?ooo`0000004P3oool2000001d0oooo0`3j7PD;0?ooo`<0
nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`1?0?ooo`03
0000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3o
ool0;`3oool006P0oooo0`0000070?ooo`<002;K6`3oool00`0007l000000000000C0?ooo`800000
703oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K
1`3oool300000340oooo001X0?ooo`030000003oool0oooo00L0oooo0`008]/K0?ooo`8000005@3o
ool2000001/0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3o
ool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3o
ool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool003H0oooo1`00000[0?ooo`030000003oool0
oooo00L0oooo0`008]/J0?ooo`030000000007l0oooo01H0oooo0P00000J0?ooo`<0nQh52`3oool3
0?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool0C`3oool0
0`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0
oooo02l0oooo000g0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool01`3oool3000R
faT0oooo0P0000000`0007l0oooo0?ooo`0F0?ooo`8000006@3oool30?XN1@/0oooo0`3j7PD<0?oo
o`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo00<0001o0?oo
o`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?oo
o`00=P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00L0oooo0`008]/H0?ooo`80
000000<0oooo0000O`3oool0603oool2000001P0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0
oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0
oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool003H0oooo
00<000000?ooo`3oool0;`3oool3000000L0oooo0`008]/G0?ooo`8000000P3oool00`0007l0oooo
0?ooo`0H0?ooo`030000003oool0oooo01H0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo
0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo
00<0001o0?ooo`3oool0CP3oool3000Rf`L0oooo0`00000a0?ooo`00=`3oool6000002/0oooo00<0
00000?ooo`3oool01`3oool3000RfaH0oooo0P0000030?ooo`030000O`3oool0oooo01T0oooo00<0
00000?ooo`3oool05@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j
7PE30?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?oo
o`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00=P3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`030000003oool0oooo0080oooo00<0001o
0?ooo`3oool06P3oool00`000000oooo0?ooo`0D0?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o
0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?
0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo000f0?oo
o`030000003oool0oooo01H0oooo100000030?ooo`040000003oool0oooo0?ooo`@000002P3oool0
0`000000oooo0?ooo`070?ooo`<002;K5@3oool00`000000oooo0?ooo`030?ooo`030000O`3oool0
oooo01/0oooo00<000000?ooo`3oool04`3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0
oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool0
0`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00=P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool3000R
fa@0oooo00<000000?ooo`3oool0103oool00`0007l0oooo0?ooo`0L0?ooo`030000003oool0oooo
0180oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`00
07l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000R
f`T0oooo00<000000?ooo`3oool0;`3oool003L0oooo1P00000A0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0
oooo0`008]/C0?ooo`030000003oool0oooo00D0oooo00<0001o0?ooo`3oool0703oool2000001<0
oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0
oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0
oooo00<000000?ooo`3oool0;`3oool004h0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00L0oooo100000060000O`<002;K4P0007l2000002L0001o
0P00000B0000O`<0nQh52`0007l30?XN1AP0001o0`3j7PGo0000OcT0001o0`008]/60000O`@00000
<@3oool004h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`<002;K4@3o
ool2000000P0oooo00<0001o0?ooo`3oool07P3oool200000140oooo0`3j7PD;0?ooo`<0nQh5303o
ool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3o
ool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3o
ool003H0oooo1`00000A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool5
000000X0oooo00<000000?ooo`3oool01`3oool3000Rfa00oooo0P0000090?ooo`030000O`3oool0
oooo01l0oooo00<000000?ooo`3oool03`3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0
oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0703ooolH
000001/0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool0
03L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`<002;K3`3oool20000
00X0oooo00<0001o0?ooo`3oool0803oool00`000000oooo0?ooo`0>0?ooo`<0nQh52`3oool30?XN
1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool0C`3oool00`00
07l0oooo0?ooo`0B0?ooo`/000005P3oool;00000140oooo00<0001o0?ooo`3oool0CP3oool3000R
f`T0oooo00<000000?ooo`3oool0;`3oool003H0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`070?ooo`<002;K3`3oool00`000000oooo0?ooo`090?ooo`030000O`3oool0oooo0240
oooo00<000000?ooo`3oool03@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0
oooo0`3j7PE30?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool02`3oool8000002X0
oooo2000000:0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0oooo02l0
oooo000f0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool3000Rf`h0oooo
00<000000?ooo`3oool02P3oool00`0007l0oooo0?ooo`0R0?ooo`030000003oool0oooo00`0oooo
0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo
0?ooo`1?0?ooo`030000O`3oool0oooo00D0oooo1`00000h0?ooo`L00000103oool00`0007l0oooo
0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00=`3oool600000180oooo1000
00070?ooo`D000002@3oool3000000L0oooo0`008]/=0?ooo`030000003oool0oooo00/0oooo00<0
001o0?ooo`3oool08`3oool00`000000oooo0?ooo`0;0?ooo`<0nQh52`3oool30?XN1@`0oooo00<0
001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?oo
o`06000004@0oooo1P00001@0?ooo`<002;K1`3oool300000340oooo000f0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool01`3oool3000Rf``0oooo00<000000?ooo`3oool0303oool0
0`0007l0oooo0?ooo`0S0?ooo`800000303oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0
oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo04h0oooo1@00001>0?ooo`D00000C03oool3
000Rf`T0oooo00<000000?ooo`3oool0;`3oool003H0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`070?ooo`<002;K2`3oool2000000h0oooo00<0001o0?ooo`3oool0903oool20000
00/0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`00
07l0oooo0?ooo`1:0?ooo`@0000000<0oooo0000O`3oool0D03oool00`0007l0oooo0?ooo`020?oo
o`D00000A`3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool003H0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`070?ooo`<002;K2P3oool2000000l0oooo00<0001o0?ooo`3o
ool09@3oool00`000000oooo0?ooo`090?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3o
ool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool0AP3oool4000000D0oooo00<0001o0?ooo`3o
ool0C`3oool00`0007l0oooo0?ooo`060?ooo`D00000@`3oool3000Rf`T0oooo00<000000?ooo`3o
ool0;`3oool003L0oooo1P00000[0?ooo`030000003oool0oooo00L0oooo0`008]/90?ooo`800000
403oool00`0007l0oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo0`3j7PD;0?ooo`<0nQh5
303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`120?ooo`@00000
2@3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo00X0oooo1@00000o0?ooo`<002;K
2@3oool00`000000oooo0?ooo`0_0?ooo`00J03oool3000000L0oooo0`008]/80?ooo`8000004@3o
ool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00L0oooo0`3j7PD;0?ooo`<0nQh5303o
ool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`0n0?ooo`@000003@3o
ool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo00h0oooo1000000l0?ooo`<002;K1`3o
ool300000340oooo000d0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`070?ooo`<002;K203oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0
oooo02L0oooo0P0000080?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool02@3oool3
0?XN1D<0oooo00<0001o0?ooo`3oool0>P3oool400000140oooo00<0001o0?ooo`3oool0C`3oool0
0`0007l0oooo0?ooo`0B0?ooo`@00000>03oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool0
03@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00L0oooo0`008]/70?ooo`8000004P3oool00`0007l0oooo0?ooo`0X0?ooo`8000001`3oool30?XN
1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo
03L0oooo1000000D0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool05@3oool40000
03D0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo000d0?ooo``00000:03oool00`000000
oooo0?ooo`070?ooo`<002;K1P3oool2000001<0oooo00<0001o0?ooo`3oool0:@3oool2000000H0
oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0
oooo0?ooo`0d0?ooo`<00000603oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo01T0
oooo1000000a0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo
0?ooo`070?ooo`<002;K1@3oool2000001@0oooo00<0001o0?ooo`3oool0:P3oool00`000000oooo
0?ooo`040?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo
00<0001o0?ooo`3oool0<03oool4000001/0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo
0?ooo`0L0?ooo`@00000;P3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool006P0oooo00<0
00000?ooo`3oool01`3oool3000Rf`D0oooo00<000000?ooo`3oool04`3oool00`0007l0oooo0?oo
o`0[0?ooo`030000003oool0oooo00<0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?oo
o`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`0]0?ooo`@000007P3oool00`0007l0oooo0?oo
o`1?0?ooo`030000O`3oool0oooo0200oooo0`00000[0?ooo`<002;K2@3oool00`000000oooo0?oo
o`0_0?ooo`00J03oool3000000L0oooo0`008]/40?ooo`030000003oool0oooo01@0oooo00<0001o
0?ooo`3oool0;03oool00`000000oooo0?ooo`020?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o
0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool0:P3oool400000240oooo00<0001o
0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0S0?ooo`<00000:03oool3000Rf`L0oooo0`00000a
0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<002;K0`3oool00`000000oooo0?ooo`0E0?oo
o`030000O`3oool0oooo02d0oooo00@000000?ooo`3oool0oooo0`3j7PD;0?ooo`<0nQh5303oool0
0`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`0W0?ooo`@00000903oool0
0`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo02H0oooo0`00000U0?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<002;K0P3oool00`00
0000oooo0?ooo`0F0?ooo`030000O`3oool0oooo02h0oooo00<000000?ooo`3oool00`3j7PD;0?oo
o`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo0?ooo`0T0?oo
o`@000009`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo02T0oooo0`00000R0?oo
o`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<0
02;K00<0oooo0000003oool0603oool00`0007l0oooo0?ooo`0^0?ooo`030000003oool0oooo00<0
nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3o
ool08@3oool4000002X0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0/0?ooo`@0
00007P3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool006P0oooo00<000000?ooo`3oool0
1`3oool3000Rf`030?ooo`000000oooo01P0oooo00<0001o0?ooo`3oool0;`3oool00`000000oooo
0?XN1@020?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000
O`3oool0oooo01h0oooo0`00000^0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0
;`3oool4000001/0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo001X0?ooo`<000001`3o
ool3000Rf`030000003oool0oooo01P0oooo00<0001o0?ooo`3oool0<03oool010000000nQh50?XN
1@3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`0007l0oooo
0?ooo`0K0?ooo`<00000<@3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo0380oooo
1000000H0?ooo`<002;K1`3oool300000340oooo001X0?ooo`030000003oool0oooo00L0oooo0P00
8]/00`000000oooo0?ooo`0I0?ooo`030000O`3oool0oooo0340oooo00<000000?XN1@3j7PD02`3o
ool30?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1D<0oooo00<0001o0?ooo`3oool0603o
ool3000003@0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0e0?ooo`<000005P3o
ool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool005`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`070?ooo`03000Rf`00000002;K01/0oooo00<0001o0?ooo`3oool0<@3oool2
000000030?XN1@3oool0oooo00T0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE3
0?ooo`030000O`3oool0oooo01D0oooo1000000f0?ooo`030000O`3oool0oooo04l0oooo00<0001o
0?ooo`3oool0>03oool3000001<0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo001L0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool3000Rfa/0oooo00<0001o0?oo
o`3oool0<@3oool00`3j7PD000000?XN1@0;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?oo
o`<0nQh5@`3oool00`0007l0oooo0?ooo`0B0?ooo`@00000>@3oool00`0007l0oooo0?ooo`1?0?oo
o`030000O`3oool0oooo03/0oooo0`00000@0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?oo
o`00G03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3o
ool0<`3oool00`000000oooo0?ooo`090?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0
nQh5@`3oool00`0007l0oooo0?ooo`0?0?ooo`@00000?03oool00`0007l0oooo0?ooo`1?0?ooo`03
0000O`3oool0oooo03d0oooo1000000=0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00
G03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0
<`3oool00`000000oooo0?ooo`090?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5
@`3oool00`0007l0oooo0?ooo`0=0?ooo`<00000?`3oool00`0007l0oooo0?ooo`1?0?ooo`030000
O`3oool0oooo0440oooo0`00000:0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00G03o
ool00`000000oooo0?ooo`090?ooo`@00000F`0007l00`000000001o0000O`080000O`<0nQh56000
07l30?XN1E00001o0`00003J0000O`<00000200007l3000Rf`H0001o1000000a0?ooo`00G03oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0=@3oool0
0`000000oooo0?ooo`070?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool0
0`0007l0oooo0?ooo`070?ooo`@00000A03oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0
oooo04H0oooo0`0000050?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00G03oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0=@3oool00`00
0000oooo0?ooo`070?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5@`3oool00`00
07l0oooo0?ooo`040?ooo`@00000A`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo
04T0oooo0`0000020?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00FP3oool00`000000
oooo0000000;0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0=@3oool2000000P0
oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0oooo0080
oooo0`00001:0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0B`3oool400000080
02;K2@3oool00`000000oooo0?ooo`0_0?ooo`00F`3oool2000000/0oooo00<000000?ooo`3oool0
9@3oool00`0007l0oooo0?ooo`0f0?ooo`030000003oool0oooo00H0oooo0`3j7PD<0?ooo`030000
O`3oool0oooo00T0oooo0`3j7PE30?ooo`030000O`3oool0000000800000C@3oool00`0007l0oooo
0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0P0000000`008]/0oooo0?ooo`070?ooo`030000
003oool0oooo02l0oooo001L0?ooo`030000003oool0oooo00T0oooo0`00000U0?ooo`030000O`3o
ool0oooo03L0oooo00<000000?ooo`3oool01@3oool30?XN1@`0oooo00<0001o0?ooo`3oool02@3o
ool30?XN1D80oooo0`00001@0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3o
ool3000Rf`L0oooo0`00000a0?ooo`00J03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0
oooo03L0oooo0P0000060?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5?`3oool4
000000030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1J
0?ooo`030000003oool0oooo02l0oooo001X0?ooo`030000003oool0oooo02D0oooo00<0001o0?oo
o`3oool0>03oool00`000000oooo0?ooo`040?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?oo
o`<0nQh5?@3oool3000000<0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?oo
o`030000O`3oool0oooo05X0oooo00<000000?ooo`3oool0;`3oool006P0oooo00<000000?ooo`3o
ool09@3oool00`0007l0oooo0?ooo`0i0?ooo`030000003oool0oooo00<0oooo0`3j7PD<0?ooo`03
0000O`3oool0oooo00T0oooo0`3j7PDj0?ooo`<000001P3oool00`0007l0oooo0?ooo`1?0?ooo`03
0000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0FP3oool00`000000oooo0?ooo`0_0?ooo`00
J03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo03T0oooo00<000000?ooo`3oool0
0`3oool30?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1CP0oooo0`0000080?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1J0?ooo`030000
003oool0oooo02l0oooo001X0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0>@3o
ool2000000@0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PDe0?ooo`<000002`3o
ool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0_0?ooo`00J03oool3000002D0oooo00<0001o0?ooo`3oool0>P3oool0
0`000000oooo0?ooo`020?ooo`<0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5<P3oool4
000000d0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0
oooo05P0oooo0`00000a0?ooo`00J03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo
03/0oooo00@000000?ooo`3oool0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PD`
0?ooo`<00000403oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o
0?ooo`3oool0FP3oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`0U0?oo
o`030000O`3oool0oooo03/0oooo00@000000?ooo`3oool0oooo0`3j7PD<0?ooo`030000O`3oool0
oooo00T0oooo0`3j7PD]0?ooo`<000004`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0
oooo04l0oooo00<0001o0?ooo`3oool0FP3oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`00
0000oooo0?ooo`0U0?ooo`030000O`3oool0oooo03`0oooo00<000000?ooo`3oool00`3j7PD<0?oo
o`030000O`3oool0oooo00T0oooo0`3j7PDZ0?ooo`@000005@3oool00`0007l0oooo0?ooo`1?0?oo
o`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0FP3oool00`000000oooo0?ooo`0_0?oo
o`00J03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo03`0oooo00<000000?ooo`3o
ool00`3j7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PDX0?ooo`<00000603oool00`0007l0
oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0FP3oool00`000000
oooo0?ooo`0_0?ooo`00J03oool3000002D0oooo00<0001o0?ooo`3oool0?@3oool00`000000oooo
0?XN1@020?XN1@`0oooo00<0001o0?ooo`3oool02@3oool30?XN1BD0oooo0`00000K0?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1H0?ooo`<00000
<@3oool006P0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0m0?ooo`8000000`3j
7PD<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PDS0?ooo`<000007@3oool00`0007l0oooo0?oo
o`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0FP3oool00`000000oooo0?oo
o`0_0?ooo`00J03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo03h0oooo00@00000
0?XN1@3j7PD0nQh5303oool00`0007l0oooo0?ooo`090?ooo`<0nQh5803oool300000200oooo00<0
001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo05X0oooo00<0
00000?ooo`3oool0;`3oool006P0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0o
0?ooo`030000003j7PD0nQh500`0oooo00<0001o0?ooo`3oool02@3oool30?XN1Ah0oooo0P00000S
0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1J
0?ooo`030000003oool0oooo02l0oooo001X0?ooo`030000003oool0oooo02D0oooo00<0001o0?oo
o`3oool0?`3oool00`000000nQh50?XN1@0<0?ooo`030000O`3oool0oooo00T0oooo0`3j7PDK0?oo
o`<000009@3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?oo
o`3oool0FP3oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`0U0?ooo`03
0000O`3oool0oooo03l0oooo00<0nQh50000003j7PD0303oool00`0007l0oooo0?ooo`090?ooo`<0
nQh5603oool4000002L0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`03
0000O`3oool0oooo05X0oooo00<000000?ooo`3oool0;`3oool006P0oooo0`00000U0?ooo`030000
O`3oool0oooo03l0oooo00<0nQh50000000000000P00000:0?ooo`030000O`3oool0oooo00T0oooo
0`3j7PDF0?ooo`<00000:P3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo
00<0001o0?ooo`3oool0F03oool300000340oooo001X0?ooo`030000003oool0oooo02D0oooo00<0
001o0?ooo`3oool0@`3oool3000000P0oooo00<0001o0?ooo`3oool02@3oool30?XN1A<0oooo0`00
000]0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?oo
o`1J0?ooo`030000003oool0oooo02l0oooo001A0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool0oooo1000000:0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0AP3o
ool2000000H0oooo00<0001o0?ooo`3oool02@3oool30?XN1A40oooo0`00000_0?ooo`030000O`3o
ool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1J0?ooo`030000003o
ool0oooo02l0oooo001A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0B03oool3
000000<0oooo00<0001o0?ooo`3oool02@3oool30?XN1@h0oooo1000000a0?ooo`030000O`3oool0
oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1J0?ooo`030000003oool0
oooo02l0oooo001A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0U0?ooo`030000O`3oool0oooo04/0oooo0`0000000`0007l0oooo0?ooo`090?oo
o`<0nQh5303oool3000003@0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?oo
o`030000O`3oool0oooo05X0oooo00<000000?ooo`3oool0;`3oool00540oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`070?ooo`@00000M00007l3000000X0001o0`3j7PD90000O`<0
0000o`0007lf0000O`@00000<@3oool00540oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo
0?ooo`1>0?ooo`030000O`3oool00000008000001`3oool30?XN1@L0oooo0`00000i0?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1J0?ooo`030000
003oool0oooo02l0oooo001A0?ooo`030000003oool0oooo00D0oooo1@00000:0?ooo`030000003o
ool0oooo02D0oooo00<0001o0?ooo`3oool0CP3oool0100007l0oooo0?ooo`3oool3000000D0oooo
0`3j7PD40?ooo`<00000?03oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo
00<0001o0?ooo`3oool0FP3oool00`000000oooo0?ooo`0_0?ooo`00D@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?oo
o`1>0?ooo`030000O`3oool0oooo00@0oooo0`0000020?ooo`<0nQh50P3oool3000003h0oooo00<0
001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo05X0oooo00<0
00000?ooo`3oool0;`3oool004l0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`06
0?ooo`<000000P3j7PD300000440oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?
0?ooo`030000O`3oool0oooo05X0oooo00<000000?ooo`3oool0;`3oool00500oooo0P0000080?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`1>0?oo
o`030000O`3oool0oooo00T0oooo0`0000130?ooo`030000O`3oool0oooo04l0oooo00<0001o0?oo
o`3oool0C`3oool00`0007l0oooo0?ooo`1J0?ooo`030000003oool0oooo02l0oooo001A0?ooo`03
0000003oool0oooo00H0oooo1@0000090?ooo`<000009@3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo00T0oooo0`3j7PE30?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00H0oooo0`00000a0?ooo`00
J03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02l0oooo001X0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0_0?ooo`00J03ooooo
00000<h00000<@3oool00?l0ooooo`3ooomX0?ooo`00o`3ooooo0?ooofP0oooo003o0?ooool0oooo
J03oool00?l0ooooo`3ooomX0?ooo`00o`3ooooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0
ooooo`3ooomX0?ooo`00o`3ooooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX
0?ooo`00o`3oool[0?ooo`H00000103oool3000000@0oooo0P0000001@3oool000000?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool3000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`3oool300000?H0oooo003o0?ooob/0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000030?ooo`040000003oool0oooo00000080oooo0P0000020?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool01@000000oooo0?ooo`3oool000000?D0oooo003o0?ooob/0oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000060?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0m`3oool00?l0oooo:`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00D000000`3oool400000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`D00000m@3oool00?l0oooo:`3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`05
0000003oool0oooo0?ooo`0000001@3oool6000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo
0?ooo`3oool000000?D0oooo003o0?ooob/0oooo1P0000030?ooo`050000003oool0oooo0?ooo`00
00000P3oool01@000000oooo0?ooo`3oool000000080oooo0P0000020?ooo`8000000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P0000020?oo
o`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`3oool0l`3oool00?l0oooo:`3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo0?ooo`<00000103oool3000000<0oooo00@000000?ooo`000000
00000P3oool2000000H0oooo00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`000000oooo
00000080oooo0`0000020?ooo`<0000000D0oooo0000003oool0oooo000000030?ooo`<00000mP3o
ool00?l0oooo:`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0nP3oool00?l0oooo:`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0nP3oool00?l0oooo:`3oool6000001l0oooo1P00000?0?ooo`<0
00000P3oool00`000000oooo0?ooo`3j0?ooo`00o`3ooooo0?ooofP0oooo003o0?ooool0ooooJ03o
ool00001\
\>"],
  ImageRangeCache->{{{57.1875, 547.375}, {359.75, 164.313}} -> {-3.63839, \
1.36126, 0.0122326, 0.0181369}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AS Port Port Beam Profile", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TelescopePlot[{zETM, 4.0}, {CavityWaist, 
          zCavityWaist}, {{ITMFocalLength, zITM}, {fLXY, zLXY}, {fL2, zL2}}, 
        kk];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.26413 0.178015 0.2 0.112484 [
[.08611 -0.0125 -10.0938 -16.375 ]
[.08611 -0.0125 10.0938 0 ]
[.26413 -0.0125 -5.59375 -16.375 ]
[.26413 -0.0125 5.59375 0 ]
[.44215 -0.0125 -5.59375 -16.375 ]
[.44215 -0.0125 5.59375 0 ]
[.62016 -0.0125 -5.59375 -16.375 ]
[.62016 -0.0125 5.59375 0 ]
[.79818 -0.0125 -5.59375 -16.375 ]
[.79818 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -16.375 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -43.1563 -32.75 ]
[.5 -0.0125 43.1563 -16.375 ]
[-0.0125 .03127 -30.9375 -8.1875 ]
[-0.0125 .03127 0 8.1875 ]
[-0.0125 .08752 -20.1875 -8.1875 ]
[-0.0125 .08752 0 8.1875 ]
[-0.0125 .14376 -30.9375 -8.1875 ]
[-0.0125 .14376 0 8.1875 ]
[-0.0125 .2 -11.1875 -8.1875 ]
[-0.0125 .2 0 8.1875 ]
[-0.0125 .25624 -21.9375 -8.1875 ]
[-0.0125 .25624 0 8.1875 ]
[-0.0125 .31248 -11.1875 -8.1875 ]
[-0.0125 .31248 0 8.1875 ]
[-0.0125 .36873 -21.9375 -8.1875 ]
[-0.0125 .36873 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .2 -47.3125 -44.3438 ]
[-0.01875 .2 -30.9375 44.3438 ]
[ 0 .4 .125 0 ]
[.5 .4125 -39 0 ]
[.5 .4125 39 16.375 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.08611 0 m
.08611 .4 L
s
.26413 0 m
.26413 .4 L
s
.44215 0 m
.44215 .4 L
s
.62016 0 m
.62016 .4 L
s
.79818 0 m
.79818 .4 L
s
0 .03127 m
1 .03127 L
s
0 .08752 m
1 .08752 L
s
0 .14376 m
1 .14376 L
s
0 .2 m
1 .2 L
s
0 .25624 m
1 .25624 L
s
0 .31248 m
1 .31248 L
s
0 .36873 m
1 .36873 L
s
0 g
.08611 0 m
.08611 .00625 L
s
gsave
.08611 -0.0125 -71.0938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.26413 0 m
.26413 .00625 L
s
gsave
.26413 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.44215 0 m
.44215 .00625 L
s
gsave
.44215 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.62016 0 m
.62016 .00625 L
s
gsave
.62016 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.79818 0 m
.79818 .00625 L
s
gsave
.79818 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.12172 0 m
.12172 .00375 L
s
.15732 0 m
.15732 .00375 L
s
.19292 0 m
.19292 .00375 L
s
.22853 0 m
.22853 .00375 L
s
.29973 0 m
.29973 .00375 L
s
.33534 0 m
.33534 .00375 L
s
.37094 0 m
.37094 .00375 L
s
.40654 0 m
.40654 .00375 L
s
.47775 0 m
.47775 .00375 L
s
.51335 0 m
.51335 .00375 L
s
.54895 0 m
.54895 .00375 L
s
.58456 0 m
.58456 .00375 L
s
.65576 0 m
.65576 .00375 L
s
.69137 0 m
.69137 .00375 L
s
.72697 0 m
.72697 .00375 L
s
.76257 0 m
.76257 .00375 L
s
.83378 0 m
.83378 .00375 L
s
.86938 0 m
.86938 .00375 L
s
.90498 0 m
.90498 .00375 L
s
.94059 0 m
.94059 .00375 L
s
.05051 0 m
.05051 .00375 L
s
.01491 0 m
.01491 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -104.156 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.438 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.875 16.625 moveto
(@) show
130.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
141.000 16.625 moveto
(D) show
145.313 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03127 m
.00625 .03127 L
s
gsave
-0.0125 .03127 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .08752 m
.00625 .08752 L
s
gsave
-0.0125 .08752 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .14376 m
.00625 .14376 L
s
gsave
-0.0125 .14376 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
gsave
-0.0125 .2 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .25624 m
.00625 .25624 L
s
gsave
-0.0125 .25624 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .31248 m
.00625 .31248 L
s
gsave
-0.0125 .31248 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .36873 m
.00625 .36873 L
s
gsave
-0.0125 .36873 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04252 m
.00375 .04252 L
s
0 .05377 m
.00375 .05377 L
s
0 .06502 m
.00375 .06502 L
s
0 .07627 m
.00375 .07627 L
s
0 .09876 m
.00375 .09876 L
s
0 .11001 m
.00375 .11001 L
s
0 .12126 m
.00375 .12126 L
s
0 .13251 m
.00375 .13251 L
s
0 .15501 m
.00375 .15501 L
s
0 .16625 m
.00375 .16625 L
s
0 .1775 m
.00375 .1775 L
s
0 .18875 m
.00375 .18875 L
s
0 .21125 m
.00375 .21125 L
s
0 .2225 m
.00375 .2225 L
s
0 .23375 m
.00375 .23375 L
s
0 .24499 m
.00375 .24499 L
s
0 .26749 m
.00375 .26749 L
s
0 .27874 m
.00375 .27874 L
s
0 .28999 m
.00375 .28999 L
s
0 .30124 m
.00375 .30124 L
s
0 .32373 m
.00375 .32373 L
s
0 .33498 m
.00375 .33498 L
s
0 .34623 m
.00375 .34623 L
s
0 .35748 m
.00375 .35748 L
s
0 .02003 m
.00375 .02003 L
s
0 .00878 m
.00375 .00878 L
s
0 .37997 m
.00375 .37997 L
s
0 .39122 m
.00375 .39122 L
s
.25 Mabswid
0 0 m
0 .4 L
s
gsave
-0.01875 .2 -144.469 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
105.344 12.1875 translate
90 rotate
-105.344 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(spot) show
90.938 16.625 moveto
(size) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.438 16.625 moveto
(@) show
121.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
143.375 16.625 moveto
(D) show
147.688 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08611 .39375 m
.08611 .4 L
s
.26413 .39375 m
.26413 .4 L
s
.44215 .39375 m
.44215 .4 L
s
.62016 .39375 m
.62016 .4 L
s
.79818 .39375 m
.79818 .4 L
s
.97619 .39375 m
.97619 .4 L
s
.125 Mabswid
.12172 .39625 m
.12172 .4 L
s
.15732 .39625 m
.15732 .4 L
s
.19292 .39625 m
.19292 .4 L
s
.22853 .39625 m
.22853 .4 L
s
.29973 .39625 m
.29973 .4 L
s
.33534 .39625 m
.33534 .4 L
s
.37094 .39625 m
.37094 .4 L
s
.40654 .39625 m
.40654 .4 L
s
.47775 .39625 m
.47775 .4 L
s
.51335 .39625 m
.51335 .4 L
s
.54895 .39625 m
.54895 .4 L
s
.58456 .39625 m
.58456 .4 L
s
.65576 .39625 m
.65576 .4 L
s
.69137 .39625 m
.69137 .4 L
s
.72697 .39625 m
.72697 .4 L
s
.76257 .39625 m
.76257 .4 L
s
.83378 .39625 m
.83378 .4 L
s
.86938 .39625 m
.86938 .4 L
s
.90498 .39625 m
.90498 .4 L
s
.94059 .39625 m
.94059 .4 L
s
.05051 .39625 m
.05051 .4 L
s
.01491 .39625 m
.01491 .4 L
s
.25 Mabswid
0 .4 m
1 .4 L
s
gsave
.5 .4125 -100 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
100.375 16.625 moveto
(Profile) show
137.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .03127 m
1 .03127 L
s
.99375 .08752 m
1 .08752 L
s
.99375 .14376 m
1 .14376 L
s
.99375 .2 m
1 .2 L
s
.99375 .25624 m
1 .25624 L
s
.99375 .31248 m
1 .31248 L
s
.99375 .36873 m
1 .36873 L
s
.125 Mabswid
.99625 .04252 m
1 .04252 L
s
.99625 .05377 m
1 .05377 L
s
.99625 .06502 m
1 .06502 L
s
.99625 .07627 m
1 .07627 L
s
.99625 .09876 m
1 .09876 L
s
.99625 .11001 m
1 .11001 L
s
.99625 .12126 m
1 .12126 L
s
.99625 .13251 m
1 .13251 L
s
.99625 .15501 m
1 .15501 L
s
.99625 .16625 m
1 .16625 L
s
.99625 .1775 m
1 .1775 L
s
.99625 .18875 m
1 .18875 L
s
.99625 .21125 m
1 .21125 L
s
.99625 .2225 m
1 .2225 L
s
.99625 .23375 m
1 .23375 L
s
.99625 .24499 m
1 .24499 L
s
.99625 .26749 m
1 .26749 L
s
.99625 .27874 m
1 .27874 L
s
.99625 .28999 m
1 .28999 L
s
.99625 .30124 m
1 .30124 L
s
.99625 .32373 m
1 .32373 L
s
.99625 .33498 m
1 .33498 L
s
.99625 .34623 m
1 .34623 L
s
.99625 .35748 m
1 .35748 L
s
.99625 .02003 m
1 .02003 L
s
.99625 .00878 m
1 .00878 L
s
.99625 .37997 m
1 .37997 L
s
.99625 .39122 m
1 .39122 L
s
.25 Mabswid
1 0 m
1 .4 L
s
.977 .121 .023 r
.0075 w
.20182 .09445 m
.20182 .30555 L
s
.2328 .04308 m
.2328 .35692 L
s
.30863 .01487 m
.30863 .38513 L
s
0 .133 .859 r
.02381 .09445 m
.02381 .30555 L
s
.97619 .00952 m
.97619 .39048 L
s
0 g
.5 Mabswid
.02381 .30555 m
.02474 .3045 L
.02575 .30334 L
.0267 .30226 L
.02761 .30122 L
.02859 .30011 L
.02952 .29905 L
.03052 .29791 L
.03148 .29682 L
.0324 .29577 L
.03338 .29466 L
.03433 .29359 L
.03524 .29256 L
.03621 .29146 L
.03714 .29041 L
.03813 .28929 L
.03908 .28821 L
.04 .28717 L
.04098 .28607 L
.04192 .28501 L
.04292 .28388 L
.04388 .2828 L
.0448 .28175 L
.04579 .28065 L
.04674 .27958 L
.04765 .27856 L
.04862 .27747 L
.04956 .27642 L
.05055 .27531 L
.05151 .27424 L
.05243 .27321 L
.05341 .27212 L
.05435 .27107 L
.05526 .27006 L
.05622 .26899 L
.05715 .26796 L
.05814 .26687 L
.05909 .26581 L
.06001 .2648 L
.06098 .26373 L
.06192 .2627 L
.06292 .26161 L
.06388 .26056 L
.0648 .25955 L
.06579 .25848 L
.06673 .25745 L
.06764 .25646 L
.06861 .25542 L
.06954 .25441 L
.07054 .25335 L
Mistroke
.07149 .25233 L
.07241 .25135 L
.07339 .25031 L
.07433 .24931 L
.07533 .24826 L
.07629 .24725 L
.07722 .24628 L
.07821 .24526 L
.07916 .24428 L
.08007 .24334 L
.08104 .24235 L
.08198 .24141 L
.08297 .24041 L
.08393 .23946 L
.08485 .23855 L
.08584 .23759 L
.08678 .23668 L
.08769 .23581 L
.08866 .2349 L
.08959 .23403 L
.09058 .23313 L
.09153 .23227 L
.09245 .23146 L
.09342 .23061 L
.09436 .22982 L
.09536 .22899 L
.09632 .22822 L
.09725 .2275 L
.09823 .22676 L
.09918 .22608 L
.10009 .22545 L
.10106 .22481 L
.10199 .22423 L
.10247 .22394 L
.10299 .22365 L
.10394 .22313 L
.10442 .22289 L
.10492 .22265 L
.10539 .22243 L
.10583 .22224 L
.10631 .22204 L
.10676 .22187 L
.10721 .2217 L
.10747 .22162 L
.10771 .22154 L
.10796 .22146 L
.1082 .22139 L
.10841 .22132 L
.10865 .22126 L
.10887 .2212 L
Mistroke
.10912 .22114 L
.10925 .22111 L
.10938 .22108 L
.10951 .22105 L
.10963 .22103 L
.10987 .22098 L
.11 .22096 L
.11014 .22093 L
.11027 .22091 L
.11039 .22089 L
.1105 .22088 L
.11062 .22086 L
.11074 .22084 L
.11085 .22083 L
.11097 .22081 L
.1111 .2208 L
.11116 .22079 L
.11123 .22078 L
.1113 .22078 L
.11136 .22077 L
.11142 .22076 L
.11149 .22076 L
.11155 .22075 L
.1116 .22075 L
.11166 .22074 L
.11172 .22074 L
.11178 .22074 L
.11185 .22073 L
.11191 .22073 L
.11196 .22072 L
.11201 .22072 L
.11207 .22072 L
.1121 .22072 L
.11213 .22072 L
.11216 .22071 L
.1122 .22071 L
.11223 .22071 L
.11227 .22071 L
.1123 .22071 L
.11233 .22071 L
.11236 .22071 L
.11239 .22071 L
.11241 .22071 L
.11242 .22071 L
.11245 .22071 L
.11248 .2207 L
.11251 .2207 L
.11254 .2207 L
.11257 .2207 L
.1126 .2207 L
Mistroke
.11263 .2207 L
.11265 .2207 L
.11266 .2207 L
.11268 .2207 L
.1127 .2207 L
.11273 .2207 L
.11275 .2207 L
.11279 .2207 L
.11282 .2207 L
.11284 .2207 L
.11287 .2207 L
.1129 .2207 L
.11292 .2207 L
.11295 .2207 L
.11298 .2207 L
.11301 .2207 L
.11304 .2207 L
.11307 .2207 L
.1131 .2207 L
.11313 .2207 L
.11316 .2207 L
.11319 .22071 L
.11321 .22071 L
.11322 .22071 L
.11325 .22071 L
.11327 .22071 L
.11328 .22071 L
.11332 .22071 L
.11335 .22071 L
.11338 .22071 L
.11342 .22071 L
.11345 .22071 L
.11348 .22071 L
.11351 .22072 L
.11354 .22072 L
.11361 .22072 L
.11364 .22072 L
.11367 .22072 L
.11373 .22073 L
.11379 .22073 L
.11386 .22074 L
.11392 .22074 L
.11399 .22075 L
.11406 .22075 L
.11411 .22076 L
.11418 .22076 L
.11429 .22077 L
.11436 .22078 L
.11442 .22078 L
.11454 .2208 L
Mistroke
.11465 .22081 L
.11477 .22083 L
.1149 .22084 L
.11502 .22086 L
.11513 .22088 L
.11524 .22089 L
.11547 .22093 L
.11558 .22095 L
.11571 .22097 L
.11593 .22101 L
.11605 .22104 L
.11616 .22106 L
.11642 .22112 L
.11666 .22118 L
.11691 .22124 L
.11712 .2213 L
.11736 .22136 L
.1176 .22144 L
.11783 .2215 L
.11809 .22159 L
.11833 .22167 L
.11879 .22184 L
.11904 .22193 L
.11929 .22203 L
.11976 .22222 L
.1202 .22241 L
.12069 .22264 L
.12114 .22285 L
.12163 .2231 L
.12209 .22334 L
.12301 .22386 L
.12396 .22442 L
.12486 .22499 L
.12583 .22564 L
.12675 .22629 L
.12774 .22701 L
.12869 .22774 L
.12961 .22846 L
.13058 .22924 L
.13152 .23002 L
.13251 .23087 L
.13347 .23171 L
.1344 .23253 L
.13538 .23342 L
.13632 .23429 L
.13723 .23514 L
.1382 .23605 L
.13913 .23694 L
.14012 .2379 L
.14108 .23884 L
Mistroke
.14199 .23975 L
.14297 .24072 L
.14391 .24166 L
.14491 .24268 L
.14587 .24366 L
.1468 .24461 L
.14778 .24563 L
.14873 .24661 L
.14965 .24757 L
.15062 .24859 L
.15155 .24957 L
.15255 .25063 L
.1535 .25164 L
.15442 .25263 L
.1554 .25368 L
.15635 .25469 L
.15726 .25567 L
.15822 .25671 L
.15915 .25772 L
.16014 .25879 L
.16109 .25983 L
.16201 .26083 L
.16298 .2619 L
.16392 .26293 L
.16492 .26402 L
.16588 .26508 L
.1668 .2661 L
.16779 .26719 L
.16873 .26824 L
.16964 .26925 L
.17061 .27032 L
.17154 .27136 L
.17254 .27247 L
.17349 .27353 L
.17441 .27456 L
.17539 .27565 L
.17633 .2767 L
.17733 .27782 L
.17829 .27891 L
.17922 .27995 L
.18021 .28106 L
.18116 .28212 L
.18207 .28315 L
.18304 .28425 L
.18398 .2853 L
.18498 .28643 L
.18593 .28751 L
.18686 .28855 L
.18784 .28966 L
.18878 .29073 L
Mistroke
.18969 .29176 L
.19066 .29286 L
.19159 .29391 L
.19258 .29503 L
.19353 .29612 L
.19445 .29716 L
.19543 .29827 L
.19637 .29934 L
.19736 .30047 L
.19833 .30157 L
.19925 .30262 L
.20024 .30374 L
.20073 .3043 L
.20118 .30482 L
.20141 .30508 L
.20162 .30532 L
.20174 .30546 L
.20177 .3055 L
.20179 .30552 L
.20181 .30553 L
.20184 .30557 L
.20185 .3056 L
.20187 .30563 L
.2021 .306 L
.20308 .30763 L
.20403 .30921 L
.20495 .31072 L
.20592 .31233 L
.20686 .31388 L
.20786 .31553 L
.20882 .31712 L
.20974 .31865 L
.21072 .32028 L
.21167 .32185 L
.21258 .32335 L
.21355 .32496 L
.21448 .3265 L
.21547 .32815 L
.21642 .32973 L
.21734 .33125 L
.21832 .33287 L
.21926 .33443 L
.22026 .33609 L
.22122 .33769 L
.22215 .33923 L
.22314 .34087 L
.22409 .34244 L
.225 .34396 L
.22597 .34557 L
.22691 .34712 L
Mistroke
.2279 .34878 L
.22886 .35037 L
.22978 .3519 L
.23076 .35353 L
.2317 .35509 L
.23218 .35588 L
.23238 .35623 L
.23261 .3566 L
.23267 .3567 L
.23273 .3568 L
.23276 .35685 L
.23279 .35689 L
.23281 .35692 L
.23284 .35693 L
.23308 .35702 L
.23358 .3572 L
.23456 .35756 L
.23551 .35791 L
.23642 .35825 L
.23739 .3586 L
.23832 .35895 L
.23932 .35931 L
.24027 .35966 L
.24119 .36 L
.24217 .36036 L
.24311 .36071 L
.24411 .36108 L
.24508 .36143 L
.246 .36178 L
.24699 .36214 L
.24794 .36249 L
.24886 .36283 L
.24983 .36319 L
.25077 .36354 L
.25176 .3639 L
.25272 .36426 L
.25364 .3646 L
.25462 .36496 L
.25557 .36531 L
.25648 .36565 L
.25745 .36601 L
.25838 .36636 L
.25937 .36672 L
.26032 .36708 L
.26124 .36742 L
.26222 .36778 L
.26316 .36813 L
.26415 .3685 L
.26512 .36886 L
.26604 .3692 L
Mistroke
.26703 .36957 L
.26798 .36992 L
.26889 .37026 L
.26986 .37062 L
.27079 .37097 L
.27179 .37134 L
.27275 .37169 L
.27367 .37204 L
.27465 .3724 L
.27559 .37275 L
.2765 .37309 L
.27746 .37345 L
.27839 .3738 L
.27938 .37417 L
.28033 .37452 L
.28125 .37487 L
.28222 .37523 L
.28316 .37558 L
.28415 .37595 L
.28512 .37631 L
.28604 .37666 L
.28702 .37702 L
.28797 .37738 L
.28888 .37772 L
.28985 .37808 L
.29078 .37843 L
.29177 .3788 L
.29273 .37916 L
.29365 .3795 L
.29462 .37987 L
.29556 .38022 L
.29656 .3806 L
.29753 .38096 L
.29846 .38131 L
.29944 .38168 L
.30039 .38203 L
.30131 .38238 L
.30228 .38274 L
.30321 .38309 L
.30421 .38347 L
.30517 .38383 L
.30609 .38417 L
.30707 .38454 L
.30756 .38473 L
.30801 .3849 L
.30823 .38498 L
.30845 .38506 L
.30857 .38511 L
.3086 .38512 L
.30862 .38513 L
Mistroke
.30864 .38513 L
.30865 .38512 L
.30867 .38511 L
.3087 .3851 L
.30892 .38498 L
.30991 .38446 L
.31085 .38395 L
.31177 .38347 L
.31274 .38295 L
.31367 .38246 L
.31466 .38193 L
.31562 .38142 L
.31654 .38093 L
.31752 .38042 L
.31846 .37992 L
.31937 .37944 L
.32033 .37892 L
.32126 .37843 L
.32225 .37791 L
.3232 .3774 L
.32411 .37692 L
.32509 .3764 L
.32602 .37591 L
.32702 .37538 L
.32798 .37487 L
.3289 .37438 L
.32988 .37386 L
.33083 .37336 L
.33174 .37288 L
.33271 .37237 L
.33364 .37188 L
.33463 .37135 L
.33558 .37085 L
.3365 .37036 L
.33748 .36985 L
.33842 .36935 L
.33942 .36882 L
.34038 .36831 L
.34131 .36783 L
.34229 .36731 L
.34324 .3668 L
.34416 .36632 L
.34513 .36581 L
.34606 .36532 L
.34706 .36479 L
.34801 .36429 L
.34893 .3638 L
.34991 .36329 L
.35086 .36279 L
.35177 .36231 L
Mistroke
.35273 .3618 L
.35366 .36131 L
.35465 .36079 L
.3556 .36029 L
.35652 .35981 L
.35749 .3593 L
.35843 .35881 L
.35943 .35828 L
.36039 .35778 L
.36131 .35729 L
.3623 .35677 L
.36324 .35628 L
.36416 .3558 L
.36512 .35529 L
.36606 .3548 L
.36705 .35428 L
.36801 .35378 L
.36892 .3533 L
.3699 .35279 L
.37084 .35229 L
.37185 .35177 L
.37281 .35126 L
.37374 .35078 L
.37472 .35026 L
.37567 .34977 L
.37659 .34929 L
.37756 .34878 L
.3785 .34829 L
.37949 .34777 L
.38045 .34727 L
.38137 .34679 L
.38236 .34628 L
.3833 .34578 L
.38421 .34531 L
.38518 .34481 L
.38611 .34432 L
.3871 .34381 L
.38805 .34331 L
.38897 .34283 L
.38994 .34232 L
.39088 .34184 L
.39188 .34132 L
.39284 .34082 L
.39377 .34034 L
.39475 .33982 L
.3957 .33933 L
.39661 .33886 L
.39759 .33836 L
.39852 .33787 L
.39951 .33736 L
Mistroke
.40047 .33686 L
.40139 .33638 L
.40237 .33588 L
.40331 .33539 L
.40422 .33492 L
.40518 .33442 L
.40611 .33394 L
.4071 .33343 L
.40805 .33294 L
.40897 .33247 L
.40994 .33196 L
.41088 .33148 L
.41188 .33097 L
.41284 .33047 L
.41376 .33 L
.41474 .32949 L
.41569 .32901 L
.4166 .32854 L
.41757 .32804 L
.4185 .32756 L
.41949 .32705 L
.42045 .32656 L
.42136 .32609 L
.42234 .32559 L
.42328 .32511 L
.42428 .3246 L
.42525 .3241 L
.42617 .32363 L
.42716 .32313 L
.42811 .32264 L
.42902 .32218 L
.42999 .32168 L
.43093 .3212 L
.43192 .3207 L
.43288 .32021 L
.4338 .31974 L
.43478 .31924 L
.43573 .31876 L
.43664 .3183 L
.4376 .31781 L
.43853 .31734 L
.43952 .31684 L
.44047 .31635 L
.44139 .31589 L
.44237 .3154 L
.4433 .31492 L
.4443 .31442 L
.44526 .31393 L
.44619 .31347 L
.44717 .31297 L
Mistroke
.44812 .31249 L
.44903 .31203 L
.45 .31155 L
.45093 .31108 L
.45193 .31058 L
.45288 .3101 L
.4538 .30964 L
.45478 .30915 L
.45572 .30868 L
.45663 .30822 L
.45759 .30774 L
.45852 .30728 L
.45951 .30679 L
.46046 .30631 L
.46137 .30586 L
.46235 .30537 L
.46328 .30491 L
.46428 .30442 L
.46524 .30394 L
.46616 .30348 L
.46714 .303 L
.46809 .30253 L
.469 .30208 L
.46997 .3016 L
.4709 .30114 L
.47189 .30066 L
.47284 .30019 L
.47376 .29974 L
.47474 .29926 L
.47568 .2988 L
.47668 .29831 L
.47764 .29784 L
.47857 .29739 L
.47955 .2969 L
.4805 .29644 L
.48141 .296 L
.48238 .29553 L
.48332 .29507 L
.48431 .29459 L
.48527 .29413 L
.48619 .29368 L
.48717 .29321 L
.48811 .29276 L
.48902 .29232 L
.48999 .29186 L
.49091 .29141 L
.4919 .29094 L
.49286 .29048 L
.49377 .29004 L
.49475 .28958 L
Mistroke
.49568 .28913 L
.49668 .28866 L
.49764 .2882 L
.49857 .28777 L
.49955 .2873 L
.5005 .28685 L
.50141 .28642 L
.50237 .28597 L
.50331 .28553 L
.5043 .28507 L
.50525 .28462 L
.50617 .28419 L
.50715 .28374 L
.50809 .2833 L
.50909 .28283 L
.51006 .28239 L
.51098 .28196 L
.51197 .2815 L
.51292 .28107 L
.51383 .28065 L
.51481 .2802 L
.51574 .27978 L
.51674 .27932 L
.5177 .27889 L
.51862 .27847 L
.5196 .27802 L
.52054 .2776 L
.52145 .27719 L
.52242 .27676 L
.52335 .27634 L
.52434 .2759 L
.52529 .27547 L
.52621 .27507 L
.52719 .27463 L
.52812 .27422 L
.52912 .27378 L
.53008 .27336 L
.53101 .27296 L
.53199 .27253 L
.53294 .27212 L
.53385 .27172 L
.53482 .2713 L
.53576 .2709 L
.53675 .27048 L
.53771 .27007 L
.53863 .26968 L
.53961 .26926 L
.54055 .26887 L
.54146 .26848 L
.54242 .26808 L
Mistroke
.54335 .26769 L
.54434 .26728 L
.54529 .26689 L
.5462 .26652 L
.54718 .26612 L
.54811 .26574 L
.54911 .26533 L
.55007 .26495 L
.55099 .26457 L
.55198 .26418 L
.55292 .26381 L
.55383 .26345 L
.5548 .26307 L
.55573 .2627 L
.55672 .26232 L
.55768 .26195 L
.5586 .2616 L
.55957 .26122 L
.56051 .26087 L
.56151 .26049 L
.56248 .26013 L
.5634 .25979 L
.56439 .25942 L
.56534 .25908 L
.56625 .25874 L
.56722 .25839 L
.56816 .25806 L
.56915 .2577 L
.57011 .25737 L
.57103 .25705 L
.57201 .25671 L
.57296 .25638 L
.57386 .25607 L
.57483 .25575 L
.57576 .25544 L
.57675 .25511 L
.5777 .2548 L
.57862 .2545 L
.57959 .25419 L
.58053 .25389 L
.58153 .25358 L
.58249 .25328 L
.58341 .25299 L
.5844 .2527 L
.58534 .25241 L
.58625 .25214 L
.58722 .25186 L
.58816 .25159 L
.58915 .25131 L
.59011 .25105 L
Mistroke
.59102 .25079 L
.592 .25053 L
.59295 .25028 L
.59395 .25001 L
.59491 .24977 L
.59584 .24953 L
.59682 .24928 L
.59778 .24905 L
.59869 .24883 L
.59966 .24861 L
.6006 .24839 L
.60159 .24817 L
.60255 .24796 L
.60348 .24776 L
.60446 .24755 L
.6054 .24736 L
.60631 .24718 L
.60728 .24699 L
.60821 .24681 L
.6092 .24663 L
.61015 .24646 L
.61107 .2463 L
.61205 .24614 L
.61299 .24599 L
.61399 .24583 L
.61495 .24569 L
.61587 .24555 L
.61686 .24542 L
.61781 .24529 L
.61872 .24518 L
.61969 .24506 L
.62063 .24495 L
.62162 .24485 L
.62258 .24475 L
.6235 .24466 L
.62396 .24462 L
.62448 .24457 L
.62542 .24449 L
.62588 .24446 L
.62638 .24442 L
.62686 .24438 L
.62737 .24435 L
.62787 .24432 L
.62832 .24429 L
.62882 .24426 L
.62926 .24423 L
.62972 .24421 L
.63022 .24418 L
.6307 .24416 L
.63094 .24415 L
Mistroke
.63121 .24414 L
.63167 .24412 L
.63193 .24411 L
.63217 .2441 L
.6324 .24409 L
.63263 .24409 L
.63289 .24408 L
.63313 .24407 L
.63338 .24406 L
.63364 .24406 L
.6339 .24405 L
.63413 .24404 L
.63424 .24404 L
.63436 .24404 L
.63458 .24404 L
.63472 .24403 L
.63484 .24403 L
.63496 .24403 L
.63508 .24403 L
.6352 .24402 L
.63531 .24402 L
.63543 .24402 L
.63549 .24402 L
.63555 .24402 L
.63568 .24402 L
.63575 .24402 L
.63582 .24402 L
.63594 .24402 L
.636 .24401 L
.63606 .24401 L
.63612 .24401 L
.63618 .24401 L
.63624 .24401 L
.6363 .24401 L
.63636 .24401 L
.63641 .24401 L
.63647 .24401 L
.63652 .24401 L
.63658 .24401 L
.63661 .24401 L
.63665 .24401 L
.63667 .24401 L
.6367 .24401 L
.63676 .24401 L
.63679 .24401 L
.63683 .24401 L
.63686 .24401 L
.6369 .24401 L
.63693 .24401 L
.63696 .24401 L
Mistroke
.63697 .24401 L
.63699 .24401 L
.63702 .24401 L
.63705 .24401 L
.63708 .24401 L
.63711 .24401 L
.63714 .24401 L
.63717 .24401 L
.63719 .24401 L
.63722 .24401 L
.63725 .24401 L
.63727 .24401 L
.63728 .24401 L
.6373 .24401 L
.63732 .24401 L
.63735 .24401 L
.63736 .24401 L
.63738 .24401 L
.63741 .24401 L
.63744 .24401 L
.63747 .24401 L
.6375 .24401 L
.63753 .24401 L
.63754 .24401 L
.63756 .24401 L
.63759 .24401 L
.63761 .24401 L
.63762 .24401 L
.63765 .24401 L
.63768 .24401 L
.63771 .24401 L
.63774 .24401 L
.63776 .24401 L
.63777 .24401 L
.63779 .24401 L
.63781 .24401 L
.63784 .24401 L
.63787 .24401 L
.6379 .24401 L
.63793 .24401 L
.63797 .24401 L
.638 .24401 L
.63804 .24401 L
.63806 .24401 L
.6381 .24401 L
.63813 .24401 L
.63816 .24401 L
.63819 .24401 L
.63825 .24401 L
.63831 .24401 L
Mistroke
.63834 .24401 L
.63838 .24401 L
.63844 .24401 L
.63851 .24401 L
.63857 .24401 L
.63864 .24401 L
.63871 .24401 L
.63877 .24401 L
.63888 .24402 L
.63893 .24402 L
.639 .24402 L
.63905 .24402 L
.63912 .24402 L
.63924 .24402 L
.63935 .24402 L
.63946 .24402 L
.63959 .24402 L
.6397 .24403 L
.63984 .24403 L
.63996 .24403 L
.6402 .24404 L
.64031 .24404 L
.64044 .24404 L
.64067 .24405 L
.64089 .24405 L
.64114 .24406 L
.64138 .24406 L
.64159 .24407 L
.64182 .24408 L
.64205 .24408 L
.6423 .24409 L
.64256 .2441 L
.6428 .24411 L
.64304 .24412 L
.64329 .24413 L
.64373 .24414 L
.64396 .24415 L
.6442 .24417 L
.64465 .24419 L
.64516 .24421 L
.64564 .24424 L
.64612 .24427 L
.64657 .24429 L
.64702 .24432 L
.64751 .24436 L
.64798 .24439 L
.64848 .24442 L
.64895 .24446 L
.64947 .2445 L
.65043 .24458 L
Mistroke
.6509 .24462 L
.6514 .24467 L
.6524 .24477 L
.65337 .24487 L
.65429 .24497 L
.65528 .24508 L
.65623 .2452 L
.65714 .24532 L
.65811 .24545 L
.65905 .24558 L
.66004 .24572 L
.661 .24586 L
.66192 .24601 L
.6629 .24617 L
.66385 .24633 L
.66475 .24648 L
.66572 .24666 L
.66665 .24683 L
.66764 .24702 L
.66859 .2472 L
.66951 .24739 L
.67048 .24759 L
.67142 .24778 L
.67242 .248 L
.67338 .24821 L
.67431 .24842 L
.67529 .24865 L
.67624 .24887 L
.67715 .24909 L
.67812 .24933 L
.67905 .24956 L
.68004 .24981 L
.681 .25006 L
.68192 .2503 L
.6829 .25056 L
.68384 .25082 L
.68484 .25109 L
.68581 .25136 L
.68673 .25163 L
.68772 .25191 L
.68867 .25219 L
.68959 .25246 L
.69056 .25275 L
.6915 .25304 L
.69249 .25334 L
.69345 .25364 L
.69437 .25393 L
.69536 .25424 L
.6963 .25455 L
.69721 .25484 L
Mistroke
.69818 .25516 L
.69911 .25547 L
.7001 .2558 L
.70105 .25612 L
.70197 .25643 L
.70295 .25677 L
.70389 .2571 L
.70489 .25745 L
.70585 .25778 L
.70677 .25811 L
.70776 .25847 L
.70871 .25881 L
.70962 .25914 L
.71059 .2595 L
.71153 .25984 L
.71252 .26021 L
.71348 .26057 L
.7144 .26092 L
.71538 .26129 L
.71632 .26165 L
.71723 .262 L
.71819 .26237 L
.71912 .26273 L
.72011 .26312 L
.72106 .2635 L
.72198 .26386 L
.72295 .26424 L
.72389 .26462 L
.72489 .26502 L
.72585 .26541 L
.72677 .26578 L
.72776 .26618 L
.7287 .26657 L
.72961 .26694 L
.73058 .26734 L
.73151 .26773 L
.73251 .26815 L
.73346 .26854 L
.73438 .26893 L
.73536 .26934 L
.7363 .26974 L
.7373 .27017 L
.73826 .27058 L
.73919 .27098 L
.74018 .2714 L
.74113 .27181 L
.74204 .27221 L
.74301 .27263 L
.74395 .27304 L
.74494 .27347 L
Mistroke
.7459 .27389 L
.74682 .2743 L
.7478 .27473 L
.74875 .27515 L
.74966 .27555 L
.75062 .27598 L
.75155 .2764 L
.75254 .27684 L
.7535 .27727 L
.75441 .27768 L
.75539 .27812 L
.75633 .27855 L
.75733 .279 L
.75829 .27944 L
.75921 .27986 L
.7602 .28031 L
.76115 .28074 L
.76206 .28116 L
.76303 .28161 L
.76396 .28204 L
.76495 .2825 L
.76591 .28294 L
.76683 .28337 L
.76781 .28382 L
.76875 .28426 L
.76966 .28468 L
.77062 .28514 L
.77155 .28557 L
.77254 .28603 L
.77349 .28648 L
.77441 .28691 L
.77538 .28737 L
.77632 .28782 L
.77731 .28829 L
.77827 .28874 L
.7792 .28918 L
.78018 .28965 L
.78112 .2901 L
.78203 .29054 L
.783 .291 L
.78393 .29145 L
.78492 .29192 L
.78588 .29238 L
.7868 .29282 L
.78777 .29329 L
.78871 .29375 L
.78971 .29423 L
.79068 .2947 L
.7916 .29514 L
.79259 .29562 L
Mistroke
.79354 .29608 L
.79445 .29653 L
.79542 .297 L
.79636 .29746 L
.79735 .29794 L
.79831 .29841 L
.79923 .29886 L
.80021 .29934 L
.80115 .29981 L
.80206 .30025 L
.80303 .30073 L
.80396 .30118 L
.80495 .30167 L
.8059 .30214 L
.80681 .30259 L
.80779 .30308 L
.80873 .30354 L
.80973 .30403 L
.81069 .30451 L
.81161 .30497 L
.81259 .30546 L
.81354 .30593 L
.81445 .30638 L
.81542 .30687 L
.81635 .30733 L
.81735 .30783 L
.8183 .3083 L
.81922 .30876 L
.8202 .30925 L
.82114 .30972 L
.82214 .31023 L
.82311 .31071 L
.82403 .31118 L
.82502 .31167 L
.82597 .31215 L
.82689 .31261 L
.82786 .3131 L
.82879 .31357 L
.82979 .31407 L
.83075 .31456 L
.83167 .31502 L
.83265 .31552 L
.8336 .316 L
.83451 .31646 L
.83547 .31695 L
.8364 .31742 L
.83739 .31792 L
.83835 .31841 L
.83927 .31887 L
.84024 .31937 L
Mistroke
.84118 .31985 L
.84218 .32035 L
.84314 .32084 L
.84407 .32132 L
.84505 .32182 L
.846 .3223 L
.84691 .32277 L
.84788 .32326 L
.84882 .32374 L
.84981 .32425 L
.85077 .32474 L
.85169 .32521 L
.85267 .32571 L
.85361 .3262 L
.85452 .32666 L
.85548 .32716 L
.85641 .32763 L
.8574 .32814 L
.85835 .32863 L
.85927 .3291 L
.86024 .3296 L
.86118 .33008 L
.86218 .3306 L
.86314 .33109 L
.86406 .33157 L
.86504 .33207 L
.86599 .33256 L
.8669 .33303 L
.86787 .33353 L
.8688 .33401 L
.86979 .33453 L
.87075 .33502 L
.87166 .33549 L
.87264 .336 L
.87358 .33649 L
.87458 .337 L
.87555 .3375 L
.87647 .33798 L
.87746 .3385 L
.87841 .33899 L
.87932 .33946 L
.88029 .33997 L
.88123 .34045 L
.88222 .34097 L
.88318 .34147 L
.8841 .34195 L
.88508 .34246 L
.88603 .34295 L
.88694 .34342 L
.8879 .34392 L
Mistroke
.88883 .34441 L
.88982 .34492 L
.89078 .34542 L
.89169 .3459 L
.89267 .34641 L
.89361 .3469 L
.8946 .34742 L
.89557 .34792 L
.89649 .3484 L
.89747 .34892 L
.89842 .34941 L
.89933 .34989 L
.9003 .3504 L
.90124 .35088 L
.90223 .3514 L
.90319 .3519 L
.90411 .35239 L
.90508 .3529 L
.90603 .35339 L
.90693 .35387 L
.9079 .35437 L
.90883 .35486 L
.90981 .35538 L
.91076 .35588 L
.91168 .35636 L
.91265 .35687 L
.91359 .35736 L
.91458 .35788 L
.91554 .35839 L
.91647 .35887 L
.91745 .35939 L
.91839 .35988 L
.9193 .36036 L
.92027 .36087 L
.9212 .36136 L
.92219 .36188 L
.92315 .36239 L
.92406 .36287 L
.92504 .36338 L
.92598 .36388 L
.92698 .3644 L
.92794 .36491 L
.92887 .3654 L
.92985 .36592 L
.9308 .36642 L
.93172 .3669 L
.93269 .36741 L
.93362 .36791 L
.93462 .36843 L
.93557 .36894 L
Mistroke
.93649 .36942 L
.93747 .36994 L
.93842 .37044 L
.93932 .37092 L
.94029 .37143 L
.94122 .37192 L
.94221 .37244 L
.94316 .37295 L
.94408 .37343 L
.94505 .37395 L
.94599 .37445 L
.94699 .37497 L
.94795 .37548 L
.94887 .37597 L
.94985 .37649 L
.9508 .37699 L
.95171 .37748 L
.95268 .37799 L
.95361 .37848 L
.95461 .37901 L
.95556 .37952 L
.95648 .38 L
.95746 .38052 L
.9584 .38102 L
.9594 .38155 L
.96036 .38206 L
.96129 .38256 L
.96228 .38308 L
.96323 .38358 L
.96414 .38407 L
.96511 .38459 L
.96605 .38508 L
.96704 .38561 L
.968 .38612 L
.96893 .38661 L
.96991 .38713 L
.97085 .38764 L
.97176 .38812 L
.97273 .38863 L
.97366 .38913 L
.97465 .38966 L
.9756 .39016 L
.97619 .39048 L
Mfstroke
.02381 .09445 m
.02474 .0955 L
.02575 .09666 L
.0267 .09774 L
.02761 .09878 L
.02859 .09989 L
.02952 .10095 L
.03052 .10209 L
.03148 .10318 L
.0324 .10423 L
.03338 .10534 L
.03433 .10641 L
.03524 .10744 L
.03621 .10854 L
.03714 .10959 L
.03813 .11071 L
.03908 .11179 L
.04 .11283 L
.04098 .11393 L
.04192 .11499 L
.04292 .11612 L
.04388 .1172 L
.0448 .11825 L
.04579 .11935 L
.04674 .12042 L
.04765 .12144 L
.04862 .12253 L
.04956 .12358 L
.05055 .12469 L
.05151 .12576 L
.05243 .12679 L
.05341 .12788 L
.05435 .12893 L
.05526 .12994 L
.05622 .13101 L
.05715 .13204 L
.05814 .13313 L
.05909 .13419 L
.06001 .1352 L
.06098 .13627 L
.06192 .1373 L
.06292 .13839 L
.06388 .13944 L
.0648 .14045 L
.06579 .14152 L
.06673 .14255 L
.06764 .14354 L
.06861 .14458 L
.06954 .14559 L
.07054 .14665 L
Mistroke
.07149 .14767 L
.07241 .14865 L
.07339 .14969 L
.07433 .15069 L
.07533 .15174 L
.07629 .15275 L
.07722 .15372 L
.07821 .15474 L
.07916 .15572 L
.08007 .15666 L
.08104 .15765 L
.08198 .15859 L
.08297 .15959 L
.08393 .16054 L
.08485 .16145 L
.08584 .16241 L
.08678 .16332 L
.08769 .16419 L
.08866 .1651 L
.08959 .16597 L
.09058 .16687 L
.09153 .16773 L
.09245 .16854 L
.09342 .16939 L
.09436 .17018 L
.09536 .17101 L
.09632 .17178 L
.09725 .1725 L
.09823 .17324 L
.09918 .17392 L
.10009 .17455 L
.10106 .17519 L
.10199 .17577 L
.10247 .17606 L
.10299 .17635 L
.10394 .17687 L
.10442 .17711 L
.10492 .17735 L
.10539 .17757 L
.10583 .17776 L
.10631 .17796 L
.10676 .17813 L
.10721 .1783 L
.10747 .17838 L
.10771 .17846 L
.10796 .17854 L
.1082 .17861 L
.10841 .17868 L
.10865 .17874 L
.10887 .1788 L
Mistroke
.10912 .17886 L
.10925 .17889 L
.10938 .17892 L
.10951 .17895 L
.10963 .17897 L
.10987 .17902 L
.11 .17904 L
.11014 .17907 L
.11027 .17909 L
.11039 .17911 L
.1105 .17912 L
.11062 .17914 L
.11074 .17916 L
.11085 .17917 L
.11097 .17919 L
.1111 .1792 L
.11116 .17921 L
.11123 .17922 L
.1113 .17922 L
.11136 .17923 L
.11142 .17924 L
.11149 .17924 L
.11155 .17925 L
.1116 .17925 L
.11166 .17926 L
.11172 .17926 L
.11178 .17926 L
.11185 .17927 L
.11191 .17927 L
.11196 .17928 L
.11201 .17928 L
.11207 .17928 L
.1121 .17928 L
.11213 .17928 L
.11216 .17929 L
.1122 .17929 L
.11223 .17929 L
.11227 .17929 L
.1123 .17929 L
.11233 .17929 L
.11236 .17929 L
.11239 .17929 L
.11241 .17929 L
.11242 .17929 L
.11245 .17929 L
.11248 .1793 L
.11251 .1793 L
.11254 .1793 L
.11257 .1793 L
.1126 .1793 L
Mistroke
.11263 .1793 L
.11265 .1793 L
.11266 .1793 L
.11268 .1793 L
.1127 .1793 L
.11273 .1793 L
.11275 .1793 L
.11279 .1793 L
.11282 .1793 L
.11284 .1793 L
.11287 .1793 L
.1129 .1793 L
.11292 .1793 L
.11295 .1793 L
.11298 .1793 L
.11301 .1793 L
.11304 .1793 L
.11307 .1793 L
.1131 .1793 L
.11313 .1793 L
.11316 .1793 L
.11319 .17929 L
.11321 .17929 L
.11322 .17929 L
.11325 .17929 L
.11327 .17929 L
.11328 .17929 L
.11332 .17929 L
.11335 .17929 L
.11338 .17929 L
.11342 .17929 L
.11345 .17929 L
.11348 .17929 L
.11351 .17928 L
.11354 .17928 L
.11361 .17928 L
.11364 .17928 L
.11367 .17928 L
.11373 .17927 L
.11379 .17927 L
.11386 .17926 L
.11392 .17926 L
.11399 .17925 L
.11406 .17925 L
.11411 .17924 L
.11418 .17924 L
.11429 .17923 L
.11436 .17922 L
.11442 .17922 L
.11454 .1792 L
Mistroke
.11465 .17919 L
.11477 .17917 L
.1149 .17916 L
.11502 .17914 L
.11513 .17912 L
.11524 .17911 L
.11547 .17907 L
.11558 .17905 L
.11571 .17903 L
.11593 .17899 L
.11605 .17896 L
.11616 .17894 L
.11642 .17888 L
.11666 .17882 L
.11691 .17876 L
.11712 .1787 L
.11736 .17864 L
.1176 .17856 L
.11783 .1785 L
.11809 .17841 L
.11833 .17833 L
.11879 .17816 L
.11904 .17807 L
.11929 .17797 L
.11976 .17778 L
.1202 .17759 L
.12069 .17736 L
.12114 .17715 L
.12163 .1769 L
.12209 .17666 L
.12301 .17614 L
.12396 .17558 L
.12486 .17501 L
.12583 .17436 L
.12675 .17371 L
.12774 .17299 L
.12869 .17226 L
.12961 .17154 L
.13058 .17076 L
.13152 .16998 L
.13251 .16913 L
.13347 .16829 L
.1344 .16747 L
.13538 .16658 L
.13632 .16571 L
.13723 .16486 L
.1382 .16395 L
.13913 .16306 L
.14012 .1621 L
.14108 .16116 L
Mistroke
.14199 .16025 L
.14297 .15928 L
.14391 .15834 L
.14491 .15732 L
.14587 .15634 L
.1468 .15539 L
.14778 .15437 L
.14873 .15339 L
.14965 .15243 L
.15062 .15141 L
.15155 .15043 L
.15255 .14937 L
.1535 .14836 L
.15442 .14737 L
.1554 .14632 L
.15635 .14531 L
.15726 .14433 L
.15822 .14329 L
.15915 .14228 L
.16014 .14121 L
.16109 .14017 L
.16201 .13917 L
.16298 .1381 L
.16392 .13707 L
.16492 .13598 L
.16588 .13492 L
.1668 .1339 L
.16779 .13281 L
.16873 .13176 L
.16964 .13075 L
.17061 .12968 L
.17154 .12864 L
.17254 .12753 L
.17349 .12647 L
.17441 .12544 L
.17539 .12435 L
.17633 .1233 L
.17733 .12218 L
.17829 .12109 L
.17922 .12005 L
.18021 .11894 L
.18116 .11788 L
.18207 .11685 L
.18304 .11575 L
.18398 .1147 L
.18498 .11357 L
.18593 .11249 L
.18686 .11145 L
.18784 .11034 L
.18878 .10927 L
Mistroke
.18969 .10824 L
.19066 .10714 L
.19159 .10609 L
.19258 .10497 L
.19353 .10388 L
.19445 .10284 L
.19543 .10173 L
.19637 .10066 L
.19736 .09953 L
.19833 .09843 L
.19925 .09738 L
.20024 .09626 L
.20073 .0957 L
.20118 .09518 L
.20141 .09492 L
.20162 .09468 L
.20174 .09454 L
.20177 .0945 L
.20179 .09448 L
.20181 .09447 L
.20184 .09443 L
.20185 .0944 L
.20187 .09437 L
.2021 .094 L
.20308 .09237 L
.20403 .09079 L
.20495 .08928 L
.20592 .08767 L
.20686 .08612 L
.20786 .08447 L
.20882 .08288 L
.20974 .08135 L
.21072 .07972 L
.21167 .07815 L
.21258 .07665 L
.21355 .07504 L
.21448 .0735 L
.21547 .07185 L
.21642 .07027 L
.21734 .06875 L
.21832 .06713 L
.21926 .06557 L
.22026 .06391 L
.22122 .06231 L
.22215 .06077 L
.22314 .05913 L
.22409 .05756 L
.225 .05604 L
.22597 .05443 L
.22691 .05288 L
Mistroke
.2279 .05122 L
.22886 .04963 L
.22978 .0481 L
.23076 .04647 L
.2317 .04491 L
.23218 .04412 L
.23238 .04377 L
.23261 .0434 L
.23267 .0433 L
.23273 .0432 L
.23276 .04315 L
.23279 .04311 L
.23281 .04308 L
.23284 .04307 L
.23308 .04298 L
.23358 .0428 L
.23456 .04244 L
.23551 .04209 L
.23642 .04175 L
.23739 .0414 L
.23832 .04105 L
.23932 .04069 L
.24027 .04034 L
.24119 .04 L
.24217 .03964 L
.24311 .03929 L
.24411 .03892 L
.24508 .03857 L
.246 .03822 L
.24699 .03786 L
.24794 .03751 L
.24886 .03717 L
.24983 .03681 L
.25077 .03646 L
.25176 .0361 L
.25272 .03574 L
.25364 .0354 L
.25462 .03504 L
.25557 .03469 L
.25648 .03435 L
.25745 .03399 L
.25838 .03364 L
.25937 .03328 L
.26032 .03292 L
.26124 .03258 L
.26222 .03222 L
.26316 .03187 L
.26415 .0315 L
.26512 .03114 L
.26604 .0308 L
Mistroke
.26703 .03043 L
.26798 .03008 L
.26889 .02974 L
.26986 .02938 L
.27079 .02903 L
.27179 .02866 L
.27275 .02831 L
.27367 .02796 L
.27465 .0276 L
.27559 .02725 L
.2765 .02691 L
.27746 .02655 L
.27839 .0262 L
.27938 .02583 L
.28033 .02548 L
.28125 .02513 L
.28222 .02477 L
.28316 .02442 L
.28415 .02405 L
.28512 .02369 L
.28604 .02334 L
.28702 .02298 L
.28797 .02262 L
.28888 .02228 L
.28985 .02192 L
.29078 .02157 L
.29177 .0212 L
.29273 .02084 L
.29365 .0205 L
.29462 .02013 L
.29556 .01978 L
.29656 .0194 L
.29753 .01904 L
.29846 .01869 L
.29944 .01832 L
.30039 .01797 L
.30131 .01762 L
.30228 .01726 L
.30321 .01691 L
.30421 .01653 L
.30517 .01617 L
.30609 .01583 L
.30707 .01546 L
.30756 .01527 L
.30801 .0151 L
.30823 .01502 L
.30845 .01494 L
.30857 .01489 L
.3086 .01488 L
.30862 .01487 L
Mistroke
.30864 .01487 L
.30865 .01488 L
.30867 .01489 L
.3087 .0149 L
.30892 .01502 L
.30991 .01554 L
.31085 .01605 L
.31177 .01653 L
.31274 .01705 L
.31367 .01754 L
.31466 .01807 L
.31562 .01858 L
.31654 .01907 L
.31752 .01958 L
.31846 .02008 L
.31937 .02056 L
.32033 .02108 L
.32126 .02157 L
.32225 .02209 L
.3232 .0226 L
.32411 .02308 L
.32509 .0236 L
.32602 .02409 L
.32702 .02462 L
.32798 .02513 L
.3289 .02562 L
.32988 .02614 L
.33083 .02664 L
.33174 .02712 L
.33271 .02763 L
.33364 .02812 L
.33463 .02865 L
.33558 .02915 L
.3365 .02964 L
.33748 .03015 L
.33842 .03065 L
.33942 .03118 L
.34038 .03169 L
.34131 .03217 L
.34229 .03269 L
.34324 .0332 L
.34416 .03368 L
.34513 .03419 L
.34606 .03468 L
.34706 .03521 L
.34801 .03571 L
.34893 .0362 L
.34991 .03671 L
.35086 .03721 L
.35177 .03769 L
Mistroke
.35273 .0382 L
.35366 .03869 L
.35465 .03921 L
.3556 .03971 L
.35652 .04019 L
.35749 .0407 L
.35843 .04119 L
.35943 .04172 L
.36039 .04222 L
.36131 .04271 L
.3623 .04323 L
.36324 .04372 L
.36416 .0442 L
.36512 .04471 L
.36606 .0452 L
.36705 .04572 L
.36801 .04622 L
.36892 .0467 L
.3699 .04721 L
.37084 .04771 L
.37185 .04823 L
.37281 .04874 L
.37374 .04922 L
.37472 .04974 L
.37567 .05023 L
.37659 .05071 L
.37756 .05122 L
.3785 .05171 L
.37949 .05223 L
.38045 .05273 L
.38137 .05321 L
.38236 .05372 L
.3833 .05422 L
.38421 .05469 L
.38518 .05519 L
.38611 .05568 L
.3871 .05619 L
.38805 .05669 L
.38897 .05717 L
.38994 .05768 L
.39088 .05816 L
.39188 .05868 L
.39284 .05918 L
.39377 .05966 L
.39475 .06018 L
.3957 .06067 L
.39661 .06114 L
.39759 .06164 L
.39852 .06213 L
.39951 .06264 L
Mistroke
.40047 .06314 L
.40139 .06362 L
.40237 .06412 L
.40331 .06461 L
.40422 .06508 L
.40518 .06558 L
.40611 .06606 L
.4071 .06657 L
.40805 .06706 L
.40897 .06753 L
.40994 .06804 L
.41088 .06852 L
.41188 .06903 L
.41284 .06953 L
.41376 .07 L
.41474 .07051 L
.41569 .07099 L
.4166 .07146 L
.41757 .07196 L
.4185 .07244 L
.41949 .07295 L
.42045 .07344 L
.42136 .07391 L
.42234 .07441 L
.42328 .07489 L
.42428 .0754 L
.42525 .0759 L
.42617 .07637 L
.42716 .07687 L
.42811 .07736 L
.42902 .07782 L
.42999 .07832 L
.43093 .0788 L
.43192 .0793 L
.43288 .07979 L
.4338 .08026 L
.43478 .08076 L
.43573 .08124 L
.43664 .0817 L
.4376 .08219 L
.43853 .08266 L
.43952 .08316 L
.44047 .08365 L
.44139 .08411 L
.44237 .0846 L
.4433 .08508 L
.4443 .08558 L
.44526 .08607 L
.44619 .08653 L
.44717 .08703 L
Mistroke
.44812 .08751 L
.44903 .08797 L
.45 .08845 L
.45093 .08892 L
.45193 .08942 L
.45288 .0899 L
.4538 .09036 L
.45478 .09085 L
.45572 .09132 L
.45663 .09178 L
.45759 .09226 L
.45852 .09272 L
.45951 .09321 L
.46046 .09369 L
.46137 .09414 L
.46235 .09463 L
.46328 .09509 L
.46428 .09558 L
.46524 .09606 L
.46616 .09652 L
.46714 .097 L
.46809 .09747 L
.469 .09792 L
.46997 .0984 L
.4709 .09886 L
.47189 .09934 L
.47284 .09981 L
.47376 .10026 L
.47474 .10074 L
.47568 .1012 L
.47668 .10169 L
.47764 .10216 L
.47857 .10261 L
.47955 .1031 L
.4805 .10356 L
.48141 .104 L
.48238 .10447 L
.48332 .10493 L
.48431 .10541 L
.48527 .10587 L
.48619 .10632 L
.48717 .10679 L
.48811 .10724 L
.48902 .10768 L
.48999 .10814 L
.49091 .10859 L
.4919 .10906 L
.49286 .10952 L
.49377 .10996 L
.49475 .11042 L
Mistroke
.49568 .11087 L
.49668 .11134 L
.49764 .1118 L
.49857 .11223 L
.49955 .1127 L
.5005 .11315 L
.50141 .11358 L
.50237 .11403 L
.50331 .11447 L
.5043 .11493 L
.50525 .11538 L
.50617 .11581 L
.50715 .11626 L
.50809 .1167 L
.50909 .11717 L
.51006 .11761 L
.51098 .11804 L
.51197 .1185 L
.51292 .11893 L
.51383 .11935 L
.51481 .1198 L
.51574 .12022 L
.51674 .12068 L
.5177 .12111 L
.51862 .12153 L
.5196 .12198 L
.52054 .1224 L
.52145 .12281 L
.52242 .12324 L
.52335 .12366 L
.52434 .1241 L
.52529 .12453 L
.52621 .12493 L
.52719 .12537 L
.52812 .12578 L
.52912 .12622 L
.53008 .12664 L
.53101 .12704 L
.53199 .12747 L
.53294 .12788 L
.53385 .12828 L
.53482 .1287 L
.53576 .1291 L
.53675 .12952 L
.53771 .12993 L
.53863 .13032 L
.53961 .13074 L
.54055 .13113 L
.54146 .13152 L
.54242 .13192 L
Mistroke
.54335 .13231 L
.54434 .13272 L
.54529 .13311 L
.5462 .13348 L
.54718 .13388 L
.54811 .13426 L
.54911 .13467 L
.55007 .13505 L
.55099 .13543 L
.55198 .13582 L
.55292 .13619 L
.55383 .13655 L
.5548 .13693 L
.55573 .1373 L
.55672 .13768 L
.55768 .13805 L
.5586 .1384 L
.55957 .13878 L
.56051 .13913 L
.56151 .13951 L
.56248 .13987 L
.5634 .14021 L
.56439 .14058 L
.56534 .14092 L
.56625 .14126 L
.56722 .14161 L
.56816 .14194 L
.56915 .1423 L
.57011 .14263 L
.57103 .14295 L
.57201 .14329 L
.57296 .14362 L
.57386 .14393 L
.57483 .14425 L
.57576 .14456 L
.57675 .14489 L
.5777 .1452 L
.57862 .1455 L
.57959 .14581 L
.58053 .14611 L
.58153 .14642 L
.58249 .14672 L
.58341 .14701 L
.5844 .1473 L
.58534 .14759 L
.58625 .14786 L
.58722 .14814 L
.58816 .14841 L
.58915 .14869 L
.59011 .14895 L
Mistroke
.59102 .14921 L
.592 .14947 L
.59295 .14972 L
.59395 .14999 L
.59491 .15023 L
.59584 .15047 L
.59682 .15072 L
.59778 .15095 L
.59869 .15117 L
.59966 .15139 L
.6006 .15161 L
.60159 .15183 L
.60255 .15204 L
.60348 .15224 L
.60446 .15245 L
.6054 .15264 L
.60631 .15282 L
.60728 .15301 L
.60821 .15319 L
.6092 .15337 L
.61015 .15354 L
.61107 .1537 L
.61205 .15386 L
.61299 .15401 L
.61399 .15417 L
.61495 .15431 L
.61587 .15445 L
.61686 .15458 L
.61781 .15471 L
.61872 .15482 L
.61969 .15494 L
.62063 .15505 L
.62162 .15515 L
.62258 .15525 L
.6235 .15534 L
.62396 .15538 L
.62448 .15543 L
.62542 .15551 L
.62588 .15554 L
.62638 .15558 L
.62686 .15562 L
.62737 .15565 L
.62787 .15568 L
.62832 .15571 L
.62882 .15574 L
.62926 .15577 L
.62972 .15579 L
.63022 .15582 L
.6307 .15584 L
.63094 .15585 L
Mistroke
.63121 .15586 L
.63167 .15588 L
.63193 .15589 L
.63217 .1559 L
.6324 .15591 L
.63263 .15591 L
.63289 .15592 L
.63313 .15593 L
.63338 .15594 L
.63364 .15594 L
.6339 .15595 L
.63413 .15596 L
.63424 .15596 L
.63436 .15596 L
.63458 .15596 L
.63472 .15597 L
.63484 .15597 L
.63496 .15597 L
.63508 .15597 L
.6352 .15598 L
.63531 .15598 L
.63543 .15598 L
.63549 .15598 L
.63555 .15598 L
.63568 .15598 L
.63575 .15598 L
.63582 .15598 L
.63594 .15598 L
.636 .15599 L
.63606 .15599 L
.63612 .15599 L
.63618 .15599 L
.63624 .15599 L
.6363 .15599 L
.63636 .15599 L
.63641 .15599 L
.63647 .15599 L
.63652 .15599 L
.63658 .15599 L
.63661 .15599 L
.63665 .15599 L
.63667 .15599 L
.6367 .15599 L
.63676 .15599 L
.63679 .15599 L
.63683 .15599 L
.63686 .15599 L
.6369 .15599 L
.63693 .15599 L
.63696 .15599 L
Mistroke
.63697 .15599 L
.63699 .15599 L
.63702 .15599 L
.63705 .15599 L
.63708 .15599 L
.63711 .15599 L
.63714 .15599 L
.63717 .15599 L
.63719 .15599 L
.63722 .15599 L
.63725 .15599 L
.63727 .15599 L
.63728 .15599 L
.6373 .15599 L
.63732 .15599 L
.63735 .15599 L
.63736 .15599 L
.63738 .15599 L
.63741 .15599 L
.63744 .15599 L
.63747 .15599 L
.6375 .15599 L
.63753 .15599 L
.63754 .15599 L
.63756 .15599 L
.63759 .15599 L
.63761 .15599 L
.63762 .15599 L
.63765 .15599 L
.63768 .15599 L
.63771 .15599 L
.63774 .15599 L
.63776 .15599 L
.63777 .15599 L
.63779 .15599 L
.63781 .15599 L
.63784 .15599 L
.63787 .15599 L
.6379 .15599 L
.63793 .15599 L
.63797 .15599 L
.638 .15599 L
.63804 .15599 L
.63806 .15599 L
.6381 .15599 L
.63813 .15599 L
.63816 .15599 L
.63819 .15599 L
.63825 .15599 L
.63831 .15599 L
Mistroke
.63834 .15599 L
.63838 .15599 L
.63844 .15599 L
.63851 .15599 L
.63857 .15599 L
.63864 .15599 L
.63871 .15599 L
.63877 .15599 L
.63888 .15598 L
.63893 .15598 L
.639 .15598 L
.63905 .15598 L
.63912 .15598 L
.63924 .15598 L
.63935 .15598 L
.63946 .15598 L
.63959 .15598 L
.6397 .15597 L
.63984 .15597 L
.63996 .15597 L
.6402 .15596 L
.64031 .15596 L
.64044 .15596 L
.64067 .15595 L
.64089 .15595 L
.64114 .15594 L
.64138 .15594 L
.64159 .15593 L
.64182 .15592 L
.64205 .15592 L
.6423 .15591 L
.64256 .1559 L
.6428 .15589 L
.64304 .15588 L
.64329 .15587 L
.64373 .15586 L
.64396 .15585 L
.6442 .15583 L
.64465 .15581 L
.64516 .15579 L
.64564 .15576 L
.64612 .15573 L
.64657 .15571 L
.64702 .15568 L
.64751 .15564 L
.64798 .15561 L
.64848 .15558 L
.64895 .15554 L
.64947 .1555 L
.65043 .15542 L
Mistroke
.6509 .15538 L
.6514 .15533 L
.6524 .15523 L
.65337 .15513 L
.65429 .15503 L
.65528 .15492 L
.65623 .1548 L
.65714 .15468 L
.65811 .15455 L
.65905 .15442 L
.66004 .15428 L
.661 .15414 L
.66192 .15399 L
.6629 .15383 L
.66385 .15367 L
.66475 .15352 L
.66572 .15334 L
.66665 .15317 L
.66764 .15298 L
.66859 .1528 L
.66951 .15261 L
.67048 .15241 L
.67142 .15222 L
.67242 .152 L
.67338 .15179 L
.67431 .15158 L
.67529 .15135 L
.67624 .15113 L
.67715 .15091 L
.67812 .15067 L
.67905 .15044 L
.68004 .15019 L
.681 .14994 L
.68192 .1497 L
.6829 .14944 L
.68384 .14918 L
.68484 .14891 L
.68581 .14864 L
.68673 .14837 L
.68772 .14809 L
.68867 .14781 L
.68959 .14754 L
.69056 .14725 L
.6915 .14696 L
.69249 .14666 L
.69345 .14636 L
.69437 .14607 L
.69536 .14576 L
.6963 .14545 L
.69721 .14516 L
Mistroke
.69818 .14484 L
.69911 .14453 L
.7001 .1442 L
.70105 .14388 L
.70197 .14357 L
.70295 .14323 L
.70389 .1429 L
.70489 .14255 L
.70585 .14222 L
.70677 .14189 L
.70776 .14153 L
.70871 .14119 L
.70962 .14086 L
.71059 .1405 L
.71153 .14016 L
.71252 .13979 L
.71348 .13943 L
.7144 .13908 L
.71538 .13871 L
.71632 .13835 L
.71723 .138 L
.71819 .13763 L
.71912 .13727 L
.72011 .13688 L
.72106 .1365 L
.72198 .13614 L
.72295 .13576 L
.72389 .13538 L
.72489 .13498 L
.72585 .13459 L
.72677 .13422 L
.72776 .13382 L
.7287 .13343 L
.72961 .13306 L
.73058 .13266 L
.73151 .13227 L
.73251 .13185 L
.73346 .13146 L
.73438 .13107 L
.73536 .13066 L
.7363 .13026 L
.7373 .12983 L
.73826 .12942 L
.73919 .12902 L
.74018 .1286 L
.74113 .12819 L
.74204 .12779 L
.74301 .12737 L
.74395 .12696 L
.74494 .12653 L
Mistroke
.7459 .12611 L
.74682 .1257 L
.7478 .12527 L
.74875 .12485 L
.74966 .12445 L
.75062 .12402 L
.75155 .1236 L
.75254 .12316 L
.7535 .12273 L
.75441 .12232 L
.75539 .12188 L
.75633 .12145 L
.75733 .121 L
.75829 .12056 L
.75921 .12014 L
.7602 .11969 L
.76115 .11926 L
.76206 .11884 L
.76303 .11839 L
.76396 .11796 L
.76495 .1175 L
.76591 .11706 L
.76683 .11663 L
.76781 .11618 L
.76875 .11574 L
.76966 .11532 L
.77062 .11486 L
.77155 .11443 L
.77254 .11397 L
.77349 .11352 L
.77441 .11309 L
.77538 .11263 L
.77632 .11218 L
.77731 .11171 L
.77827 .11126 L
.7792 .11082 L
.78018 .11035 L
.78112 .1099 L
.78203 .10946 L
.783 .109 L
.78393 .10855 L
.78492 .10808 L
.78588 .10762 L
.7868 .10718 L
.78777 .10671 L
.78871 .10625 L
.78971 .10577 L
.79068 .1053 L
.7916 .10486 L
.79259 .10438 L
Mistroke
.79354 .10392 L
.79445 .10347 L
.79542 .103 L
.79636 .10254 L
.79735 .10206 L
.79831 .10159 L
.79923 .10114 L
.80021 .10066 L
.80115 .10019 L
.80206 .09975 L
.80303 .09927 L
.80396 .09882 L
.80495 .09833 L
.8059 .09786 L
.80681 .09741 L
.80779 .09692 L
.80873 .09646 L
.80973 .09597 L
.81069 .09549 L
.81161 .09503 L
.81259 .09454 L
.81354 .09407 L
.81445 .09362 L
.81542 .09313 L
.81635 .09267 L
.81735 .09217 L
.8183 .0917 L
.81922 .09124 L
.8202 .09075 L
.82114 .09028 L
.82214 .08977 L
.82311 .08929 L
.82403 .08882 L
.82502 .08833 L
.82597 .08785 L
.82689 .08739 L
.82786 .0869 L
.82879 .08643 L
.82979 .08593 L
.83075 .08544 L
.83167 .08498 L
.83265 .08448 L
.8336 .084 L
.83451 .08354 L
.83547 .08305 L
.8364 .08258 L
.83739 .08208 L
.83835 .08159 L
.83927 .08113 L
.84024 .08063 L
Mistroke
.84118 .08015 L
.84218 .07965 L
.84314 .07916 L
.84407 .07868 L
.84505 .07818 L
.846 .0777 L
.84691 .07723 L
.84788 .07674 L
.84882 .07626 L
.84981 .07575 L
.85077 .07526 L
.85169 .07479 L
.85267 .07429 L
.85361 .0738 L
.85452 .07334 L
.85548 .07284 L
.85641 .07237 L
.8574 .07186 L
.85835 .07137 L
.85927 .0709 L
.86024 .0704 L
.86118 .06992 L
.86218 .0694 L
.86314 .06891 L
.86406 .06843 L
.86504 .06793 L
.86599 .06744 L
.8669 .06697 L
.86787 .06647 L
.8688 .06599 L
.86979 .06547 L
.87075 .06498 L
.87166 .06451 L
.87264 .064 L
.87358 .06351 L
.87458 .063 L
.87555 .0625 L
.87647 .06202 L
.87746 .0615 L
.87841 .06101 L
.87932 .06054 L
.88029 .06003 L
.88123 .05955 L
.88222 .05903 L
.88318 .05853 L
.8841 .05805 L
.88508 .05754 L
.88603 .05705 L
.88694 .05658 L
.8879 .05608 L
Mistroke
.88883 .05559 L
.88982 .05508 L
.89078 .05458 L
.89169 .0541 L
.89267 .05359 L
.89361 .0531 L
.8946 .05258 L
.89557 .05208 L
.89649 .0516 L
.89747 .05108 L
.89842 .05059 L
.89933 .05011 L
.9003 .0496 L
.90124 .04912 L
.90223 .0486 L
.90319 .0481 L
.90411 .04761 L
.90508 .0471 L
.90603 .04661 L
.90693 .04613 L
.9079 .04563 L
.90883 .04514 L
.90981 .04462 L
.91076 .04412 L
.91168 .04364 L
.91265 .04313 L
.91359 .04264 L
.91458 .04212 L
.91554 .04161 L
.91647 .04113 L
.91745 .04061 L
.91839 .04012 L
.9193 .03964 L
.92027 .03913 L
.9212 .03864 L
.92219 .03812 L
.92315 .03761 L
.92406 .03713 L
.92504 .03662 L
.92598 .03612 L
.92698 .0356 L
.92794 .03509 L
.92887 .0346 L
.92985 .03408 L
.9308 .03358 L
.93172 .0331 L
.93269 .03259 L
.93362 .03209 L
.93462 .03157 L
.93557 .03106 L
Mistroke
.93649 .03058 L
.93747 .03006 L
.93842 .02956 L
.93932 .02908 L
.94029 .02857 L
.94122 .02808 L
.94221 .02756 L
.94316 .02705 L
.94408 .02657 L
.94505 .02605 L
.94599 .02555 L
.94699 .02503 L
.94795 .02452 L
.94887 .02403 L
.94985 .02351 L
.9508 .02301 L
.95171 .02252 L
.95268 .02201 L
.95361 .02152 L
.95461 .02099 L
.95556 .02048 L
.95648 .02 L
.95746 .01948 L
.9584 .01898 L
.9594 .01845 L
.96036 .01794 L
.96129 .01744 L
.96228 .01692 L
.96323 .01642 L
.96414 .01593 L
.96511 .01541 L
.96605 .01492 L
.96704 .01439 L
.968 .01388 L
.96893 .01339 L
.96991 .01287 L
.97085 .01236 L
.97176 .01188 L
.97273 .01137 L
.97366 .01087 L
.97465 .01034 L
.9756 .00984 L
.97619 .00952 L
Mfstroke
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{614, 245.563},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009V0000mB000`400?l00000o`00003oo`3ooooo
0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0oooo=P3oool00`000000oooo0?ooo`0/0?ooo`<0
00003@3oool300000>l0oooo003o0?ooocH0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0>d0oooo003o0?ooocH0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0>d0oooo003o0?ooobL0oooo1@00000:
0?ooo`040000003oool00000000000@0oooo0`0000040?ooo`<000000`3oool00`000000oooo0?oo
o`0200000080oooo00@000000?ooo`3oool0oooo0`0000030?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0>d0oooo003o0?ooobP0oooo00<000000?ooo`3o
ool02`3oool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000003
0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3]0?ooo`00o`3ooolX0?ooo`030000003oool0oooo00/0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo0?oo
o`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0k@3o
ool00?l0oooo:@3oool010000000oooo0?ooo`3oool700000080oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool3000000<0oooo00@000000?ooo`3o
ool000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0>d0oooo003o0?ooobX0oooo00<0
00000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0>d0oooo003o0?ooobX0oooo00<000000?ooo`3oool02@3o
ool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3]0?ooo`00o`3ooolW0?ooo`D000002P3oool010000000oooo0000000000040?ooo`<00000103o
ool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`040000003oool0oooo0?ooo`<00000
0`3oool010000000oooo0000000000050?ooo`030000003oool0oooo0080oooo00@000000?ooo`00
000000000P3oool2000000D0oooo00<000000?ooo`3oool0k@3oool00?l0ooooCP3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0k@3oool00?l0oooo
CP3oool00`000000oooo0?ooo`0D0?ooo`<000003@3oool300000>l0oooo003o0?oood/0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooa<0oooo003o0?ooool0ooooJ03oool0
0?l0ooooo`3ooomX0?ooo`00o`3ooooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3o
oomX0?ooo`00o`3ooooo0?ooofP0oooo002C0?ooo`030000003oool0oooo04T0oooo1000001@0?oo
o`030000003oool0oooo04`0oooo1P00001<0?ooo`@00000D@3oool00`000000oooo0?ooo`0j0?oo
o`00T`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo03X0oooo002C0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo04h0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1:0?ooo`H00000
>`3oool008P0oooo1`0000040?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`1;0?ooo`040000003oool0oooo000003`0oooo002C0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo0500oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1;0?ooo`040000003o
ool0oooo000003`0oooo002C0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0B`3o
ool3000004l0oooo00<000000?ooo`000000?03oool009<0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`000000?03oool0
0940oooo00<000000?ooo`000000BP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`000000D`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
04d0oooo0P00000l0?ooo`00TP3oool2000004X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`1<0?ooo`800000CP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`800000?03oool009<0oooo
00<000000?ooo`3oool0B@3oool400000500oooo00<000000?ooo`3oool0C@3oool4000004d0oooo
1000001A0?ooo`030000003oool0oooo03X0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX
0?ooo`00o`3ooooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00o`3o
oooo0?ooofP0oooo003o0?ooool0ooooJ03oool006P0ooooo`00003>00000340oooo001X0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0_0?ooo`00
J03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
;`3oool006P0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0_0?ooo`00J03oool3
000002D0oooo00<0001o0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0
oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K1`3oool3
00000340oooo001X0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0CP3oool00`00
07l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`00
07l0oooo0?ooo`1>0?ooo`80000000<002;K0?ooo`3oool01`3oool00`000000oooo0?ooo`0_0?oo
o`00J03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3o
ool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`03
0000O`3oool0oooo04`0oooo0P000003000Rf`T0oooo00<000000?ooo`3oool0;`3oool006P0oooo
00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`1>0?ooo`030000O`3oool0oooo0140oooo
0P0000000`3j7PD0oooo0?ooo`0i0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0
C`3oool00`0007l0oooo0?ooo`1:0?ooo`<0000000@0oooo000Rf`008]/002;K2@3oool00`000000
oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo04h0oooo
00<0001o0?ooo`3oool03`3oool6000003X0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo
0?ooo`1?0?ooo`030000O`3oool0oooo04P0oooo0`0000030?ooo`<002;K2@3oool00`000000oooo
0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo04h0oooo00<0
001o0?ooo`3oool0303oool4000000040?ooo`3j7PD0nQh50?XN1@<00000>03oool00`0007l0oooo
0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0AP3oool3000000D0oooo
0`008]/90?ooo`030000003oool0oooo02l0oooo001X0?ooo`<000009@3oool00`0007l0oooo0?oo
o`1>0?ooo`030000O`3oool0oooo00X0oooo0`0000040?ooo`<0nQh50P3oool3000003H0oooo00<0
001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04@0oooo0`00
00070?ooo`<002;K1`3oool300000340oooo001A0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool0oooo1000000:0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0CP3o
ool00`0007l0oooo0?ooo`070?ooo`<000001`3oool30?XN1@@0oooo0P00000e0?ooo`030000O`3o
ool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`120?ooo`<000002@3o
ool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool00540oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool09@3oool0
0`0007l0oooo0?ooo`1>0?ooo`030000O`3oool0oooo00@0oooo0`00000:0?ooo`<0nQh51P3oool3
00000380oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0
oooo0440oooo0P00000;0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00D@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool09@3oool00`00
07l0oooo0?ooo`1>0?ooo`040000O`3oool0oooo0?ooo`@00000303oool30?XN1@P0oooo0P00000a
0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0o
0?ooo`8000003@3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool004H0oooo1`0000040?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0U0?oo
o`030000O`3oool0oooo04h0oooo00<0001o0?ooo`0000000P00000?0?ooo`<0nQh52P3oool20000
02l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo
03d0oooo0P00000?0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00D@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool4000007@0
001o0`00000B0000O`<0nQh5300007l200000?l0001o400007l200000140001o0`008]/60000O`@0
0000<@3oool00540oooo00<000000?ooo`3oool01@3oool5000000X0oooo00<000000?ooo`3oool0
9@3oool00`0007l0oooo0?ooo`1;0?ooo`<0000000<0001o0?ooo`3oool04@3oool30?XN1@h0oooo
0P00000[0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo
0?ooo`0i0?ooo`8000004`3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool00540oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02D0oooo00<0
001o0?ooo`3oool0B03oool3000000<0oooo00<0001o0?ooo`3oool04@3oool30?XN1A00oooo0P00
000Y0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?oo
o`0g0?ooo`<00000503oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool004l0oooo00<00000
0?ooo`000000203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02D0oooo00<0001o
0?ooo`3oool0A@3oool3000000H0oooo00<0001o0?ooo`3oool04@3oool30?XN1A40oooo0`00000W
0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0e
0?ooo`<000005P3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool00500oooo0P0000080?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0o0?oo
o`<0nQh5100000080?ooo`030000O`3oool0oooo0140oooo0`3j7PDD0?ooo`8000009@3oool00`00
07l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0<`3oool30000
01P0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo001A0?ooo`030000003oool0oooo00H0
oooo1@0000090?ooo`<000009@3oool00`0007l0oooo0?ooo`0o0?ooo`040?XN1@00000000000000
00/0oooo00<0001o0?ooo`3oool04@3oool30?XN1AD0oooo0`00000S0?ooo`030000O`3oool0oooo
04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0b0?ooo`8000006P3oool3000R
f`L0oooo0`00000a0?ooo`00J03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo03l0
oooo00<0nQh50000003j7PD0303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh55`3oool300000240
oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo02l0
oooo0`00000L0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo
0?ooo`0U0?ooo`030000O`3oool0oooo03l0oooo00<000000?XN1@3j7PD0303oool00`0007l0oooo
0?ooo`0A0?ooo`<0nQh56@3oool3000001l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo
0?ooo`1?0?ooo`030000O`3oool0oooo02h0oooo0P00000N0?ooo`<002;K2@3oool00`000000oooo
0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo03h0oooo0P00
00020?XN1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1A/0oooo0P00000N0?ooo`030000O`3o
ool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0/0?ooo`800000803o
ool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool006P0oooo00<000000?ooo`3oool09@3oool0
0`0007l0oooo0?ooo`0n0?ooo`040000003j7PD0nQh50?XN1@`0oooo00<0001o0?ooo`3oool04@3o
ool30?XN1Ad0oooo0P00000L0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3o
ool00`0007l0oooo0?ooo`0Z0?ooo`8000008P3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3o
ool006P0oooo0`00000U0?ooo`030000O`3oool0oooo03d0oooo00<000000?ooo`3j7PD00P3j7PD<
0?ooo`030000O`3oool0oooo0140oooo0`3j7PDO0?ooo`8000006P3oool00`0007l0oooo0?ooo`1?
0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0:03oool2000002@0oooo0`008]/7
0?ooo`<00000<@3oool006P0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0l0?oo
o`030000003oool0oooo00<0nQh5303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh58@3oool20000
01P0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo
02H0oooo0`00000U0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000
oooo0?ooo`0U0?ooo`030000O`3oool0oooo03`0oooo00<000000?ooo`3oool00`3j7PD<0?ooo`03
0000O`3oool0oooo0140oooo0`3j7PDR0?ooo`<000005P3oool00`0007l0oooo0?ooo`1?0?ooo`03
0000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0903oool2000002P0oooo0`008]/90?ooo`03
0000003oool0oooo02l0oooo001X0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0
>`3oool200000080oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDU0?ooo`800000
503oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0
8P3oool3000002T0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo001X0?ooo`030000003o
ool0oooo02D0oooo00<0001o0?ooo`3oool0>`3oool010000000oooo0?ooo`3oool30?XN1@`0oooo
00<0001o0?ooo`3oool04@3oool30?XN1BH0oooo0`00000B0?ooo`030000O`3oool0oooo04l0oooo
00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0P0?ooo`800000;03oool3000Rf`T0oooo
00<000000?ooo`3oool0;`3oool006P0oooo0`00000U0?ooo`030000O`3oool0oooo03X0oooo00<0
00000?ooo`3oool00P3oool30?XN1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1BT0oooo0P00
000@0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?oo
o`0N0?ooo`<00000;@3oool3000Rf`L0oooo0`00000a0?ooo`00J03oool00`000000oooo0?ooo`0U
0?ooo`030000O`3oool0oooo03T0oooo0P0000040?ooo`<0nQh5303oool00`0007l0oooo0?ooo`0A
0?ooo`<0nQh5:P3oool3000000h0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?
0?ooo`030000O`3oool0oooo01`0oooo0`00000_0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_
0?ooo`00J03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo03T0oooo00<000000?oo
o`3oool00`3oool30?XN1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1B`0oooo0`00000<0?oo
o`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0J0?oo
o`<00000<@3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool006P0oooo00<000000?ooo`3o
ool09@3oool00`0007l0oooo0?ooo`0h0?ooo`8000001@3oool30?XN1@`0oooo00<0001o0?ooo`3o
ool04@3oool30?XN1Bh0oooo0`00000:0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3o
ool0C`3oool00`0007l0oooo0?ooo`0H0?ooo`<00000<`3oool3000Rf`T0oooo00<000000?ooo`3o
ool0;`3oool006P0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0h0?ooo`030000
003oool0oooo00@0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PD`0?ooo`<00000
203oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0
5`3oool2000003D0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo001X0?ooo`030000003o
ool0oooo02D0oooo00<0001o0?ooo`3oool0=`3oool00`000000oooo0?ooo`050?ooo`<0nQh5303o
ool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5<P3oool3000000H0oooo00<0001o0?ooo`3oool0C`3o
ool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo01D0oooo0P00000g0?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0_0?ooo`00J03oool3000002D0oooo00<0001o0?ooo`3oool0=P3oool2
000000L0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDd0?ooo`<00000103oool0
0`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool04`3oool2
000003T0oooo0`008]/70?ooo`<00000<@3oool005`0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0U0?ooo`030000O`3oool0oooo03H0oooo00<000000?ooo`3oool01P3oool30?XN
1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1CH0oooo0P0000030?ooo`030000O`3oool0oooo
04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0A0?ooo`800000>`3oool3000R
f`T0oooo00<000000?ooo`3oool0;`3oool005`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0U0?ooo`030000O`3oool0oooo03D0oooo00<000000?ooo`3oool01`3oool30?XN1@`0
oooo00<0001o0?ooo`3oool04@3oool30?XN1CP0oooo0`0000000`0007l0oooo0?ooo`1?0?ooo`03
0000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool03`3oool2000003d0oooo0`008]/90?ooo`03
0000003oool0oooo02l0oooo001L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
9@3oool00`0007l0oooo0?ooo`0e0?ooo`030000003oool0oooo00L0oooo0`3j7PD<0?ooo`030000
O`3oool0oooo0140oooo0`3j7PDj0?ooo`800000D@3oool00`0007l0oooo0?ooo`1?0?ooo`030000
O`3oool0oooo00d0oooo0P00000o0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00D@3o
ool7000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0U0?ooo`030000O`3o
ool0oooo03@0oooo00<000000?ooo`3oool0203oool30?XN1@`0oooo00<0001o0?ooo`3oool04@3o
ool30?XN1C/0oooo00@0001o0000000000000000CP3oool00`0007l0oooo0?ooo`1?0?ooo`030000
O`3oool0oooo00/0oooo0P0000110?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00G03o
ool00`000000oooo0?ooo`090?ooo`@00000FP0007l2000000X0001o0`3j7PDP0000O`<0nQh5?P00
07l200000:X0001o0`0000130000O`<002;K1P0007l400000340oooo001L0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0c0?ooo`030000003oool0
oooo00T0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?ooo`030000O`3oool0
oooo0080oooo0`00001:0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool01`3oool2
000004D0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo001L0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01`3oool3000Rfa/0oooo00<0001o0?ooo`3oool0<@3oool00`3j
7PD000000?XN1@0;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`00
07l0oooo0?ooo`040?ooo`800000B@3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo
00D0oooo0P0000170?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00FP3oool00`000000
oooo0000000;0?ooo`030000003oool0oooo00L0oooo00<002;K000000008]/06`3oool00`0007l0
oooo0?ooo`0a0?ooo`80000000<0nQh50?ooo`3oool02@3oool30?XN1@`0oooo00<0001o0?ooo`3o
ool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool01P3oool2000004L0oooo00<0001o0?ooo`3o
ool0C`3oool00`0007l0oooo0?ooo`030?ooo`800000B@3oool3000Rf`T0oooo00<000000?ooo`3o
ool0;`3oool005/0oooo0P00000;0?ooo`030000003oool0oooo00L0oooo0P008]/00`000000oooo
0?ooo`0I0?ooo`030000O`3oool0oooo0340oooo00<000000?XN1@3j7PD02`3oool30?XN1@`0oooo
00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0203oool3000004@0oooo
00<0001o0?ooo`3oool0C`3oool0100007l0oooo0?ooo`3oool2000004/0oooo0`008]/90?ooo`03
0000003oool0oooo02l0oooo001L0?ooo`030000003oool0oooo00T0oooo0`0000070?ooo`<002;K
00<000000?ooo`3oool0603oool00`0007l0oooo0?ooo`0`0?ooo`040000003j7PD0nQh50?XN1@/0
oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?ooo`030000O`3oool0oooo00X0
oooo0P0000130?ooo`030000O`3oool0oooo04l0oooo00@0001o0?ooo`0000000000C@3oool3000R
f`L0oooo0`00000a0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<002;K00<0oooo0000003o
ool0603oool00`0007l0oooo0?ooo`0_0?ooo`030000003oool0nQh50080nQh52`3oool30?XN1@`0
oooo00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0303oool300000400
oooo00<0001o0?ooo`3oool0C`3oool2000004l0oooo0`008]/90?ooo`030000003oool0oooo02l0
oooo001X0?ooo`030000003oool0oooo00L0oooo0`008]/00`3oool000000000000H0?ooo`030000
O`3oool0oooo02h0oooo00<000000?ooo`3oool00`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo
0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`0>0?ooo`<00000?P3oool00`0007l0oooo
0?ooo`1<0?ooo`<0000000<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0
;`3oool006P0oooo00<000000?ooo`3oool01`3oool3000Rf`80oooo0P00000G0?ooo`030000O`3o
ool0oooo02d0oooo0P0000020?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool04@3o
ool30?XN1C/0oooo00<0001o0?ooo`3oool0403oool3000003`0oooo00<0001o0?ooo`3oool0B`3o
ool200000080oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3o
ool006P0oooo00<000000?ooo`3oool01`3oool3000Rf`<0oooo0P00000F0?ooo`030000O`3oool0
oooo02`0oooo0P0000030?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool04@3oool3
0?XN1C/0oooo00<0001o0?ooo`3oool04P3oool3000003X0oooo00<0001o0?ooo`3oool0B03oool3
000000@0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool0
06P0oooo0`0000070?ooo`<002;K103oool2000001D0oooo00<0001o0?ooo`3oool0:`3oool20000
00@0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`00
07l0oooo0?ooo`0D0?ooo`<00000>03oool00`0007l0oooo0?ooo`160?ooo`<000001P3oool00`00
07l0oooo0?ooo`1>0?ooo`<002;K1`3oool300000340oooo000g0?ooo`8000000P3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo00L0oooo0`008]/50?ooo`030000003oool0oooo01<0
oooo00<0001o0?ooo`3oool0:P3oool2000000D0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0
oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`0F0?ooo`<00000=P3oool00`0007l0
oooo0?ooo`140?ooo`<00000203oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000
oooo0?ooo`0_0?ooo`00=P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool01`3oool3000Rf`H0oooo00<000000?ooo`3oool04P3oool00`0007l0
oooo0?ooo`0Z0?ooo`030000003oool0oooo00@0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0
oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`0I0?ooo`800000=03oool00`0007l0
oooo0?ooo`120?ooo`<000002P3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000
oooo0?ooo`0_0?ooo`00=P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool01`3oool3000Rf`L0oooo00<000000?ooo`3oool04@3oool00`0007l0
oooo0?ooo`0Y0?ooo`030000003oool0oooo00D0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0
oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`0K0?ooo`800000<P3oool00`0007l0
oooo0?ooo`100?ooo`8000003@3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000
oooo0?ooo`0_0?ooo`00=P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool01`3oool3000Rf`P0oooo00<000000?ooo`3oool0403oool00`0007l0
oooo0?ooo`0X0?ooo`030000003oool0oooo00H0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0
oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`0M0?ooo`800000<03oool00`0007l0
oooo0?ooo`0n0?ooo`8000003`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000
oooo0?ooo`0_0?ooo`00=`3oool00`000000oooo0?ooo`02000002`0oooo0`0000070?ooo`<002;K
203oool200000140oooo00<0001o0?ooo`3oool09`3oool00`000000oooo0?ooo`070?ooo`<0nQh5
2`3oool30?XN1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0
7`3oool2000002h0oooo00<0001o0?ooo`3oool0>`3oool300000140oooo00<0001o0?ooo`3oool0
CP3oool3000Rf`L0oooo0`00000a0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<002;K2@3o
ool200000100oooo00<0001o0?ooo`3oool09P3oool2000000T0oooo0`3j7PD;0?ooo`<0nQh5303o
ool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`0Q0?ooo`<00000:`3o
ool00`0007l0oooo0?ooo`0i0?ooo`<000004`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<002;K2P3oool2
000000l0oooo00<0001o0?ooo`3oool09@3oool2000000X0oooo0`3j7PD;0?ooo`<0nQh5303oool0
0`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`0S0?ooo`<00000:@3oool0
0`0007l0oooo0?ooo`0g0?ooo`<000005@3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool0
0`000000oooo0?ooo`0_0?ooo`00=P3oool:000002P0oooo00<000000?ooo`3oool01`3oool3000R
f`/0oooo0P00000>0?ooo`030000O`3oool0oooo02@0oooo0P00000;0?ooo`<0nQh52`3oool30?XN
1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool09P3oool20000
02L0oooo00<0001o0?ooo`3oool0=@3oool3000001L0oooo00<0001o0?ooo`3oool0CP3oool3000R
f`T0oooo00<000000?ooo`3oool0;`3oool003L0oooo00D000000?ooo`3oool0oooo0000000/0?oo
o`030000003oool0oooo00L0oooo0`008]/<0?ooo`030000003oool0oooo00`0oooo00<0001o0?oo
o`3oool08`3oool2000000`0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`0A0?oo
o`<0nQh5>`3oool00`0007l0oooo0?ooo`0X0?ooo`<00000903oool00`0007l0oooo0?ooo`0c0?oo
o`8000006P3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?oo
o`00=P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02T0oooo0`0000070?ooo`<0
02;K3@3oool00`000000oooo0?ooo`0;0?ooo`030000O`3oool0oooo02<0oooo00<000000?ooo`3o
ool02`3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?ooo`03
0000O`3oool0oooo02X0oooo0`00000R0?ooo`030000O`3oool0oooo0300oooo0`00000L0?ooo`03
0000O`3oool0oooo04h0oooo0`008]/70?ooo`<00000<@3oool003H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00L0oooo0`008]/>0?ooo`030000
003oool0oooo00X0oooo00<0001o0?ooo`3oool08@3oool2000000h0oooo0`3j7PD;0?ooo`<0nQh5
303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`0]0?ooo`800000
803oool00`0007l0oooo0?ooo`0^0?ooo`8000007`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K
2@3oool00`000000oooo0?ooo`0_0?ooo`00=`3oool5000001<0oooo100000030?ooo`040000003o
ool0oooo0?ooo`@000002P3oool00`000000oooo0?ooo`070?ooo`<002;K3`3oool00`000000oooo
0?ooo`090?ooo`030000O`3oool0oooo0200oooo0P00000?0?ooo`<0nQh52`3oool30?XN1@`0oooo
00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0;`3oool3000001d0oooo
00<0001o0?ooo`3oool0:`3oool300000240oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo
00<000000?ooo`3oool0;`3oool004h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`<002;K3`3oool2000000X0oooo00<0001o0?ooo`3oool07`3oool200000100oooo0`3j
7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?oo
o`0b0?ooo`<000006P3oool00`0007l0oooo0?ooo`0X0?ooo`@000008`3oool00`0007l0oooo0?oo
o`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00CP3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`<002;K403oool2000000T0oooo00<0001o0?ooo`3oool07`3oool00`000000oooo0?ooo`0?
0?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o
0?ooo`3oool0=03oool3000001P0oooo00<0001o0?ooo`3oool09P3oool3000002H0oooo00<0001o
0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool003L0oooo1@00000:0?oo
o`L0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool3000Rfa40oooo0P0000080?ooo`030000O`3oool0oooo
01h0oooo00<000000?ooo`3oool0403oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo
0140oooo0`3j7PDk0?ooo`030000O`3oool0oooo03L0oooo0`00000E0?ooo`030000O`3oool0oooo
02<0oooo0`00000Y0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0oooo
02l0oooo000f0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`@000001P0007l3000Rfa<0001o00<000000000O`0007l09@0007l00`000000
001o0000O`0A0000O`<0nQh52`0007l30?XN1B00001o0`3j7PEh0000O`@00000=00007l3000007d0
001o0`008]/60000O`@00000<@3oool003H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool5000000X0oooo
00<000000?ooo`3oool01`3oool3000Rfa<0oooo0P0000060?ooo`030000O`3oool0oooo01`0oooo
00<000000?ooo`3oool04P3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo
0`3j7PDk0?ooo`030000O`3oool0oooo03d0oooo1000000>0?ooo`030000O`3oool0oooo01d0oooo
0`00000_0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo
000f0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`070?ooo`<002;K503oool2000000D0oooo00<0001o0?ooo`3oool06`3oool2000001@0oooo0`3j
7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?oo
o`100?ooo`@000002`3oool00`0007l0oooo0?ooo`0I0?ooo`@00000<P3oool00`0007l0oooo0?oo
o`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00=`3oool500000180oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01`3oool3000RfaD0oooo0P0000040?ooo`030000O`3oool0oooo01X0oooo0P00000E
0?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o
0?ooo`3oool0A03oool4000000L0oooo00<0001o0?ooo`3oool05@3oool4000003H0oooo00<0001o
0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool004h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool3000RfaH0oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?ooo`0I0?oo
o`8000005P3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?oo
o`030000O`3oool0oooo04P0oooo1P0000000`3oool0001o0?ooo`0@0?ooo`H00000>P3oool00`00
07l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00=P3oool00`000000
oooo0?ooo`0F0?ooo`@000001`3oool5000000T0oooo0`0000070?ooo`<002;K5`3oool200000080
oooo00<0001o0?ooo`3oool0603oool00`000000oooo0?ooo`0F0?ooo`<0nQh52`3oool30?XN1@`0
oooo00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0CP3ooolD000003l0
oooo00<0001o0?ooo`3oool0CP3oool3000Rf`L0oooo0`00000a0?ooo`00=03oool9000002/0oooo
00<000000?ooo`3oool01`3oool3000RfaP0oooo0P0000000`3oool0001o0?ooo`0H0?ooo`800000
603oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K
2@3oool00`000000oooo0?ooo`0_0?ooo`00=P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool01`3oool3000RfaT0oooo0P0000000`0007l0oooo0?oo
o`0F0?ooo`8000006@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j
7PDk0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?oo
o`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`07
0?ooo`<002;K6P3oool00`000000001o0?ooo`0F0?ooo`8000006P3oool30?XN1@/0oooo0`3j7PD<
0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?ooo`030000O`3oool0oooo04l0oooo00<0001o
0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_
0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<002;K6`3oool2000001D0oooo0P00000K0?oo
o`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o0?oo
o`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?oo
o`030000003oool0oooo02l0oooo001X0?ooo`<000001`3oool3000Rfa/0oooo00<0001o00000000
00004`3oool2000001`0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`0A0?ooo`<0
nQh5>`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3o
ool0CP3oool3000Rf`L0oooo0`00000a0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<002;K
6`3oool0100007l0oooo00000000000A0?ooo`030000003oool0oooo01`0oooo0`3j7PD;0?ooo`<0
nQh5303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`1?0?ooo`03
0000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3o
ool0;`3oool006P0oooo00<000000?ooo`3oool01`3oool3000Rfa/0oooo00<0001o0?ooo`3oool0
0P00000?0?ooo`030000003oool0oooo01d0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo
0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo
00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool003L0oooo0P00
00020?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool01`3oool3000Rfa/0oooo00<0
001o0?ooo`3oool00P3oool2000000/0oooo0P00000P0?ooo`<0nQh52`3oool30?XN1@`0oooo00<0
001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?oo
o`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo000f
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`070?ooo`<002;K6`3oool00`0007l0oooo0?ooo`030?ooo`8000002@3oool200000240oooo0`3j
7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?oo
o`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<0
00000?ooo`3oool0;`3oool003H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0Y0?ooo`<000001`3oool3000Rfa/0oooo00<0001o0?ooo`3oool0103oool4000000<0oooo0`00
000S0?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0
001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`00
8]/70?ooo`<00000<@3oool003H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo00L0oooo0`008]/K0?ooo`030000O`3oool0oooo00L0oooo1@00
000U0?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0
001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`00
8]/90?ooo`030000003oool0oooo02l0oooo000g0?ooo`030000003oool0oooo00800000;03oool0
0`000000oooo0?ooo`070?ooo`<002;K6`3oool00`0007l0oooo0?ooo`0a0?ooo`<0nQh52`3oool3
0?XN1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0C`3oool0
0`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0
oooo02l0oooo001X0?ooo`030000003oool0oooo00L0oooo0`008]/K0?ooo`030000O`3oool0oooo
0340oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`00
07l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000R
f`T0oooo00<000000?ooo`3oool0;`3oool006P0oooo00<000000?ooo`3oool01`3oool3000Rfa/0
oooo00<0001o0?ooo`3oool0<@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140
oooo0`3j7PDk0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0
oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00<`3oool00`000000oooo
0?ooo`07000002/0oooo0`0000070?ooo`<002;K6`3oool00`0007l0oooo0?ooo`0a0?ooo`<0nQh5
2`3oool30?XN1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0
C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/70?ooo`<00000
<@3oool006P0oooo00<000000?ooo`3oool01`3oool3000Rfa/0oooo00<0001o0?ooo`3oool0<@3o
ool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?ooo`030000O`3o
ool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0_0?ooo`00FP3oool4000000X0oooo00<000000?ooo`3oool01`3oool3
000Rfa/0oooo00<0001o0?ooo`3oool0<@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0
oooo0140oooo0`3j7PDk0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool0
0`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00=P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0`008]/K0?ooo`030000O`3oool0oooo
0340oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`00
07l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000R
f`T0oooo00<000000?ooo`3oool0;`3oool003H0oooo00@000000?ooo`3oool0oooo0`00000L0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`<002;K6`3oool00`0007l0oooo0?ooo`0a0?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?oo
o`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?oo
o`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo000f0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00L0oooo100000060000O`<002;KC`0007l30?XN1@/0001o0`3j7PDP0000
O`<0nQh5o`0007la0000O`<002;K1P0007l400000340oooo000f0?ooo`<000000`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`<002;K6`3oool00`0007l0oooo0?ooo`0a0?ooo`<0nQh52`3oool30?XN1@`0
oooo00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0
oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0oooo02l0
oooo000f0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool3000Rfa/0oooo
00<0001o0?ooo`3oool0<@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo
0`3j7PDk0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo
0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00F@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool3000Rfa/0oooo00<0
001o0?ooo`3oool0<@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j
7PDk0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?oo
o`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00F@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool3000Rfa/0oooo00<0001o
0?ooo`3oool0<@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk
0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00=`3oool5000001d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0`008]/K0?oo
o`030000O`3oool0oooo0340oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`0A0?oo
o`<0nQh5>`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?oo
o`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool003H0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0K0?ooo`@000002P3oool3000000L0oooo0`008]/K0?oo
o`030000O`3oool0oooo0340oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`0A0?oo
o`<0nQh5>`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?oo
o`3oool0CP3oool3000Rf`L0oooo0`00000a0?ooo`00=P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool3000Rfa/0oooo00<0001o0?oo
o`3oool0<@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?oo
o`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?oo
o`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00=P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool3000Rfa/0oooo00<0001o0?oo
o`3oool0<@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?oo
o`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?oo
o`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00=`3oool3000000030?ooo`000000oooo02/0
oooo00<000000?ooo`3oool01`3oool3000Rfa/0oooo00<0001o0?ooo`3oool0<@3oool30?XN1@/0
oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?ooo`030000O`3oool0oooo04l0
oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000
oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<002;K6`3oool00`0007l0oooo
0?ooo`060?ooo`L00000903oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo
0`3j7PDk0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo
0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00J03oool3000000L0oooo0`00
8]/K0?ooo`030000O`3oool0oooo00@0oooo0`0000050?ooo`<000008P3oool30?XN1@/0oooo0`3j
7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?ooo`030000O`3oool0oooo04l0oooo00<0
001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K1`3oool300000340oooo001X
0?ooo`030000003oool0oooo00L0oooo0`008]/K0?ooo`030000O`3oool0oooo00<0oooo0P000009
0?ooo`8000008@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk
0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`070?oo
o`<002;K6`3oool0100007l0oooo0?ooo`3oool2000000d0oooo0P00000O0?ooo`<0nQh52`3oool3
0?XN1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0C`3oool0
0`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0
oooo02l0oooo000d0?ooo``00000:03oool00`000000oooo0?ooo`070?ooo`<002;K6`3oool00`00
07l0oooo0?ooo`02000000l0oooo00<000000?ooo`3oool07@3oool30?XN1@/0oooo0`3j7PD<0?oo
o`030000O`3oool0oooo0140oooo0`3j7PDk0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?oo
o`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?oo
o`00=03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool01`3oool3000Rfa/0oooo00<0001o0?ooo`0000004P3oool2000001d0oooo0`3j7PD;0?ooo`<0
nQh5303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`1?0?ooo`03
0000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3o
ool0;`3oool003@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0V0?ooo`<00000
1`3oool3000Rfa/0oooo00<0001o0000000000004`3oool2000001`0oooo0`3j7PD;0?ooo`<0nQh5
303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`1?0?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`L0oooo0`00000a0?ooo`00J03o
ool00`000000oooo0?ooo`070?ooo`<002;K6`3oool00`000000oooo0?ooo`0D0?ooo`8000006`3o
ool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?ooo`030000O`3o
ool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<002;K6P3oool0
0`000000001o0?ooo`0F0?ooo`8000006P3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0
oooo0140oooo0`3j7PDk0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool0
0`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00=P3oool70000
02/0oooo00<000000?ooo`3oool01`3oool3000RfaT0oooo0P0000000`0007l0oooo0?ooo`0F0?oo
o`8000006@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?oo
o`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?oo
o`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00=`3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo00L0oooo0`008]/H0?ooo`040000003oool0oooo0000OaT0oooo0P00000H0?oo
o`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o0?oo
o`3oool0C`3oool00`0007l0oooo0?ooo`040?ooo`@00000A`3oool00`0007l0oooo0?ooo`1>0?oo
o`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00=P3oool00`000000oooo0?ooo`0_0?ooo`<0
00001`3oool3000RfaL0oooo00D000000?ooo`3oool0oooo0000O`0J0?ooo`8000005`3oool30?XN
1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?ooo`030000O`3oool0oooo
04`0oooo5`00000n0?ooo`030000O`3oool0oooo04h0oooo0`008]/70?ooo`<00000<@3oool003H0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`070?ooo`<002;K5P3oool00`000000
oooo0?ooo`020?ooo`030000O`3oool0oooo01T0oooo0P00000F0?ooo`<0nQh52`3oool30?XN1@`0
oooo00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0A`3oool600000080
oooo00<0001o0?ooo`3oool0403oool6000003T0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0
oooo00<000000?ooo`3oool0;`3oool003L0oooo1P00000B0?ooo`@000000`3oool010000000oooo
0?ooo`3oool4000000X0oooo00<000000?ooo`3oool01`3oool3000RfaD0oooo0P0000040?ooo`03
0000O`3oool0oooo01X0oooo0P00000E0?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3o
ool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0@`3oool5000000L0oooo00<0001o0?ooo`3o
ool05P3oool4000003D0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3o
ool0;`3oool003H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo0`008]/D0?ooo`8000001@3oool00`0007l0oooo0?ooo`0K0?ooo`800000
503oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?ooo`030000
O`3oool0oooo0400oooo1000000;0?ooo`030000O`3oool0oooo01X0oooo1000000a0?ooo`030000
O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo000f0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool3000Rfa<0oooo00<000000?ooo`3oool01@3o
ool00`0007l0oooo0?ooo`0L0?ooo`030000003oool0oooo0180oooo0`3j7PD;0?ooo`<0nQh5303o
ool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`0l0?ooo`@000003`3o
ool00`0007l0oooo0?ooo`0M0?ooo`@00000;P3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3o
ool00`000000oooo0?ooo`0_0?ooo`00=P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`@000001P0007l3
000Rfa80001o0P00000W0000O`8000004P0007l30?XN1@/0001o0`3j7PDP0000O`<0nQh5M`0007l4
000003H0001o0`00001l0000O`<002;K1P0007l400000340oooo000g0?ooo`H000004@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0`008]/A0?ooo`800000203oool00`00
07l0oooo0?ooo`0N0?ooo`8000004@3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo
0140oooo0`3j7PDk0?ooo`030000O`3oool0oooo03H0oooo1000000E0?ooo`030000O`3oool0oooo
02<0oooo1000000X0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0oooo
02l0oooo001>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool5000000X0
oooo00<000000?ooo`3oool01`3oool3000Rfa00oooo0P0000090?ooo`030000O`3oool0oooo01l0
oooo00<000000?ooo`3oool03`3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140
oooo0`3j7PDk0?ooo`030000O`3oool0oooo03@0oooo0`00000H0?ooo`030000O`3oool0oooo02H0
oooo0`00000V0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0oooo02l0
oooo001>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00L0oooo0`008]/?0?ooo`8000002P3oool00`0007l0oooo
0?ooo`0P0?ooo`030000003oool0oooo00h0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo
0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`0a0?ooo`<000006`3oool00`0007l0oooo
0?ooo`0Y0?ooo`<000008`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo
0?ooo`0_0?ooo`00=P3oool700000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool3000Rf`l0oooo00<0
00000?ooo`3oool02@3oool00`0007l0oooo0?ooo`0Q0?ooo`030000003oool0oooo00d0oooo0`3j
7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?oo
o`0^0?ooo`@000007@3oool00`0007l0oooo0?ooo`0/0?ooo`<00000803oool00`0007l0oooo0?oo
o`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00=`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;
0?ooo`<000001`3oool3000Rf`h0oooo00<000000?ooo`3oool02P3oool00`0007l0oooo0?ooo`0R
0?ooo`030000003oool0oooo00`0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`0A
0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`0/0?ooo`<00000803oool00`0007l0oooo0?ooo`0^
0?ooo`<000007P3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K1`3oool300000340oooo000f0?oo
o`030000003oool0oooo01H0oooo100000070?ooo`D000002@3oool00`000000oooo0?ooo`070?oo
o`<002;K3@3oool00`000000oooo0?ooo`0;0?ooo`030000O`3oool0oooo02<0oooo00<000000?oo
o`3oool02`3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?oo
o`030000O`3oool0oooo02X0oooo0`00000R0?ooo`030000O`3oool0oooo0300oooo1000000K0?oo
o`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo000f0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool01`3oool3000Rf``0oooo00<000000?ooo`3o
ool0303oool00`0007l0oooo0?ooo`0S0?ooo`800000303oool30?XN1@/0oooo0`3j7PD<0?ooo`03
0000O`3oool0oooo0140oooo0`3j7PDk0?ooo`030000O`3oool0oooo02L0oooo0`00000U0?ooo`03
0000O`3oool0oooo03<0oooo0`00000I0?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`03
0000003oool0oooo02l0oooo000g0?ooo`H00000:`3oool00`000000oooo0?ooo`070?ooo`<002;K
2`3oool2000000h0oooo00<0001o0?ooo`3oool0903oool2000000/0oooo0`3j7PD;0?ooo`<0nQh5
303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`0U0?ooo`<00000
9`3oool00`0007l0oooo0?ooo`0e0?ooo`<000005`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K
2@3oool00`000000oooo0?ooo`0_0?ooo`00=P3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo00L0oooo0`008]/:0?ooo`8000003`3oool00`0007l0oooo0?ooo`0U0?ooo`8000002P3o
ool30?XN1@/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?ooo`030000O`3o
ool0oooo02<0oooo0`00000Y0?ooo`030000O`3oool0oooo03L0oooo0`00000E0?ooo`030000O`3o
ool0oooo04h0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo000f0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool01`3oool3000Rf`T0oooo0P00000@0?ooo`030000O`3oool0
oooo02H0oooo0P0000090?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool04@3oool3
0?XN1C/0oooo00<0001o0?ooo`3oool0803oool4000002/0oooo00<0001o0?ooo`3oool0>P3oool2
000001<0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool0
03H0oooo00<000000?ooo`3oool0;`3oool3000000L0oooo0`008]/80?ooo`8000004@3oool00`00
07l0oooo0?ooo`0W0?ooo`030000003oool0oooo00L0oooo0`3j7PD;0?ooo`<0nQh5303oool00`00
07l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`0N0?ooo`<00000;P3oool00`00
07l0oooo0?ooo`0l0?ooo`<00000403oool00`0007l0oooo0?ooo`1>0?ooo`<002;K1`3oool30000
0340oooo000g0?ooo`H00000:`3oool00`000000oooo0?ooo`070?ooo`<002;K1`3oool200000180
oooo00<0001o0?ooo`3oool0:03oool00`000000oooo0?ooo`060?ooo`<0nQh52`3oool30?XN1@`0
oooo00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0703oool300000300
oooo00<0001o0?ooo`3oool0?P3oool3000000h0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0
oooo00<000000?ooo`3oool0;`3oool006P0oooo00<000000?ooo`3oool01`3oool3000Rf`H0oooo
0P00000C0?ooo`030000O`3oool0oooo02T0oooo00<000000?ooo`3oool01@3oool30?XN1@/0oooo
0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?ooo`030000O`3oool0oooo01X0oooo
0`00000b0?ooo`030000O`3oool0oooo0400oooo0`00000<0?ooo`030000O`3oool0oooo04h0oooo
0`008]/90?ooo`030000003oool0oooo02l0oooo000d0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`070?ooo`<002;K1@3oool2000001@0oooo00<0
001o0?ooo`3oool0:P3oool00`000000oooo0?ooo`040?ooo`<0nQh52`3oool30?XN1@`0oooo00<0
001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0603oool3000003@0oooo00<0
001o0?ooo`3oool0@P3oool3000000X0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<0
00000?ooo`3oool0;`3oool003@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00L0oooo0`008]/50?ooo`030000003oool0oooo01<0oooo00<0001o
0?ooo`3oool0:P3oool2000000D0oooo0`3j7PD;0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`0A
0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`0F0?ooo`<00000=P3oool00`0007l0oooo0?ooo`15
0?ooo`800000203oool00`0007l0oooo0?ooo`1>0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_
0?ooo`00=03oool<000002P0oooo0`0000070?ooo`<002;K103oool00`000000oooo0?ooo`0D0?oo
o`030000O`3oool0oooo02/0oooo0P0000040?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?oo
o`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0503oool2000003T0oooo00<0001o0?oo
o`3oool0A`3oool2000000H0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`L0oooo0`00000a0?oo
o`00J03oool00`000000oooo0?ooo`070?ooo`<002;K0`3oool00`000000oooo0?ooo`0E0?ooo`03
0000O`3oool0oooo02`0oooo0P0000030?ooo`<0nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3o
ool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool04P3oool2000003/0oooo00<0001o0?ooo`3o
ool0B@3oool2000000@0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3o
ool0;`3oool006P0oooo00<000000?ooo`3oool01`3oool3000Rf`80oooo00<000000?ooo`3oool0
5P3oool00`0007l0oooo0?ooo`0]0?ooo`8000000P3oool30?XN1@/0oooo0`3j7PD<0?ooo`030000
O`3oool0oooo0140oooo0`3j7PDk0?ooo`030000O`3oool0oooo0100oooo0P00000m0?ooo`030000
O`3oool0oooo04/0oooo0P0000020?ooo`030000O`3oool0oooo04h0oooo0`008]/90?ooo`030000
003oool0oooo02l0oooo001X0?ooo`030000003oool0oooo00L0oooo0`008]/00`3oool000000?oo
o`0H0?ooo`030000O`3oool0oooo02h0oooo00<000000?ooo`3oool00`3j7PD;0?ooo`<0nQh5303o
ool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool00`0007l0oooo0?ooo`0>0?ooo`800000?`3o
ool00`0007l0oooo0?ooo`1=0?ooo`<00000D03oool3000Rf`T0oooo00<000000?ooo`3oool0;`3o
ool006P0oooo00<000000?ooo`3oool01`3oool3000Rf`8000006@3oool00`0007l0oooo0?ooo`0_
0?ooo`030000003oool0nQh50080nQh52`3oool30?XN1@`0oooo00<0001o0?ooo`3oool04@3oool3
0?XN1C/0oooo00<0001o0?ooo`3oool02`3oool300000440oooo00<0001o0?ooo`3oool0C`3oool2
000004l0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo001X0?ooo`<000001`3oool2000R
f`8000006P3oool00`0007l0oooo0?ooo`0`0?ooo`040000003j7PD0nQh50?XN1@/0oooo0`3j7PD<
0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?ooo`030000O`3oool0oooo00X0oooo0P000013
0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`0000000P00001<0?ooo`<002;K1`3oool3
00000340oooo001X0?ooo`030000003oool0oooo00L0oooo00<002;K0000000000006`3oool00`00
07l0oooo0?ooo`0a0?ooo`030000003j7PD0nQh500/0oooo0`3j7PD<0?ooo`030000O`3oool0oooo
0140oooo0`3j7PDk0?ooo`030000O`3oool0oooo00L0oooo0`0000150?ooo`030000O`3oool0oooo
04l0oooo00@0001o0?ooo`3oool0oooo0`00001:0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_
0?ooo`00G03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<002;K0000
00008]/06`3oool00`0007l0oooo0?ooo`0a0?ooo`80000000<0nQh50?ooo`3oool02@3oool30?XN
1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool01P3oool20000
04L0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`030?ooo`<00000B03oool3000R
f`T0oooo00<000000?ooo`3oool0;`3oool005`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`070?ooo`<002;K6`3oool00`0007l0oooo0?ooo`0a0?ooo`030?XN1@000000nQh500/0
oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?ooo`030000O`3oool0oooo00@0
oooo0P0000190?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool01@3oool3000004H0
oooo0`008]/90?ooo`030000003oool0oooo02l0oooo001L0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0c0?ooo`030000003oool0oooo00T0oooo
0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDk0?ooo`040000O`3oool0oooo0?ooo`<0
0000B`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo00L0oooo0P0000150?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0_0?ooo`00G03oool00`000000oooo0?ooo`090?ooo`@00000
F`0007l00`000000001o0000O`080000O`<0nQh5800007l30?XN1Ch0001o0P00002[0000O`<00000
@P0007l3000Rf`H0001o1000000a0?ooo`00G03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo02D0oooo00<0001o0?ooo`3oool0=03oool00`000000oooo0?ooo`080?ooo`<0nQh5303o
ool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5>`3oool3000004l0oooo00<0001o0?ooo`3oool0C`3o
ool00`0007l0oooo0?ooo`0;0?ooo`800000@@3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3o
ool005`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0
oooo03D0oooo00<000000?ooo`3oool01`3oool30?XN1@`0oooo00<0001o0?ooo`3oool04@3oool3
0?XN1CX0oooo0P00001A0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool03@3oool3
000003h0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo001L0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0e0?ooo`030000003oool0oooo
00L0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDg0?ooo`<0000000<0oooo0000
O`3oool0D03oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo00l0oooo0P00000m0?oo
o`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00FP3oool00`000000oooo0000000;0?ooo`03
0000003oool0oooo02D0oooo00<0001o0?ooo`3oool0=P3oool00`000000oooo0?ooo`060?ooo`<0
nQh5303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5=P3oool2000000<0oooo00<0001o0?ooo`3o
ool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo0140oooo0`00000j0?ooo`<0
02;K2@3oool00`000000oooo0?ooo`0_0?ooo`00F`3oool2000000/0oooo0`00000U0?ooo`030000
O`3oool0oooo03L0oooo00<000000?ooo`3oool01@3oool30?XN1@`0oooo00<0001o0?ooo`3oool0
4@3oool30?XN1C@0oooo0P0000050?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0
C`3oool00`0007l0oooo0?ooo`0C0?ooo`800000>@3oool3000Rf`L0oooo0`00000a0?ooo`00G03o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0=`3o
ool00`000000oooo0?ooo`050?ooo`<0nQh5303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5<P3o
ool2000000L0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3o
ool0oooo01D0oooo0`00000f0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00J03oool0
0`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo03P0oooo00<000000?ooo`3oool0103oool3
0?XN1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1C00oooo0P0000090?ooo`030000O`3oool0
oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0G0?ooo`800000=@3oool3
000Rf`T0oooo00<000000?ooo`3oool0;`3oool006P0oooo00<000000?ooo`3oool09@3oool00`00
07l0oooo0?ooo`0i0?ooo`030000003oool0oooo00<0oooo0`3j7PD<0?ooo`030000O`3oool0oooo
0140oooo0`3j7PD^0?ooo`<000002P3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo
04l0oooo00<0001o0?ooo`3oool06@3oool2000003<0oooo0`008]/90?ooo`030000003oool0oooo
02l0oooo001X0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0>@3oool00`000000
oooo0?ooo`030?ooo`<0nQh5303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5;03oool2000000d0
oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo01/0
oooo0P00000a0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00J03oool3000002D0oooo
00<0001o0?ooo`3oool0>@3oool2000000@0oooo0`3j7PD<0?ooo`030000O`3oool0oooo0140oooo
0`3j7PDZ0?ooo`<000003P3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo
00<0001o0?ooo`3oool07@3oool2000002l0oooo0`008]/70?ooo`<00000<@3oool006P0oooo00<0
00000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo0080oooo0`3j
7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDX0?ooo`8000004@3oool00`0007l0oooo0?oo
o`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool07`3oool2000002d0oooo0`00
8]/90?ooo`030000003oool0oooo02l0oooo001X0?ooo`030000003oool0oooo02D0oooo00<0001o
0?ooo`3oool0>`3oool010000000oooo0?ooo`3oool30?XN1@`0oooo00<0001o0?ooo`3oool04@3o
ool30?XN1BH0oooo0`00000B0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3o
ool00`0007l0oooo0?ooo`0Q0?ooo`800000:`3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3o
ool006P0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0l0?ooo`030000003oool0
oooo00<0nQh5303oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh5903oool3000001@0oooo00<0001o
0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo0280oooo0`00000Y
0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`0U0?oo
o`030000O`3oool0oooo03`0oooo00<000000?ooo`3oool00`3j7PD<0?ooo`030000O`3oool0oooo
0140oooo0`3j7PDR0?ooo`<000005P3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo
04l0oooo00<0001o0?ooo`3oool09@3oool2000002L0oooo0`008]/90?ooo`030000003oool0oooo
02l0oooo001X0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0?03oool200000004
0?ooo`3j7PD0nQh50?XN1@`0oooo00<0001o0?ooo`3oool04@3oool30?XN1B00oooo0`00000H0?oo
o`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0V0?oo
o`<000009@3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool006P0oooo0`00000U0?ooo`03
0000O`3oool0oooo03d0oooo00<000000?ooo`3j7PD00P3j7PD<0?ooo`030000O`3oool0oooo0140
oooo0`3j7PDN0?ooo`<000006P3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0
oooo00<0001o0?ooo`3oool0:03oool3000002<0oooo0`008]/70?ooo`<00000<@3oool006P0oooo
00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0n0?ooo`040000003j7PD0nQh50?XN1@`0
oooo00<0001o0?ooo`3oool04@3oool30?XN1Ad0oooo0P00000L0?ooo`030000O`3oool0oooo04l0
oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0Z0?ooo`<000008@3oool3000Rf`T0
oooo00<000000?ooo`3oool0;`3oool006P0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo
0?ooo`0n0?ooo`8000000P3j7PD<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDK0?ooo`800000
7P3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0
;03oool3000001l0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo001X0?ooo`030000003o
ool0oooo02D0oooo00<0001o0?ooo`3oool0?`3oool00`000000nQh50?XN1@0<0?ooo`030000O`3o
ool0oooo0140oooo0`3j7PDI0?ooo`800000803oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3o
ool0oooo04l0oooo00<0001o0?ooo`3oool0;P3oool2000001h0oooo0`008]/90?ooo`030000003o
ool0oooo02l0oooo001X0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0?`3oool0
0`3j7PD000000?XN1@0<0?ooo`030000O`3oool0oooo0140oooo0`3j7PDG0?ooo`8000008P3oool0
0`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0<03oool2
000001`0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo001X0?ooo`<000009@3oool00`00
07l0oooo0?ooo`0o0?ooo`030?XN1@0000000000008000002P3oool00`0007l0oooo0?ooo`0A0?oo
o`<0nQh55@3oool2000002@0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?oo
o`030000O`3oool0oooo0380oooo0P00000J0?ooo`<002;K1`3oool300000340oooo001X0?ooo`03
0000003oool0oooo02D0oooo00<0001o0?ooo`3oool0?`3oool30?XN1@040?ooo`00000000000000
00P0oooo00<0001o0?ooo`3oool04@3oool30?XN1A<0oooo0P00000V0?ooo`030000O`3oool0oooo
04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0d0?ooo`800000603oool3000R
f`T0oooo00<000000?ooo`3oool0;`3oool00540oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`3oool4000000X0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`160?oo
o`<000001@3oool00`0007l0oooo0?ooo`0A0?ooo`<0nQh54@3oool3000002L0oooo00<0001o0?oo
o`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo03H0oooo0P00000F0?oo
o`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00D@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0U0?ooo`03
0000O`3oool0oooo04P0oooo100000020?ooo`030000O`3oool0oooo0140oooo0`3j7PD?0?ooo`80
0000:P3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3o
ool0=`3oool3000001@0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo001A0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0U0?ooo`030000
O`3oool0oooo04/0oooo0`0000000`0007l0oooo0?ooo`0A0?ooo`<0nQh53@3oool3000002/0oooo
00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo03X0oooo
0P00000B0?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00D@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00L0oooo1000001e0000O`<000004@0007l30?XN1@`0001o0P00
003o0000Oa00001o0`00000@0000O`<002;K1P0007l400000340oooo001A0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo02D0oooo00<0001o0?ooo`3oool0CP3oool00`0007l0oooo00000002000000l0oooo0`3j7PD9
0?ooo`<00000;`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o
0?ooo`3oool0?@3oool3000000h0oooo0`008]/90?ooo`030000003oool0oooo02l0oooo001A0?oo
o`030000003oool0oooo00D0oooo1@00000:0?ooo`030000003oool0oooo02D0oooo00<0001o0?oo
o`3oool0CP3oool00`0007l0oooo0?ooo`020?ooo`<00000303oool30?XN1@P0oooo0P00000a0?oo
o`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0o0?oo
o`<00000303oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool00540oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3o
ool0CP3oool00`0007l0oooo0?ooo`050?ooo`<000002@3oool30?XN1@H0oooo0P00000c0?ooo`03
0000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`110?ooo`80
00002`3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool004l0oooo00<000000?ooo`000000
203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02D0oooo00<0001o0?ooo`3oool0
CP3oool00`0007l0oooo0?ooo`080?ooo`<000001P3oool30?XN1@@0oooo0P00000e0?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`130?ooo`800000
2@3oool3000Rf`T0oooo00<000000?ooo`3oool0;`3oool00500oooo0P0000080?ooo`030000003o
ool0oooo00/0oooo0`00000U0?ooo`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool02P3o
ool3000000@0oooo0`3j7PD20?ooo`800000=`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3o
ool0oooo04l0oooo00<0001o0?ooo`3oool0A@3oool2000000L0oooo0`008]/70?ooo`<00000<@3o
ool00540oooo00<000000?ooo`3oool01P3oool5000000T0oooo00<000000?ooo`3oool09@3oool0
0`0007l0oooo0?ooo`1>0?ooo`030000O`3oool0oooo00d0oooo0`000000103oool0nQh50?XN1@3j
7PD3000003P0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3o
ool0oooo04L0oooo0P0000050?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00J03oool0
0`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool03`3oool6
000003X0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0
oooo04P0oooo0`0000030?ooo`<002;K2@3oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`00
0000oooo0?ooo`0U0?ooo`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool04@3oool00`3j
7PD000000?XN1@0k0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`00
07l0oooo0?ooo`1:0?ooo`<0000000@0oooo000Rf`008]/002;K2@3oool00`000000oooo0?ooo`0_
0?ooo`00J03oool00`000000oooo0?ooo`0U0?ooo`030000O`3oool0oooo04h0oooo00<0001o0?oo
o`3oool04@3oool30?XN1C/0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1?0?oo
o`030000O`3oool0oooo04`0oooo0`000002000Rf`T0oooo00<000000?ooo`3oool0;`3oool006P0
oooo0`00000U0?ooo`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0
oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool200000003
000Rf`3oool0oooo00D0oooo0`00000a0?ooo`00J03oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo04h0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool0CP3oool3000Rf`T0oooo00<000000?ooo`3oool0
;`3oool006P0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0_0?ooo`00J03oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0;`3oool0
06P0ooooo`00003>00000340oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00o`3o
oooo0?ooofP0oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00o`3ooooo0?ooofP0
oooo003o0?ooool0ooooJ03oool00?l0ooooo`3ooomX0?ooo`00o`3ooooo0?ooofP0oooo003o0?oo
ool0ooooJ03oool00?l0oooo:`3oool6000000@0oooo0`0000040?ooo`80000000D0oooo0000003o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo0`0000030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool0oooo0`00003f0?ooo`00o`3oool[0?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`8000000P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?oo
o`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00D000000?ooo`3oool0oooo0000003e0?ooo`00o`3oool[0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000001P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0?L0oooo003o0?ooob/0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05000000<0oooo100000020?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool500000?D0oooo003o0?ooob/0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000
0`3oool01@000000oooo0?ooo`3oool0000000D0oooo1P0000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`3oool0oooo0000003e0?ooo`00o`3oool[0?ooo`H000000`3oool01@000000oooo0?oo
o`3oool000000080oooo00D000000?ooo`3oool0oooo000000020?ooo`8000000P3oool200000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
00000P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo0?<0oooo003o0?ooob/0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`3oool3000000@0oooo0`0000030?ooo`040000003o
ool0000000000080oooo0P0000060?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool0
00000?ooo`0000020?ooo`<000000P3oool3000000050?ooo`000000oooo0?ooo`0000000`3oool3
00000?H0oooo003o0?ooob/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0?X0oooo003o0?ooob/0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0?X0oooo003o0?ooob/0oooo1P00000O0?ooo`H00000
3`3oool300000080oooo00<000000?ooo`3oool0nP3oool00?l0ooooo`3ooomX0?ooo`00o`3ooooo
0?ooofP0oooo0000\
\>"],
  ImageRangeCache->{{{57.1875, 547.375}, {651.688, 456.25}} -> {-3.63839, \
8.51755, 0.0122326, 0.0193591}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Probe Beam Port Beam Profile with Mode Matching", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TelescopePlot[{zETM, 4.0}, {CavityWaist, 
          zCavityWaist}, {{ITMFocalLength, zITM}, {fLXY, zLXY}, {fL3, 
            zL3}, {fL4, zL4}, {fL5, zL5}}, kk];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.26413 0.178015 0.2 0.112854 [
[.08611 -0.0125 -10.0938 -16.375 ]
[.08611 -0.0125 10.0938 0 ]
[.26413 -0.0125 -5.59375 -16.375 ]
[.26413 -0.0125 5.59375 0 ]
[.44215 -0.0125 -5.59375 -16.375 ]
[.44215 -0.0125 5.59375 0 ]
[.62016 -0.0125 -5.59375 -16.375 ]
[.62016 -0.0125 5.59375 0 ]
[.79818 -0.0125 -5.59375 -16.375 ]
[.79818 -0.0125 5.59375 0 ]
[.97619 -0.0125 -5.59375 -16.375 ]
[.97619 -0.0125 5.59375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -43.1563 -32.75 ]
[.5 -0.0125 43.1563 -16.375 ]
[-0.0125 .03072 -30.9375 -8.1875 ]
[-0.0125 .03072 0 8.1875 ]
[-0.0125 .08715 -20.1875 -8.1875 ]
[-0.0125 .08715 0 8.1875 ]
[-0.0125 .14357 -30.9375 -8.1875 ]
[-0.0125 .14357 0 8.1875 ]
[-0.0125 .2 -11.1875 -8.1875 ]
[-0.0125 .2 0 8.1875 ]
[-0.0125 .25643 -21.9375 -8.1875 ]
[-0.0125 .25643 0 8.1875 ]
[-0.0125 .31285 -11.1875 -8.1875 ]
[-0.0125 .31285 0 8.1875 ]
[-0.0125 .36928 -21.9375 -8.1875 ]
[-0.0125 .36928 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .2 -47.3125 -44.3438 ]
[-0.01875 .2 -30.9375 44.3438 ]
[ 0 .4 .125 0 ]
[.5 .4125 -39 0 ]
[.5 .4125 39 16.375 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.08611 0 m
.08611 .4 L
s
.26413 0 m
.26413 .4 L
s
.44215 0 m
.44215 .4 L
s
.62016 0 m
.62016 .4 L
s
.79818 0 m
.79818 .4 L
s
0 .03072 m
1 .03072 L
s
0 .08715 m
1 .08715 L
s
0 .14357 m
1 .14357 L
s
0 .2 m
1 .2 L
s
0 .25643 m
1 .25643 L
s
0 .31285 m
1 .31285 L
s
0 .36928 m
1 .36928 L
s
0 g
.08611 0 m
.08611 .00625 L
s
gsave
.08611 -0.0125 -71.0938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.26413 0 m
.26413 .00625 L
s
gsave
.26413 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.44215 0 m
.44215 .00625 L
s
gsave
.44215 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.62016 0 m
.62016 .00625 L
s
gsave
.62016 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.79818 0 m
.79818 .00625 L
s
gsave
.79818 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.12172 0 m
.12172 .00375 L
s
.15732 0 m
.15732 .00375 L
s
.19292 0 m
.19292 .00375 L
s
.22853 0 m
.22853 .00375 L
s
.29973 0 m
.29973 .00375 L
s
.33534 0 m
.33534 .00375 L
s
.37094 0 m
.37094 .00375 L
s
.40654 0 m
.40654 .00375 L
s
.47775 0 m
.47775 .00375 L
s
.51335 0 m
.51335 .00375 L
s
.54895 0 m
.54895 .00375 L
s
.58456 0 m
.58456 .00375 L
s
.65576 0 m
.65576 .00375 L
s
.69137 0 m
.69137 .00375 L
s
.72697 0 m
.72697 .00375 L
s
.76257 0 m
.76257 .00375 L
s
.83378 0 m
.83378 .00375 L
s
.86938 0 m
.86938 .00375 L
s
.90498 0 m
.90498 .00375 L
s
.94059 0 m
.94059 .00375 L
s
.05051 0 m
.05051 .00375 L
s
.01491 0 m
.01491 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -104.156 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.438 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
77.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(position) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
125.875 16.625 moveto
(@) show
130.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
141.000 16.625 moveto
(D) show
145.313 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03072 m
.00625 .03072 L
s
gsave
-0.0125 .03072 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .08715 m
.00625 .08715 L
s
gsave
-0.0125 .08715 -81.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .14357 m
.00625 .14357 L
s
gsave
-0.0125 .14357 -91.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
gsave
-0.0125 .2 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .25643 m
.00625 .25643 L
s
gsave
-0.0125 .25643 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .31285 m
.00625 .31285 L
s
gsave
-0.0125 .31285 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .36928 m
.00625 .36928 L
s
gsave
-0.0125 .36928 -82.9375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .042 m
.00375 .042 L
s
0 .05329 m
.00375 .05329 L
s
0 .06457 m
.00375 .06457 L
s
0 .07586 m
.00375 .07586 L
s
0 .09843 m
.00375 .09843 L
s
0 .10972 m
.00375 .10972 L
s
0 .121 m
.00375 .121 L
s
0 .13229 m
.00375 .13229 L
s
0 .15486 m
.00375 .15486 L
s
0 .16614 m
.00375 .16614 L
s
0 .17743 m
.00375 .17743 L
s
0 .18871 m
.00375 .18871 L
s
0 .21129 m
.00375 .21129 L
s
0 .22257 m
.00375 .22257 L
s
0 .23386 m
.00375 .23386 L
s
0 .24514 m
.00375 .24514 L
s
0 .26771 m
.00375 .26771 L
s
0 .279 m
.00375 .279 L
s
0 .29028 m
.00375 .29028 L
s
0 .30157 m
.00375 .30157 L
s
0 .32414 m
.00375 .32414 L
s
0 .33543 m
.00375 .33543 L
s
0 .34671 m
.00375 .34671 L
s
0 .358 m
.00375 .358 L
s
0 .01943 m
.00375 .01943 L
s
0 .00815 m
.00375 .00815 L
s
0 .38057 m
.00375 .38057 L
s
0 .39185 m
.00375 .39185 L
s
.25 Mabswid
0 0 m
0 .4 L
s
gsave
-0.01875 .2 -144.469 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
105.344 12.1875 translate
90 rotate
-105.344 -12.1875 translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(spot) show
90.938 16.625 moveto
(size) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.438 16.625 moveto
(@) show
121.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Mathematica2
%%IncludeFont: Mathematica2
/Mathematica2 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
143.375 16.625 moveto
(D) show
147.688 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08611 .39375 m
.08611 .4 L
s
.26413 .39375 m
.26413 .4 L
s
.44215 .39375 m
.44215 .4 L
s
.62016 .39375 m
.62016 .4 L
s
.79818 .39375 m
.79818 .4 L
s
.97619 .39375 m
.97619 .4 L
s
.125 Mabswid
.12172 .39625 m
.12172 .4 L
s
.15732 .39625 m
.15732 .4 L
s
.19292 .39625 m
.19292 .4 L
s
.22853 .39625 m
.22853 .4 L
s
.29973 .39625 m
.29973 .4 L
s
.33534 .39625 m
.33534 .4 L
s
.37094 .39625 m
.37094 .4 L
s
.40654 .39625 m
.40654 .4 L
s
.47775 .39625 m
.47775 .4 L
s
.51335 .39625 m
.51335 .4 L
s
.54895 .39625 m
.54895 .4 L
s
.58456 .39625 m
.58456 .4 L
s
.65576 .39625 m
.65576 .4 L
s
.69137 .39625 m
.69137 .4 L
s
.72697 .39625 m
.72697 .4 L
s
.76257 .39625 m
.76257 .4 L
s
.83378 .39625 m
.83378 .4 L
s
.86938 .39625 m
.86938 .4 L
s
.90498 .39625 m
.90498 .4 L
s
.94059 .39625 m
.94059 .4 L
s
.05051 .39625 m
.05051 .4 L
s
.01491 .39625 m
.01491 .4 L
s
.25 Mabswid
0 .4 m
1 .4 L
s
gsave
.5 .4125 -100 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 24.375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
100.375 16.625 moveto
(Profile) show
137.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99375 .03072 m
1 .03072 L
s
.99375 .08715 m
1 .08715 L
s
.99375 .14357 m
1 .14357 L
s
.99375 .2 m
1 .2 L
s
.99375 .25643 m
1 .25643 L
s
.99375 .31285 m
1 .31285 L
s
.99375 .36928 m
1 .36928 L
s
.125 Mabswid
.99625 .042 m
1 .042 L
s
.99625 .05329 m
1 .05329 L
s
.99625 .06457 m
1 .06457 L
s
.99625 .07586 m
1 .07586 L
s
.99625 .09843 m
1 .09843 L
s
.99625 .10972 m
1 .10972 L
s
.99625 .121 m
1 .121 L
s
.99625 .13229 m
1 .13229 L
s
.99625 .15486 m
1 .15486 L
s
.99625 .16614 m
1 .16614 L
s
.99625 .17743 m
1 .17743 L
s
.99625 .18871 m
1 .18871 L
s
.99625 .21129 m
1 .21129 L
s
.99625 .22257 m
1 .22257 L
s
.99625 .23386 m
1 .23386 L
s
.99625 .24514 m
1 .24514 L
s
.99625 .26771 m
1 .26771 L
s
.99625 .279 m
1 .279 L
s
.99625 .29028 m
1 .29028 L
s
.99625 .30157 m
1 .30157 L
s
.99625 .32414 m
1 .32414 L
s
.99625 .33543 m
1 .33543 L
s
.99625 .34671 m
1 .34671 L
s
.99625 .358 m
1 .358 L
s
.99625 .01943 m
1 .01943 L
s
.99625 .00815 m
1 .00815 L
s
.99625 .38057 m
1 .38057 L
s
.99625 .39185 m
1 .39185 L
s
.25 Mabswid
1 0 m
1 .4 L
s
.977 .121 .023 r
.0075 w
.20182 .0941 m
.20182 .3059 L
s
.2328 .04257 m
.2328 .35743 L
s
.29083 .02096 m
.29083 .37904 L
s
.49395 .09366 m
.49395 .30634 L
s
.51584 .1199 m
.51584 .2801 L
s
0 .133 .859 r
.02381 .0941 m
.02381 .3059 L
s
.97619 .00952 m
.97619 .39048 L
s
0 g
.5 Mabswid
.02381 .3059 m
.02474 .30484 L
.02575 .30368 L
.0267 .3026 L
.02761 .30155 L
.02859 .30044 L
.02952 .29937 L
.03052 .29824 L
.03148 .29714 L
.0324 .29609 L
.03338 .29497 L
.03433 .2939 L
.03524 .29286 L
.03621 .29176 L
.03714 .2907 L
.03813 .28958 L
.03908 .2885 L
.04 .28746 L
.04098 .28635 L
.04192 .28529 L
.04292 .28416 L
.04388 .28307 L
.0448 .28202 L
.04579 .28091 L
.04674 .27984 L
.04765 .27882 L
.04862 .27772 L
.04956 .27667 L
.05055 .27556 L
.05151 .27448 L
.05243 .27345 L
.05341 .27236 L
.05435 .2713 L
.05526 .27029 L
.05622 .26922 L
.05715 .26818 L
.05814 .26709 L
.05909 .26603 L
.06001 .26502 L
.06098 .26394 L
.06192 .26291 L
.06292 .26181 L
.06388 .26076 L
.0648 .25974 L
.06579 .25867 L
.06673 .25764 L
.06764 .25665 L
.06861 .2556 L
.06954 .25459 L
.07054 .25352 L
Mistroke
.07149 .2525 L
.07241 .25151 L
.07339 .25047 L
.07433 .24947 L
.07533 .24842 L
.07629 .2474 L
.07722 .24643 L
.07821 .24541 L
.07916 .24442 L
.08007 .24349 L
.08104 .24249 L
.08198 .24154 L
.08297 .24054 L
.08393 .23959 L
.08485 .23867 L
.08584 .23771 L
.08678 .2368 L
.08769 .23593 L
.08866 .23501 L
.08959 .23415 L
.09058 .23324 L
.09153 .23238 L
.09245 .23156 L
.09342 .23072 L
.09436 .22992 L
.09536 .22909 L
.09632 .22832 L
.09725 .22759 L
.09823 .22685 L
.09918 .22616 L
.10009 .22553 L
.10106 .22489 L
.10199 .22431 L
.10247 .22402 L
.10299 .22373 L
.10394 .22321 L
.10442 .22296 L
.10492 .22272 L
.10539 .2225 L
.10583 .22231 L
.10631 .22211 L
.10676 .22194 L
.10721 .22177 L
.10747 .22169 L
.10771 .22161 L
.10796 .22153 L
.1082 .22146 L
.10841 .2214 L
.10865 .22133 L
.10887 .22127 L
Mistroke
.10912 .22121 L
.10925 .22118 L
.10938 .22115 L
.10951 .22112 L
.10963 .2211 L
.10987 .22105 L
.11 .22103 L
.11014 .221 L
.11027 .22098 L
.11039 .22096 L
.1105 .22094 L
.11062 .22093 L
.11074 .22091 L
.11085 .2209 L
.11097 .22088 L
.1111 .22087 L
.11116 .22086 L
.11123 .22085 L
.1113 .22084 L
.11136 .22084 L
.11142 .22083 L
.11149 .22083 L
.11155 .22082 L
.1116 .22082 L
.11166 .22081 L
.11172 .22081 L
.11178 .2208 L
.11185 .2208 L
.11191 .2208 L
.11196 .22079 L
.11201 .22079 L
.11207 .22079 L
.1121 .22079 L
.11213 .22078 L
.11216 .22078 L
.1122 .22078 L
.11223 .22078 L
.11227 .22078 L
.1123 .22078 L
.11233 .22078 L
.11236 .22078 L
.11239 .22077 L
.11241 .22077 L
.11242 .22077 L
.11245 .22077 L
.11248 .22077 L
.11251 .22077 L
.11254 .22077 L
.11257 .22077 L
.1126 .22077 L
Mistroke
.11263 .22077 L
.11265 .22077 L
.11266 .22077 L
.11268 .22077 L
.1127 .22077 L
.11273 .22077 L
.11275 .22077 L
.11279 .22077 L
.11282 .22077 L
.11284 .22077 L
.11287 .22077 L
.1129 .22077 L
.11292 .22077 L
.11295 .22077 L
.11298 .22077 L
.11301 .22077 L
.11304 .22077 L
.11307 .22077 L
.1131 .22077 L
.11313 .22077 L
.11316 .22077 L
.11319 .22077 L
.11321 .22077 L
.11322 .22077 L
.11325 .22078 L
.11327 .22078 L
.11328 .22078 L
.11332 .22078 L
.11335 .22078 L
.11338 .22078 L
.11342 .22078 L
.11345 .22078 L
.11348 .22078 L
.11351 .22078 L
.11354 .22079 L
.11361 .22079 L
.11364 .22079 L
.11367 .22079 L
.11373 .2208 L
.11379 .2208 L
.11386 .2208 L
.11392 .22081 L
.11399 .22081 L
.11406 .22082 L
.11411 .22082 L
.11418 .22083 L
.11429 .22084 L
.11436 .22085 L
.11442 .22085 L
.11454 .22087 L
Mistroke
.11465 .22088 L
.11477 .22089 L
.1149 .22091 L
.11502 .22093 L
.11513 .22094 L
.11524 .22096 L
.11547 .221 L
.11558 .22102 L
.11571 .22104 L
.11593 .22108 L
.11605 .22111 L
.11616 .22113 L
.11642 .22119 L
.11666 .22125 L
.11691 .22131 L
.11712 .22137 L
.11736 .22143 L
.1176 .22151 L
.11783 .22158 L
.11809 .22166 L
.11833 .22174 L
.11879 .22191 L
.11904 .222 L
.11929 .2221 L
.11976 .22229 L
.1202 .22249 L
.12069 .22271 L
.12114 .22293 L
.12163 .22318 L
.12209 .22342 L
.12301 .22393 L
.12396 .2245 L
.12486 .22508 L
.12583 .22572 L
.12675 .22638 L
.12774 .2271 L
.12869 .22783 L
.12961 .22855 L
.13058 .22934 L
.13152 .23012 L
.13251 .23097 L
.13347 .23181 L
.1344 .23264 L
.13538 .23353 L
.13632 .2344 L
.13723 .23525 L
.1382 .23617 L
.13913 .23707 L
.14012 .23803 L
.14108 .23897 L
Mistroke
.14199 .23988 L
.14297 .24085 L
.14391 .2418 L
.14491 .24282 L
.14587 .2438 L
.1468 .24476 L
.14778 .24578 L
.14873 .24677 L
.14965 .24772 L
.15062 .24875 L
.15155 .24974 L
.15255 .25079 L
.1535 .25181 L
.15442 .2528 L
.1554 .25385 L
.15635 .25487 L
.15726 .25585 L
.15822 .2569 L
.15915 .25791 L
.16014 .25899 L
.16109 .26003 L
.16201 .26103 L
.16298 .2621 L
.16392 .26314 L
.16492 .26423 L
.16588 .2653 L
.1668 .26632 L
.16779 .26741 L
.16873 .26846 L
.16964 .26947 L
.17061 .27055 L
.17154 .2716 L
.17254 .2727 L
.17349 .27377 L
.17441 .2748 L
.17539 .2759 L
.17633 .27696 L
.17733 .27808 L
.17829 .27917 L
.17922 .28021 L
.18021 .28132 L
.18116 .28239 L
.18207 .28343 L
.18304 .28453 L
.18398 .28558 L
.18498 .28671 L
.18593 .2878 L
.18686 .28884 L
.18784 .28996 L
.18878 .29103 L
Mistroke
.18969 .29206 L
.19066 .29316 L
.19159 .29422 L
.19258 .29535 L
.19353 .29643 L
.19445 .29748 L
.19543 .29859 L
.19637 .29966 L
.19736 .3008 L
.19833 .3019 L
.19925 .30296 L
.20024 .30408 L
.20073 .30464 L
.20118 .30517 L
.20141 .30543 L
.20162 .30567 L
.20174 .30581 L
.20177 .30584 L
.20179 .30586 L
.20181 .30588 L
.20184 .30592 L
.20185 .30595 L
.20187 .30598 L
.2021 .30635 L
.20308 .30799 L
.20403 .30957 L
.20495 .31109 L
.20592 .3127 L
.20686 .31426 L
.20786 .31591 L
.20882 .31751 L
.20974 .31904 L
.21072 .32068 L
.21167 .32225 L
.21258 .32376 L
.21355 .32537 L
.21448 .32692 L
.21547 .32857 L
.21642 .33016 L
.21734 .33169 L
.21832 .33331 L
.21926 .33488 L
.22026 .33654 L
.22122 .33815 L
.22215 .33969 L
.22314 .34133 L
.22409 .34291 L
.225 .34443 L
.22597 .34605 L
.22691 .34761 L
Mistroke
.2279 .34927 L
.22886 .35086 L
.22978 .3524 L
.23076 .35403 L
.2317 .35561 L
.23218 .35639 L
.23238 .35674 L
.23261 .35712 L
.23267 .35721 L
.23273 .35731 L
.23276 .35736 L
.23279 .35741 L
.23281 .35744 L
.23284 .35745 L
.23308 .35753 L
.23358 .35772 L
.23456 .35808 L
.23551 .35843 L
.23642 .35877 L
.23739 .35912 L
.23832 .35947 L
.23932 .35984 L
.24027 .36019 L
.24119 .36053 L
.24217 .36089 L
.24311 .36124 L
.24411 .36161 L
.24508 .36197 L
.246 .36231 L
.24699 .36268 L
.24794 .36303 L
.24886 .36337 L
.24983 .36373 L
.25077 .36408 L
.25176 .36444 L
.25272 .3648 L
.25364 .36514 L
.25462 .36551 L
.25557 .36586 L
.25648 .3662 L
.25745 .36656 L
.25838 .3669 L
.25937 .36727 L
.26032 .36763 L
.26124 .36797 L
.26222 .36833 L
.26316 .36868 L
.26415 .36905 L
.26512 .36941 L
.26604 .36976 L
Mistroke
.26703 .37013 L
.26798 .37048 L
.26889 .37082 L
.26986 .37118 L
.27079 .37153 L
.27179 .3719 L
.27275 .37226 L
.27367 .3726 L
.27465 .37297 L
.27559 .37332 L
.2765 .37366 L
.27746 .37402 L
.27839 .37437 L
.27938 .37474 L
.28033 .3751 L
.28125 .37544 L
.28222 .37581 L
.28316 .37616 L
.28415 .37653 L
.28512 .37689 L
.28604 .37724 L
.28702 .37761 L
.28797 .37796 L
.28888 .3783 L
.28985 .37867 L
.29029 .37884 L
.29053 .37892 L
.29066 .37897 L
.29072 .379 L
.29078 .37902 L
.29081 .37903 L
.29083 .37904 L
.29085 .37903 L
.29087 .37903 L
.29088 .37902 L
.29092 .37901 L
.29104 .37896 L
.29129 .37887 L
.29177 .37868 L
.29277 .37831 L
.29373 .37795 L
.29465 .37761 L
.29563 .37724 L
.29657 .37688 L
.29748 .37654 L
.29845 .37618 L
.29938 .37583 L
.30037 .37546 L
.30132 .3751 L
.30224 .37476 L
Mistroke
.30321 .37439 L
.30415 .37404 L
.30515 .37367 L
.30611 .37331 L
.30704 .37296 L
.30802 .3726 L
.30897 .37224 L
.30988 .3719 L
.31085 .37154 L
.31178 .37119 L
.31278 .37082 L
.31373 .37046 L
.31465 .37012 L
.31563 .36975 L
.31657 .3694 L
.31748 .36906 L
.31845 .36871 L
.31937 .36836 L
.32036 .36799 L
.32131 .36764 L
.32223 .3673 L
.3232 .36693 L
.32414 .36659 L
.32513 .36622 L
.32609 .36586 L
.32702 .36552 L
.328 .36515 L
.32895 .3648 L
.32985 .36446 L
.33082 .3641 L
.33175 .36376 L
.33275 .36339 L
.3337 .36304 L
.33462 .3627 L
.33559 .36233 L
.33653 .36199 L
.33753 .36162 L
.3385 .36126 L
.33942 .36092 L
.34041 .36055 L
.34136 .3602 L
.34227 .35986 L
.34324 .35951 L
.34418 .35916 L
.34517 .35879 L
.34613 .35844 L
.34705 .3581 L
.34803 .35774 L
.34897 .35739 L
.34988 .35706 L
Mistroke
.35085 .3567 L
.35178 .35636 L
.35277 .356 L
.35372 .35565 L
.35463 .35531 L
.35561 .35495 L
.35655 .35461 L
.35754 .35424 L
.35851 .35389 L
.35943 .35355 L
.36041 .35319 L
.36136 .35284 L
.36227 .35251 L
.36324 .35215 L
.36417 .35181 L
.36517 .35145 L
.36612 .3511 L
.36704 .35076 L
.36802 .3504 L
.36896 .35006 L
.36996 .34969 L
.37092 .34934 L
.37185 .349 L
.37284 .34864 L
.37379 .3483 L
.3747 .34796 L
.37568 .34761 L
.37661 .34727 L
.37761 .34691 L
.37857 .34656 L
.37949 .34622 L
.38047 .34587 L
.38142 .34552 L
.38232 .34519 L
.38329 .34484 L
.38422 .34451 L
.38521 .34415 L
.38617 .3438 L
.38708 .34347 L
.38806 .34312 L
.389 .34278 L
.39 .34242 L
.39096 .34207 L
.39189 .34174 L
.39287 .34138 L
.39382 .34104 L
.39473 .34071 L
.3957 .34036 L
.39663 .34002 L
.39763 .33967 L
Mistroke
.39858 .33932 L
.39951 .33899 L
.40048 .33864 L
.40143 .3383 L
.40233 .33798 L
.4033 .33763 L
.40423 .3373 L
.40522 .33694 L
.40617 .3366 L
.40708 .33628 L
.40806 .33593 L
.40899 .33559 L
.40999 .33524 L
.41095 .33489 L
.41188 .33456 L
.41286 .33421 L
.4138 .33388 L
.41471 .33355 L
.41568 .33321 L
.41661 .33288 L
.41761 .33253 L
.41856 .33219 L
.41948 .33186 L
.42046 .33151 L
.4214 .33118 L
.4224 .33083 L
.42336 .33049 L
.42429 .33016 L
.42527 .32981 L
.42622 .32948 L
.42714 .32915 L
.42811 .32881 L
.42904 .32848 L
.43004 .32813 L
.431 .3278 L
.43192 .32747 L
.4329 .32713 L
.43384 .3268 L
.43475 .32648 L
.43572 .32614 L
.43665 .32581 L
.43764 .32547 L
.43859 .32514 L
.43951 .32482 L
.44048 .32448 L
.44142 .32415 L
.44242 .3238 L
.44338 .32347 L
.4443 .32314 L
.44529 .3228 L
Mistroke
.44624 .32247 L
.44715 .32216 L
.44812 .32182 L
.44905 .3215 L
.45004 .32116 L
.451 .32083 L
.45192 .32051 L
.4529 .32017 L
.45384 .31985 L
.45474 .31953 L
.45571 .3192 L
.45664 .31888 L
.45762 .31855 L
.45858 .31822 L
.45949 .31791 L
.46046 .31757 L
.4614 .31725 L
.4624 .31691 L
.46336 .31659 L
.46428 .31627 L
.46526 .31594 L
.46621 .31561 L
.46711 .31531 L
.46808 .31498 L
.46901 .31466 L
.47 .31433 L
.47096 .314 L
.47188 .31369 L
.47285 .31336 L
.47379 .31305 L
.47479 .31271 L
.47575 .31239 L
.47668 .31208 L
.47767 .31175 L
.47861 .31143 L
.47953 .31112 L
.4805 .3108 L
.48143 .31049 L
.48243 .31015 L
.48338 .30984 L
.4843 .30953 L
.48528 .3092 L
.48623 .30889 L
.48713 .30859 L
.4881 .30827 L
.48903 .30796 L
.49002 .30764 L
.49097 .30732 L
.49189 .30702 L
.49286 .3067 L
Mistroke
.49331 .30655 L
.49355 .30648 L
.4938 .30639 L
.49386 .30637 L
.49389 .30636 L
.49393 .30635 L
.49394 .30635 L
.49396 .30633 L
.49398 .3063 L
.494 .30628 L
.49407 .3062 L
.49431 .30591 L
.4948 .30532 L
.49574 .30419 L
.49674 .30298 L
.4977 .30182 L
.49863 .30071 L
.49962 .29952 L
.50057 .29838 L
.50148 .29728 L
.50245 .29611 L
.50339 .29499 L
.50438 .29379 L
.50534 .29264 L
.50626 .29154 L
.50724 .29036 L
.50819 .28923 L
.5091 .28815 L
.51006 .28699 L
.51099 .28588 L
.51198 .2847 L
.51294 .28356 L
.51385 .28247 L
.51483 .28131 L
.51528 .28077 L
.51552 .28049 L
.51565 .28033 L
.51577 .28019 L
.5158 .28015 L
.51583 .28012 L
.51585 .2801 L
.51587 .28009 L
.5159 .28008 L
.51604 .28001 L
.51628 .2799 L
.51677 .27968 L
.51775 .27923 L
.51869 .27881 L
.5196 .2784 L
.52056 .27796 L
Mistroke
.52149 .27754 L
.52248 .2771 L
.52343 .27667 L
.52434 .27627 L
.52532 .27583 L
.52625 .27542 L
.52725 .27497 L
.52821 .27455 L
.52913 .27415 L
.53012 .27371 L
.53106 .2733 L
.53197 .2729 L
.53294 .27248 L
.53387 .27208 L
.53486 .27165 L
.53582 .27124 L
.53674 .27085 L
.53771 .27043 L
.53865 .27003 L
.53965 .26961 L
.54062 .2692 L
.54154 .26881 L
.54253 .2684 L
.54348 .26801 L
.54439 .26763 L
.54536 .26723 L
.5463 .26684 L
.54729 .26644 L
.54825 .26605 L
.54917 .26567 L
.55015 .26528 L
.55109 .2649 L
.552 .26454 L
.55297 .26415 L
.5539 .26378 L
.55489 .26339 L
.55584 .26302 L
.55676 .26267 L
.55773 .26229 L
.55867 .26193 L
.55967 .26155 L
.56063 .26118 L
.56155 .26084 L
.56254 .26047 L
.56348 .26012 L
.56439 .25978 L
.56536 .25942 L
.5663 .25908 L
.56729 .25873 L
.56825 .25838 L
Mistroke
.56916 .25806 L
.57014 .25771 L
.57108 .25738 L
.57209 .25703 L
.57305 .2567 L
.57398 .25639 L
.57496 .25605 L
.57592 .25574 L
.57683 .25543 L
.5778 .25511 L
.57874 .25481 L
.57973 .25449 L
.58069 .25419 L
.58162 .2539 L
.5826 .25359 L
.58354 .2533 L
.58445 .25303 L
.58542 .25274 L
.58635 .25246 L
.58734 .25217 L
.58829 .2519 L
.58921 .25164 L
.59019 .25136 L
.59113 .2511 L
.59213 .25083 L
.59309 .25058 L
.59401 .25033 L
.595 .25008 L
.59595 .24984 L
.59686 .24961 L
.59783 .24937 L
.59876 .24915 L
.59976 .24891 L
.60072 .24869 L
.60164 .24848 L
.60262 .24827 L
.60356 .24806 L
.60447 .24787 L
.60543 .24767 L
.60636 .24749 L
.60735 .24729 L
.6083 .24711 L
.60922 .24694 L
.61019 .24677 L
.61113 .24661 L
.61212 .24644 L
.61308 .24628 L
.61401 .24614 L
.61499 .24599 L
.61594 .24585 L
Mistroke
.61685 .24572 L
.61782 .24559 L
.61875 .24547 L
.61974 .24535 L
.6207 .24524 L
.62161 .24514 L
.62259 .24504 L
.62353 .24494 L
.62401 .2449 L
.62453 .24485 L
.6255 .24477 L
.62598 .24473 L
.62648 .24469 L
.6274 .24462 L
.62786 .24459 L
.62837 .24456 L
.62888 .24453 L
.62936 .2445 L
.62984 .24447 L
.63028 .24445 L
.63073 .24443 L
.63099 .24442 L
.63123 .24441 L
.63169 .24439 L
.63194 .24438 L
.6322 .24437 L
.63242 .24436 L
.63267 .24435 L
.6329 .24434 L
.63311 .24433 L
.63336 .24433 L
.63363 .24432 L
.63386 .24431 L
.63411 .24431 L
.63434 .2443 L
.63446 .2443 L
.63458 .2443 L
.63469 .24429 L
.63481 .24429 L
.63502 .24429 L
.63514 .24428 L
.63525 .24428 L
.63537 .24428 L
.6355 .24428 L
.63562 .24428 L
.63576 .24427 L
.63587 .24427 L
.636 .24427 L
.63606 .24427 L
.63613 .24427 L
Mistroke
.63618 .24427 L
.63625 .24427 L
.6363 .24427 L
.63636 .24427 L
.63647 .24427 L
.63654 .24427 L
.6366 .24427 L
.63666 .24426 L
.63673 .24426 L
.63679 .24426 L
.63685 .24426 L
.63691 .24426 L
.63694 .24426 L
.63697 .24426 L
.63703 .24426 L
.63706 .24426 L
.63709 .24426 L
.63712 .24426 L
.63715 .24426 L
.63718 .24426 L
.63721 .24426 L
.63724 .24426 L
.63727 .24426 L
.63729 .24426 L
.63732 .24426 L
.63735 .24426 L
.63738 .24426 L
.63741 .24426 L
.63744 .24426 L
.63746 .24426 L
.6375 .24426 L
.63753 .24426 L
.63755 .24426 L
.63758 .24426 L
.6376 .24426 L
.63762 .24426 L
.63765 .24426 L
.63766 .24426 L
.63768 .24426 L
.6377 .24426 L
.63771 .24426 L
.63774 .24426 L
.63776 .24426 L
.63778 .24426 L
.63779 .24426 L
.63781 .24426 L
.63783 .24426 L
.63785 .24426 L
.63788 .24426 L
.63791 .24426 L
Mistroke
.63794 .24426 L
.63797 .24426 L
.638 .24426 L
.63802 .24426 L
.63805 .24426 L
.63808 .24426 L
.6381 .24426 L
.63811 .24426 L
.63814 .24426 L
.63817 .24426 L
.6382 .24426 L
.63823 .24426 L
.63825 .24426 L
.63828 .24426 L
.6383 .24426 L
.63833 .24426 L
.63836 .24426 L
.63839 .24426 L
.63842 .24426 L
.63845 .24426 L
.63851 .24426 L
.63854 .24426 L
.63858 .24426 L
.63861 .24426 L
.63865 .24426 L
.63871 .24426 L
.63876 .24426 L
.63882 .24426 L
.63889 .24426 L
.63894 .24426 L
.639 .24427 L
.63911 .24427 L
.63917 .24427 L
.63924 .24427 L
.63936 .24427 L
.63942 .24427 L
.63949 .24427 L
.6396 .24427 L
.63967 .24427 L
.63974 .24427 L
.63987 .24427 L
.63998 .24428 L
.6401 .24428 L
.64023 .24428 L
.64035 .24428 L
.64056 .24429 L
.64068 .24429 L
.64079 .24429 L
.6409 .24429 L
.64103 .2443 L
Mistroke
.64125 .2443 L
.64151 .24431 L
.64174 .24431 L
.64198 .24432 L
.64221 .24433 L
.64245 .24433 L
.64271 .24434 L
.64293 .24435 L
.64318 .24436 L
.64362 .24438 L
.64386 .24438 L
.64413 .2444 L
.64436 .24441 L
.64461 .24442 L
.64509 .24444 L
.64559 .24447 L
.64606 .24449 L
.64656 .24452 L
.64704 .24455 L
.64755 .24458 L
.64803 .24461 L
.64847 .24464 L
.64941 .24471 L
.64992 .24476 L
.6504 .2448 L
.65133 .24488 L
.65231 .24497 L
.65326 .24506 L
.65417 .24516 L
.65514 .24527 L
.65607 .24538 L
.65707 .2455 L
.65802 .24563 L
.65894 .24575 L
.65992 .24589 L
.66086 .24603 L
.66186 .24618 L
.66283 .24633 L
.66376 .24649 L
.66474 .24665 L
.66569 .24682 L
.66661 .24699 L
.66758 .24717 L
.66852 .24735 L
.66951 .24755 L
.67047 .24774 L
.67139 .24793 L
.67238 .24814 L
.67332 .24835 L
.67423 .24855 L
Mistroke
.6752 .24877 L
.67613 .24898 L
.67712 .24922 L
.67807 .24945 L
.67899 .24968 L
.67997 .24992 L
.68091 .25016 L
.68191 .25042 L
.68287 .25068 L
.6838 .25092 L
.68478 .25119 L
.68573 .25146 L
.68664 .25171 L
.68761 .25199 L
.68855 .25226 L
.68954 .25255 L
.6905 .25284 L
.69142 .25311 L
.6924 .25341 L
.69334 .2537 L
.69425 .25398 L
.69521 .25429 L
.69614 .25459 L
.69713 .2549 L
.69808 .25521 L
.699 .25551 L
.69997 .25584 L
.70091 .25615 L
.70191 .25649 L
.70287 .25682 L
.70379 .25714 L
.70478 .25748 L
.70572 .25781 L
.70663 .25813 L
.7076 .25848 L
.70853 .25881 L
.70953 .25917 L
.71048 .25952 L
.7114 .25986 L
.71238 .26022 L
.71332 .26057 L
.71432 .26095 L
.71528 .26131 L
.71621 .26166 L
.7172 .26204 L
.71815 .2624 L
.71906 .26276 L
.72003 .26314 L
.72097 .2635 L
.72196 .26389 L
Mistroke
.72292 .26427 L
.72384 .26464 L
.72482 .26503 L
.72577 .26541 L
.72668 .26578 L
.72764 .26617 L
.72858 .26655 L
.72956 .26696 L
.73052 .26735 L
.73143 .26773 L
.73241 .26813 L
.73335 .26853 L
.73435 .26894 L
.73531 .26935 L
.73623 .26974 L
.73722 .27016 L
.73817 .27056 L
.73908 .27095 L
.74005 .27137 L
.74098 .27177 L
.74198 .2722 L
.74293 .27261 L
.74385 .27301 L
.74483 .27344 L
.74577 .27385 L
.74668 .27425 L
.74764 .27467 L
.74857 .27508 L
.74956 .27552 L
.75051 .27594 L
.75143 .27635 L
.7524 .27678 L
.75334 .2772 L
.75433 .27765 L
.75529 .27808 L
.75622 .2785 L
.7572 .27895 L
.75814 .27938 L
.75905 .27979 L
.76002 .28023 L
.76095 .28066 L
.76194 .28111 L
.7629 .28155 L
.76382 .28197 L
.76479 .28242 L
.76573 .28286 L
.76673 .28332 L
.7677 .28377 L
.76862 .2842 L
.76961 .28466 L
Mistroke
.77056 .2851 L
.77147 .28553 L
.77244 .28598 L
.77338 .28642 L
.77437 .28689 L
.77533 .28734 L
.77625 .28778 L
.77723 .28824 L
.77817 .28869 L
.77908 .28912 L
.78005 .28958 L
.78098 .29002 L
.78197 .29049 L
.78292 .29095 L
.78384 .29139 L
.78481 .29185 L
.78575 .29231 L
.78675 .29278 L
.78771 .29325 L
.78863 .29369 L
.78961 .29417 L
.79056 .29463 L
.79147 .29507 L
.79244 .29554 L
.79338 .29599 L
.79437 .29647 L
.79532 .29694 L
.79624 .29739 L
.79722 .29786 L
.79816 .29832 L
.79916 .29881 L
.80013 .29928 L
.80105 .29974 L
.80204 .30022 L
.80299 .30069 L
.80391 .30114 L
.80488 .30162 L
.80582 .30208 L
.80681 .30257 L
.80777 .30305 L
.80869 .3035 L
.80967 .30399 L
.81062 .30446 L
.81153 .30491 L
.81249 .30539 L
.81343 .30585 L
.81442 .30634 L
.81537 .30682 L
.81629 .30728 L
.81726 .30776 L
Mistroke
.8182 .30823 L
.8192 .30873 L
.82016 .30921 L
.82109 .30968 L
.82207 .31017 L
.82302 .31065 L
.82393 .3111 L
.8249 .31159 L
.82584 .31206 L
.82683 .31256 L
.82779 .31304 L
.82871 .31351 L
.82969 .314 L
.83063 .31448 L
.83154 .31493 L
.8325 .31542 L
.83343 .31589 L
.83442 .31639 L
.83537 .31687 L
.83629 .31734 L
.83726 .31783 L
.8382 .31831 L
.8392 .31881 L
.84016 .3193 L
.84108 .31977 L
.84206 .32027 L
.84301 .32075 L
.84392 .32122 L
.84489 .32171 L
.84582 .32219 L
.84681 .32269 L
.84777 .32318 L
.84869 .32365 L
.84966 .32415 L
.8506 .32463 L
.8516 .32514 L
.85257 .32564 L
.85349 .32611 L
.85448 .32662 L
.85543 .32711 L
.85634 .32757 L
.85731 .32807 L
.85825 .32855 L
.85924 .32907 L
.8602 .32956 L
.86112 .33003 L
.86211 .33054 L
.86305 .33102 L
.86396 .33149 L
.86492 .33199 L
Mistroke
.86585 .33247 L
.86684 .33298 L
.8678 .33347 L
.86871 .33395 L
.86969 .33445 L
.87063 .33494 L
.87163 .33545 L
.87259 .33595 L
.87351 .33643 L
.8745 .33694 L
.87544 .33743 L
.87635 .3379 L
.87732 .3384 L
.87826 .33889 L
.87925 .3394 L
.88021 .3399 L
.88113 .34038 L
.88211 .34089 L
.88305 .34138 L
.88395 .34185 L
.88492 .34235 L
.88585 .34283 L
.88683 .34335 L
.88778 .34384 L
.8887 .34432 L
.88967 .34483 L
.89061 .34531 L
.8916 .34583 L
.89256 .34633 L
.89349 .34682 L
.89447 .34733 L
.89541 .34782 L
.89632 .3483 L
.89729 .3488 L
.89822 .34929 L
.89921 .34981 L
.90017 .35031 L
.90109 .35079 L
.90206 .3513 L
.903 .35179 L
.904 .35231 L
.90496 .35282 L
.90589 .3533 L
.90688 .35382 L
.90782 .35432 L
.90874 .3548 L
.90971 .35531 L
.91064 .3558 L
.91164 .35632 L
.91259 .35682 L
Mistroke
.91352 .3573 L
.91449 .35782 L
.91544 .35832 L
.91635 .35879 L
.91731 .3593 L
.91824 .35979 L
.91923 .36031 L
.92018 .36081 L
.9211 .36129 L
.92207 .36181 L
.92301 .3623 L
.92401 .36282 L
.92497 .36333 L
.92589 .36382 L
.92688 .36434 L
.92782 .36484 L
.92873 .36532 L
.9297 .36583 L
.93063 .36632 L
.93163 .36684 L
.93258 .36735 L
.9335 .36783 L
.93448 .36835 L
.93542 .36885 L
.93642 .36937 L
.93738 .36988 L
.93831 .37037 L
.9393 .3709 L
.94025 .3714 L
.94116 .37188 L
.94213 .3724 L
.94307 .37289 L
.94407 .37342 L
.94502 .37393 L
.94595 .37441 L
.94693 .37493 L
.94787 .37543 L
.94878 .37592 L
.94975 .37643 L
.95068 .37692 L
.95167 .37745 L
.95262 .37795 L
.95354 .37844 L
.95451 .37896 L
.95545 .37945 L
.95645 .37998 L
.95741 .38049 L
.95834 .38099 L
.95932 .38151 L
.96027 .38201 L
Mistroke
.96118 .3825 L
.96215 .38301 L
.96309 .38351 L
.96408 .38403 L
.96504 .38454 L
.96596 .38503 L
.96694 .38555 L
.96788 .38605 L
.96879 .38654 L
.96975 .38705 L
.97068 .38754 L
.97167 .38807 L
.97262 .38858 L
.97353 .38906 L
.97451 .38958 L
.97545 .39008 L
.97619 .39048 L
Mfstroke
.02381 .0941 m
.02474 .09516 L
.02575 .09632 L
.0267 .0974 L
.02761 .09845 L
.02859 .09956 L
.02952 .10063 L
.03052 .10176 L
.03148 .10286 L
.0324 .10391 L
.03338 .10503 L
.03433 .1061 L
.03524 .10714 L
.03621 .10824 L
.03714 .1093 L
.03813 .11042 L
.03908 .1115 L
.04 .11254 L
.04098 .11365 L
.04192 .11471 L
.04292 .11584 L
.04388 .11693 L
.0448 .11798 L
.04579 .11909 L
.04674 .12016 L
.04765 .12118 L
.04862 .12228 L
.04956 .12333 L
.05055 .12444 L
.05151 .12552 L
.05243 .12655 L
.05341 .12764 L
.05435 .1287 L
.05526 .12971 L
.05622 .13078 L
.05715 .13182 L
.05814 .13291 L
.05909 .13397 L
.06001 .13498 L
.06098 .13606 L
.06192 .13709 L
.06292 .13819 L
.06388 .13924 L
.0648 .14026 L
.06579 .14133 L
.06673 .14236 L
.06764 .14335 L
.06861 .1444 L
.06954 .14541 L
.07054 .14648 L
Mistroke
.07149 .1475 L
.07241 .14849 L
.07339 .14953 L
.07433 .15053 L
.07533 .15158 L
.07629 .1526 L
.07722 .15357 L
.07821 .15459 L
.07916 .15558 L
.08007 .15651 L
.08104 .15751 L
.08198 .15846 L
.08297 .15946 L
.08393 .16041 L
.08485 .16133 L
.08584 .16229 L
.08678 .1632 L
.08769 .16407 L
.08866 .16499 L
.08959 .16585 L
.09058 .16676 L
.09153 .16762 L
.09245 .16844 L
.09342 .16928 L
.09436 .17008 L
.09536 .17091 L
.09632 .17168 L
.09725 .17241 L
.09823 .17315 L
.09918 .17384 L
.10009 .17447 L
.10106 .17511 L
.10199 .17569 L
.10247 .17598 L
.10299 .17627 L
.10394 .17679 L
.10442 .17704 L
.10492 .17728 L
.10539 .1775 L
.10583 .17769 L
.10631 .17789 L
.10676 .17806 L
.10721 .17823 L
.10747 .17831 L
.10771 .17839 L
.10796 .17847 L
.1082 .17854 L
.10841 .1786 L
.10865 .17867 L
.10887 .17873 L
Mistroke
.10912 .17879 L
.10925 .17882 L
.10938 .17885 L
.10951 .17888 L
.10963 .1789 L
.10987 .17895 L
.11 .17897 L
.11014 .179 L
.11027 .17902 L
.11039 .17904 L
.1105 .17906 L
.11062 .17907 L
.11074 .17909 L
.11085 .1791 L
.11097 .17912 L
.1111 .17913 L
.11116 .17914 L
.11123 .17915 L
.1113 .17916 L
.11136 .17916 L
.11142 .17917 L
.11149 .17917 L
.11155 .17918 L
.1116 .17918 L
.11166 .17919 L
.11172 .17919 L
.11178 .1792 L
.11185 .1792 L
.11191 .1792 L
.11196 .17921 L
.11201 .17921 L
.11207 .17921 L
.1121 .17921 L
.11213 .17922 L
.11216 .17922 L
.1122 .17922 L
.11223 .17922 L
.11227 .17922 L
.1123 .17922 L
.11233 .17922 L
.11236 .17922 L
.11239 .17923 L
.11241 .17923 L
.11242 .17923 L
.11245 .17923 L
.11248 .17923 L
.11251 .17923 L
.11254 .17923 L
.11257 .17923 L
.1126 .17923 L
Mistroke
.11263 .17923 L
.11265 .17923 L
.11266 .17923 L
.11268 .17923 L
.1127 .17923 L
.11273 .17923 L
.11275 .17923 L
.11279 .17923 L
.11282 .17923 L
.11284 .17923 L
.11287 .17923 L
.1129 .17923 L
.11292 .17923 L
.11295 .17923 L
.11298 .17923 L
.11301 .17923 L
.11304 .17923 L
.11307 .17923 L
.1131 .17923 L
.11313 .17923 L
.11316 .17923 L
.11319 .17923 L
.11321 .17923 L
.11322 .17923 L
.11325 .17922 L
.11327 .17922 L
.11328 .17922 L
.11332 .17922 L
.11335 .17922 L
.11338 .17922 L
.11342 .17922 L
.11345 .17922 L
.11348 .17922 L
.11351 .17922 L
.11354 .17921 L
.11361 .17921 L
.11364 .17921 L
.11367 .17921 L
.11373 .1792 L
.11379 .1792 L
.11386 .1792 L
.11392 .17919 L
.11399 .17919 L
.11406 .17918 L
.11411 .17918 L
.11418 .17917 L
.11429 .17916 L
.11436 .17915 L
.11442 .17915 L
.11454 .17913 L
Mistroke
.11465 .17912 L
.11477 .17911 L
.1149 .17909 L
.11502 .17907 L
.11513 .17906 L
.11524 .17904 L
.11547 .179 L
.11558 .17898 L
.11571 .17896 L
.11593 .17892 L
.11605 .17889 L
.11616 .17887 L
.11642 .17881 L
.11666 .17875 L
.11691 .17869 L
.11712 .17863 L
.11736 .17857 L
.1176 .17849 L
.11783 .17842 L
.11809 .17834 L
.11833 .17826 L
.11879 .17809 L
.11904 .178 L
.11929 .1779 L
.11976 .17771 L
.1202 .17751 L
.12069 .17729 L
.12114 .17707 L
.12163 .17682 L
.12209 .17658 L
.12301 .17607 L
.12396 .1755 L
.12486 .17492 L
.12583 .17428 L
.12675 .17362 L
.12774 .1729 L
.12869 .17217 L
.12961 .17145 L
.13058 .17066 L
.13152 .16988 L
.13251 .16903 L
.13347 .16819 L
.1344 .16736 L
.13538 .16647 L
.13632 .1656 L
.13723 .16475 L
.1382 .16383 L
.13913 .16293 L
.14012 .16197 L
.14108 .16103 L
Mistroke
.14199 .16012 L
.14297 .15915 L
.14391 .1582 L
.14491 .15718 L
.14587 .1562 L
.1468 .15524 L
.14778 .15422 L
.14873 .15323 L
.14965 .15228 L
.15062 .15125 L
.15155 .15026 L
.15255 .14921 L
.1535 .14819 L
.15442 .1472 L
.1554 .14615 L
.15635 .14513 L
.15726 .14415 L
.15822 .1431 L
.15915 .14209 L
.16014 .14101 L
.16109 .13997 L
.16201 .13897 L
.16298 .1379 L
.16392 .13686 L
.16492 .13577 L
.16588 .1347 L
.1668 .13368 L
.16779 .13259 L
.16873 .13154 L
.16964 .13053 L
.17061 .12945 L
.17154 .1284 L
.17254 .1273 L
.17349 .12623 L
.17441 .1252 L
.17539 .1241 L
.17633 .12304 L
.17733 .12192 L
.17829 .12083 L
.17922 .11979 L
.18021 .11868 L
.18116 .11761 L
.18207 .11657 L
.18304 .11547 L
.18398 .11442 L
.18498 .11329 L
.18593 .1122 L
.18686 .11116 L
.18784 .11004 L
.18878 .10897 L
Mistroke
.18969 .10794 L
.19066 .10684 L
.19159 .10578 L
.19258 .10465 L
.19353 .10357 L
.19445 .10252 L
.19543 .10141 L
.19637 .10034 L
.19736 .0992 L
.19833 .0981 L
.19925 .09704 L
.20024 .09592 L
.20073 .09536 L
.20118 .09483 L
.20141 .09457 L
.20162 .09433 L
.20174 .09419 L
.20177 .09416 L
.20179 .09414 L
.20181 .09412 L
.20184 .09408 L
.20185 .09405 L
.20187 .09402 L
.2021 .09365 L
.20308 .09201 L
.20403 .09043 L
.20495 .08891 L
.20592 .0873 L
.20686 .08574 L
.20786 .08409 L
.20882 .08249 L
.20974 .08096 L
.21072 .07932 L
.21167 .07775 L
.21258 .07624 L
.21355 .07463 L
.21448 .07308 L
.21547 .07143 L
.21642 .06984 L
.21734 .06831 L
.21832 .06669 L
.21926 .06512 L
.22026 .06346 L
.22122 .06185 L
.22215 .06031 L
.22314 .05867 L
.22409 .05709 L
.225 .05557 L
.22597 .05395 L
.22691 .05239 L
Mistroke
.2279 .05073 L
.22886 .04914 L
.22978 .0476 L
.23076 .04597 L
.2317 .04439 L
.23218 .04361 L
.23238 .04326 L
.23261 .04288 L
.23267 .04279 L
.23273 .04269 L
.23276 .04264 L
.23279 .04259 L
.23281 .04256 L
.23284 .04255 L
.23308 .04247 L
.23358 .04228 L
.23456 .04192 L
.23551 .04157 L
.23642 .04123 L
.23739 .04088 L
.23832 .04053 L
.23932 .04016 L
.24027 .03981 L
.24119 .03947 L
.24217 .03911 L
.24311 .03876 L
.24411 .03839 L
.24508 .03803 L
.246 .03769 L
.24699 .03732 L
.24794 .03697 L
.24886 .03663 L
.24983 .03627 L
.25077 .03592 L
.25176 .03556 L
.25272 .0352 L
.25364 .03486 L
.25462 .03449 L
.25557 .03414 L
.25648 .0338 L
.25745 .03344 L
.25838 .0331 L
.25937 .03273 L
.26032 .03237 L
.26124 .03203 L
.26222 .03167 L
.26316 .03132 L
.26415 .03095 L
.26512 .03059 L
.26604 .03024 L
Mistroke
.26703 .02987 L
.26798 .02952 L
.26889 .02918 L
.26986 .02882 L
.27079 .02847 L
.27179 .0281 L
.27275 .02774 L
.27367 .0274 L
.27465 .02703 L
.27559 .02668 L
.2765 .02634 L
.27746 .02598 L
.27839 .02563 L
.27938 .02526 L
.28033 .0249 L
.28125 .02456 L
.28222 .02419 L
.28316 .02384 L
.28415 .02347 L
.28512 .02311 L
.28604 .02276 L
.28702 .02239 L
.28797 .02204 L
.28888 .0217 L
.28985 .02133 L
.29029 .02116 L
.29053 .02108 L
.29066 .02103 L
.29072 .021 L
.29078 .02098 L
.29081 .02097 L
.29083 .02096 L
.29085 .02097 L
.29087 .02097 L
.29088 .02098 L
.29092 .02099 L
.29104 .02104 L
.29129 .02113 L
.29177 .02132 L
.29277 .02169 L
.29373 .02205 L
.29465 .02239 L
.29563 .02276 L
.29657 .02312 L
.29748 .02346 L
.29845 .02382 L
.29938 .02417 L
.30037 .02454 L
.30132 .0249 L
.30224 .02524 L
Mistroke
.30321 .02561 L
.30415 .02596 L
.30515 .02633 L
.30611 .02669 L
.30704 .02704 L
.30802 .0274 L
.30897 .02776 L
.30988 .0281 L
.31085 .02846 L
.31178 .02881 L
.31278 .02918 L
.31373 .02954 L
.31465 .02988 L
.31563 .03025 L
.31657 .0306 L
.31748 .03094 L
.31845 .03129 L
.31937 .03164 L
.32036 .03201 L
.32131 .03236 L
.32223 .0327 L
.3232 .03307 L
.32414 .03341 L
.32513 .03378 L
.32609 .03414 L
.32702 .03448 L
.328 .03485 L
.32895 .0352 L
.32985 .03554 L
.33082 .0359 L
.33175 .03624 L
.33275 .03661 L
.3337 .03696 L
.33462 .0373 L
.33559 .03767 L
.33653 .03801 L
.33753 .03838 L
.3385 .03874 L
.33942 .03908 L
.34041 .03945 L
.34136 .0398 L
.34227 .04014 L
.34324 .04049 L
.34418 .04084 L
.34517 .04121 L
.34613 .04156 L
.34705 .0419 L
.34803 .04226 L
.34897 .04261 L
.34988 .04294 L
Mistroke
.35085 .0433 L
.35178 .04364 L
.35277 .044 L
.35372 .04435 L
.35463 .04469 L
.35561 .04505 L
.35655 .04539 L
.35754 .04576 L
.35851 .04611 L
.35943 .04645 L
.36041 .04681 L
.36136 .04716 L
.36227 .04749 L
.36324 .04785 L
.36417 .04819 L
.36517 .04855 L
.36612 .0489 L
.36704 .04924 L
.36802 .0496 L
.36896 .04994 L
.36996 .05031 L
.37092 .05066 L
.37185 .051 L
.37284 .05136 L
.37379 .0517 L
.3747 .05204 L
.37568 .05239 L
.37661 .05273 L
.37761 .05309 L
.37857 .05344 L
.37949 .05378 L
.38047 .05413 L
.38142 .05448 L
.38232 .05481 L
.38329 .05516 L
.38422 .05549 L
.38521 .05585 L
.38617 .0562 L
.38708 .05653 L
.38806 .05688 L
.389 .05722 L
.39 .05758 L
.39096 .05793 L
.39189 .05826 L
.39287 .05862 L
.39382 .05896 L
.39473 .05929 L
.3957 .05964 L
.39663 .05998 L
.39763 .06033 L
Mistroke
.39858 .06068 L
.39951 .06101 L
.40048 .06136 L
.40143 .0617 L
.40233 .06202 L
.4033 .06237 L
.40423 .0627 L
.40522 .06306 L
.40617 .0634 L
.40708 .06372 L
.40806 .06407 L
.40899 .06441 L
.40999 .06476 L
.41095 .06511 L
.41188 .06544 L
.41286 .06579 L
.4138 .06612 L
.41471 .06645 L
.41568 .06679 L
.41661 .06712 L
.41761 .06747 L
.41856 .06781 L
.41948 .06814 L
.42046 .06849 L
.4214 .06882 L
.4224 .06917 L
.42336 .06951 L
.42429 .06984 L
.42527 .07019 L
.42622 .07052 L
.42714 .07085 L
.42811 .07119 L
.42904 .07152 L
.43004 .07187 L
.431 .0722 L
.43192 .07253 L
.4329 .07287 L
.43384 .0732 L
.43475 .07352 L
.43572 .07386 L
.43665 .07419 L
.43764 .07453 L
.43859 .07486 L
.43951 .07518 L
.44048 .07552 L
.44142 .07585 L
.44242 .0762 L
.44338 .07653 L
.4443 .07686 L
.44529 .0772 L
Mistroke
.44624 .07753 L
.44715 .07784 L
.44812 .07818 L
.44905 .0785 L
.45004 .07884 L
.451 .07917 L
.45192 .07949 L
.4529 .07983 L
.45384 .08015 L
.45474 .08047 L
.45571 .0808 L
.45664 .08112 L
.45762 .08145 L
.45858 .08178 L
.45949 .08209 L
.46046 .08243 L
.4614 .08275 L
.4624 .08309 L
.46336 .08341 L
.46428 .08373 L
.46526 .08406 L
.46621 .08439 L
.46711 .08469 L
.46808 .08502 L
.46901 .08534 L
.47 .08567 L
.47096 .086 L
.47188 .08631 L
.47285 .08664 L
.47379 .08695 L
.47479 .08729 L
.47575 .08761 L
.47668 .08792 L
.47767 .08825 L
.47861 .08857 L
.47953 .08888 L
.4805 .0892 L
.48143 .08951 L
.48243 .08985 L
.48338 .09016 L
.4843 .09047 L
.48528 .0908 L
.48623 .09111 L
.48713 .09141 L
.4881 .09173 L
.48903 .09204 L
.49002 .09236 L
.49097 .09268 L
.49189 .09298 L
.49286 .0933 L
Mistroke
.49331 .09345 L
.49355 .09352 L
.4938 .09361 L
.49386 .09363 L
.49389 .09364 L
.49393 .09365 L
.49394 .09365 L
.49396 .09367 L
.49398 .0937 L
.494 .09372 L
.49407 .0938 L
.49431 .09409 L
.4948 .09468 L
.49574 .09581 L
.49674 .09702 L
.4977 .09818 L
.49863 .09929 L
.49962 .10048 L
.50057 .10162 L
.50148 .10272 L
.50245 .10389 L
.50339 .10501 L
.50438 .10621 L
.50534 .10736 L
.50626 .10846 L
.50724 .10964 L
.50819 .11077 L
.5091 .11185 L
.51006 .11301 L
.51099 .11412 L
.51198 .1153 L
.51294 .11644 L
.51385 .11753 L
.51483 .11869 L
.51528 .11923 L
.51552 .11951 L
.51565 .11967 L
.51577 .11981 L
.5158 .11985 L
.51583 .11988 L
.51585 .1199 L
.51587 .11991 L
.5159 .11992 L
.51604 .11999 L
.51628 .1201 L
.51677 .12032 L
.51775 .12077 L
.51869 .12119 L
.5196 .1216 L
.52056 .12204 L
Mistroke
.52149 .12246 L
.52248 .1229 L
.52343 .12333 L
.52434 .12373 L
.52532 .12417 L
.52625 .12458 L
.52725 .12503 L
.52821 .12545 L
.52913 .12585 L
.53012 .12629 L
.53106 .1267 L
.53197 .1271 L
.53294 .12752 L
.53387 .12792 L
.53486 .12835 L
.53582 .12876 L
.53674 .12915 L
.53771 .12957 L
.53865 .12997 L
.53965 .13039 L
.54062 .1308 L
.54154 .13119 L
.54253 .1316 L
.54348 .13199 L
.54439 .13237 L
.54536 .13277 L
.5463 .13316 L
.54729 .13356 L
.54825 .13395 L
.54917 .13433 L
.55015 .13472 L
.55109 .1351 L
.552 .13546 L
.55297 .13585 L
.5539 .13622 L
.55489 .13661 L
.55584 .13698 L
.55676 .13733 L
.55773 .13771 L
.55867 .13807 L
.55967 .13845 L
.56063 .13882 L
.56155 .13916 L
.56254 .13953 L
.56348 .13988 L
.56439 .14022 L
.56536 .14058 L
.5663 .14092 L
.56729 .14127 L
.56825 .14162 L
Mistroke
.56916 .14194 L
.57014 .14229 L
.57108 .14262 L
.57209 .14297 L
.57305 .1433 L
.57398 .14361 L
.57496 .14395 L
.57592 .14426 L
.57683 .14457 L
.5778 .14489 L
.57874 .14519 L
.57973 .14551 L
.58069 .14581 L
.58162 .1461 L
.5826 .14641 L
.58354 .1467 L
.58445 .14697 L
.58542 .14726 L
.58635 .14754 L
.58734 .14783 L
.58829 .1481 L
.58921 .14836 L
.59019 .14864 L
.59113 .1489 L
.59213 .14917 L
.59309 .14942 L
.59401 .14967 L
.595 .14992 L
.59595 .15016 L
.59686 .15039 L
.59783 .15063 L
.59876 .15085 L
.59976 .15109 L
.60072 .15131 L
.60164 .15152 L
.60262 .15173 L
.60356 .15194 L
.60447 .15213 L
.60543 .15233 L
.60636 .15251 L
.60735 .15271 L
.6083 .15289 L
.60922 .15306 L
.61019 .15323 L
.61113 .15339 L
.61212 .15356 L
.61308 .15372 L
.61401 .15386 L
.61499 .15401 L
.61594 .15415 L
Mistroke
.61685 .15428 L
.61782 .15441 L
.61875 .15453 L
.61974 .15465 L
.6207 .15476 L
.62161 .15486 L
.62259 .15496 L
.62353 .15506 L
.62401 .1551 L
.62453 .15515 L
.6255 .15523 L
.62598 .15527 L
.62648 .15531 L
.6274 .15538 L
.62786 .15541 L
.62837 .15544 L
.62888 .15547 L
.62936 .1555 L
.62984 .15553 L
.63028 .15555 L
.63073 .15557 L
.63099 .15558 L
.63123 .15559 L
.63169 .15561 L
.63194 .15562 L
.6322 .15563 L
.63242 .15564 L
.63267 .15565 L
.6329 .15566 L
.63311 .15567 L
.63336 .15567 L
.63363 .15568 L
.63386 .15569 L
.63411 .15569 L
.63434 .1557 L
.63446 .1557 L
.63458 .1557 L
.63469 .15571 L
.63481 .15571 L
.63502 .15571 L
.63514 .15572 L
.63525 .15572 L
.63537 .15572 L
.6355 .15572 L
.63562 .15572 L
.63576 .15573 L
.63587 .15573 L
.636 .15573 L
.63606 .15573 L
.63613 .15573 L
Mistroke
.63618 .15573 L
.63625 .15573 L
.6363 .15573 L
.63636 .15573 L
.63647 .15573 L
.63654 .15573 L
.6366 .15573 L
.63666 .15574 L
.63673 .15574 L
.63679 .15574 L
.63685 .15574 L
.63691 .15574 L
.63694 .15574 L
.63697 .15574 L
.63703 .15574 L
.63706 .15574 L
.63709 .15574 L
.63712 .15574 L
.63715 .15574 L
.63718 .15574 L
.63721 .15574 L
.63724 .15574 L
.63727 .15574 L
.63729 .15574 L
.63732 .15574 L
.63735 .15574 L
.63738 .15574 L
.63741 .15574 L
.63744 .15574 L
.63746 .15574 L
.6375 .15574 L
.63753 .15574 L
.63755 .15574 L
.63758 .15574 L
.6376 .15574 L
.63762 .15574 L
.63765 .15574 L
.63766 .15574 L
.63768 .15574 L
.6377 .15574 L
.63771 .15574 L
.63774 .15574 L
.63776 .15574 L
.63778 .15574 L
.63779 .15574 L
.63781 .15574 L
.63783 .15574 L
.63785 .15574 L
.63788 .15574 L
.63791 .15574 L
Mistroke
.63794 .15574 L
.63797 .15574 L
.638 .15574 L
.63802 .15574 L
.63805 .15574 L
.63808 .15574 L
.6381 .15574 L
.63811 .15574 L
.63814 .15574 L
.63817 .15574 L
.6382 .15574 L
.63823 .15574 L
.63825 .15574 L
.63828 .15574 L
.6383 .15574 L
.63833 .15574 L
.63836 .15574 L
.63839 .15574 L
.63842 .15574 L
.63845 .15574 L
.63851 .15574 L
.63854 .15574 L
.63858 .15574 L
.63861 .15574 L
.63865 .15574 L
.63871 .15574 L
.63876 .15574 L
.63882 .15574 L
.63889 .15574 L
.63894 .15574 L
.639 .15573 L
.63911 .15573 L
.63917 .15573 L
.63924 .15573 L
.63936 .15573 L
.63942 .15573 L
.63949 .15573 L
.6396 .15573 L
.63967 .15573 L
.63974 .15573 L
.63987 .15573 L
.63998 .15572 L
.6401 .15572 L
.64023 .15572 L
.64035 .15572 L
.64056 .15571 L
.64068 .15571 L
.64079 .15571 L
.6409 .15571 L
.64103 .1557 L
Mistroke
.64125 .1557 L
.64151 .15569 L
.64174 .15569 L
.64198 .15568 L
.64221 .15567 L
.64245 .15567 L
.64271 .15566 L
.64293 .15565 L
.64318 .15564 L
.64362 .15562 L
.64386 .15562 L
.64413 .1556 L
.64436 .15559 L
.64461 .15558 L
.64509 .15556 L
.64559 .15553 L
.64606 .15551 L
.64656 .15548 L
.64704 .15545 L
.64755 .15542 L
.64803 .15539 L
.64847 .15536 L
.64941 .15529 L
.64992 .15524 L
.6504 .1552 L
.65133 .15512 L
.65231 .15503 L
.65326 .15494 L
.65417 .15484 L
.65514 .15473 L
.65607 .15462 L
.65707 .1545 L
.65802 .15437 L
.65894 .15425 L
.65992 .15411 L
.66086 .15397 L
.66186 .15382 L
.66283 .15367 L
.66376 .15351 L
.66474 .15335 L
.66569 .15318 L
.66661 .15301 L
.66758 .15283 L
.66852 .15265 L
.66951 .15245 L
.67047 .15226 L
.67139 .15207 L
.67238 .15186 L
.67332 .15165 L
.67423 .15145 L
Mistroke
.6752 .15123 L
.67613 .15102 L
.67712 .15078 L
.67807 .15055 L
.67899 .15032 L
.67997 .15008 L
.68091 .14984 L
.68191 .14958 L
.68287 .14932 L
.6838 .14908 L
.68478 .14881 L
.68573 .14854 L
.68664 .14829 L
.68761 .14801 L
.68855 .14774 L
.68954 .14745 L
.6905 .14716 L
.69142 .14689 L
.6924 .14659 L
.69334 .1463 L
.69425 .14602 L
.69521 .14571 L
.69614 .14541 L
.69713 .1451 L
.69808 .14479 L
.699 .14449 L
.69997 .14416 L
.70091 .14385 L
.70191 .14351 L
.70287 .14318 L
.70379 .14286 L
.70478 .14252 L
.70572 .14219 L
.70663 .14187 L
.7076 .14152 L
.70853 .14119 L
.70953 .14083 L
.71048 .14048 L
.7114 .14014 L
.71238 .13978 L
.71332 .13943 L
.71432 .13905 L
.71528 .13869 L
.71621 .13834 L
.7172 .13796 L
.71815 .1376 L
.71906 .13724 L
.72003 .13686 L
.72097 .1365 L
.72196 .13611 L
Mistroke
.72292 .13573 L
.72384 .13536 L
.72482 .13497 L
.72577 .13459 L
.72668 .13422 L
.72764 .13383 L
.72858 .13345 L
.72956 .13304 L
.73052 .13265 L
.73143 .13227 L
.73241 .13187 L
.73335 .13147 L
.73435 .13106 L
.73531 .13065 L
.73623 .13026 L
.73722 .12984 L
.73817 .12944 L
.73908 .12905 L
.74005 .12863 L
.74098 .12823 L
.74198 .1278 L
.74293 .12739 L
.74385 .12699 L
.74483 .12656 L
.74577 .12615 L
.74668 .12575 L
.74764 .12533 L
.74857 .12492 L
.74956 .12448 L
.75051 .12406 L
.75143 .12365 L
.7524 .12322 L
.75334 .1228 L
.75433 .12235 L
.75529 .12192 L
.75622 .1215 L
.7572 .12105 L
.75814 .12062 L
.75905 .12021 L
.76002 .11977 L
.76095 .11934 L
.76194 .11889 L
.7629 .11845 L
.76382 .11803 L
.76479 .11758 L
.76573 .11714 L
.76673 .11668 L
.7677 .11623 L
.76862 .1158 L
.76961 .11534 L
Mistroke
.77056 .1149 L
.77147 .11447 L
.77244 .11402 L
.77338 .11358 L
.77437 .11311 L
.77533 .11266 L
.77625 .11222 L
.77723 .11176 L
.77817 .11131 L
.77908 .11088 L
.78005 .11042 L
.78098 .10998 L
.78197 .10951 L
.78292 .10905 L
.78384 .10861 L
.78481 .10815 L
.78575 .10769 L
.78675 .10722 L
.78771 .10675 L
.78863 .10631 L
.78961 .10583 L
.79056 .10537 L
.79147 .10493 L
.79244 .10446 L
.79338 .10401 L
.79437 .10353 L
.79532 .10306 L
.79624 .10261 L
.79722 .10214 L
.79816 .10168 L
.79916 .10119 L
.80013 .10072 L
.80105 .10026 L
.80204 .09978 L
.80299 .09931 L
.80391 .09886 L
.80488 .09838 L
.80582 .09792 L
.80681 .09743 L
.80777 .09695 L
.80869 .0965 L
.80967 .09601 L
.81062 .09554 L
.81153 .09509 L
.81249 .09461 L
.81343 .09415 L
.81442 .09366 L
.81537 .09318 L
.81629 .09272 L
.81726 .09224 L
Mistroke
.8182 .09177 L
.8192 .09127 L
.82016 .09079 L
.82109 .09032 L
.82207 .08983 L
.82302 .08935 L
.82393 .0889 L
.8249 .08841 L
.82584 .08794 L
.82683 .08744 L
.82779 .08696 L
.82871 .08649 L
.82969 .086 L
.83063 .08552 L
.83154 .08507 L
.8325 .08458 L
.83343 .08411 L
.83442 .08361 L
.83537 .08313 L
.83629 .08266 L
.83726 .08217 L
.8382 .08169 L
.8392 .08119 L
.84016 .0807 L
.84108 .08023 L
.84206 .07973 L
.84301 .07925 L
.84392 .07878 L
.84489 .07829 L
.84582 .07781 L
.84681 .07731 L
.84777 .07682 L
.84869 .07635 L
.84966 .07585 L
.8506 .07537 L
.8516 .07486 L
.85257 .07436 L
.85349 .07389 L
.85448 .07338 L
.85543 .07289 L
.85634 .07243 L
.85731 .07193 L
.85825 .07145 L
.85924 .07093 L
.8602 .07044 L
.86112 .06997 L
.86211 .06946 L
.86305 .06898 L
.86396 .06851 L
.86492 .06801 L
Mistroke
.86585 .06753 L
.86684 .06702 L
.8678 .06653 L
.86871 .06605 L
.86969 .06555 L
.87063 .06506 L
.87163 .06455 L
.87259 .06405 L
.87351 .06357 L
.8745 .06306 L
.87544 .06257 L
.87635 .0621 L
.87732 .0616 L
.87826 .06111 L
.87925 .0606 L
.88021 .0601 L
.88113 .05962 L
.88211 .05911 L
.88305 .05862 L
.88395 .05815 L
.88492 .05765 L
.88585 .05717 L
.88683 .05665 L
.88778 .05616 L
.8887 .05568 L
.88967 .05517 L
.89061 .05469 L
.8916 .05417 L
.89256 .05367 L
.89349 .05318 L
.89447 .05267 L
.89541 .05218 L
.89632 .0517 L
.89729 .0512 L
.89822 .05071 L
.89921 .05019 L
.90017 .04969 L
.90109 .04921 L
.90206 .0487 L
.903 .04821 L
.904 .04769 L
.90496 .04718 L
.90589 .0467 L
.90688 .04618 L
.90782 .04568 L
.90874 .0452 L
.90971 .04469 L
.91064 .0442 L
.91164 .04368 L
.91259 .04318 L
Mistroke
.91352 .0427 L
.91449 .04218 L
.91544 .04168 L
.91635 .04121 L
.91731 .0407 L
.91824 .04021 L
.91923 .03969 L
.92018 .03919 L
.9211 .03871 L
.92207 .03819 L
.92301 .0377 L
.92401 .03718 L
.92497 .03667 L
.92589 .03618 L
.92688 .03566 L
.92782 .03516 L
.92873 .03468 L
.9297 .03417 L
.93063 .03368 L
.93163 .03316 L
.93258 .03265 L
.9335 .03217 L
.93448 .03165 L
.93542 .03115 L
.93642 .03063 L
.93738 .03012 L
.93831 .02963 L
.9393 .0291 L
.94025 .0286 L
.94116 .02812 L
.94213 .0276 L
.94307 .02711 L
.94407 .02658 L
.94502 .02607 L
.94595 .02559 L
.94693 .02507 L
.94787 .02457 L
.94878 .02408 L
.94975 .02357 L
.95068 .02308 L
.95167 .02255 L
.95262 .02205 L
.95354 .02156 L
.95451 .02104 L
.95545 .02055 L
.95645 .02002 L
.95741 .01951 L
.95834 .01901 L
.95932 .01849 L
.96027 .01799 L
Mistroke
.96118 .0175 L
.96215 .01699 L
.96309 .01649 L
.96408 .01597 L
.96504 .01546 L
.96596 .01497 L
.96694 .01445 L
.96788 .01395 L
.96879 .01346 L
.96975 .01295 L
.97068 .01246 L
.97167 .01193 L
.97262 .01142 L
.97353 .01094 L
.97451 .01042 L
.97545 .00992 L
.97619 .00952 L
Mfstroke
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{612.625, 245},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009T0000mB000`400?l00000o`00003oo`3ooooo
0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo=@3oool00`000000oooo0?ooo`0/0?ooo`<0
00003@3oool300000>h0oooo003o0?ooocD0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0>`0oooo003o0?ooocD0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0>`0oooo003o0?ooobH0oooo1@00000:
0?ooo`040000003oool00000000000@0oooo0`0000040?ooo`<000000`3oool00`000000oooo0?oo
o`0200000080oooo00@000000?ooo`3oool0oooo0`0000030?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0>`0oooo003o0?ooobL0oooo00<000000?ooo`3o
ool02`3oool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000003
0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`3/0?ooo`00o`3ooolW0?ooo`030000003oool0oooo00/0oooo00D000000?oo
o`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001P3oool010000000oooo0?oo
o`0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0k03o
ool00?l0oooo:03oool010000000oooo0?ooo`3oool700000080oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool3000000<0oooo00@000000?ooo`3o
ool000000`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0>`0oooo003o0?ooobT0oooo00<0
00000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0>`0oooo003o0?ooobT0oooo00<000000?ooo`3oool02@3o
ool200000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`8000000P3oool200000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3/0?ooo`00o`3ooolV0?ooo`D000002P3oool010000000oooo0000000000040?ooo`<00000103o
ool3000000<0oooo00<000000?ooo`0000000P0000020?ooo`040000003oool0oooo0?ooo`<00000
0`3oool010000000oooo0000000000050?ooo`030000003oool0oooo0080oooo00@000000?ooo`00
000000000P3oool2000000D0oooo00<000000?ooo`3oool0k03oool00?l0ooooC@3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0k03oool00?l0oooo
C@3oool00`000000oooo0?ooo`0D0?ooo`<000003@3oool300000>h0oooo003o0?ooodX0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?oooa80oooo003o0?ooool0ooooIP3oool0
0?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3o
oomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool009<0oooo00<000000?ooo`3o
ool0B03oool400000500oooo00<000000?ooo`3oool0C03oool6000004`0oooo1000001A0?ooo`03
0000003oool0oooo03T0oooo002C0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
>@3oool009<0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo04X0oooo1P00000j0?ooo`00R03oool7000000@0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo04/0oooo00@000000?ooo`3oool00000>`3o
ool009<0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo04/0oooo00@000000?ooo`3oool00000>`3oool009<0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`1;0?ooo`<00000C`3oool00`000000oooo0000000k0?ooo`00T`3oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0000000k0?ooo`00T@3oool00`000000oooo000000190?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0000001C0?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool0C@3oool2000003/0oooo002B0?ooo`800000B@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo04`0oooo0P00001>0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04d0oooo
0P00000k0?ooo`00T`3oool00`000000oooo0?ooo`180?ooo`@00000D03oool00`000000oooo0?oo
o`1=0?ooo`@00000C@3oool400000540oooo00<000000?ooo`3oool0>@3oool00?l0ooooo`3ooomV
0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00o`3o
oooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?ooo`00J03ooooo00000<`0
0000<@3oool006P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo02l0oooo001X0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool0CP3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool0
06P0oooo0`00000T0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`00
07l0oooo0?ooo`1>0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool00`00
8]/00000000Rf`070?ooo`800000<@3oool006P0oooo00<000000?ooo`3oool0903oool00`0007l0
oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool00`0007l0
oooo0?ooo`1?0?ooo`030000O`3oool0oooo04`0oooo0`000002000Rf`P0oooo00<000000?ooo`3o
ool0;`3oool006P0oooo00<000000?ooo`3oool0903oool00`0007l0oooo0?ooo`1?0?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`1?0?ooo`030000
O`3oool0oooo04/0oooo0P000000103oool002;K000Rf`008]/80?ooo`030000003oool0oooo02l0
oooo001X0?ooo`030000003oool0oooo02@0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo
0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo
0?ooo`190?ooo`8000000`3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool006P0oooo00<0
00000?ooo`3oool0903oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0
001o0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04L0oooo0`00
00040?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00J03oool3000002@0oooo00<0001o
0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`080?ooo`030?XN1@000000000004@0oooo00<0001o
0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04D0oooo0P000007
0?ooo`<002;K1`3oool200000340oooo001X0?ooo`030000003oool0oooo02@0oooo00<0001o0?oo
o`3oool0C`3oool00`0007l0oooo0?ooo`070?ooo`D00000@`3oool00`0007l0oooo0?ooo`1>0?oo
o`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0@`3oool3000000P0oooo0`008]/80?oo
o`030000003oool0oooo02l0oooo001A0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool0oooo1000000:0?ooo`030000003oool0oooo02@0oooo00<0001o0?ooo`3oool0C`3oool00`00
07l0oooo0?ooo`040?ooo`@000000`3j7PD0103oool000000000000000100?ooo`030000O`3oool0
oooo04h0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`110?ooo`<000002P3oool3
000Rf`P0oooo00<000000?ooo`3oool0;`3oool00540oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0903oool00`00
07l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo0080oooo0`0000030?ooo`<0nQh5103oool30000
03d0oooo00<0001o0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo
03l0oooo0`00000<0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00D@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0903oool00`0007l0
oooo0?ooo`1?0?ooo`030000O`3oool00000008000001P3oool30?XN1@H0oooo0`00000k0?ooo`03
0000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0n0?ooo`80
00003P3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool004H0oooo1`0000040?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool4000007D0001o0`0000080000O`<0nQh5
2@0007l300000?l0001o6P0007l300000100001o0`008]/60000O`<00000<@3oool00540oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0903oool00`0007l0oooo0?ooo`1<0?ooo`<0000000<0001o0?ooo`3oool0203o
ool30?XN1@`0oooo0`00000e0?ooo`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool0C`3o
ool00`0007l0oooo0?ooo`0j0?ooo`8000004P3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3o
ool00540oooo00<000000?ooo`3oool01@3oool5000000X0oooo00<000000?ooo`3oool0903oool0
0`0007l0oooo0?ooo`190?ooo`<000000`3oool00`0007l0oooo0?ooo`080?ooo`<0nQh53P3oool4
00000380oooo00<0001o0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0
oooo03P0oooo0P00000D0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00D@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0903oool00`00
07l0oooo0?ooo`160?ooo`<000001P3oool00`0007l0oooo0?ooo`080?ooo`<0nQh54@3oool30000
0300oooo00<0001o0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo
03H0oooo0P00000F0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00C`3oool00`000000
oooo000000080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0903oool00`0007l0
oooo0?ooo`100?ooo`<0nQh500@0oooo0000000000000000203oool00`0007l0oooo0?ooo`080?oo
o`<0nQh5503oool3000002d0oooo00<0001o0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`1?0?oo
o`030000O`3oool0oooo03@0oooo0P00000H0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?oo
o`00D03oool2000000P0oooo00<000000?ooo`3oool02`3oool3000002@0oooo00<0001o0?ooo`3o
ool0@03oool0103j7PD0000000000000000;0?ooo`030000O`3oool0oooo00P0oooo0`3j7PDF0?oo
o`@00000:P3oool00`0007l0oooo0?ooo`1>0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?oo
o`3oool0<P3oool3000001T0oooo0`008]/70?ooo`800000<@3oool00540oooo00<000000?ooo`3o
ool01P3oool5000000T0oooo00<000000?ooo`3oool0903oool00`0007l0oooo0?ooo`100?ooo`80
000000<0nQh50?ooo`3oool02P3oool00`0007l0oooo0?ooo`080?ooo`<0nQh56@3oool4000002L0
oooo00<0001o0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo0300
oooo0`00000K0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo
0?ooo`0T0?ooo`030000O`3oool0oooo0400oooo00<000000?XN1@3j7PD0303oool00`0007l0oooo
0?ooo`080?ooo`<0nQh5703oool3000002D0oooo00<0001o0?ooo`3oool0CP3oool00`0007l0oooo
0?ooo`1?0?ooo`030000O`3oool0oooo02h0oooo0`00000M0?ooo`<002;K203oool00`000000oooo
0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`0T0?ooo`030000O`3oool0oooo03l0oooo00@0
00000?XN1@3j7PD0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh57`3oool300000280oooo
00<0001o0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo02d0oooo
0P00000O0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?oo
o`0T0?ooo`030000O`3oool0oooo03h0oooo0P0000030?XN1@`0oooo00<0001o0?ooo`3oool0203o
ool30?XN1B40oooo0`00000P0?ooo`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool0C`3o
ool00`0007l0oooo0?ooo`0Z0?ooo`<000008@3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3o
ool006P0oooo0`00000T0?ooo`030000O`3oool0oooo03h0oooo00<000000?ooo`3j7PD00P3j7PD<
0?ooo`030000O`3oool0oooo00P0oooo0`3j7PDT0?ooo`@00000703oool00`0007l0oooo0?ooo`1>
0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0:@3oool2000002<0oooo0`008]/7
0?ooo`800000<@3oool006P0oooo00<000000?ooo`3oool0903oool00`0007l0oooo0?ooo`0m0?oo
o`80000000@0oooo0?XN1@3j7PD0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh59`3oool3
000001X0oooo00<0001o0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0
oooo02L0oooo0P00000U0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`00
0000oooo0?ooo`0T0?ooo`030000O`3oool0oooo03d0oooo00<000000?ooo`3oool00`3j7PD<0?oo
o`030000O`3oool0oooo00P0oooo0`3j7PDZ0?ooo`<000005`3oool00`0007l0oooo0?ooo`1>0?oo
o`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool09@3oool2000002L0oooo0`008]/80?oo
o`030000003oool0oooo02l0oooo001X0?ooo`030000003oool0oooo02@0oooo00<0001o0?ooo`3o
ool0?03oool010000000oooo0?ooo`3oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN
1B`0oooo1000000D0?ooo`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool0C`3oool00`00
07l0oooo0?ooo`0S0?ooo`800000:@3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool006P0
oooo00<000000?ooo`3oool0903oool00`0007l0oooo0?ooo`0k0?ooo`8000000`3oool30?XN1@`0
oooo00<0001o0?ooo`3oool0203oool30?XN1Bl0oooo0`00000B0?ooo`030000O`3oool0oooo04h0
oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0Q0?ooo`<00000:P3oool3000Rf`P0
oooo00<000000?ooo`3oool0;`3oool006P0oooo00<000000?ooo`3oool0903oool00`0007l0oooo
0?ooo`0k0?ooo`030000003oool0oooo0080oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo
0`3j7PDb0?ooo`<000003`3oool00`0007l0oooo0?ooo`1>0?ooo`030000O`3oool0oooo04l0oooo
00<0001o0?ooo`3oool07`3oool2000002d0oooo0`008]/80?ooo`030000003oool0oooo02l0oooo
001X0?ooo`<00000903oool00`0007l0oooo0?ooo`0j0?ooo`030000003oool0oooo00<0oooo0`3j
7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PDd0?ooo`@00000303oool00`0007l0oooo0?oo
o`1>0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool07@3oool3000002h0oooo0`00
8]/70?ooo`800000<@3oool006P0oooo00<000000?ooo`3oool0903oool00`0007l0oooo0?ooo`0j
0?ooo`030000003oool0oooo00<0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PDh
0?ooo`<000002@3oool00`0007l0oooo0?ooo`1>0?ooo`030000O`3oool0oooo04l0oooo00<0001o
0?ooo`3oool06`3oool200000340oooo0`008]/80?ooo`030000003oool0oooo02l0oooo001X0?oo
o`030000003oool0oooo02@0oooo00<0001o0?ooo`3oool0>@3oool00`000000oooo0?ooo`040?oo
o`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5>P3oool4000000H0oooo00<0001o0?oo
o`3oool0CP3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo01T0oooo0`00000b0?oo
o`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`0T0?ooo`03
0000O`3oool0oooo03P0oooo0P0000060?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0
nQh5?@3oool3000000@0oooo00<0001o0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`1?0?ooo`03
0000O`3oool0oooo01L0oooo0`00000d0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00
J03oool00`000000oooo0?ooo`0T0?ooo`030000O`3oool0oooo03P0oooo00<000000?ooo`3oool0
1@3oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D00oooo0`0000000`3oool0001o
0?ooo`1?0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool05@3oool3000003H0oooo
0`008]/80?ooo`030000003oool0oooo02l0oooo001X0?ooo`<00000903oool00`0007l0oooo0?oo
o`0g0?ooo`030000003oool0oooo00H0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j
7PE30?ooo`<00000C`3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo01<0oooo0`00
000h0?ooo`<002;K1`3oool200000340oooo001X0?ooo`030000003oool0oooo02@0oooo00<0001o
0?ooo`3oool0=`3oool00`000000oooo0?ooo`060?ooo`<0nQh5303oool00`0007l0oooo0?ooo`08
0?ooo`<0nQh5A03oool00`0007l0oooo00000002000004`0oooo00<0001o0?ooo`3oool0C`3oool0
0`0007l0oooo0?ooo`0A0?ooo`<00000>P3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool0
05`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0T0?ooo`030000O`3oool0oooo
03H0oooo00<000000?ooo`3oool01`3oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN
1D@0oooo00<0001o0?ooo`3oool00P3oool3000004T0oooo00<0001o0?ooo`3oool0C`3oool00`00
07l0oooo0?ooo`0?0?ooo`<00000?03oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool005`0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0T0?ooo`030000O`3oool0oooo03H0
oooo00<000000?ooo`3oool01`3oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0
oooo00<0001o0?ooo`3oool01@3oool3000004H0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0
oooo0?ooo`0>0?ooo`800000?P3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool005`0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0T0?ooo`030000O`3oool0oooo03D0oooo
00<000000?ooo`3oool0203oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo
00<0001o0?ooo`3oool01`3oool4000004<0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo
0?ooo`0;0?ooo`<00000@03oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool00540oooo1`00
00040?ooo`030000003oool0oooo00T0oooo1000001J0000O`030000000007l0001o00T0001o0`3j
7PDG0000O`<0nQh5D@0007l4000009l0001o0P0000120000O`<002;K1P0007l300000340oooo001L
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0903oool00`0007l0oooo0?ooo`0c
0?ooo`8000002`3oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o
0?ooo`3oool03@3oool4000003d0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`07
0?ooo`<00000A03oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool005`0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`070?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0a0?oo
o`80nQh500<000000?ooo`3oool02P3oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN
1D@0oooo00<0001o0?ooo`3oool0403oool400000080nQh5>03oool00`0007l0oooo0?ooo`1?0?oo
o`030000O`3oool0oooo00D0oooo0`0000160?ooo`<002;K203oool00`000000oooo0?ooo`0_0?oo
o`00G03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<002;K00000000
8]/06P3oool00`0007l0oooo0?ooo`0a0?ooo`030?XN1@000000000000`0oooo0`3j7PD<0?ooo`03
0000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo0`00000h0?ooo`03
0000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool00`3oool3000004P0oooo0`008]/80?ooo`03
0000003oool0oooo02l0oooo001J0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool0
1`3oool00`008]/000000000000J0?ooo`030000O`3oool0oooo0340oooo0P0000000`3j7PD0oooo
0?ooo`0:0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5A03oool00`0007l0oooo
0?ooo`0C0?ooo`80nQh50P00000g0?ooo`030000O`3oool0oooo04l0oooo00@0001o0?ooo`3oool0
oooo0`00001:0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00F`3oool2000000/0oooo
0`0000070?ooo`8002;K0P00000I0?ooo`030000O`3oool0oooo0300oooo0P0000020?XN1@`0oooo
0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo
0`3j7PD00`000000oooo0?ooo`0e0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0
0P00001<0?ooo`<002;K1`3oool200000340oooo001L0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01`3oool3000Rf`030000003oool0oooo01L0oooo00<0001o0?ooo`3oool0<03o
ool010000000nQh50?XN1@3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5
A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh500<0oooo0000003oool0=@3oool00`0007l0oooo
0?ooo`1?0?ooo`<00000CP3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool006P0oooo00<0
00000?ooo`3oool01`3oool3000Rf`030?ooo`000000oooo01L0oooo00<0001o0?ooo`3oool0;`3o
ool00`000000oooo0?XN1@020?XN1@`0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j
7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD00`3oool000000000000e0?ooo`030000O`3o
ool0oooo04d0oooo0`00001@0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00J03oool0
0`000000oooo0?ooo`070?ooo`<002;K0P3oool00`000000oooo0?ooo`0E0?ooo`030000O`3oool0
oooo02h0oooo00<000000?ooo`3oool00`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`08
0?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh50P3oool2000003@0oooo00<0001o
0?ooo`3oool0B`3oool3000000030?ooo`0007l0oooo04l0oooo0`008]/80?ooo`030000003oool0
oooo02l0oooo001X0?ooo`030000003oool0oooo00L0oooo0`008]/30?ooo`030000003oool0oooo
01@0oooo00<0001o0?ooo`3oool0;@3oool010000000oooo0?ooo`3oool30?XN1@`0oooo0`3j7PD<
0?ooo`030000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD3
0?ooo`800000<`3oool00`0007l0oooo0?ooo`190?ooo`<000000`3oool00`0007l0oooo0?ooo`1>
0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00J03oool3000000L0oooo0`008]/40?oo
o`030000003oool0oooo01<0oooo00<0001o0?ooo`3oool0;03oool2000000<0oooo0`3j7PD<0?oo
o`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?oo
o`<0nQh5103oool200000380oooo00<0001o0?ooo`3oool0A`3oool3000000D0oooo00<0001o0?oo
o`3oool0CP3oool3000Rf`L0oooo0P00000a0?ooo`00=`3oool200000080oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`070?ooo`<002;K103oool2000001@0oooo00<0001o0?ooo`3o
ool0:`3oool2000000@0oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0
nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51@3oool00`000000oooo0?ooo`0`0?ooo`03
0000O`3oool0oooo04D0oooo0`0000070?ooo`030000O`3oool0oooo04h0oooo0`008]/80?ooo`03
0000003oool0oooo02l0oooo000f0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`070?ooo`<002;K1@3oool2000001<0oooo00<0001o0?ooo`3o
ool0:P3oool2000000D0oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0
nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51P3oool00`000000oooo0?ooo`0_0?ooo`03
0000O`3oool0oooo04<0oooo0P00000:0?ooo`030000O`3oool0oooo04h0oooo0`008]/80?ooo`03
0000003oool0oooo02l0oooo000f0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`070?ooo`<002;K1P3oool200000180oooo00<0001o0?ooo`3o
ool0:@3oool2000000H0oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0
nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool00`000000oooo0?ooo`0^0?ooo`03
0000O`3oool0oooo0440oooo0P00000<0?ooo`030000O`3oool0oooo04h0oooo0`008]/80?ooo`03
0000003oool0oooo02l0oooo000f0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`070?ooo`<002;K1`3oool00`000000oooo0?ooo`0@0?ooo`03
0000O`3oool0oooo02T0oooo00<000000?ooo`3oool01@3oool30?XN1@`0oooo0`3j7PD<0?ooo`03
0000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD70?ooo`03
0?XN1@000000nQh502h0oooo00<0001o0?ooo`3oool0?P3oool3000000h0oooo00<0001o0?ooo`3o
ool0CP3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool003L0oooo00<000000?ooo`3oool0
0P00000/0?ooo`<000001`3oool3000Rf`P0oooo00<000000?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0X0?ooo`030000003oool0oooo00H0oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo
0?ooo`080?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool00`3j7PD00000
0000000^0?ooo`030000O`3oool0oooo03`0oooo0`00000@0?ooo`030000O`3oool0oooo04h0oooo
0`008]/70?ooo`800000<@3oool006P0oooo00<000000?ooo`3oool01`3oool3000Rf`T0oooo00<0
00000?ooo`3oool03P3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo00L0oooo0`3j
7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5A03oool00`0007l0oooo0?oo
o`0C0?ooo`<0nQh51`3oool30?XN1@<00000:`3oool00`0007l0oooo0?ooo`0j0?ooo`<000004P3o
ool00`0007l0oooo0?ooo`1>0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00J03oool0
0`000000oooo0?ooo`070?ooo`<002;K2P3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0
oooo02H0oooo00<000000?ooo`3oool0203oool30?XN1@`0oooo0`3j7PD<0?ooo`030000O`3oool0
oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD70?ooo`<0nQh50P3oool3
000002T0oooo00<0001o0?ooo`3oool0>03oool2000001D0oooo00<0001o0?ooo`3oool0CP3oool3
000Rf`P0oooo00<000000?ooo`3oool0;`3oool003H0oooo2P00000X0?ooo`030000003oool0oooo
00L0oooo0`008]/;0?ooo`030000003oool0oooo00`0oooo00<0001o0?ooo`3oool09@3oool00`00
0000oooo0?ooo`090?ooo`<0nQh5303oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN
1D@0oooo00<0001o0?ooo`3oool04`3oool30?XN1@L0oooo0`3j7PD40?ooo`<000009`3oool00`00
07l0oooo0?ooo`0f0?ooo`8000005`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K203oool00`00
0000oooo0?ooo`0_0?ooo`00=`3oool01@000000oooo0?ooo`3oool0000002`0oooo00<000000?oo
o`3oool01`3oool3000Rf`/0oooo0P00000=0?ooo`030000O`3oool0oooo02@0oooo0P00000;0?oo
o`<0nQh5303oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?oo
o`3oool04`3oool30?XN1@L0oooo0`3j7PD70?ooo`8000009@3oool00`0007l0oooo0?ooo`0c0?oo
o`<000006@3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?oo
o`00=P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool01`3oool3000Rf`d0oooo00<000000?ooo`3oool02P3oool00`0007l0oooo0?ooo`0S0?ooo`80
0000303oool30?XN1@`0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PE40?ooo`03
0000O`3oool0oooo01<0oooo0`3j7PD70?ooo`<0nQh52@3oool300000280oooo00<0001o0?ooo`3o
ool0<@3oool3000001/0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`P0oooo00<000000?ooo`3o
ool0;`3oool003H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Y0?ooo`<00000
1`3oool3000Rf`h0oooo00<000000?ooo`3oool02@3oool00`0007l0oooo0?ooo`0R0?ooo`800000
3@3oool30?XN1@`0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000
O`3oool0oooo01<0oooo0`3j7PD70?ooo`<0nQh52`3oool300000200oooo00<0001o0?ooo`3oool0
;`3oool2000001h0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`L0oooo0P00000a0?ooo`00=`3o
ool5000001<0oooo100000030?ooo`040000003oool0oooo0?ooo`@000002P3oool00`000000oooo
0?ooo`070?ooo`<002;K3P3oool2000000X0oooo00<0001o0?ooo`3oool08P3oool00`000000oooo
0?ooo`0<0?ooo`<0nQh5303oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo
00<0001o0?ooo`3oool04`3oool30?XN1@L0oooo0`3j7PD>0?ooo`<000007@3oool00`0007l0oooo
0?ooo`0/0?ooo`<00000803oool00`0007l0oooo0?ooo`1>0?ooo`<002;K203oool00`000000oooo
0?ooo`0_0?ooo`00CP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0`00
8]/?0?ooo`8000002@3oool00`0007l0oooo0?ooo`0Q0?ooo`030000003oool0oooo00d0oooo0`3j
7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5A03oool00`0007l0oooo0?oo
o`0C0?ooo`<0nQh51`3oool30?XN1A00oooo1000000J0?ooo`030000O`3oool0oooo02T0oooo1000
000R0?ooo`030000O`3oool0oooo04h0oooo0`008]/80?ooo`030000003oool0oooo02l0oooo001>
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo0`008]/@0?ooo`800000203oool00`0007l0oooo0?ooo`0P
0?ooo`030000003oool0oooo00h0oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`08
0?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool30?XN1A<0oooo0`00000H
0?ooo`030000O`3oool0oooo02L0oooo0`00000U0?ooo`030000O`3oool0oooo04h0oooo0`008]/8
0?ooo`030000003oool0oooo02l0oooo000g0?ooo`D000002P3oool7000000030?ooo`000000oooo
00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo0`008]/A0?ooo`8000001`3oool00`0007l0oooo0?ooo`0O0?ooo`030000003oool0oooo
00l0oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5A03oool00`00
07l0oooo0?ooo`0C0?ooo`<0nQh51`3oool30?XN1AH0oooo0`00000E0?ooo`030000O`3oool0oooo
02@0oooo0`00000X0?ooo`030000O`3oool0oooo04h0oooo0`008]/80?ooo`030000003oool0oooo
02l0oooo000f0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`070?ooo`@000001P0007l3000Rfa80001o00<000000000O`0007l09P0007l00`000000
001o0000O`0@0000O`<0nQh5300007l30?XN1AL0001o0`3j7PEJ0000O`<0nQh51`0007l30?XN1AP0
001o1000000f0000O`<00000O00007l3000Rf`H0001o0`00000a0?ooo`00=P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`D000002P3oool00`000000oooo0?ooo`070?ooo`<002;K4`3oool00`000000oooo
0?ooo`040?ooo`030000O`3oool0oooo01d0oooo0P00000B0?ooo`<0nQh5303oool30?XN1@`0oooo
00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3oool04`3oool30?XN1@L0oooo
0`3j7PDK0?ooo`@000003`3oool00`0007l0oooo0?ooo`0N0?ooo`@00000;@3oool00`0007l0oooo
0?ooo`1>0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00=P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool3000Rfa@0oooo00<0
00000?ooo`3oool00`3oool00`0007l0oooo0?ooo`0L0?ooo`030000003oool0oooo0180oooo0`3j
7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5A03oool00`0007l0oooo0?oo
o`0C0?ooo`<0nQh51`3oool30?XN1Ah0oooo1@00000;0?ooo`030000O`3oool0oooo01X0oooo1000
000a0?ooo`030000O`3oool0oooo04h0oooo0`008]/80?ooo`030000003oool0oooo02l0oooo000g
0?ooo`D000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`<002;K5@3oool00`000000oooo0?ooo`02
0?ooo`030000O`3oool0oooo01/0oooo00<000000?ooo`3oool04`3oool30?XN1@`0oooo0`3j7PD<
0?ooo`030000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD7
0?ooo`<0nQh58P3oool5000000L0oooo00<0001o0?ooo`3oool05P3oool5000003@0oooo00<0001o
0?ooo`3oool0CP3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool004h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool01`3oool3000RfaH0oooo00D000000?ooo`3oool0oooo0000O`0L0?ooo`8000005@3oool3
0?XN1@`0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0
oooo01<0oooo0`3j7PD70?ooo`<0nQh59P3oool600000080oooo00<0001o0?ooo`3oool04@3oool6
000003P0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool0
03H0oooo00<000000?ooo`3oool05P3oool4000000L0oooo1@0000090?ooo`<000001`3oool3000R
faL0oooo00@000000?ooo`3oool0001o6`3oool2000001H0oooo0`3j7PD<0?ooo`<0nQh5303oool0
0`0007l0oooo0?ooo`080?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool3
0?XN1B/0oooo5`00000n0?ooo`030000O`3oool0oooo04h0oooo0`008]/70?ooo`800000<@3oool0
03@0oooo2@00000[0?ooo`030000003oool0oooo00L0oooo0`008]/H0?ooo`030000003oool0001o
01X0oooo0P00000G0?ooo`<0nQh5303oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN
1D@0oooo00<0001o0?ooo`3oool04`3oool30?XN1@L0oooo0`3j7PD^0?ooo`030000O`3oool0oooo
04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool003H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00L0
oooo0`008]/I0?ooo`030000000007l0oooo01P0oooo0P00000H0?ooo`<0nQh5303oool30?XN1@`0
oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3oool04`3oool30?XN1@L0
oooo0`3j7PD^0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`P0
oooo00<000000?ooo`3oool0;`3oool006P0oooo00<000000?ooo`3oool01`3oool3000RfaT0oooo
0P00000H0?ooo`8000006@3oool30?XN1@`0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo
0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD70?ooo`<0nQh5;P3oool00`0007l0oooo
0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/80?ooo`030000003oool0oooo02l0oooo
001X0?ooo`030000003oool0oooo00L0oooo0`008]/J0?ooo`030000O`000000oooo01D0oooo0P00
000J0?ooo`<0nQh5303oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0
001o0?ooo`3oool04`3oool30?XN1@L0oooo0`3j7PD^0?ooo`030000O`3oool0oooo04l0oooo00<0
001o0?ooo`3oool0CP3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool006P0oooo0`000007
0?ooo`<002;K6P3oool00`0007l0oooo0000000D0?ooo`8000006`3oool30?XN1@`0oooo0`3j7PD<
0?ooo`030000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD7
0?ooo`<0nQh5;P3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/7
0?ooo`800000<@3oool006P0oooo00<000000?ooo`3oool01`3oool3000RfaX0oooo00@0001o0?oo
o`3oool000004P3oool2000001`0oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`08
0?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool30?XN1Bh0oooo00<0001o
0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K203oool00`000000oooo0?ooo`0_
0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<002;K6P3oool0100007l0oooo0?ooo`3oool2
000000l0oooo00<000000?ooo`3oool0703oool30?XN1@`0oooo0`3j7PD<0?ooo`030000O`3oool0
oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD70?ooo`<0nQh5;P3oool0
0`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/80?ooo`030000003oool0
oooo02l0oooo000g0?ooo`8000000P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
00L0oooo0`008]/J0?ooo`030000O`3oool0oooo0080oooo0P00000=0?ooo`030000003oool0oooo
01d0oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5A03oool00`00
07l0oooo0?ooo`0C0?ooo`<0nQh51`3oool30?XN1Bh0oooo00<0001o0?ooo`3oool0C`3oool00`00
07l0oooo0?ooo`1>0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00=P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool3000R
faX0oooo00<0001o0?ooo`3oool00`3oool2000000X0oooo0P00000P0?ooo`<0nQh5303oool30?XN
1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3oool04`3oool30?XN
1@L0oooo0`3j7PD^0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000R
f`P0oooo00<000000?ooo`3oool0;`3oool003H0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0Y0?ooo`<000001`3oool3000RfaX0oooo00<0001o0?ooo`3oool01@3oool20000
00H0oooo0P00000R0?ooo`<0nQh5303oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN
1D@0oooo00<0001o0?ooo`3oool04`3oool30?XN1@L0oooo0`3j7PD^0?ooo`030000O`3oool0oooo
04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`L0oooo0P00000a0?ooo`00=P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool3000R
faX0oooo00<0001o0?ooo`3oool01`3oool7000002<0oooo0`3j7PD<0?ooo`<0nQh5303oool00`00
07l0oooo0?ooo`080?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool30?XN
1Bh0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K203oool00`00
0000oooo0?ooo`0_0?ooo`00=`3oool00`000000oooo0?ooo`02000002`0oooo00<000000?ooo`3o
ool01`3oool3000RfaX0oooo00<0001o0?ooo`3oool0<@3oool30?XN1@`0oooo0`3j7PD<0?ooo`03
0000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD70?ooo`<0
nQh5;P3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/80?ooo`03
0000003oool0oooo02l0oooo001X0?ooo`030000003oool0oooo00L0oooo0`008]/J0?ooo`030000
O`3oool0oooo0340oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5
A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool30?XN1Bh0oooo00<0001o0?ooo`3oool0
C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00J03o
ool00`000000oooo0?ooo`070?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0a0?ooo`<0nQh5303o
ool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3oool04`3o
ool30?XN1@L0oooo0`3j7PD^0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3o
ool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool003<0oooo00<000000?ooo`3oool01`00000[
0?ooo`030000003oool0oooo00L0oooo0`008]/J0?ooo`030000O`3oool0oooo0340oooo0`3j7PD<
0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C
0?ooo`<0nQh51`3oool30?XN1Bh0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>
0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00J03oool3000000L0oooo0`008]/J0?oo
o`030000O`3oool0oooo0340oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?oo
o`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool30?XN1Bh0oooo00<0001o0?oo
o`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K1`3oool200000340oooo001J0?ooo`@0
00002P3oool00`000000oooo0?ooo`070?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0a0?ooo`<0
nQh5303oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3o
ool04`3oool30?XN1@L0oooo0`3j7PD^0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3o
ool0CP3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool003H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`070?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0a0?ooo`<0nQh5
303oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3oool0
4`3oool30?XN1@L0oooo0`3j7PD^0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0
CP3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool003H0oooo00@000000?ooo`3oool0oooo
0`00000L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0a0?ooo`<0nQh5303oool30?XN1@`0oooo
00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3oool04`3oool30?XN1@L0oooo
0`3j7PD^0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`P0oooo
00<000000?ooo`3oool0;`3oool003H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0a0?ooo`<0nQh5303oool30?XN1@`0oooo
00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3oool04`3oool30?XN1@L0oooo
0`3j7PD^0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`P0oooo
00<000000?ooo`3oool0;`3oool003H0oooo0`0000030?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`@000001P0007l3000Rfdh0001o0`3j
7PD<0000O`<0nQh55`0007l30?XN1EX0001o0`3j7PD70000O`<0nQh5d@0007l3000Rf`H0001o0`00
000a0?ooo`00=P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0`008]/J
0?ooo`030000O`3oool0oooo0340oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`08
0?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool30?XN1Bh0oooo00<0001o
0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K203oool00`000000oooo0?ooo`0_
0?ooo`00F@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool3000RfaX0oooo00<0001o0?ooo`3oool0<@3oool30?XN1@`0oooo0`3j7PD<0?oo
o`030000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD70?oo
o`<0nQh5;P3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/80?oo
o`030000003oool0oooo02l0oooo001I0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0a0?ooo`<0
nQh5303oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3o
ool04`3oool30?XN1@L0oooo0`3j7PD^0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3o
ool0CP3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool003L0oooo1@00000M0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`<002;K
6P3oool00`0007l0oooo0?ooo`0a0?ooo`<0nQh5303oool30?XN1@`0oooo00<0001o0?ooo`3oool0
203oool30?XN1D@0oooo00<0001o0?ooo`3oool04`3oool30?XN1@L0oooo0`3j7PD^0?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`P0oooo00<000000?ooo`3oool0
;`3oool003H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0K0?ooo`@00000
2P3oool3000000L0oooo0`008]/J0?ooo`030000O`3oool0oooo0340oooo0`3j7PD<0?ooo`<0nQh5
303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh5
1`3oool30?XN1Bh0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K
1`3oool200000340oooo000f0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`070?ooo`<002;K6P3oool00`0007l0oooo0?ooo`0a0?ooo`<0nQh5
303oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3oool0
4`3oool30?XN1@L0oooo0`3j7PD^0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0
CP3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool003H0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00L0oooo0`008]/J0?ooo`030000
O`3oool0oooo0340oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5
A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool30?XN1Bh0oooo00<0001o0?ooo`3oool0
C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00=`3o
ool3000000030?ooo`000000oooo02/0oooo00<000000?ooo`3oool01`3oool3000RfaX0oooo00<0
001o0?ooo`3oool0<@3oool30?XN1@`0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j
7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD70?ooo`<0nQh5;P3oool00`0007l0oooo0?oo
o`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/80?ooo`030000003oool0oooo02l0oooo001X
0?ooo`030000003oool0oooo00L0oooo0`008]/J0?ooo`030000O`3oool0oooo00P0oooo1@00000T
0?ooo`<0nQh5303oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o
0?ooo`3oool04`3oool30?XN1@L0oooo0`3j7PD^0?ooo`030000O`3oool0oooo04l0oooo00<0001o
0?ooo`3oool0CP3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool006P0oooo0`0000070?oo
o`<002;K6P3oool00`0007l0oooo0?ooo`060?ooo`<000000`3oool300000280oooo0`3j7PD<0?oo
o`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?oo
o`<0nQh51`3oool30?XN1Bh0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?oo
o`<002;K1`3oool200000340oooo001X0?ooo`030000003oool0oooo00L0oooo0`008]/J0?ooo`03
0000O`3oool0oooo00@0oooo0P0000080?ooo`<00000803oool30?XN1@`0oooo0`3j7PD<0?ooo`03
0000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD70?ooo`<0
nQh5;P3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/80?ooo`03
0000003oool0oooo02l0oooo001X0?ooo`030000003oool0oooo00L0oooo0`008]/J0?ooo`030000
O`3oool0oooo00<0oooo00<000000?ooo`3oool02P3oool2000001l0oooo0`3j7PD<0?ooo`<0nQh5
303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh5
1`3oool30?XN1Bh0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K
203oool00`000000oooo0?ooo`0_0?ooo`00=03oool<000002P0oooo00<000000?ooo`3oool01`3o
ool3000RfaX0oooo00@0001o0?ooo`3oool0oooo0P00000>0?ooo`8000007P3oool30?XN1@`0oooo
0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo
0`3j7PD70?ooo`<0nQh5;P3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo
0`008]/80?ooo`030000003oool0oooo02l0oooo000d0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`070?ooo`<002;K6P3oool00`0007l0oooo0?oo
o`0200000140oooo00<000000?ooo`3oool06`3oool30?XN1@`0oooo0`3j7PD<0?ooo`030000O`3o
ool0oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD70?ooo`<0nQh5;P3o
ool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo0`008]/80?ooo`030000003o
ool0oooo02l0oooo000d0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool09P3oool3
000000L0oooo0`008]/J0?ooo`040000O`3oool00000000001<0oooo00<000000?ooo`3oool06P3o
ool30?XN1@`0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000O`3o
ool0oooo01<0oooo0`3j7PD70?ooo`<0nQh5;P3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3o
ool0oooo04h0oooo0`008]/70?ooo`800000<@3oool006P0oooo00<000000?ooo`3oool01`3oool3
000RfaX0oooo00<0001o0000000000005@3oool00`000000oooo0?ooo`0I0?ooo`<0nQh5303oool3
0?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3oool04`3oool3
0?XN1@L0oooo0`3j7PD^0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3
000Rf`P0oooo00<000000?ooo`3oool0;`3oool006P0oooo00<000000?ooo`3oool01`3oool3000R
faX0oooo0P00000G0?ooo`030000003oool0oooo01P0oooo0`3j7PD<0?ooo`<0nQh5303oool00`00
07l0oooo0?ooo`080?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool30?XN
1Bh0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K203oool00`00
0000oooo0?ooo`0_0?ooo`00=P3oool7000002/0oooo00<000000?ooo`3oool01`3oool3000RfaT0
oooo00<000000000O`3oool0603oool00`000000oooo0?ooo`0G0?ooo`<0nQh5303oool30?XN1@`0
oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3oool04`3oool30?XN1@L0
oooo0`3j7PD^0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`P0
oooo00<000000?ooo`3oool0;`3oool003L0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`070?ooo`<002;K603oool2000000030000O`3oool0oooo01P0oooo00<000000?ooo`3oool0
5P3oool30?XN1@`0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000
O`3oool0oooo01<0oooo0`3j7PD70?ooo`<0nQh5;P3oool00`0007l0oooo0?ooo`1?0?ooo`030000
O`3oool0oooo04h0oooo0`008]/80?ooo`030000003oool0oooo02l0oooo000f0?ooo`030000003o
ool0oooo02l0oooo0`0000070?ooo`<002;K5`3oool2000000030?ooo`0007l0oooo01X0oooo00<0
00000?ooo`3oool05@3oool30?XN1@`0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j
7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD70?ooo`<0nQh5;P3ooolB00000400oooo00<0
001o0?ooo`3oool0CP3oool3000Rf`L0oooo0P00000a0?ooo`00=P3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo00L0oooo0`008]/F0?ooo`8000000P3oool00`0007l0oooo0?ooo`0J
0?ooo`030000003oool0oooo01@0oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`08
0?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool30?XN1BP0oooo1`00000@
0?ooo`L00000>P3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K203oool00`000000oooo0?ooo`0_
0?ooo`00=`3oool600000180oooo100000030?ooo`040000003oool0oooo0?ooo`@000002P3oool0
0`000000oooo0?ooo`070?ooo`<002;K5@3oool00`000000oooo0?ooo`020?ooo`030000O`3oool0
oooo01/0oooo00<000000?ooo`3oool04`3oool30?XN1@`0oooo0`3j7PD<0?ooo`030000O`3oool0
oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD70?ooo`<0nQh5903oool5
000000D0oooo00<0001o0?ooo`3oool0503oool5000003H0oooo00<0001o0?ooo`3oool0CP3oool3
000Rf`P0oooo00<000000?ooo`3oool0;`3oool003H0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0`008]/D0?ooo`800000103oool00`00
07l0oooo0?ooo`0L0?ooo`030000003oool0oooo0180oooo0`3j7PD<0?ooo`<0nQh5303oool00`00
07l0oooo0?ooo`080?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool30?XN
1B00oooo1000000:0?ooo`030000O`3oool0oooo01T0oooo1000000b0?ooo`030000O`3oool0oooo
04h0oooo0`008]/80?ooo`030000003oool0oooo02l0oooo000f0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool3000Rfa<0oooo0P0000050?ooo`030000O`3oool0oooo01d0
oooo00<000000?ooo`3oool04@3oool30?XN1@`0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0
oooo0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD70?ooo`<0nQh57@3oool3000000h0
oooo00<0001o0?ooo`3oool0703oool4000002l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`P0
oooo00<000000?ooo`3oool0;`3oool003H0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`<002;K4P3oool2000000H0oooo00<0001o0?ooo`3oool07P3oool00`000000oooo
0?ooo`0@0?ooo`<0nQh5303oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo
00<0001o0?ooo`3oool04`3oool30?XN1@L0oooo0`3j7PDJ0?ooo`<000004@3oool00`0007l0oooo
0?ooo`0P0?ooo`<00000;03oool00`0007l0oooo0?ooo`1>0?ooo`<002;K203oool00`000000oooo
0?ooo`0_0?ooo`00=`3oool600000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool4000000H0001o0`00
8]/B0000O`030000000007l0001o02H0001o0P00000A0000O`<0nQh5300007l30?XN1AL0001o0`3j
7PEJ0000O`<0nQh51`0007l30?XN1AL0001o0`00000j0000O`<00000NP0007l3000Rf`H0001o0`00
000a0?ooo`00CP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo1@00000:
0?ooo`030000003oool0oooo00L0oooo0`008]/A0?ooo`030000003oool0oooo00H0oooo00<0001o
0?ooo`3oool07`3oool200000100oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`08
0?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool30?XN1A@0oooo0`00000G
0?ooo`030000O`3oool0oooo02D0oooo1000000V0?ooo`030000O`3oool0oooo04h0oooo0`008]/8
0?ooo`030000003oool0oooo02l0oooo001>0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo0`008]/@0?oo
o`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0803oool2000000l0oooo0`3j7PD<0?oo
o`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?oo
o`<0nQh51`3oool30?XN1A40oooo0`00000J0?ooo`030000O`3oool0oooo02P0oooo1000000S0?oo
o`030000O`3oool0oooo04h0oooo0`008]/80?ooo`030000003oool0oooo02l0oooo000f0?ooo`L0
00004@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`070?ooo`<002;K3P3oool2000000X0oooo00<0001o0?ooo`3o
ool08@3oool2000000h0oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0
nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool30?XN1@l0oooo0`00000L0?ooo`03
0000O`3oool0oooo02/0oooo0`00000Q0?ooo`030000O`3oool0oooo04h0oooo0`008]/80?ooo`03
0000003oool0oooo02l0oooo000g0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
1`3oool3000Rf`h0oooo00<000000?ooo`3oool02@3oool00`0007l0oooo0?ooo`0R0?ooo`030000
003oool0oooo00`0oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5
A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool30?XN1@`0oooo0`00000O0?ooo`030000
O`3oool0oooo02d0oooo0`00000O0?ooo`030000O`3oool0oooo04h0oooo0`008]/80?ooo`030000
003oool0oooo02l0oooo000f0?ooo`030000003oool0oooo01H0oooo100000070?ooo`D000002@3o
ool3000000L0oooo0`008]/=0?ooo`030000003oool0oooo00X0oooo00<0001o0?ooo`3oool08`3o
ool00`000000oooo0?ooo`0;0?ooo`<0nQh5303oool30?XN1@`0oooo00<0001o0?ooo`3oool0203o
ool30?XN1D@0oooo00<0001o0?ooo`3oool04`3oool30?XN1@L0oooo0`3j7PD:0?ooo`<000008@3o
ool00`0007l0oooo0?ooo`0`0?ooo`<00000703oool00`0007l0oooo0?ooo`1>0?ooo`<002;K1`3o
ool200000340oooo000f0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool01`3oool3
000Rf``0oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0T0?ooo`030000003oool0
oooo00X0oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5A03oool0
0`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool30?XN1@P0oooo0P00000T0?ooo`030000O`3oool0
oooo03<0oooo0P00000J0?ooo`030000O`3oool0oooo04h0oooo0`008]/80?ooo`030000003oool0
oooo02l0oooo000g0?ooo`H00000:`3oool00`000000oooo0?ooo`070?ooo`<002;K2`3oool00`00
0000oooo0?ooo`0<0?ooo`030000O`3oool0oooo02D0oooo00<000000?ooo`3oool02@3oool30?XN
1@`0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0oooo
01<0oooo0`3j7PD70?ooo`<0nQh51@3oool3000002H0oooo00<0001o0?ooo`3oool0=@3oool20000
01P0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool003H0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`070?ooo`<002;K2P3oool2000000h0
oooo00<0001o0?ooo`3oool09@3oool2000000X0oooo0`3j7PD<0?ooo`<0nQh5303oool00`0007l0
oooo0?ooo`080?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh51`3oool30?XN1@<0
oooo0`00000X0?ooo`030000O`3oool0oooo03L0oooo0`00000E0?ooo`030000O`3oool0oooo04h0
oooo0`008]/80?ooo`030000003oool0oooo02l0oooo000f0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool01`3oool3000Rf`T0oooo0P00000?0?ooo`030000O`3oool0oooo02L0oooo
00<000000?ooo`3oool01`3oool30?XN1@`0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo
0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD70?ooo`<0nQh500<0oooo000000000000
:`3oool00`0007l0oooo0?ooo`0i0?ooo`<000004`3oool00`0007l0oooo0?ooo`1>0?ooo`<002;K
203oool00`000000oooo0?ooo`0_0?ooo`00=P3oool00`000000oooo0?ooo`0_0?ooo`<000001`3o
ool3000Rf`P0oooo0P00000@0?ooo`030000O`3oool0oooo02P0oooo00<000000?ooo`3oool01P3o
ool30?XN1@`0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000O`3o
ool0oooo01<0oooo0`3j7PD70?ooo`040?XN1@0000000000000002d0oooo00<0001o0?ooo`3oool0
?03oool200000140oooo00<0001o0?ooo`3oool0CP3oool3000Rf`L0oooo0P00000a0?ooo`00=`3o
ool6000002/0oooo00<000000?ooo`3oool01`3oool3000Rf`L0oooo0P00000A0?ooo`030000O`3o
ool0oooo02T0oooo00<000000?ooo`3oool01@3oool30?XN1@`0oooo0`3j7PD<0?ooo`030000O`3o
ool0oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j7PD70?ooo`030?XN1@00
0000nQh502h0oooo00<0001o0?ooo`3oool0?P3oool3000000h0oooo00<0001o0?ooo`3oool0CP3o
ool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool006P0oooo00<000000?ooo`3oool01`3oool3
000Rf`L0oooo00<000000?ooo`3oool0403oool00`0007l0oooo0?ooo`0Y0?ooo`8000001P3oool3
0?XN1@`0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0
oooo01<0oooo0`3j7PD70?ooo`800000;`3oool00`0007l0oooo0?ooo`100?ooo`8000003@3oool0
0`0007l0oooo0?ooo`1>0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`00
0000oooo0?ooo`070?ooo`<002;K1P3oool00`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo
02X0oooo0P0000050?ooo`<0nQh5303oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN
1D@0oooo00<0001o0?ooo`3oool04`3oool30?XN1@H0oooo0P00000`0?ooo`030000O`3oool0oooo
0480oooo0`00000:0?ooo`030000O`3oool0oooo04h0oooo0`008]/80?ooo`030000003oool0oooo
02l0oooo000d0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`070?ooo`<002;K1@3oool00`000000oooo0?ooo`0B0?ooo`030000O`3oool0oooo02/0
oooo0P0000040?ooo`<0nQh5303oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0
oooo00<0001o0?ooo`3oool04`3oool30?XN1@D0oooo0P00000a0?ooo`030000O`3oool0oooo04@0
oooo0`0000080?ooo`030000O`3oool0oooo04h0oooo0`008]/80?ooo`030000003oool0oooo02l0
oooo000d0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool09P3oool3000000L0oooo
0`008]/40?ooo`030000003oool0oooo01<0oooo00<0001o0?ooo`3oool0;03oool2000000<0oooo
0`3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5A03oool00`0007l0oooo
0?ooo`0C0?ooo`<0nQh51@3oool00`000000oooo0?ooo`0`0?ooo`030000O`3oool0oooo04H0oooo
0`0000060?ooo`030000O`3oool0oooo04h0oooo0`008]/70?ooo`800000<@3oool003@0oooo3000
000X0?ooo`030000003oool0oooo00L0oooo0`008]/30?ooo`8000005@3oool00`0007l0oooo0?oo
o`0]0?ooo`040000003oool0oooo0?ooo`<0nQh5303oool30?XN1@`0oooo00<0001o0?ooo`3oool0
203oool30?XN1D@0oooo00<0001o0?ooo`3oool04`3oool30?XN1@@0oooo00<000000?ooo`3oool0
<@3oool00`0007l0oooo0?ooo`180?ooo`<00000103oool00`0007l0oooo0?ooo`1>0?ooo`<002;K
203oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`070?ooo`<002;K0P3o
ool2000001H0oooo00<0001o0?ooo`3oool0;P3oool00`000000oooo0?ooo`030?XN1@`0oooo0`3j
7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PE40?ooo`030000O`3oool0oooo01<0oooo0`3j
7PD30?ooo`030000003oool0oooo0380oooo00<0001o0?ooo`3oool0B`3oool200000080oooo00<0
001o0?ooo`3oool0CP3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool006P0oooo00<00000
0?ooo`3oool01`3oool3000Rf`030?ooo`000000000001L0oooo00<0001o0?ooo`3oool0;`3oool0
0`000000oooo0?XN1@020?XN1@`0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PE4
0?ooo`030000O`3oool0oooo01<0oooo0`3j7PD20?ooo`030000003oool0oooo03<0oooo00<0001o
0?ooo`3oool0C@3oool2000000030000O`3oool0oooo04h0oooo0`008]/80?ooo`030000003oool0
oooo02l0oooo001X0?ooo`030000003oool0oooo00L0oooo0`008]/2000001P0oooo00<0001o0?oo
o`3oool0<03oool010000000nQh50?XN1@3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`08
0?ooo`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`<0nQh500<0oooo0000003oool0=@3oool0
0`0007l0oooo0?ooo`1>0?ooo`<00000C`3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool0
06P0oooo0`0000070?ooo`<002;K00<000000?ooo`3oool05`3oool00`0007l0oooo0?ooo`0`0?oo
o`8000000P3j7PD<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5A03oool00`00
07l0oooo0?ooo`0C0?ooo`<0nQh50P00000f0?ooo`030000O`3oool0oooo04l0oooo00@0001o0?oo
o`0000000000C@3oool3000Rf`L0oooo0P00000a0?ooo`00J03oool00`000000oooo0?ooo`070?oo
o`8002;K00<000000?ooo`3oool0603oool00`0007l0oooo0?ooo`0a0?ooo`80000000<0nQh50?oo
o`3oool02P3oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?oo
o`3oool04`3oool20?XN1@800000=`3oool00`0007l0oooo0?ooo`1?0?ooo`040000O`3oool0oooo
0?ooo`800000B`3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool005`0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`070?ooo`03000Rf`00000002;K01X0oooo00<0001o0?oo
o`3oool0<@3oool00`3j7PD000000000000<0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?oo
o`<0nQh5A03oool00`0007l0oooo0?ooo`0C0?ooo`030?XN1@000000000003P0oooo00<0001o0?oo
o`3oool0C`3oool00`0007l0oooo0?ooo`030?ooo`800000B@3oool3000Rf`P0oooo00<000000?oo
o`3oool0;`3oool005`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`<0
02;K6P3oool00`0007l0oooo0?ooo`0a0?ooo`80nQh500<000000?ooo`3oool02P3oool30?XN1@`0
oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3oool04@3oool400000003
0?XN1@3oool0oooo03H0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`050?ooo`80
0000A`3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool005`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0T0?ooo`030000O`3oool0oooo03<0oooo00<000000?ooo`3oool0
2P3oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3oool0
3P3oool4000003`0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`070?ooo`800000
A@3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool005`0oooo00<000000?ooo`3oool02@3o
ool4000005X0001o00<000000000O`0007l02@0007l30?XN1AL0001o0`3j7PEC0000O`<00000W@00
07l2000004<0001o0`008]/60000O`<00000<@3oool005`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0T0?ooo`030000O`3oool0oooo03D0oooo00<000000?ooo`3oool0203oool3
0?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3oool02@3oool3
00000480oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0;0?ooo`800000@@3oool3
000Rf`P0oooo00<000000?ooo`3oool0;`3oool005`0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0T0?ooo`030000O`3oool0oooo03D0oooo00<000000?ooo`3oool0203oool30?XN
1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3oool01P3oool30000
04D0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0=0?ooo`800000?`3oool3000R
f`P0oooo00<000000?ooo`3oool0;`3oool005`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0T0?ooo`030000O`3oool0oooo03H0oooo00<000000?ooo`3oool01`3oool30?XN1@`0
oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3oool00P3oool4000004P0
oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0?0?ooo`800000?@3oool3000Rf`P0
oooo00<000000?ooo`3oool0;`3oool005X0oooo00<000000?ooo`0000002`3oool00`000000oooo
0?ooo`0T0?ooo`030000O`3oool0oooo03L0oooo00<000000?ooo`3oool01P3oool30?XN1@`0oooo
00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3oool00`00001;0?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool04@3oool2000003/0oooo0`008]/80?ooo`030000
003oool0oooo02l0oooo001K0?ooo`8000002`3oool00`000000oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo03L0oooo00<000000?ooo`3oool01P3oool30?XN1@`0oooo00<0001o0?ooo`3oool0203o
ool30?XN1D@0oooo0`00001>0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool04`3o
ool2000003T0oooo0`008]/80?ooo`030000003oool0oooo02l0oooo001L0?ooo`030000003oool0
oooo00T0oooo0`00000T0?ooo`030000O`3oool0oooo03P0oooo00<000000?ooo`3oool01@3oool3
0?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1D40oooo0`0000000`0007l0oooo0?ooo`1>
0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool05@3oool2000003L0oooo0`008]/7
0?ooo`800000<@3oool006P0oooo00<000000?ooo`3oool0903oool00`0007l0oooo0?ooo`0h0?oo
o`030000003oool0oooo00D0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PDn0?oo
o`@000000P3oool00`0007l0oooo0?ooo`1>0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?oo
o`3oool05P3oool3000003D0oooo0`008]/80?ooo`030000003oool0oooo02l0oooo001X0?ooo`03
0000003oool0oooo02@0oooo00<0001o0?ooo`3oool0>@3oool00`000000oooo0?ooo`040?ooo`<0
nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh5>`3oool4000000D0oooo00<0001o0?ooo`3o
ool0CP3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo01P0oooo0`00000c0?ooo`<0
02;K203oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`0T0?ooo`030000
O`3oool0oooo03X0oooo00<000000?ooo`3oool00`3oool30?XN1@`0oooo00<0001o0?ooo`3oool0
203oool30?XN1CP0oooo100000080?ooo`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool0
C`3oool00`0007l0oooo0?ooo`0J0?ooo`<00000<@3oool3000Rf`P0oooo00<000000?ooo`3oool0
;`3oool006P0oooo00<000000?ooo`3oool0903oool00`0007l0oooo0?ooo`0j0?ooo`030000003o
ool0oooo00<0oooo0`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PDf0?ooo`<000002`3o
ool00`0007l0oooo0?ooo`1>0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0703o
ool3000002l0oooo0`008]/80?ooo`030000003oool0oooo02l0oooo001X0?ooo`<00000903oool0
0`0007l0oooo0?ooo`0j0?ooo`800000103oool30?XN1@`0oooo00<0001o0?ooo`3oool0203oool3
0?XN1C<0oooo0`00000>0?ooo`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool0C`3oool0
0`0007l0oooo0?ooo`0N0?ooo`<00000;@3oool3000Rf`L0oooo0P00000a0?ooo`00J03oool00`00
0000oooo0?ooo`0T0?ooo`030000O`3oool0oooo03/0oooo00<000000?ooo`3oool00P3oool30?XN
1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1C00oooo0`00000A0?ooo`030000O`3oool0oooo
04h0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0P0?ooo`<00000:`3oool3000R
f`P0oooo00<000000?ooo`3oool0;`3oool006P0oooo00<000000?ooo`3oool0903oool00`0007l0
oooo0?ooo`0l0?ooo`040000003oool0oooo0?ooo`<0nQh5303oool00`0007l0oooo0?ooo`080?oo
o`<0nQh5;P3oool3000001<0oooo00<0001o0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`1?0?oo
o`030000O`3oool0oooo0280oooo0P00000Z0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?oo
o`00J03oool00`000000oooo0?ooo`0T0?ooo`030000O`3oool0oooo03d0oooo00<000000?ooo`3o
ool00`3j7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PDZ0?ooo`@000005P3oool00`0007l0
oooo0?ooo`1>0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0903oool3000002L0
oooo0`008]/80?ooo`030000003oool0oooo02l0oooo001X0?ooo`030000003oool0oooo02@0oooo
00<0001o0?ooo`3oool0?@3oool00`000000oooo0?ooo`030?XN1@`0oooo00<0001o0?ooo`3oool0
203oool30?XN1BP0oooo0`00000I0?ooo`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool0
C`3oool00`0007l0oooo0?ooo`0V0?ooo`8000009P3oool3000Rf`P0oooo00<000000?ooo`3oool0
;`3oool006P0oooo0`00000T0?ooo`030000O`3oool0oooo03h0oooo00<000000?ooo`3j7PD00P3j
7PD<0?ooo`030000O`3oool0oooo00P0oooo0`3j7PDU0?ooo`<00000703oool00`0007l0oooo0?oo
o`1>0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0:03oool3000002<0oooo0`00
8]/70?ooo`800000<@3oool006P0oooo00<000000?ooo`3oool0903oool00`0007l0oooo0?ooo`0n
0?ooo`030000003oool0nQh50080nQh5303oool00`0007l0oooo0?ooo`080?ooo`<0nQh58P3oool4
000001h0oooo00<0001o0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0
oooo02X0oooo0P00000R0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`00
0000oooo0?ooo`0T0?ooo`030000O`3oool0oooo03l0oooo00@000000?XN1@3j7PD0nQh5303oool0
0`0007l0oooo0?ooo`080?ooo`<0nQh57`3oool400000240oooo00<0001o0?ooo`3oool0CP3oool0
0`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo02`0oooo0P00000P0?ooo`<002;K203oool0
0`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`0T0?ooo`030000O`3oool0oooo
03l0oooo0P0000020?XN1@`0oooo00<0001o0?ooo`3oool0203oool30?XN1Ad0oooo0`00000T0?oo
o`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0]0?oo
o`<000007P3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool006P0oooo00<000000?ooo`3o
ool0903oool00`0007l0oooo0?ooo`100?ooo`030000003j7PD0nQh500`0oooo00<0001o0?ooo`3o
ool0203oool30?XN1AX0oooo0`00000W0?ooo`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3o
ool0C`3oool00`0007l0oooo0?ooo`0`0?ooo`800000703oool3000Rf`P0oooo00<000000?ooo`3o
ool0;`3oool006P0oooo0`00000T0?ooo`030000O`3oool0oooo0400oooo0`00000<0?ooo`030000
O`3oool0oooo00P0oooo0`3j7PDG0?ooo`@00000:@3oool00`0007l0oooo0?ooo`1>0?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0<@3oool3000001X0oooo0`008]/70?ooo`800000
<@3oool006P0oooo00<000000?ooo`3oool0903oool00`0007l0oooo0?ooo`100?ooo`<0nQh50`00
00090?ooo`030000O`3oool0oooo00P0oooo0`3j7PDE0?ooo`<00000;03oool00`0007l0oooo0?oo
o`1>0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0=03oool2000001P0oooo0`00
8]/80?ooo`030000003oool0oooo02l0oooo001A0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool0oooo1000000:0?ooo`030000003oool0oooo02@0oooo00<0001o0?ooo`3oool0A@3o
ool4000000H0oooo00<0001o0?ooo`3oool0203oool30?XN1A80oooo0`00000_0?ooo`030000O`3o
ool0oooo04h0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0e0?ooo`<000005P3o
ool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool00540oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0903oool0
0`0007l0oooo0?ooo`180?ooo`<00000103oool00`0007l0oooo0?ooo`080?ooo`<0nQh53`3oool4
00000340oooo00<0001o0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0
oooo03L0oooo0`00000D0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00D@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0903oool00`00
07l0oooo0?ooo`1;0?ooo`<0000000<0oooo0000O`3oool02@3oool30?XN1@d0oooo0`00000d0?oo
o`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0i0?oo
o`<000004P3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool00540oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`070?ooo`@00000L`0007l4000000T0001o0`3j7PD:0000O`<0
0000o`0007lI0000O`8000004@0007l3000Rf`H0001o0`00000a0?ooo`00D@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0T0?ooo`030000O`3oool0oooo04l0oooo00@0001o00000000000000001`3oool30?XN1@L0
oooo1000000i0?ooo`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0
oooo0?ooo`0m0?ooo`8000003`3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool00540oooo
00<000000?ooo`3oool01@3oool5000000X0oooo00<000000?ooo`3oool0903oool00`0007l0oooo
0?ooo`1?0?ooo`040000O`3oool0oooo0?ooo`<00000103oool30?XN1@@0oooo1000000l0?ooo`03
0000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`0o0?ooo`80
00003@3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool00540oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02@0oooo00<0001o0?ooo`3oool0
C`3oool00`0007l0oooo0?ooo`040?ooo`<0000000@0oooo0?XN1@3j7PD0nQh50P3oool3000003l0
oooo00<0001o0?ooo`3oool0CP3oool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo0440
oooo0P00000;0?ooo`<002;K203oool00`000000oooo0?ooo`0_0?ooo`00C`3oool00`000000oooo
000000080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0903oool00`0007l0oooo
0?ooo`1?0?ooo`030000O`3oool0oooo00H0oooo0`000000103j7PD000000000000000120?ooo`03
0000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`120?ooo`<0
00002@3oool3000Rf`P0oooo00<000000?ooo`3oool0;`3oool00500oooo0P0000080?ooo`030000
003oool0oooo00/0oooo0`00000T0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0
203oool00`3j7PD00000000000140?ooo`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool0
C`3oool00`0007l0oooo0?ooo`140?ooo`<000001`3oool3000Rf`L0oooo0P00000a0?ooo`00D@3o
ool00`000000oooo0?ooo`060?ooo`D000002@3oool00`000000oooo0?ooo`0T0?ooo`030000O`3o
ool0oooo04l0oooo00<0001o0?ooo`3oool0203oool30?XN1D@0oooo00<0001o0?ooo`3oool0CP3o
ool00`0007l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04H0oooo0`0000050?ooo`<002;K203o
ool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000oooo0?ooo`0T0?ooo`030000O`3oool0
oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`030000O`3oool0
oooo04l0oooo00<0001o0?ooo`3oool0B03oool2000000@0oooo0`008]/80?ooo`030000003oool0
oooo02l0oooo001X0?ooo`030000003oool0oooo02@0oooo00<0001o0?ooo`3oool0C`3oool00`00
07l0oooo0?ooo`1?0?ooo`030000O`3oool0oooo04h0oooo00<0001o0?ooo`3oool0C`3oool00`00
07l0oooo0?ooo`1:0?ooo`<0000000@0oooo000Rf`008]/002;K203oool00`000000oooo0?ooo`0_
0?ooo`00J03oool00`000000oooo0?ooo`0T0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?oo
o`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?oo
o`3oool0C03oool2000000<002;K203oool00`000000oooo0?ooo`0_0?ooo`00J03oool00`000000
oooo0?ooo`0T0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0
oooo0?ooo`1>0?ooo`030000O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool200000003
000Rf`3oool0oooo00H0oooo00<000000?ooo`3oool0;`3oool006P0oooo0`00000T0?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0C`3oool00`0007l0oooo0?ooo`1>0?ooo`030000
O`3oool0oooo04l0oooo00<0001o0?ooo`3oool0CP3oool3000Rf`L0oooo0P00000a0?ooo`00J03o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02l0oooo001X0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0_0?ooo`00J03ooooo0000
0<`00000<@3oool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3o
ool00?l0ooooo`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0oooo
o`3ooomV0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool00?l0ooooo`3ooomV0?oo
o`00o`3ooolZ0?ooo`H00000103oool3000000@0oooo0P0000001@3oool000000?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool3000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`3oool300000?@0oooo003o0?ooobX0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000030?ooo`040000003oool0oooo00000080oooo0P0000020?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool01@000000oooo0?ooo`3oool000000?<0oooo003o0?ooobX0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000060?ooo`050000003oool0oooo0?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0m@3oool00?l0oooo:P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D000000`3oool400000080oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`D00000l`3oool00?l0oooo:P3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`050000
003oool0oooo0?ooo`0000001P3oool6000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?oo
o`3oool000000?<0oooo003o0?ooobX0oooo1P0000030?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool000000080oooo0P0000020?ooo`8000000P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P0000020?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0l@3oool00?l0oooo:P3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo0?ooo`<00000103oool3000000<0oooo00@000000?ooo`0000000000
0P3oool2000000L0oooo00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`000000oooo0000
0080oooo0`0000020?ooo`<0000000D0oooo0000003oool0oooo000000030?ooo`<00000m03oool0
0?l0oooo:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0n03oool00?l0oooo:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0n03oool00?l0oooo:P3oool600000200oooo1P00000?0?ooo`<00000
0P3oool00`000000oooo0?ooo`3h0?ooo`00o`3ooooo0?ooofH0oooo003o0?ooool0ooooIP3oool0
0001\
\>"],
  ImageRangeCache->{{{57.1875, 546.25}, {359.313, 164.313}} -> {-3.64356, \
1.45759, 0.012267, 0.0193499}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 681}},
AutoGeneratedPackage->Automatic,
WindowToolbars->{},
WindowSize->{1016, 647},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 66, 3, 150, "Title"],
Cell[1845, 58, 71, 9, 170, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1941, 71, 43, 3, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2009, 78, 49, 0, 73, "Section"],
Cell[2061, 80, 87, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2173, 85, 29, 0, 38, "Subsection"],
Cell[2205, 87, 198, 3, 70, "Input"],
Cell[2406, 92, 59, 1, 30, "Input"],
Cell[2468, 95, 119, 2, 30, "Input"],
Cell[2590, 99, 377, 6, 90, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3016, 111, 29, 0, 73, "Section"],
Cell[3048, 113, 54, 0, 33, "Text"],
Cell[3105, 115, 271, 5, 124, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3413, 125, 32, 0, 73, "Section"],
Cell[3448, 127, 60, 0, 33, "Text"],
Cell[3511, 129, 1434, 26, 375, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4982, 160, 37, 0, 73, "Section"],
Cell[5022, 162, 384, 6, 52, "Text"],
Cell[5409, 170, 1239, 24, 186, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6685, 199, 26, 0, 73, "Section"],
Cell[6714, 201, 216, 4, 33, "Text"],
Cell[6933, 207, 1948, 36, 290, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8918, 248, 32, 0, 73, "Section"],
Cell[8953, 250, 218, 4, 33, "Text"],
Cell[9174, 256, 1805, 34, 270, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11028, 296, 39, 3, 80, "Subtitle"],
Cell[11070, 301, 142, 5, 90, "Text"],
Cell[11215, 308, 2464, 46, 648, "Input"],

Cell[CellGroupData[{
Cell[13704, 358, 3581, 63, 590, "Input"],
Cell[17288, 423, 194, 4, 25, "Print"],
Cell[17485, 429, 211, 4, 25, "Print"],
Cell[17699, 435, 211, 4, 25, "Print"],
Cell[17913, 441, 229, 4, 25, "Print"],
Cell[18145, 447, 229, 4, 25, "Print"],
Cell[18377, 453, 229, 4, 25, "Print"],
Cell[18609, 459, 227, 4, 25, "Print"],
Cell[18839, 465, 227, 4, 25, "Print"],
Cell[19069, 471, 261, 5, 25, "Print"],
Cell[19333, 478, 253, 5, 25, "Print"],
Cell[19589, 485, 236, 4, 25, "Print"],
Cell[19828, 491, 237, 4, 25, "Print"],
Cell[20068, 497, 232, 4, 25, "Print"],
Cell[20303, 503, 254, 5, 25, "Print"],
Cell[20560, 510, 278, 6, 25, "Print"],
Cell[20841, 518, 278, 6, 25, "Print"],
Cell[21122, 526, 278, 6, 25, "Print"],
Cell[21403, 534, 225, 4, 25, "Print"],
Cell[21631, 540, 225, 4, 25, "Print"],
Cell[21859, 546, 271, 5, 25, "Print"],
Cell[22133, 553, 269, 5, 25, "Print"],
Cell[22405, 560, 219, 4, 25, "Print"],
Cell[22627, 566, 227, 4, 25, "Print"],
Cell[22857, 572, 235, 4, 25, "Print"],
Cell[23095, 578, 235, 4, 25, "Print"],
Cell[23333, 584, 180, 4, 25, "Print"],
Cell[23516, 590, 253, 5, 25, "Print"],
Cell[23772, 597, 264, 5, 25, "Print"],
Cell[24039, 604, 262, 5, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24350, 615, 51, 3, 80, "Subtitle"],
Cell[24404, 620, 119, 3, 52, "Text"],
Cell[24526, 625, 1203, 24, 358, "Input"],

Cell[CellGroupData[{
Cell[25754, 653, 1738, 30, 310, "Input"],
Cell[27495, 685, 226, 4, 25, "Print"],
Cell[27724, 691, 269, 5, 25, "Print"],
Cell[27996, 698, 220, 4, 25, "Print"],
Cell[28219, 704, 233, 4, 25, "Print"],
Cell[28455, 710, 245, 4, 25, "Print"],
Cell[28703, 716, 241, 4, 25, "Print"],
Cell[28947, 722, 226, 4, 25, "Print"],
Cell[29176, 728, 306, 6, 25, "Print"],
Cell[29485, 736, 246, 4, 25, "Print"],
Cell[29734, 742, 233, 4, 25, "Print"],
Cell[29970, 748, 245, 4, 25, "Print"],
Cell[30218, 754, 241, 4, 25, "Print"],
Cell[30462, 760, 262, 5, 25, "Print"],
Cell[30727, 767, 274, 5, 25, "Print"],
Cell[31004, 774, 270, 5, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31311, 784, 37, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[31373, 788, 228, 3, 50, "Input"],
Cell[31604, 793, 85519, 1980, 253, 24626, 1224, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[117172, 2779, 37, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[117234, 2783, 228, 3, 50, "Input"],
Cell[117465, 2788, 85490, 1977, 253, 24546, 1220, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[203004, 4771, 65, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[203094, 4775, 228, 3, 50, "Input"],
Cell[203325, 4780, 87630, 2104, 253, 27288, 1355, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[291004, 6890, 65, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[291094, 6894, 228, 3, 50, "Input"],
Cell[291325, 6899, 88327, 2068, 253, 25173, 1284, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[379713, 8974, 39, 3, 80, "Subtitle"],
Cell[379755, 8979, 75, 0, 33, "Text"],
Cell[379833, 8981, 652, 13, 210, "Input"],

Cell[CellGroupData[{
Cell[380510, 8998, 1387, 24, 230, "Input"],
Cell[381900, 9024, 226, 4, 25, "Print"],
Cell[382129, 9030, 202, 4, 25, "Print"],
Cell[382334, 9036, 233, 4, 25, "Print"],
Cell[382570, 9042, 237, 4, 25, "Print"],
Cell[382810, 9048, 238, 4, 25, "Print"],
Cell[383051, 9054, 277, 5, 25, "Print"],
Cell[383331, 9061, 291, 6, 25, "Print"],
Cell[383625, 9069, 292, 6, 25, "Print"],
Cell[383920, 9077, 277, 5, 25, "Print"],
Cell[384200, 9084, 290, 6, 25, "Print"],
Cell[384493, 9092, 292, 6, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[384822, 9103, 60, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[384907, 9107, 155, 2, 30, "Input"],
Cell[385065, 9111, 88, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[385190, 9117, 370, 6, 50, "Input"],
Cell[385563, 9125, 104265, 2933, 286, 38218, 2113, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[489865, 12063, 381, 6, 50, "Input"],
Cell[490249, 12071, 95495, 2667, 287, 34381, 1908, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[585781, 14743, 1215, 20, 150, "Input"],

Cell[CellGroupData[{
Cell[587021, 14767, 149464, 3272, 315, 33257, 1833, "GraphicsData", \
"PostScript", "Graphics"],
Cell[736488, 18041, 152965, 3457, 315, 36139, 2010, "GraphicsData", \
"PostScript", "Graphics"],
Cell[889456, 21500, 150692, 3312, 315, 34142, 1869, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1040209, 24819, 60, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[1040294, 24823, 169, 3, 30, "Input"],
Cell[1040466, 24828, 94285, 2230, 254, 26970, 1395, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1134800, 27064, 61, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[1134886, 27068, 249, 4, 50, "Input"],
Cell[1135138, 27074, 93905, 2209, 253, 26692, 1375, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1229092, 29289, 61, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[1229178, 29293, 249, 4, 50, "Input"],
Cell[1229430, 29299, 93736, 2208, 253, 26656, 1375, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1323227, 31514, 41, 3, 80, "Subtitle"],
Cell[1323271, 31519, 103, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[1323399, 31526, 569, 11, 170, "Input"],
Cell[1323971, 31539, 77, 1, 29, "Output"],
Cell[1324051, 31542, 79, 1, 29, "Output"],
Cell[1324133, 31545, 79, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1324249, 31551, 1536, 26, 250, "Input"],
Cell[1325788, 31579, 226, 4, 25, "Print"],
Cell[1326017, 31585, 261, 5, 25, "Print"],
Cell[1326281, 31592, 242, 4, 25, "Print"],
Cell[1326526, 31598, 233, 4, 25, "Print"],
Cell[1326762, 31604, 237, 4, 25, "Print"],
Cell[1327002, 31610, 238, 4, 25, "Print"],
Cell[1327243, 31616, 277, 5, 25, "Print"],
Cell[1327523, 31623, 290, 6, 25, "Print"],
Cell[1327816, 31631, 292, 6, 25, "Print"],
Cell[1328111, 31639, 277, 5, 25, "Print"],
Cell[1328391, 31646, 290, 6, 25, "Print"],
Cell[1328684, 31654, 291, 6, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1329012, 31665, 62, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[1329099, 31669, 169, 3, 30, "Input"],
Cell[1329271, 31674, 94284, 2230, 254, 26970, 1395, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1423604, 33910, 63, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[1423692, 33914, 249, 4, 50, "Input"],
Cell[1423944, 33920, 93913, 2209, 253, 26692, 1375, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1517906, 36135, 63, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[1517994, 36139, 249, 4, 50, "Input"],
Cell[1518246, 36145, 93728, 2208, 253, 26656, 1375, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1612035, 38360, 39, 3, 80, "Subtitle"],
Cell[1612077, 38365, 192, 4, 52, "Text"],
Cell[1612272, 38371, 1086, 21, 250, "Input"],

Cell[CellGroupData[{
Cell[1613383, 38396, 50, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[1613458, 38400, 449, 8, 70, "Input"],
Cell[1613910, 38410, 108, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1614055, 38417, 1682, 32, 310, "Input"],
Cell[1615740, 38451, 250, 5, 25, "Print"],
Cell[1615993, 38458, 240, 5, 25, "Print"],
Cell[1616236, 38465, 233, 4, 25, "Print"],
Cell[1616472, 38471, 239, 4, 25, "Print"],
Cell[1616714, 38477, 239, 4, 25, "Print"],
Cell[1616956, 38483, 227, 4, 25, "Print"],
Cell[1617186, 38489, 218, 4, 25, "Print"],
Cell[1617407, 38495, 234, 4, 25, "Print"],
Cell[1617644, 38501, 239, 4, 25, "Print"],
Cell[1617886, 38507, 240, 4, 25, "Print"],
Cell[1618129, 38513, 232, 4, 25, "Print"],
Cell[1618364, 38519, 218, 4, 25, "Print"],
Cell[1618585, 38525, 233, 4, 25, "Print"],
Cell[1618821, 38531, 237, 4, 25, "Print"],
Cell[1619061, 38537, 240, 4, 25, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1619350, 38547, 69, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[1619444, 38551, 169, 3, 30, "Input"],
Cell[1619616, 38556, 131970, 4657, 254, 65611, 3833, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1751635, 43219, 47, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[1751707, 43223, 169, 3, 30, "Input"],
Cell[1751879, 43228, 133010, 4681, 254, 65671, 3845, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1884938, 47915, 69, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[1885032, 47919, 197, 3, 50, "Input"],
Cell[1885232, 47924, 136145, 4765, 253, 66551, 3901, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

